@@ -458,11 +458,12 @@ namespace Magick
   //
   // ImageMagick symbols used in implementation code
   //
-  using MagickLib::AcquireCacheView;
+  using MagickLib::AcquireCacheViewPixels;
   using MagickLib::AcquireImagePixels;
   using MagickLib::AcquireMagickMemory;
   using MagickLib::AcquireString;
 	using MagickLib::AcquireStringInfo;
+  using MagickLib::AdaptiveBlurImage;
   using MagickLib::AdaptiveThresholdImage;
   using MagickLib::AddNoiseImage;
   using MagickLib::AffineMatrix;
@@ -636,7 +637,7 @@ namespace Magick
   using MagickLib::GaussianBlurImage;
   using MagickLib::GetAffineMatrix;
   using MagickLib::GetBlobSize;
-  using MagickLib::GetCacheView;
+  using MagickLib::GetCacheViewPixels;
   using MagickLib::GetCacheViewIndexes;
   using MagickLib::GetImageChannelMean;
   using MagickLib::GetImageChannelRange;
@@ -668,7 +669,7 @@ namespace Magick
   using MagickLib::GetTypeMetrics;
   using MagickLib::GlobExpression;
   using MagickLib::GreaterValue;
-  using MagickLib::HSLTransform;
+  using MagickLib::ConvertHSLToRGB;
   using MagickLib::HeightValue;
   using MagickLib::ImageError;
   using MagickLib::ImageFatalError;
@@ -796,7 +797,7 @@ namespace Magick
   using MagickLib::SyncImagePixels;
   using MagickLib::TextureImage;
   using MagickLib::ThrowException;
-  using MagickLib::TransformHSL;
+  using MagickLib::ConvertRGBToHSL;
   using MagickLib::TransformImage;
   using MagickLib::TransformRGBImage;
   using MagickLib::TrimImage;
