@@ -10,6 +10,18 @@
 #include <Magick++/Image.h>
 #include <Magick++/STL.h>
 
+// Adaptive-blur image with specified blur factor
+Magick::adaptiveBlurImage::adaptiveBlurImage( const double radius_,
+      const double sigma_  )
+      : _radius( radius_ ),
+        _sigma( sigma_ )
+{
+}
+void Magick::adaptiveBlurImage::operator()( Magick::Image &image_ ) const
+{
+  image_.adaptiveBlur( _radius, _sigma );
+}
+
 // Local adaptive threshold image
 Magick::adaptiveThresholdImage::adaptiveThresholdImage( const unsigned int width_,
                                                         const unsigned int height_,
