@@ -706,7 +706,12 @@ static Image *ReadCINImage(const ImageInfo *image_info,
       quantum_type=GrayQuantum;
       length=GetBytesPerRow(image->columns,1,image->depth,MagickTrue);
     }
-  pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   for (y=0; y < (long) image->rows; y++)
@@ -971,7 +976,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
     offset+=WriteBlobFloat(image,cin.image.channel[0].min_quantity);
     cin.image.channel[i].max_data=(float) ((1UL << image->depth)-1UL);
     offset+=WriteBlobFloat(image,cin.image.channel[0].max_data);
-    cin.image.channel[i].max_quantity=2.048;
+    cin.image.channel[i].max_quantity=2.048f;
     offset+=WriteBlobFloat(image,cin.image.channel[0].max_quantity);
   }
   offset+=WriteBlobFloat(image,image->chromaticity.white_point.x);
@@ -1144,7 +1149,7 @@ static MagickBooleanType WriteCINImage(const ImageInfo *image_info,Image *image)
       quantum_type=GrayQuantum;
       length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
     }
-  pixels=(unsigned char *) AcquireMagickMemory(length);
+  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   for (y=0; y < (long) image->rows; y++)
