@@ -155,6 +155,8 @@ static MagickBooleanType WriteCLIPImage(const ImageInfo *image_info,
   MagickBooleanType
     status;
 
+  if (image->clip_mask == (Image *) NULL)
+    (void) ClipImage(image);
   if (image->clip_mask == (Image *) NULL)
     ThrowWriterException(CoderError,"ImageDoesNotHaveAClipMask");
   clip_image=CloneImage(image->clip_mask,0,0,MagickTrue,&image->exception);
@@ -164,7 +166,7 @@ static MagickBooleanType WriteCLIPImage(const ImageInfo *image_info,
   (void) CopyMagickString(clip_image->filename,image->filename,MaxTextExtent);
   write_info=CloneImageInfo(image_info);
   (void) SetImageInfo(write_info,MagickTrue,&image->exception);
-  if (LocaleCompare(write_info->magick,"HISTOGRAM") == 0)
+  if (LocaleCompare(write_info->magick,"CLIP") == 0)
     (void) FormatMagickString(clip_image->filename,MaxTextExtent,"miff:%s",
       write_info->filename);
   status=WriteImage(write_info,clip_image);
