@@ -91,7 +91,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadCMYKImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -151,7 +150,12 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
           return((Image *) NULL);
         }
       for (i=0; i < image->offset; i++)
-        (void) ReadBlobByte(image);
+        if (ReadBlobByte(image) == EOF)
+          {
+            ThrowFileException(exception,CorruptImageError,
+              "UnexpectedEndOfFile",image->filename);
+            break;
+          }
     }
   /*
     Allocate memory for a pixels.
@@ -162,8 +166,13 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
       packet_size+=(image->depth+7)/8;
       image->matte=MagickTrue;
     }
-  pixels=(unsigned char *)
-    AcquireMagickMemory(packet_size*image->extract_info.width*sizeof(*pixels));
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  pixels=(unsigned char *) AcquireQuantumMemory(image->extract_info.width,
+    packet_size*sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->number_scenes != 0)
@@ -207,7 +216,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         for (y=0; y < (long) image->rows; y++)
         {
-          if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
+          if ((y != 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 pixels);
@@ -258,7 +267,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         }
         for (y=0; y < (long) image->rows; y++)
         {
-          if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
+          if ((y != 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 pixels);
@@ -345,7 +354,7 @@ static Image *ReadCMYKImage(const ImageInfo *image_info,
         span=image->rows*(image->matte != MagickFalse ? 5 : 4);
         for (y=0; y < (long) image->rows; y++)
         {
-          if ((y > 0) || (GetPreviousImageInList(image) == (Image *) NULL))
+          if ((y != 0) || (GetPreviousImageInList(image) == (Image *) NULL))
             {
               count=ReadBlob(image,packet_size*image->extract_info.width,
                 pixels);
@@ -715,7 +724,6 @@ ModuleExport void UnregisterCMYKImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
   Image *image)
@@ -753,8 +761,8 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
   packet_size=(size_t) ((4*image->depth+7)/8);
   if (LocaleCompare(image_info->magick,"CMYKA") == 0)
     packet_size+=(image->depth+7)/8;
-  pixels=(unsigned char *)
-    AcquireMagickMemory(packet_size*image->columns*sizeof(*pixels));
+  pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
+    sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->interlace != PartitionInterlace)
