@@ -299,7 +299,6 @@ static int GetCutColors(Image *image)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -386,6 +385,11 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->colors=1UL << (unsigned long) i;
 
   if (image_info->ping) goto Finish;
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
 
   /* ----- Do something with palette ----- */
   if ((clone_info=CloneImageInfo(image_info)) == NULL) goto NoPalette;
@@ -516,7 +520,8 @@ static Image *ReadCUTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
 
   /* ----- Load RLE compressed raster ----- */
-  BImgBuff=(unsigned char *) AcquireMagickMemory((size_t) ldblk);  /*Ldblk was set in the check phase*/
+  BImgBuff=(unsigned char *) AcquireQuantumMemory((size_t) ldblk,
+    sizeof(*BImgBuff));  /*Ldblk was set in the check phase*/
   if(BImgBuff==NULL) goto NoMemory;
 
   offset=SeekBlob(image,6 /*sizeof(Header)*/,SEEK_SET);
