@@ -81,7 +81,6 @@
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsDJVU(const unsigned char *magick,const size_t length)
 {
@@ -756,7 +755,7 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
   /*
    * Allocate a LoadContext structure.
    */
-  lc = (LoadContext *) AcquireMagickMemory(sizeof(LoadContext));
+  lc = (LoadContext *) AcquireMagickMemory(sizeof(*lc));
   if (lc == NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
 
