@@ -520,6 +520,7 @@ static void TimeCodeToString(const unsigned long timestamp,char *code)
   register long
     i;
 
+  *code='\0';
   shift=4*TimeFields;
   for (i=0; i <= TimeFields; i++)
   {
@@ -529,8 +530,8 @@ static void TimeCodeToString(const unsigned long timestamp,char *code)
     if (((i % 2) != 0) && (i < TimeFields))
       *code++=':';
     shift-=4;
+    *code='\0';
   }
-  *code='\0';
 }
 
 static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
@@ -608,6 +609,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->endian=LSBEndian;
   if (LocaleNCompare(magick,"SDPX",4) == 0)
     image->endian=MSBEndian;
+  (void) ResetMagickMemory(&dpx,0,sizeof(dpx));
   dpx.file.image_offset=ReadBlobLong(image);
   offset+=4;
   offset+=ReadBlob(image,sizeof(dpx.file.version),(unsigned char *)
@@ -1007,6 +1009,11 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Convert DPX raster image to pixel packets.
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   GetQuantumInfo(image_info,&quantum_info);
   quantum_info.quantum=32;
   quantum_info.pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
@@ -1056,7 +1063,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   }
   length=GetBytesPerRow(image->columns,samples_per_pixel,image->depth,
     dpx.image.image_element[0].packing == 0 ? MagickFalse : MagickTrue);
-  pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
+  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if ((quantum_type == GrayQuantum) && (quantum_info.pack == MagickFalse) &&
@@ -1467,6 +1474,19 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
   /*
     Write orientation header.
   */
+  if ((image->rows != image->magick_rows) ||
+      (image->columns != image->magick_columns))
+    {
+      /*
+        These properties are not valid if image size changed.
+      */
+      (void) DeleteImageProperty(image,"dpx:orientation.x_offset");
+      (void) DeleteImageProperty(image,"dpx:orientation.y_offset");
+      (void) DeleteImageProperty(image,"dpx:orientation.x_center");
+      (void) DeleteImageProperty(image,"dpx:orientation.y_center");
+      (void) DeleteImageProperty(image,"dpx:orientation.x_size");
+      (void) DeleteImageProperty(image,"dpx:orientation.y_size");
+    }
   dpx.orientation.x_offset=0UL;
   value=GetDPXProperty(image_info,image,"dpx:orientation.x_offset");
   if (value != (const char *) NULL)
@@ -1726,7 +1746,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
       quantum_type=GrayQuantum;
       length=GetBytesPerRow(image->columns,3,image->depth,MagickTrue);
     }
-  pixels=(unsigned char *) AcquireMagickMemory(length);
+  pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   for (y=0; y < (long) image->rows; y++)
