@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -169,6 +169,9 @@ static Image *ReadEPTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickBooleanType
     status;
 
+  MagickOffsetType
+    offset;
+
   /*
     Open image file.
   */
@@ -196,17 +199,22 @@ static Image *ReadEPTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   ept_info.tiff_offset=(MagickOffsetType) ReadBlobLSBLong(image);
   ept_info.tiff_length=ReadBlobLSBLong(image);
   (void) ReadBlobLSBShort(image);
-  ept_info.postscript=(unsigned char *) AcquireMagickMemory(
-    ept_info.postscript_length);
-  ept_info.tiff=(unsigned char *) AcquireMagickMemory(ept_info.tiff_length);
+  ept_info.postscript=(unsigned char *) AcquireQuantumMemory(
+    ept_info.postscript_length,sizeof(*ept_info.postscript));
+  ept_info.tiff=(unsigned char *) AcquireQuantumMemory(ept_info.tiff_length,
+    sizeof(*ept_info.tiff));
   if ((ept_info.postscript == (unsigned char *) NULL) ||
       (ept_info.tiff == (unsigned char *) NULL))
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-  (void) SeekBlob(image,ept_info.tiff_offset,SEEK_SET);
+  offset=SeekBlob(image,ept_info.tiff_offset,SEEK_SET);
+  if (offset < 0)
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   count=ReadBlob(image,ept_info.tiff_length,ept_info.tiff);
   if (count != (ssize_t) (ept_info.tiff_length))
     ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
-  (void) SeekBlob(image,ept_info.postscript_offset,SEEK_SET);
+  offset=SeekBlob(image,ept_info.postscript_offset,SEEK_SET);
+  if (offset < 0)
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   count=ReadBlob(image,ept_info.postscript_length,ept_info.postscript);
   if (count != (ssize_t) (ept_info.postscript_length))
     ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
