@@ -198,7 +198,25 @@ static Image *ReadEXRImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->columns=max_x-min_x+1UL;
   image->rows=max_y-min_y+1UL;
   image->matte=MagickTrue;
-  scanline=(ImfRgba *) AcquireMagickMemory(image->columns*sizeof(*scanline));
+  if (image_info->ping != MagickFalse)
+    {
+      (void) ImfCloseInputFile(file);
+      if (LocaleCompare(image_info->filename,read_info->filename) != 0)
+        (void) RelinquishUniqueFileResource(read_info->filename);
+      read_info=DestroyImageInfo(read_info);
+      CloseBlob(image);
+      return(GetFirstImageInList(image));
+    }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      (void) ImfCloseInputFile(file);
+      if (LocaleCompare(image_info->filename,read_info->filename) != 0)
+        (void) RelinquishUniqueFileResource(read_info->filename);
+      read_info=DestroyImageInfo(read_info);
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  scanline=(ImfRgba *) AcquireQuantumMemory(image->columns,sizeof(*scanline));
   if (scanline == (ImfRgba *) NULL)
     {
       (void) ImfCloseInputFile(file);
@@ -387,7 +405,7 @@ static MagickBooleanType WriteEXRImage(const ImageInfo *image_info,Image *image)
       write_info=DestroyImageInfo(write_info);
       return(MagickFalse);
     }
-  scanline=(ImfRgba *) AcquireMagickMemory(image->columns*sizeof(*scanline));
+  scanline=(ImfRgba *) AcquireQuantumMemory(image->columns,sizeof(*scanline));
   if (scanline == (ImfRgba *) NULL)
     {
       (void) ImfCloseOutputFile(file);
