@@ -175,6 +175,11 @@ static Image *ReadFAXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   status=HuffmanDecodeImage(image);
   if (status == MagickFalse)
     ThrowReaderException(CorruptImageError,"UnableToReadImageData");
@@ -216,10 +221,10 @@ ModuleExport void RegisterFAXImage(void)
   static const char
     *Note=
     {
-      "See TIFF format.  Note that FAX machines use non-square pixels which\n"
-      "are 1.5 times wider than they are tall but computer displays use\n"
-      "square pixels. FAX images may appear to be narrow unless they are\n"
-      "explicitly resized using a resize specification of \"150x100%\"."
+      "FAX machines use non-square pixels which are 1.5 times wider than they\n"
+      "are tall but computer displays use square pixels, therefore FAX images\n"
+      "may appear to be narrow unless they are explicitly resized using a\n"
+      "geometry of \"150x100%\".\n"
     };
 
   entry=SetMagickInfo("FAX");
