@@ -199,9 +199,9 @@ static LZWInfo *AcquireLZWInfo(Image *image,const unsigned long data_size)
   lzw_info->maximum_data_value=(1UL << data_size)-1;
   lzw_info->clear_code=lzw_info->maximum_data_value+1;
   lzw_info->end_code=lzw_info->maximum_data_value+2;
-  lzw_info->table[0]=(unsigned long *) AcquireMagickMemory(MaximumLZWCode*
+  lzw_info->table[0]=(unsigned long *) AcquireQuantumMemory(MaximumLZWCode,
     sizeof(*lzw_info->table));
-  lzw_info->table[1]=(unsigned long *) AcquireMagickMemory(MaximumLZWCode*
+  lzw_info->table[1]=(unsigned long *) AcquireQuantumMemory(MaximumLZWCode,
     sizeof(*lzw_info->table));
   if ((lzw_info->table[0] == (unsigned long *) NULL) ||
       (lzw_info->table[1] == (unsigned long *) NULL))
@@ -227,8 +227,8 @@ static LZWInfo *AcquireLZWInfo(Image *image,const unsigned long data_size)
       lzw_info=RelinquishLZWInfo(lzw_info);
       return((LZWInfo *) NULL);
     }
-  lzw_info->stack->codes=(unsigned long *) AcquireMagickMemory(2*MaximumLZWCode*
-    sizeof(*lzw_info->stack->codes));
+  lzw_info->stack->codes=(unsigned long *) AcquireQuantumMemory(2UL*
+    MaximumLZWCode,sizeof(*lzw_info->stack->codes));
   if (lzw_info->stack->codes == (unsigned long *) NULL)
     {
       lzw_info=RelinquishLZWInfo(lzw_info);
@@ -613,10 +613,10 @@ static MagickBooleanType EncodeImage(const ImageInfo *image_info,Image *image,
     Allocate encoder tables.
   */
   assert(image != (Image *) NULL);
-  packet=(unsigned char *) AcquireMagickMemory(256*sizeof(*packet));
-  hash_code=(short *) AcquireMagickMemory(MaxHashTable*sizeof(*hash_code));
-  hash_prefix=(short *) AcquireMagickMemory(MaxHashTable*sizeof(*hash_prefix));
-  hash_suffix=(unsigned char *) AcquireMagickMemory(MaxHashTable*
+  packet=(unsigned char *) AcquireQuantumMemory(256,sizeof(*packet));
+  hash_code=(short *) AcquireQuantumMemory(MaxHashTable,sizeof(*hash_code));
+  hash_prefix=(short *) AcquireQuantumMemory(MaxHashTable,sizeof(*hash_prefix));
+  hash_suffix=(unsigned char *) AcquireQuantumMemory(MaxHashTable,
     sizeof(*hash_suffix));
   if ((packet == (unsigned char *) NULL) || (hash_code == (short *) NULL) ||
       (hash_prefix == (short *) NULL) ||
@@ -1033,8 +1033,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   background=(unsigned char) ReadBlobByte(image);
   c=(unsigned char) ReadBlobByte(image);  /* reserved */
   global_colors=1UL << (((unsigned long) flag & 0x07)+1);
-  global_colormap=(unsigned char *) AcquireMagickMemory((size_t)
-    (3*MagickMax(global_colors,256))*sizeof(*global_colormap));
+  global_colormap=(unsigned char *) AcquireQuantumMemory((size_t)
+    MagickMax(global_colors,256),3UL*sizeof(*global_colormap));
   if (global_colormap == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (BitSet((int) flag,0x80) != 0)
@@ -1151,7 +1151,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 number_extensionss++;
                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                   "    Reading GIF application extension");
-                info=(unsigned char *) AcquireMagickMemory(255*sizeof(*info));
+                info=(unsigned char *) AcquireQuantumMemory(255UL,
+                  sizeof(*info));
                 info_length=0;
                 reserved_length=255;
                 for ( ; ; )
@@ -1163,12 +1164,12 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   if (info_length > (reserved_length-255))
                     {
                        reserved_length+=4096;
-                       info=(unsigned char *) ResizeMagickMemory(info,
-                         (size_t) reserved_length);
+                       info=(unsigned char *) ResizeQuantumMemory(info,
+                         (size_t) reserved_length,sizeof(*info));
                     }
                 }
-                info=(unsigned char *) ResizeMagickMemory(info,(size_t)
-                  (info_length+1)*sizeof(*info));
+                info=(unsigned char *) ResizeQuantumMemory(info,(size_t)
+                  (info_length+1),sizeof(*info));
                 profile=AcquireStringInfo((size_t) info_length);
                 SetStringInfoDatum(profile,(const unsigned char *) info);
                 if (i8bim == MagickTrue)
@@ -1292,8 +1293,8 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Read local colormap.
         */
-        colormap=(unsigned char *) AcquireMagickMemory((3*image->colors)*
-          sizeof(*colormap));
+        colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+          3*sizeof(*colormap));
         if (colormap == (unsigned char *) NULL)
           {
             global_colormap=(unsigned char *) RelinquishMagickMemory(
@@ -1329,7 +1330,14 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (image_info->ping != MagickFalse)
       status=PingGIFImage(image);
     else
-      status=DecodeImage(image,(Quantum) opacity);
+      {
+        if (SetImageExtent(image,0,0) == MagickFalse)
+          {
+            InheritException(exception,&image->exception);
+            return(DestroyImageList(image));
+          }
+        status=DecodeImage(image,(Quantum) opacity);
+      }
     if ((image_info->ping == MagickFalse) && (status == MagickFalse))
       {
         global_colormap=(unsigned char *) RelinquishMagickMemory(
@@ -1503,9 +1511,9 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
   /*
     Allocate colormap.
   */
-  global_colormap=(unsigned char *) AcquireMagickMemory(768*
+  global_colormap=(unsigned char *) AcquireQuantumMemory(768UL,
     sizeof(*global_colormap));
-  colormap=(unsigned char *) AcquireMagickMemory(768*sizeof(*colormap));
+  colormap=(unsigned char *) AcquireQuantumMemory(768UL,sizeof(*colormap));
   if ((global_colormap == (unsigned char *) NULL) ||
       (colormap == (unsigned char *) NULL))
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
@@ -1717,16 +1725,15 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
             (void) WriteBlobLSBShort(image,(unsigned short) image->iterations);
             (void) WriteBlobByte(image,(unsigned char) 0x00);
           }
-
         ResetImageProfileIterator(image);
-        for (;;)
+        for ( ; ; )
         {
-          const StringInfo
-            *profile;
-
           char
             *name;
 
+          const StringInfo
+            *profile;
+
           name=GetNextImageProfile(image);
           if (name == (const char *) NULL)
             break;
@@ -1739,68 +1746,76 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
                 (LocaleCompare(name,"8BIM") == 0) ||
                 (LocaleNCompare(name,"gif:",4) == 0))
             {
-               int
-                 profile_length,
-                 profile_ptr;
-              
+               size_t
+                 length;
+
+               ssize_t
+                 offset;
+
                unsigned char
-                 *profile_data;
-
-               profile_data=GetStringInfoDatum(profile);
-               profile_length=(int) GetStringInfoLength(profile);
+                 *datum;
 
+               datum=GetStringInfoDatum(profile);
+               length=GetStringInfoLength(profile);
                (void) WriteBlobByte(image,(unsigned char) 0x21);
                (void) WriteBlobByte(image,(unsigned char) 0xff);
                (void) WriteBlobByte(image,(unsigned char) 0x0b);
-
                if ((LocaleCompare(name,"ICC") == 0) ||
                    (LocaleCompare(name,"ICM") == 0))
-               {
-                 /* write ICC extension */
-                 (void) WriteBlob(image,11,(unsigned char *)"ICCRGBG1012");
-                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                     "  Writing GIF Extension %s","ICCRGBG1012");
-               }
-               else if ((LocaleCompare(name,"IPTC") == 0))
-               {
-                 /* write IPTC extension */
-                 (void) WriteBlob(image,11,(unsigned char *)"MGKIPTC0000");
-                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                     "  Writing GIF Extension %s","MGKIPTC0000");
-               }
-               else if ((LocaleCompare(name,"8BIM") == 0))
-               {
-                 /* write 8BIM extension */
-                 (void) WriteBlob(image,11,(unsigned char *)"MGK8BIM0000");
-                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                     "  Writing GIF Extension %s","MGK8BIM0000");
-               }
+                 {
+                   /*
+                     Write ICC extension.
+                   */
+                   (void) WriteBlob(image,11,(unsigned char *)"ICCRGBG1012");
+                   (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                       "  Writing GIF Extension %s","ICCRGBG1012");
+                 }
                else
-               {
-                 char
-                   extension[MaxTextExtent];
+                 if ((LocaleCompare(name,"IPTC") == 0))
+                   {
+                     /*
+                       write IPTC extension.
+                     */
+                     (void) WriteBlob(image,11,(unsigned char *)"MGKIPTC0000");
+                     (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                         "  Writing GIF Extension %s","MGKIPTC0000");
+                   }
+                 else
+                   if ((LocaleCompare(name,"8BIM") == 0))
+                     {
+                       /*
+                         Write 8BIM extension>
+                       */
+                        (void) WriteBlob(image,11,(unsigned char *)
+                          "MGK8BIM0000");
+                        (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                          "  Writing GIF Extension %s","MGK8BIM0000");
+                     }
+                   else
+                     {
+                       char
+                         extension[MaxTextExtent];
 
-                 /* write generic extension */
-                 (void) CopyMagickString(extension,name+4,sizeof(extension));
-                 (void) WriteBlob(image,11,(unsigned char *) extension);
-                 (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-                     "  Writing GIF Extension %s",name);
-               }
-
-               profile_ptr=0;
-               while (profile_length > profile_ptr)
+                       /* write generic extension */
+                       (void) CopyMagickString(extension,name+4,
+                         sizeof(extension));
+                       (void) WriteBlob(image,11,(unsigned char *) extension);
+                       (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+                          "  Writing GIF Extension %s",name);
+                     }
+               offset=0;
+               while ((ssize_t) length > offset)
                {
-                 int
+                 size_t
                    block_length;
 
-                 if (profile_length - profile_ptr < 255)
-                   block_length=profile_length-profile_ptr;
+                 if ((length-offset) < 255)
+                   block_length=length-offset;
                  else
                    block_length=255;
                  (void) WriteBlobByte(image,(unsigned char) block_length);
-                 (void) WriteBlob(image,(size_t) block_length,
-                   &profile_data[profile_ptr]);
-                 profile_ptr+=block_length;
+                 (void) WriteBlob(image,(size_t) block_length,datum+offset);
+                 offset+=(ssize_t) block_length;
                }
                (void) WriteBlobByte(image,(unsigned char) 0x00);
             }
