@@ -242,10 +242,10 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   /*
     Allocate histogram count arrays.
   */
-  length=MagickMax((size_t) ScaleQuantumToChar(QuantumRange)+1,
+  length=MagickMax((size_t) ScaleQuantumToChar(QuantumRange)+1UL,
     histogram_image->columns);
-  histogram=(MagickPixelPacket *)
-    AcquireMagickMemory(length*sizeof(*histogram));
+  histogram=(MagickPixelPacket *) AcquireQuantumMemory(length,
+    sizeof(*histogram));
   if (histogram == (MagickPixelPacket *) NULL)
     {
       histogram_image=DestroyImage(histogram_image);
