@@ -158,18 +158,18 @@ static Image *ReadJBIGImage(const ImageInfo *image_info,
     Initialize JBIG toolkit.
   */
   jbg_dec_init(&jbig_info);
-  jbg_dec_maxsize(&jbig_info,(unsigned long) image->columns,
-    (unsigned long) image->rows);
-  image->columns= jbg_dec_getwidth(&jbig_info);
-  image->rows= jbg_dec_getheight(&jbig_info);
+  jbg_dec_maxsize(&jbig_info,(unsigned long) image->columns,(unsigned long)
+    image->rows);
+  image->columns=jbg_dec_getwidth(&jbig_info);
+  image->rows=jbg_dec_getheight(&jbig_info);
   image->depth=8;
   image->storage_class=PseudoClass;
   image->colors=2;
   /*
     Read JBIG file.
   */
-  buffer=(unsigned char *) AcquireMagickMemory(MagickMaxBufferSize*
-    sizeof(buffer));
+  buffer=(unsigned char *) AcquireQuantumMemory(MagickMaxBufferSize,
+    sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   status=JBG_EAGAIN;
@@ -216,6 +216,11 @@ static Image *ReadJBIGImage(const ImageInfo *image_info,
   /*
     Convert X bitmap image to pixel packets.
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   p=jbg_dec_getimage(&jbig_info,0);
   for (y=0; y < (long) image->rows; y++)
   {
@@ -449,8 +454,9 @@ static MagickBooleanType WriteJBIGImage(const ImageInfo *image_info,
     */
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
-    number_packets=((image->columns+7) >> 3)*image->rows;
-    pixels=(unsigned char *) AcquireMagickMemory(number_packets);
+    number_packets=(image->columns+7)/8;
+    pixels=(unsigned char *) AcquireQuantumMemory(number_packets,
+      image->rows*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
