@@ -17,7 +17,7 @@
 %                                 June 2001                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -207,20 +207,20 @@ static int BlobRead(jas_stream_obj_t *object,char *buffer,const int length)
     *source;
 
   source=(StreamManager *) object;
-  count=ReadBlob(source->image,(size_t) length,(void *) buffer);
+  count=ReadBlob(source->image,(size_t) length,(unsigned char *) buffer);
   return((int) count);
 }
 
 static int BlobWrite(jas_stream_obj_t *object,char *buffer,const int length)
 {
-  size_t
+  ssize_t
     count;
 
   StreamManager
     *source;
 
   source=(StreamManager *) object;
-  count=WriteBlob(source->image,(size_t) length,(void *) buffer);
+  count=WriteBlob(source->image,(size_t) length,(unsigned char *) buffer);
   return((int) count);
 }
 
@@ -230,7 +230,7 @@ static long BlobSeek(jas_stream_obj_t *object,long offset,int origin)
     *source;
 
   source=(StreamManager *) object;
-  return(SeekBlob(source->image,offset,origin));
+  return((long) SeekBlob(source->image,offset,origin));
 }
 
 static int BlobClose(jas_stream_obj_t *object)
@@ -285,7 +285,8 @@ static jas_stream_t *JP2StreamManager(Image *image)
   (void) ResetMagickMemory(stream->obj_,0,sizeof(StreamManager));
   stream->ops_=(&StreamOperators);
   stream->openmode_=JAS_STREAM_READ | JAS_STREAM_WRITE | JAS_STREAM_BINARY;
-  stream->bufbase_=jas_malloc(JAS_STREAM_BUFSIZE+JAS_STREAM_MAXPUTBACK);
+  stream->bufbase_=(unsigned char *) jas_malloc(JAS_STREAM_BUFSIZE+
+    JAS_STREAM_MAXPUTBACK);
   if (stream->bufbase_ == (void *) NULL)
     {
       stream->bufbase_=stream->tinybuf_;
@@ -456,25 +457,31 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
         jas_image_destroy(jp2_image);
         ThrowReaderException(CoderError,"IrregularChannelGeometryNotSupported");
       }
-    x_step[i]=jas_image_cmpthstep(jp2_image,components[i]);
-    y_step[i]=jas_image_cmptvstep(jp2_image,components[i]);
+    x_step[i]=(unsigned int) jas_image_cmpthstep(jp2_image,components[i]);
+    y_step[i]=(unsigned int) jas_image_cmptvstep(jp2_image,components[i]);
   }
   /*
     Convert JPEG 2000 pixels.
   */
+  image->matte=number_components > 3 ? MagickTrue : MagickFalse;
   if (image_info->ping != MagickFalse)
     {
       (void) jas_stream_close(jp2_stream);
       jas_image_destroy(jp2_image);
       return(GetFirstImageInList(image));
     }
-  image->matte=number_components > 3;
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   maximum_component_depth=0;
   for (i=0; i < (long) number_components; i++)
   {
-    maximum_component_depth=(unsigned int) MagickMax(jas_image_cmptprec(
-      jp2_image,components[i]),(long) maximum_component_depth);
-    pixels[i]=jas_matrix_create(1,((unsigned int) image->columns)/x_step[i]);
+    maximum_component_depth=(unsigned int) MagickMax((size_t)
+      jas_image_cmptprec(jp2_image,components[i]),(size_t)
+      maximum_component_depth);
+    pixels[i]=jas_matrix_create(1,(int) image->columns/x_step[i]);
     if (pixels[i] == (jas_matrix_t *) NULL)
       {
         jas_image_destroy(jp2_image);
@@ -489,12 +496,12 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
   {
     scale[i]=1;
     if (jas_image_cmptprec(jp2_image,components[i]) < 16)
-      scale[i]=(1 << (16-jas_image_cmptprec(jp2_image,components[i])));
+      scale[i]=(1U << (16-jas_image_cmptprec(jp2_image,components[i])));
   }
   if (number_components == 1)
     {
       image->storage_class=PseudoClass;
-      image->colors=(image->depth == 8 ? 256 : MaxColormapSize);
+      image->colors=(image->depth == 8 ? 256UL : MaxColormapSize);
       if (AllocateImageColormap(image,image->colors) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     }
@@ -622,9 +629,9 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
           SetStringInfoDatum(profile,blob->buf_);
           icc_profile=(StringInfo *) GetImageProfile(image,"icc");
           if (icc_profile == (StringInfo *) NULL)
-            SetImageProfile(image,"icc",profile);
+            (void) SetImageProfile(image,"icc",profile);
           else
-            ConcatenateStringInfo(icc_profile,profile);
+            (void) ConcatenateStringInfo(icc_profile,profile);
           profile=DestroyStringInfo(profile);
           (void) jas_stream_close(icc_stream);
         }
@@ -833,7 +840,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   jp2_stream=JP2StreamManager(image);
   if (jp2_stream == (jas_stream_t *) NULL)
     ThrowWriterException(DelegateError,"UnableToManageJP2Stream");
-  number_components=image->matte ? 4 : 3;
+  number_components=image->matte ? 4UL : 3UL;
   if ((image_info->type != TrueColorType) &&
       IsGrayImage(image,&image->exception))
     number_components=1;
@@ -845,10 +852,10 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
     component_info[i].vstep=1;
     component_info[i].width=(unsigned int) image->columns;
     component_info[i].height=(unsigned int) image->rows;
-    component_info[i].prec=(unsigned int) MagickMin(image->depth,16);
+    component_info[i].prec=(int) MagickMin(image->depth,16);
     component_info[i].sgnd=MagickFalse;
   }
-  jp2_image=jas_image_create(number_components,component_info,
+  jp2_image=jas_image_create((int) number_components,component_info,
     JAS_CLRSPC_UNKNOWN);
   if (jp2_image == (jas_image_t *) NULL)
     ThrowWriterException(DelegateError,"UnableToCreateImage");
@@ -881,7 +888,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   */
   for (i=0; i < (long) number_components; i++)
   {
-    pixels[i]=jas_matrix_create(1,(unsigned int) image->columns);
+    pixels[i]=jas_matrix_create(1,(int) image->columns);
     if (pixels[i] == (jas_matrix_t *) NULL)
       {
         for (x=0; x < i; x++)
@@ -940,10 +947,10 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
       {
         if (LocaleNCompare(key,"jp2:",4) == 0)
           {
-            ConcatenateString(&options,key+4);
-            ConcatenateString(&options,"=");
-            ConcatenateString(&options,option);
-            ConcatenateString(&options," ");
+            (void) ConcatenateString(&options,key+4);
+            (void) ConcatenateString(&options,"=");
+            (void) ConcatenateString(&options,option);
+            (void) ConcatenateString(&options," ");
           }
        }
     key=GetNextImageOption(image_info);
@@ -952,7 +959,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   if ((option == (const char *) NULL) &&
       (image->compression != LosslessJPEGCompression) &&
       (image->quality != UndefinedCompressionQuality) &&
-      (image->quality < 99.5) && ((image->rows*image->columns) > 2500))
+      (image->quality <= 99) && ((image->rows*image->columns) > 2500))
     {
       char
         option[MaxTextExtent];
@@ -964,7 +971,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
         rate,
         target_size;
 
-      alpha=115-image->quality;
+      alpha=115.0-image->quality;
       rate=100.0/(alpha*alpha);
       header_size=550.0;
       header_size+=(number_components-1)*142;
@@ -972,10 +979,11 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
         (GetImageQuantumDepth(image,MagickTrue)/8);
       target_size=(number_pixels*rate)+header_size;
       rate=target_size/number_pixels;
-      FormatMagickString(option,MaxTextExtent,"rate=%g",rate);
-      ConcatenateString(&options,option);
+      (void) FormatMagickString(option,MaxTextExtent,"rate=%g",rate);
+      (void) ConcatenateString(&options,option);
     }
-  status=jas_image_encode(jp2_image,jp2_stream,format,options);
+  status=jas_image_encode(jp2_image,jp2_stream,format,options) != 0 ?
+    MagickTrue : MagickFalse;
   (void) jas_stream_close(jp2_stream);
   for (i=0; i < (long) number_components; i++)
     jas_matrix_destroy(pixels[i]);
