@@ -309,7 +309,10 @@ static boolean ReadComment(j_decompress_ptr jpeg_info)
   length-=2;
   if (length <= 0)
     return(MagickTrue);
-  comment=(char *) AcquireMagickMemory(length+MaxTextExtent);
+  comment=(char *) NULL;
+  if (~length >= MaxTextExtent)
+    comment=(char *) AcquireQuantumMemory(length+MaxTextExtent,
+      sizeof(*comment));
   if (comment == (char *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
@@ -1024,8 +1027,14 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
-  jpeg_pixels=(JSAMPLE *) AcquireMagickMemory((size_t)
-    jpeg_info.output_components*image->columns*sizeof(JSAMPLE));
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      jpeg_destroy_decompress(&jpeg_info);
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  jpeg_pixels=(JSAMPLE *) AcquireQuantumMemory((size_t) image->columns,
+    jpeg_info.output_components*sizeof(JSAMPLE));
   if (jpeg_pixels == (JSAMPLE *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   /*
@@ -1100,14 +1109,14 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
           else
             for (x=0; x < (long) image->columns; x++)
             {
-              q->red=QuantumRange-ScaleShortToQuantum((unsigned char)
+              q->red=(Quantum) QuantumRange-ScaleShortToQuantum((unsigned char)
                 (GETJSAMPLE(*p++) << 4));
-              q->green=QuantumRange-ScaleShortToQuantum((unsigned char)
-                (GETJSAMPLE(*p++) << 4));
-              q->blue=QuantumRange-ScaleShortToQuantum((unsigned char)
-                (GETJSAMPLE(*p++) << 4));
-              indexes[x]=QuantumRange-ScaleShortToQuantum((unsigned char)
+              q->green=(Quantum) QuantumRange-ScaleShortToQuantum(
+                (unsigned char) (GETJSAMPLE(*p++) << 4));
+              q->blue=(Quantum) QuantumRange-ScaleShortToQuantum((unsigned char)
                 (GETJSAMPLE(*p++) << 4));
+              indexes[x]=(IndexPacket) QuantumRange-ScaleShortToQuantum(
+                (unsigned char) (GETJSAMPLE(*p++) << 4));
               q++;
             }
       }
@@ -1132,14 +1141,14 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
         else
           for (x=0; x < (long) image->columns; x++)
           {
-            q->red=QuantumRange-ScaleCharToQuantum((unsigned char)
+            q->red=(Quantum) QuantumRange-ScaleCharToQuantum((unsigned char)
               GETJSAMPLE(*p++));
-            q->green=QuantumRange-ScaleCharToQuantum((unsigned char)
+            q->green=(Quantum) QuantumRange-ScaleCharToQuantum((unsigned char)
               GETJSAMPLE(*p++));
-            q->blue=QuantumRange-ScaleCharToQuantum((unsigned char)
-              GETJSAMPLE(*p++));
-            indexes[x]=QuantumRange-ScaleCharToQuantum((unsigned char)
+            q->blue=(Quantum) QuantumRange-ScaleCharToQuantum((unsigned char)
               GETJSAMPLE(*p++));
+            indexes[x]=(IndexPacket) QuantumRange-ScaleCharToQuantum(
+              (unsigned char) GETJSAMPLE(*p++));
             q++;
           }
     if (SyncImagePixels(image) == MagickFalse)
@@ -1343,8 +1352,6 @@ static void TerminateDestination(j_compress_ptr cinfo)
           (MaxBufferExtent-destination->manager.free_in_buffer))
         ERREXIT(cinfo,JERR_FILE_WRITE);
     }
-  if (SyncBlob(destination->image) != MagickFalse)
-    ERREXIT(cinfo,JERR_FILE_WRITE);
 }
 
 static void WriteProfile(j_compress_ptr jpeg_info,Image *image)
@@ -1483,21 +1490,20 @@ static char **SamplingFactorToList(const char *text)
   for (p=text; *p != '\0'; p++)
     if (*p == ',')
       lines++;
-  textlist=(char **)
-    AcquireMagickMemory(((size_t) lines+MaxTextExtent)*sizeof(*textlist));
+  textlist=(char **) AcquireQuantumMemory((size_t) lines+MaxTextExtent,
+    sizeof(*textlist));
   if (textlist == (char **) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"UnableToConvertText",
-      text);
+    ThrowFatalException(ResourceLimitFatalError,"UnableToConvertText");
   p=text;
   for (i=0; i < (long) lines; i++)
   {
     for (q=(char *) p; *q != '\0'; q++)
       if (*q == ',')
         break;
-    textlist[i]=(char *) AcquireMagickMemory((size_t) (q-p)+MaxTextExtent);
+    textlist[i]=(char *) AcquireQuantumMemory((size_t) (q-p)+MaxTextExtent,
+      sizeof(*textlist[i]));
     if (textlist[i] == (char *) NULL)
-      ThrowMagickFatalException(ResourceLimitFatalError,"UnableToConvertText",
-        text);
+      ThrowFatalException(ResourceLimitFatalError,"UnableToConvertText");
     (void) CopyMagickString(textlist[i],p,(size_t) (q-p+1));
     if (*q == '\r')
       q++;
@@ -1672,7 +1678,7 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
       /*
         Perform optimization only if available memory resources permit it.
       */
-      status=AcquireMagickResource(MemoryResource,8*number_pixels);
+      status=AcquireMagickResource(MemoryResource,8UL*number_pixels);
       if (status != MagickFalse)
         {
           const char
@@ -1688,26 +1694,28 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
 #if (JPEG_LIB_VERSION >= 61) && defined(C_PROGRESSIVE_SUPPORTED)
   if ((LocaleCompare(image_info->magick,"PJPEG") == 0) ||
       (image_info->interlace != NoInterlace))
-    jpeg_simple_progression(&jpeg_info);
-  if (image->debug != MagickFalse)
     {
-      if (image_info->interlace != NoInterlace)
+      if (image->debug != MagickFalse)
         (void) LogMagickEvent(CoderEvent,GetMagickModule(),
           "Interlace: progressive");
-      else
-        (void) LogMagickEvent(CoderEvent,GetMagickModule(),
-          "Interlace: non-progressive");
+      jpeg_simple_progression(&jpeg_info);
     }
+  else
+    if (image->debug != MagickFalse)
+      (void) LogMagickEvent(CoderEvent,GetMagickModule(),
+        "Interlace: non-progressive");
 #else
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(CoderEvent,GetMagickModule(),
       "Interlace: nonprogressive");
 #endif
   if ((image->compression != LosslessJPEGCompression) &&
-      (image->quality != UndefinedCompressionQuality) &&
       (image->quality <= 100))
     {
-      jpeg_set_quality(&jpeg_info,(int) image->quality,MagickTrue);
+      if (image->quality == UndefinedCompressionQuality)
+        jpeg_set_quality(&jpeg_info,85,MagickTrue);
+      else
+        jpeg_set_quality(&jpeg_info,(int) image->quality,MagickTrue);
       if (image->debug != MagickFalse)
         (void) LogMagickEvent(CoderEvent,GetMagickModule(),"Quality: %lu",
           image->quality);
@@ -1936,8 +1944,8 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
   /*
     Convert MIFF to JPEG raster pixels.
   */
-  jpeg_pixels=(JSAMPLE *) AcquireMagickMemory((size_t)
-    jpeg_info.input_components*image->columns*sizeof(*jpeg_pixels));
+  jpeg_pixels=(JSAMPLE *) AcquireQuantumMemory((size_t) image->columns,
+    jpeg_info.input_components*sizeof(*jpeg_pixels));
   if (jpeg_pixels == (JSAMPLE *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   scanline[0]=(JSAMPROW) jpeg_pixels;
