@@ -121,6 +121,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
+  (void) ResetImagePage(image,"0x0+0+0");
   (void) SetImageProperty(image,"label",InterpretImageProperties(image_info,
     image,image_info->filename));
   label=GetImageProperty(image,"label");
@@ -180,6 +181,11 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   if (image->rows == 0)
     image->rows=(unsigned long) (draw_info->pointsize+draw_info->stroke_width+
       0.5);
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   (void) SetImageBackgroundColor(image);
   (void) AnnotateImage(image,draw_info);
   draw_info=DestroyDrawInfo(draw_info);
