@@ -88,7 +88,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -162,9 +161,11 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   depth=GetImageQuantumDepth(image,MagickTrue);
   packet_size=(size_t) (depth/8);
-  pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
-  packet_size=(size_t) (image->colors > 256 ? 6 : 3);
-  colormap=(unsigned char *) AcquireMagickMemory(packet_size*image->colors);
+  pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
+    sizeof(*pixels));
+  packet_size=(size_t) (image->colors > 256 ? 6UL : 3UL);
+  colormap=(unsigned char *) AcquireQuantumMemory(image->colors,packet_size*
+    sizeof(*colormap));
   if ((pixels == (unsigned char *) NULL) ||
       (colormap == (unsigned char *) NULL))
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -204,6 +205,11 @@ static Image *ReadMAPImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Read image pixels.
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   packet_size=(size_t) (depth/8);
   for (y=0; y < (long) image->rows; y++)
   {
@@ -379,9 +385,11 @@ static MagickBooleanType WriteMAPImage(const ImageInfo *image_info,Image *image)
     (void) SetImageType(image,PaletteType);
   depth=GetImageQuantumDepth(image,MagickTrue);
   packet_size=(size_t) (depth/8);
-  pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
-  packet_size=(size_t) (image->colors > 256 ? 6 : 3);
-  colormap=(unsigned char *) AcquireMagickMemory(packet_size*image->colors);
+  pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
+    sizeof(*pixels));
+  packet_size=(size_t) (image->colors > 256 ? 6UL : 3UL);
+  colormap=(unsigned char *) AcquireQuantumMemory(image->colors,packet_size*
+    sizeof(*colormap));
   if ((pixels == (unsigned char *) NULL) ||
       (colormap == (unsigned char *) NULL))
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
