@@ -64,6 +64,12 @@
 #include "magick/string_.h"
 #include "magick/transform.h"
 
+/*
+  Forward declaration.
+*/
+static MagickBooleanType
+  WriteMATImage(const ImageInfo *,Image *);
+
 /* Auto coloring method, sorry this creates some artefact inside data
 MinReal+j*MaxComplex = red  MaxReal+j*MaxComplex = black
 MinReal+j*0 = white          MaxReal+j*0 = black
@@ -75,7 +81,7 @@ typedef struct
   char identific[124];
   unsigned short Version;
   char EndianIndicator[2];
-  unsigned long unknown0;
+  unsigned long DataType;
   unsigned long ObjectSize;
   unsigned long unknown1;
   unsigned long unknown2;
@@ -94,9 +100,9 @@ typedef struct
 }
 MATHeader;
 
-char *MonthsTab[12]={"Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};
-char *DayOfWTab[7]={"Sun","Mon","Tue","Wed","Thu","Fri","Sat"};
-char *OsDesc=
+static const char *MonthsTab[12]={"Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};
+static const char *DayOfWTab[7]={"Sun","Mon","Tue","Wed","Thu","Fri","Sat"};
+static const char *OsDesc=
 #ifdef __WIN32__
     "PCWIN";
 #else
@@ -153,159 +159,10 @@ typedef enum
 #define FLAG_GLOBAL  0x4
 #define FLAG_LOGICAL 0x2
 
-
-/* Update one byte row inside image. */
-static void InsertByteRow(unsigned char *p, int y, Image * image, int channel)
-{
-  int x;
-  register PixelPacket *q;
-  IndexPacket index;
-  register IndexPacket *indexes;
-
-                       /* Convert PseudoColor scanline. */  
-  q = SetImagePixels(image, 0, y, image->columns, 1);
-  if (q == (PixelPacket *) NULL) return;
-
-  switch(channel)
-    {
-    case 0:          
-      indexes = GetIndexes(image);
-
-      for (x = 0; x < (long) image->columns; x++)
-        {
-        index = (IndexPacket) (*p);
-        index=ConstrainColormapIndex(image,index);
-        indexes[x] = index;
-        *q++ = image->colormap[(long) index];
-        p++;
-        }
-      break;
-    case 1:
-       for (x = 0; x < (long) image->columns; x++)        
-         { 
-         q->blue = ScaleCharToQuantum(*p);
-         p++;
-         q++;
-         }
-       break;
-    case 2:
-       for (x = 0; x < (long) image->columns; x++)        
-         {
-         q->green = ScaleCharToQuantum(*p);
-         p++;
-         q++;
-         }
-       break;
-    case 3:
-       for (x = 0; x < (long) image->columns; x++)        
-	 {         
-         q->red = ScaleCharToQuantum(*p);
-         q->opacity = OpaqueOpacity;
-         p++;
-         q++;
-         }
-       break;
-    }
-  if (SyncImagePixels(image) == MagickFalse)
-    return;
-        /*           if (image->previous == (Image *) NULL)
-           if (QuantumTick(y,image->rows))
-           ProgressMonitor(LoadImageText,image->rows-y-1,image->rows); */
-      
-  return;
-}
+static const QuantumType z2qtype[4] = {GrayQuantum, BlueQuantum, GreenQuantum, RedQuantum};
 
 
-/* Update one word row inside image. */
-static void InsertWordRow(unsigned char *p, int y, Image * image, int channel)
-{
-  int x;
-  register PixelPacket *q;
-
-  q = SetImagePixels(image, 0, y, image->columns, 1);
-  if (q == (PixelPacket *) NULL) return;
-
-  switch(channel)
-    {
-    case 0: 
-      for (x = 0; x < (long) image->columns; x++)
-        {
-        q->red =
-          q->green =
-          q->blue = ScaleShortToQuantum(*(unsigned short *) p);    
-        q->opacity = OpaqueOpacity;
-        p += 2;
-        q++;
-        }
-       break;
-    case 1:
-       for (x = 0; x < (long) image->columns; x++)        
-         { 
-         q->blue = ScaleShortToQuantum(*(unsigned short *) p);
-         p += 2;
-         q++;
-         }
-       break;
-    case 2:
-       for (x = 0; x < (long) image->columns; x++)        
-         {
-         q->green = ScaleShortToQuantum(*(unsigned short *) p);
-         p += 2;
-         q++;
-         }
-       break;
-    case 3:
-       for (x = 0; x < (long) image->columns; x++)        
-	 {
-         q->red = ScaleShortToQuantum(*(unsigned short *) p);
-         p += 2;
-         q++;
-         }
-       break;
-    }   
-         
-  if (SyncImagePixels(image) == MagickFalse)
-    return;
-        /*          if (image->previous == (Image *) NULL)
-           if (QuantumTick(y,image->rows))
-           MagickMonitor(LoadImageText,image->rows-y-1,image->rows); */
-  return; 
-}
-
-
-/* Update one double organised row inside image. */
-static void InsertFloatRow(double *p, int y, Image * image, double MinVal, double MaxVal)
-{
-  double f;
-  int x;
-  register PixelPacket *q;
-
-  if (MinVal >= MaxVal)
-    MaxVal = MinVal + 1;
-
-  q = SetImagePixels(image, 0, y, image->columns, 1);
-  if (q == (PixelPacket *) NULL)
-    return;
-  for (x = 0; x < (long) image->columns; x++)
-  {
-    f = (double) QuantumRange *(*p - MinVal) / (MaxVal - MinVal);
-    q->red = 
-      q->green = 
-      q->blue = RoundToQuantum(f);
-    q->opacity = OpaqueOpacity;
-  
-    p++;
-    q++;
-  }
-  if (SyncImagePixels(image) == MagickFalse)
-    return;
-  /*          if (image->previous == (Image *) NULL)
-     if (QuantumTick(y,image->rows))
-     MagickMonitor(LoadImageText,image->rows-y-1,image->rows); */
-  return;
-}
-
-static void InsertComplexFloatRow(double *p, int y, Image * image, double MinVal,
+static void InsertComplexDoubleRow(double *p, int y, Image * image, double MinVal,
                                   double MaxVal)
 {
   double f;
@@ -324,9 +181,9 @@ static void InsertComplexFloatRow(double *p, int y, Image * image, double MinVal
   {
     if (*p > 0)
     {
-      f = (*p / MaxVal) * (QuantumRange - q->red);
-      if (f + q->red > QuantumRange)
-        q->red = QuantumRange;
+      f = (*p / MaxVal) * (MaxRGB - q->red);
+      if (f + q->red > MaxRGB)
+        q->red = MaxRGB;
       else
         q->red += (int) f;
       if ((int) f / 2.0 > q->green)
@@ -336,9 +193,9 @@ static void InsertComplexFloatRow(double *p, int y, Image * image, double MinVal
     }
     if (*p < 0)
     {
-      f = (*p / MaxVal) * (QuantumRange - q->blue);
-      if (f + q->blue > QuantumRange)
-        q->blue = QuantumRange;
+      f = (*p / MaxVal) * (MaxRGB - q->blue);
+      if (f + q->blue > MaxRGB)
+        q->blue = MaxRGB;
       else
         q->blue += (int) f;
       if ((int) f / 2.0 > q->green)
@@ -349,7 +206,7 @@ static void InsertComplexFloatRow(double *p, int y, Image * image, double MinVal
     p++;
     q++;
   }
-  if (SyncImagePixels(image) == MagickFalse)
+  if (!SyncImagePixels(image))
     return;
   /*          if (image->previous == (Image *) NULL)
      if (QuantumTick(y,image->rows))
@@ -357,126 +214,186 @@ static void InsertComplexFloatRow(double *p, int y, Image * image, double MinVal
   return;
 }
 
-/* This function reads one block of unsigned shortS*/
-static void ReadBlobWordLSB(Image * image, size_t len, unsigned short *data)
+
+static void InsertComplexFloatRow(float *p, int y, Image * image, double MinVal,
+                                  double MaxVal)
 {
-  while (len >= 2)
+  double f;
+  int x;
+  register PixelPacket *q;
+
+  if (MinVal == 0)
+    MinVal = -1;
+  if (MaxVal == 0)
+    MaxVal = 1;
+
+  q = SetImagePixels(image, 0, y, image->columns, 1);
+  if (q == (PixelPacket *) NULL)
+    return;
+  for (x = 0; x < (long) image->columns; x++)
   {
-    *data++ = ReadBlobLSBShort(image);
-    len -= 2;
+    if (*p > 0)
+    {
+      f = (*p / MaxVal) * (MaxRGB - q->red);
+      if (f + q->red > MaxRGB)
+        q->red = MaxRGB;
+      else
+        q->red += (int) f;
+      if ((int) f / 2.0 > q->green)
+        q->green = q->blue = 0;
+      else
+        q->green = q->blue -= (int) (f / 2.0);
+    }
+    if (*p < 0)
+    {
+      f = (*p / MaxVal) * (MaxRGB - q->blue);
+      if (f + q->blue > MaxRGB)
+        q->blue = MaxRGB;
+      else
+        q->blue += (int) f;
+      if ((int) f / 2.0 > q->green)
+        q->green = q->red = 0;
+      else
+        q->green = q->red -= (int) (f / 2.0);
+    }
+    p++;
+    q++;
+  }
+  if (!SyncImagePixels(image))
+    return;
+  /*          if (image->previous == (Image *) NULL)
+     if (QuantumTick(y,image->rows))
+     MagickMonitor(LoadImageText,image->rows-y-1,image->rows); */
+  return;
+}
+
+
+/************** READERS ******************/
+
+/* This function reads one block of floats*/
+static void ReadBlobFloatsLSB(Image * image, size_t len, float *data)
+{
+  while (len >= 4)
+  {
+    *data++ = ReadBlobFloat(image);
+    len -= sizeof(float);
   }
   if (len > 0)
     (void) SeekBlob(image, len, SEEK_CUR);
 }
 
-static void ReadBlobWordMSB(Image * image, size_t len, unsigned short *data)
+static void ReadBlobFloatsMSB(Image * image, size_t len, float *data)
 {
-  while (len >= 2)
+  while (len >= 4)
   {
-    *data++ = ReadBlobMSBShort(image);
-    len -= 2;
+    *data++ = ReadBlobFloat(image);
+    len -= sizeof(float);
   }
   if (len > 0)
     (void) SeekBlob(image, len, SEEK_CUR);
 }
 
-static double ReadBlobLSBdouble(Image * image)
-{
-  typedef union
-  {
-    double d;
-    char chars[8];
-  }
-  dbl;
-  static unsigned long lsb_first = 1;
-  dbl buffer;
-  char c;
-
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-
-  if (ReadBlob(image, 8, (unsigned char *) &buffer) == 0)
-    return (0.0);
-  if (*(char *) &lsb_first == 1)
-    return (buffer.d);
-
-  c = buffer.chars[0];
-  buffer.chars[0] = buffer.chars[7];
-  buffer.chars[7] = c;
-  c = buffer.chars[1];
-  buffer.chars[1] = buffer.chars[6];
-  buffer.chars[6] = c;
-  c = buffer.chars[2];
-  buffer.chars[2] = buffer.chars[5];
-  buffer.chars[5] = c;
-  c = buffer.chars[3];
-  buffer.chars[3] = buffer.chars[4];
-  buffer.chars[4] = c;
-  return (buffer.d);
-}
-
+/* This function reads one block of doubles*/
 static void ReadBlobDoublesLSB(Image * image, size_t len, double *data)
 {
   while (len >= 8)
   {
-    *data++ = ReadBlobLSBdouble(image);
+    *data++ = ReadBlobDouble(image);
     len -= sizeof(double);
   }
   if (len > 0)
     (void) SeekBlob(image, len, SEEK_CUR);
 }
 
-static double ReadBlobMSBdouble(Image * image)
-{
-  typedef union
-  {
-    double d;
-    char chars[8];
-  }
-  dbl;
-  static unsigned long lsb_first = 1;
-  dbl buffer;
-  char c;
-
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-
-  if (ReadBlob(image, 8, (unsigned char *) &buffer) == 0)
-    return (0.0);
-  if (*(char *) &lsb_first != 1)
-    return (buffer.d);
-
-  c = buffer.chars[0];
-  buffer.chars[0] = buffer.chars[7];
-  buffer.chars[7] = c;
-  c = buffer.chars[1];
-  buffer.chars[1] = buffer.chars[6];
-  buffer.chars[6] = c;
-  c = buffer.chars[2];
-  buffer.chars[2] = buffer.chars[5];
-  buffer.chars[5] = c;
-  c = buffer.chars[3];
-  buffer.chars[3] = buffer.chars[4];
-  buffer.chars[4] = c;
-  return (buffer.d);
-}
-
 static void ReadBlobDoublesMSB(Image * image, size_t len, double *data)
 {
   while (len >= 8)
   {
-    *data++ = ReadBlobMSBdouble(image);
+    *data++ = ReadBlobDouble(image);
     len -= sizeof(double);
   }
   if (len > 0)
     (void) SeekBlob(image, len, SEEK_CUR);
 }
-
-/*
-  Forward declaration.
-*/
-static MagickBooleanType
-  WriteMATImage(const ImageInfo *,Image *);
+
+
+/* Calculate minimum and maximum from a given block of data */
+static void CalcMinMax(Image *image, MATHeader *MATLAB_HDR, unsigned long CellType, unsigned ldblk, void *BImgBuff, double *Min, double *Max)
+{
+MagickOffsetType filepos;
+int i, x;
+void (*ReadBlobDoublesXXX)(Image * image, size_t len, double *data);
+void (*ReadBlobFloatsXXX)(Image * image, size_t len, float *data);
+double *dblrow;
+float *fltrow;
+
+  if (!strncmp(MATLAB_HDR->EndianIndicator, "IM", 2))
+  {    
+    ReadBlobDoublesXXX = ReadBlobDoublesLSB;
+    ReadBlobFloatsXXX = ReadBlobFloatsLSB;   
+  } 
+  else		/* MI */
+  {    
+    ReadBlobDoublesXXX = ReadBlobDoublesMSB;
+    ReadBlobFloatsXXX = ReadBlobFloatsMSB;   
+  }
+
+  filepos = TellBlob(image);	   /* Please note that file seeking occurs only in the case of doubles */
+  for (i = 0; i < (long) MATLAB_HDR->SizeY; i++)
+  {
+    if (CellType==miDOUBLE)
+    {
+      ReadBlobDoublesXXX(image, ldblk, (double *)BImgBuff);
+      dblrow = (double *)BImgBuff;
+      if (i == 0)
+      {
+        *Min = *Max = *dblrow;
+      }
+      for (x = 0; x < (long) MATLAB_HDR->SizeX; x++)
+      {
+        if (*Min > *dblrow)
+          *Min = *dblrow;
+        if (*Max < *dblrow)
+          *Max = *dblrow;
+        dblrow++;
+      }
+    }
+    if (CellType==miSINGLE)
+    {
+      ReadBlobFloatsXXX(image, ldblk, (float *)BImgBuff);
+      fltrow = (float *)BImgBuff;
+      if (i == 0)
+      {
+        *Min = *Max = *fltrow;
+      }
+    for (x = 0; x < (long) MATLAB_HDR->SizeX; x++)
+      {
+        if (*Min > *fltrow)
+          *Min = *fltrow;
+        if (*Max < *fltrow)
+          *Max = *fltrow;
+        fltrow++;
+      }
+    }
+  }
+  (void) SeekBlob(image, filepos, SEEK_SET);
+}
+
+
+static void FixSignedValues(PixelPacket *q, int y)
+{
+  while(y-->0)
+  {
+     /* Please note that negative values will overflow
+        Q=8; MaxRGB=255: <0;127> + 127+1 = <128; 255> 
+		       <-1;-128> + 127+1 = <0; 127> */
+    q->red += MaxRGB/2 + 1;
+    q->green += MaxRGB/ + 1;
+    q->blue += MaxRGB/ + 1;
+    q++;
+  }
+}
+
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -489,9 +406,9 @@ static MagickBooleanType
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  Method ReadMATImage reads an MAT X image file and returns it.  It
-%  allocates the memory necessary for the new Image structure and returns a
-%  pointer to the new image.
+%  ReadMATImage() reads an MAT X image file and returns it.  It allocates
+%  the memory necessary for the new Image structure and returns a pointer to
+%  the new image.
 %
 %  The format of the ReadMATImage method is:
 %
@@ -499,10 +416,6 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image:  Method ReadMATImage returns a pointer to the image after
-%      reading. A null image is returned if there is a memory shortage or if
-%      the image cannot be read.
-%
 %    o image_info: Specifies a pointer to a ImageInfo structure.
 %
 %    o exception: return any errors or warnings in this structure.
@@ -516,33 +429,43 @@ static inline size_t MagickMin(const size_t x,const size_t y)
   return(y);
 }
 
-static Image *ReadMATImage(const ImageInfo * image_info, ExceptionInfo * exception)
+static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   Image *image,
    *rotated_image;
+  PixelPacket *q;
   unsigned int status;
   MATHeader MATLAB_HDR;
-  unsigned long size;
-  MagickOffsetType filepos;
+  unsigned long size;  
   unsigned long CellType;
-  int i,
-    x;
+  QuantumInfo quantum_info;
+  int i;
   long ldblk;
   unsigned char *BImgBuff = NULL;
-  double MinVal, MaxVal,
-   *dblrow;
-  unsigned long z, Unknown5;
+  double MinVal, MaxVal;
+  unsigned long Unknown6;
+  unsigned z;
+  int logging;
+  MagickOffsetType filepos=0x80;
+  BlobInfo *blob;
 
   unsigned long (*ReadBlobXXXLong)(Image *image);
   unsigned short (*ReadBlobXXXShort)(Image *image);
   void (*ReadBlobDoublesXXX)(Image * image, size_t len, double *data);
-  
+  void (*ReadBlobFloatsXXX)(Image * image, size_t len, float *data);
+
+
+  assert(image_info != (const ImageInfo *) NULL);
+  assert(image_info->signature == MagickSignature);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  logging=LogMagickEvent(CoderEvent,GetMagickModule(),"enter"); 
+
   /*
      Open image file.
    */
   image = AllocateImage(image_info);
-
-  status=OpenBlob(image_info, image, ReadBinaryBlobMode, exception);
+  status = OpenBlob(image_info, image, ReadBinaryBlobMode, exception);
   if (status == MagickFalse)
     {
       image=DestroyImageList(image);
@@ -555,279 +478,294 @@ static Image *ReadMATImage(const ImageInfo * image_info, ExceptionInfo * excepti
   MATLAB_HDR.Version = ReadBlobLSBShort(image);
   (void) ReadBlob(image, 2, (unsigned char *) &MATLAB_HDR.EndianIndicator);
 
+  GetQuantumInfo(image_info,&quantum_info);
+
+  if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),"  Endian %c%c",
+        MATLAB_HDR.EndianIndicator[0],MATLAB_HDR.EndianIndicator[1]);
   if (!strncmp(MATLAB_HDR.EndianIndicator, "IM", 2))
   {
     ReadBlobXXXLong = ReadBlobLSBLong;
     ReadBlobXXXShort = ReadBlobLSBShort;
     ReadBlobDoublesXXX = ReadBlobDoublesLSB;
+    ReadBlobFloatsXXX = ReadBlobFloatsLSB;
+    image->endian = LSBEndian;
   } 
   else if (!strncmp(MATLAB_HDR.EndianIndicator, "MI", 2))
   {
     ReadBlobXXXLong = ReadBlobMSBLong;
     ReadBlobXXXShort = ReadBlobMSBShort;
     ReadBlobDoublesXXX = ReadBlobDoublesMSB;
+    ReadBlobFloatsXXX = ReadBlobFloatsMSB;
+    image->endian = MSBEndian;
   }
   else 
-    goto MATLAB_KO;    //unsupported endian
+    goto MATLAB_KO;    /* unsupported endian */
 
   if (strncmp(MATLAB_HDR.identific, "MATLAB", 6))
-  MATLAB_KO:ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
 
-  MATLAB_HDR.unknown0 = ReadBlobXXXLong(image);
-  MATLAB_HDR.ObjectSize = ReadBlobXXXLong(image);
-  MATLAB_HDR.unknown1 = ReadBlobXXXLong(image);
-  MATLAB_HDR.unknown2 = ReadBlobXXXLong(image);  
-
-  MATLAB_HDR.unknown5 = ReadBlobXXXLong(image);
-  MATLAB_HDR.StructureClass = MATLAB_HDR.unknown5 & 0xFF;
-  MATLAB_HDR.StructureFlag = (MATLAB_HDR.unknown5>>8) & 0xFF;  
-
-  MATLAB_HDR.unknown3 = ReadBlobXXXLong(image);
-  MATLAB_HDR.unknown4 = ReadBlobXXXLong(image);
-  MATLAB_HDR.DimFlag = ReadBlobXXXLong(image);
-  MATLAB_HDR.SizeX = ReadBlobXXXLong(image);
-  MATLAB_HDR.SizeY = ReadBlobXXXLong(image);  
-    
-  if (MATLAB_HDR.unknown0 != 0x0E)
-    goto MATLAB_KO;
-
-  switch(MATLAB_HDR.DimFlag)
+  filepos = TellBlob(image);
+  while(!EOFBlob(image)) /* object parser loop */
   {
-    case  8: z=1; break;	       /* 2D matrix*/
-    case 12: z=ReadBlobXXXLong(image); /* 3D matrix RGB*/
-	     Unknown5 = ReadBlobXXXLong(image);
-	     if(z!=3) ThrowReaderException(CoderError,
-           "MultidimensionalMatricesAreNotSupported");
-	     break;
-    default: ThrowReaderException(CoderError,
-      "MultidimensionalMatricesAreNotSupported");
-  }  
+    SeekBlob(image,filepos,SEEK_SET);
+    //printf("pos=%X\n",TellBlob(image));
 
-  MATLAB_HDR.Flag1 = ReadBlobXXXShort(image);
-  MATLAB_HDR.NameFlag = ReadBlobXXXShort(image);
+    MATLAB_HDR.DataType = ReadBlobXXXLong(image);
+    if(EOFBlob(image)) break;
+    MATLAB_HDR.ObjectSize = ReadBlobXXXLong(image);
+    if(EOFBlob(image)) break;
+    filepos += MATLAB_HDR.ObjectSize + 4 + 4;
 
-  /* printf("MATLAB_HDR.StructureClass %ld\n",MATLAB_HDR.StructureClass); */
-  if (MATLAB_HDR.StructureClass != mxCHAR_CLASS && 
-      MATLAB_HDR.StructureClass != mxDOUBLE_CLASS &&	     /* double / complex double */      
-      MATLAB_HDR.StructureClass != mxUINT8_CLASS &&           /* uint8 3D */
-      MATLAB_HDR.StructureClass != mxUINT16_CLASS)	     /* uint16 3D */
-    goto MATLAB_KO;
+    if (MATLAB_HDR.DataType != miMATRIX) continue;  /* skip another objects. */    
+ 
+    MATLAB_HDR.unknown1 = ReadBlobXXXLong(image);
+    MATLAB_HDR.unknown2 = ReadBlobXXXLong(image);  
 
-  switch (MATLAB_HDR.NameFlag)
-  {
-    case 0:
-      size = ReadBlobXXXLong(image);	/* Object name string size */
-      size = 4 * (long) ((size + 3 + 1) / 4);
-      (void) SeekBlob(image, size, SEEK_CUR);
-      break;
-    case 1:
-    case 2:
-    case 3:
-    case 4:
-      (void) ReadBlob(image, 4, (unsigned char *) &size); /* Object name string */
-      break;
-    default:
-      goto MATLAB_KO;
-  }
+    MATLAB_HDR.unknown5 = ReadBlobXXXLong(image);
+    MATLAB_HDR.StructureClass = MATLAB_HDR.unknown5 & 0xFF;
+    MATLAB_HDR.StructureFlag = (MATLAB_HDR.unknown5>>8) & 0xFF;  
 
-  CellType = ReadBlobXXXLong(image);    /* Additional object type */
-  /* fprintf(stdout,"Cell type:%ld\n",CellType); */
-  (void) ReadBlob(image, 4, (unsigned char *) &size);     /* data size */
+    MATLAB_HDR.unknown3 = ReadBlobXXXLong(image);
+    MATLAB_HDR.unknown4 = ReadBlobXXXLong(image);
+    MATLAB_HDR.DimFlag = ReadBlobXXXLong(image);
+    MATLAB_HDR.SizeX = ReadBlobXXXLong(image);
+    MATLAB_HDR.SizeY = ReadBlobXXXLong(image);  
+   
 
-  switch (CellType)
-  {
-    case miUINT8:
-      image->depth = (unsigned long) MagickMin(QuantumDepth,8);         /* Byte type cell */
-      ldblk = (long) MATLAB_HDR.SizeX;      
-      if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
-        goto MATLAB_KO;
-      break;
-    case miUINT16:
-      image->depth = (unsigned long) MagickMin(QuantumDepth,16);        /* Word type cell */
-      ldblk = (long) (2 * MATLAB_HDR.SizeX);      
-      if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
-        goto MATLAB_KO;
-      break;   
-    case miDOUBLE:
-      image->depth = (unsigned long) MagickMin(QuantumDepth,32);        /* double type cell */
-      if (sizeof(double) != 8)
-        ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-      if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
-      {                         /* complex double type cell */        
-      }      
-      ldblk = (long) (8 * MATLAB_HDR.SizeX);
-      break;
-    default:
-      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-  }
-
-  image->columns = MATLAB_HDR.SizeX;
-  image->rows = MATLAB_HDR.SizeY;
-  image->colors = 1l >> 8;
-  if (image->columns == 0 || image->rows == 0)
-    goto MATLAB_KO;
-
-  /* ----- Create gray palette ----- */
-
-  if (CellType == miUINT8  && z!=3)
-  {
-    image->colors = 256;
-    if (!AllocateImageColormap(image, image->colors))
+    switch(MATLAB_HDR.DimFlag)
     {
-  NoMemory:ThrowReaderException(ResourceLimitError,
-          "MemoryAllocationFailed"); }
+      case  8: z=1; break;	       /* 2D matrix*/
+      case 12: z=ReadBlobXXXLong(image); /* 3D matrix RGB*/
+  	       Unknown6 = ReadBlobXXXLong(image);
+	       if(z!=3) ThrowReaderException(CoderError, "MultidimensionalMatricesAreNotSupported");
+	       break;
+      default: ThrowReaderException(CoderError, "MultidimensionalMatricesAreNotSupported");
+    }  
 
-    for (i = 0; i < (long) image->colors; i++)
+    MATLAB_HDR.Flag1 = ReadBlobXXXShort(image);
+    MATLAB_HDR.NameFlag = ReadBlobXXXShort(image);
+
+    if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),
+          "MATLAB_HDR.StructureClass %d",MATLAB_HDR.StructureClass);
+    if (MATLAB_HDR.StructureClass != mxCHAR_CLASS && 
+        MATLAB_HDR.StructureClass != mxSINGLE_CLASS &&	     /* float + complex float */
+        MATLAB_HDR.StructureClass != mxDOUBLE_CLASS &&	     /* double + complex double */
+        MATLAB_HDR.StructureClass != mxINT8_CLASS &&
+        MATLAB_HDR.StructureClass != mxUINT8_CLASS &&          /* uint8 + uint8 3D */
+        MATLAB_HDR.StructureClass != mxINT16_CLASS &&
+        MATLAB_HDR.StructureClass != mxUINT16_CLASS &&	     /* uint16 + uint16 3D */
+        MATLAB_HDR.StructureClass != mxINT32_CLASS &&
+        MATLAB_HDR.StructureClass != mxUINT32_CLASS &&	     /* uint32 + uint32 3D */
+        MATLAB_HDR.StructureClass != mxINT64_CLASS &&
+        MATLAB_HDR.StructureClass != mxUINT64_CLASS)	     /* uint64 + uint64 3D */
+      ThrowReaderException(CoderError,"UnsupportedCellTypeInTheMatrix");
+
+    switch (MATLAB_HDR.NameFlag)
     {
-      image->colormap[i].red = ScaleCharToQuantum(i);
-      image->colormap[i].green = ScaleCharToQuantum(i);
-      image->colormap[i].blue = ScaleCharToQuantum(i);
+      case 0:
+        size = ReadBlobXXXLong(image);	/* Object name string size */
+        size = 4 * (long) ((size + 3 + 1) / 4);
+        (void) SeekBlob(image, size, SEEK_CUR);
+        break;
+      case 1:
+      case 2:
+      case 3:
+      case 4:
+        (void) ReadBlob(image, 4, (unsigned char *) &size); /* Object name string */
+        break;
+      default:
+        goto MATLAB_KO;
     }
-  }
 
-  if (image_info->ping)
+    CellType = ReadBlobXXXLong(image);    /* Additional object type */
+    if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),
+          "MATLAB_HDR.CellType: %ld",CellType);
+  
+    (void) ReadBlob(image, 4, (unsigned char *) &size);     /* data size */
+
+    switch (CellType)
+    {
+      case miINT8:
+      case miUINT8:
+        image->depth= 8;
+        ldblk = (long) MATLAB_HDR.SizeX;      
+        break;
+      case miINT16:
+      case miUINT16:
+        image->depth= 16;
+        ldblk = (long) (2 * MATLAB_HDR.SizeX);
+        break;
+      case miINT32:
+      case miUINT32:
+        image->depth= 32;
+        ldblk = (long) (4 * MATLAB_HDR.SizeX);      
+        break;
+      case miINT64:
+      case miUINT64:
+        image->depth= 64;
+        ldblk = (long) (8 * MATLAB_HDR.SizeX);      
+        break;   
+      case miSINGLE:
+        image->depth= 32;
+        quantum_info.format=FloatingPointQuantumFormat;
+        if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
+	{                         /* complex float type cell */
+	}
+        ldblk = (long) (4 * MATLAB_HDR.SizeX);
+        break;
+      case miDOUBLE:
+        image->depth= 64; 
+        quantum_info.format=FloatingPointQuantumFormat;
+        if (sizeof(double) != 8)
+          ThrowReaderException(CoderError, "IncompatibleSizeOfDouble");
+        if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
+	{                         /* complex double type cell */        
+	}
+        ldblk = (long) (8 * MATLAB_HDR.SizeX);
+        break;
+      default:
+        ThrowReaderException(CoderError, "UnsupportedCellTypeInTheMatrix");
+    }
+
+    image->columns = MATLAB_HDR.SizeX;
+    image->rows = MATLAB_HDR.SizeY;
+    image->colors = 1l >> 8;
+    if (image->columns == 0 || image->rows == 0)
+      goto MATLAB_KO;
+
+    /*
+      If ping is true, then only set image size and colors without
+      reading any image data.
+    */
+    if (image_info->ping)
     {
       unsigned long temp = image->columns;
       image->columns = image->rows;
       image->rows = temp;
-      goto done_reading;
-    }
+      goto done_reading; //!!!!!! BAD  !!!!
+    }  
 
   /* ----- Load raster data ----- */
-  BImgBuff = (unsigned char *) AcquireMagickMemory(ldblk);    /* Ldblk was set in the check phase */
-  if (BImgBuff == NULL)
-    goto NoMemory;
+    BImgBuff = (unsigned char *) AcquireQuantumMemory(ldblk,sizeof(*BImgBuff));
+    if (BImgBuff == NULL)
+      ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
 
-  MinVal = 0;
-  MaxVal = 0;
-  if (CellType == miDOUBLE)        /* Find Min and Max Values for floats */
-  {
-    filepos = TellBlob(image);
-    for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
-    {      
-      ReadBlobDoublesXXX(image, ldblk, (double *) BImgBuff);      
-      dblrow = (double *) BImgBuff;
-      if (i == 0)
-      {
-        MinVal = MaxVal = *dblrow;
-      }
-      for (x = 0; x < (long) MATLAB_HDR.SizeX; x++)
-      {
-        if (MinVal > *dblrow)
-          MinVal = *dblrow;
-        if (MaxVal < *dblrow)
-          MaxVal = *dblrow;
-        dblrow++;
-      }
-    }
-    (void) SeekBlob(image, filepos, SEEK_SET);
-  }
-
-  /* Main loop for reading all scanlines */
-  if(z==1)
-  {  
-    for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
+    MinVal = 0;
+    MaxVal = 0;
+    if (CellType==miDOUBLE || CellType==miSINGLE)        /* Find Min and Max Values for floats */
     {
-      switch (CellType)
-      {
-        case miUINT8:	/* Byte order */
-          (void) ReadBlob(image, ldblk, (unsigned char *) BImgBuff);
-          InsertByteRow(BImgBuff, i, image,0);
-          break;
-        case miUINT16:	/* Word order */
-          if (MATLAB_HDR.EndianIndicator[0]=='I')
-            ReadBlobWordLSB(image, ldblk, (unsigned short *) BImgBuff);
-          else
-            ReadBlobWordMSB(image, ldblk, (unsigned short *) BImgBuff);
-          InsertWordRow(BImgBuff, i, image,0);
-          break;
-        case miDOUBLE:
-          ReadBlobDoublesXXX(image, ldblk, (double *) BImgBuff);          
-          InsertFloatRow((double *) BImgBuff, i, image, MinVal, MaxVal);
-          break;      
-      }
-    }
-  }
-  else
-   while(z>=1)
-   {
-   for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
-    {
-      switch (CellType)
-      {
-        case miUINT8:	/* Byte order */
-          (void) ReadBlob(image, ldblk, BImgBuff);
-          InsertByteRow(BImgBuff, i, image, z);
-          break;
-        case miUINT16: 	/* Word order */          
-          if (MATLAB_HDR.EndianIndicator[0]=='I')
-            ReadBlobWordLSB(image, ldblk, (unsigned short *) BImgBuff);
-          else
-            ReadBlobWordMSB(image, ldblk, (unsigned short *) BImgBuff);
-          InsertWordRow(BImgBuff, i, image, z);
-          break;
-        case miDOUBLE:
-          goto MATLAB_KO;
-          /* ReadBlobDoublesXXX(image, ldblk, (double *) BImgBuff);
-          InsertFloatRow((double *) BImgBuff, i, image, MinVal, MaxVal);
-          break; */
-      }
+      CalcMinMax(image, &MATLAB_HDR, CellType, ldblk, BImgBuff, &quantum_info.minimum, &quantum_info.maximum);
     }
 
-   z--;
-   } 
-
-  /* Read complex part of numbers here */
-  if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
-  {
-    if (CellType == miDOUBLE)        /* Find Min and Max Values for complex parts of floats */
+    /* Main loop for reading all scanlines */
+    if(z==1) z=0; /* read grey scanlines */
+		/* else read color scanlines */
+    do
     {
-      filepos = TellBlob(image);
-      for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
-      {        
-        ReadBlobDoublesXXX(image, ldblk, (double *) BImgBuff);        
-
-        dblrow = (double *) BImgBuff;
-        if (i == 0)
-        {
-          MinVal = MaxVal = *dblrow;
-        }
-        for (x = 0; x < (long) MATLAB_HDR.SizeX; x++)
-        {
-          if (MinVal > *dblrow)
-            MinVal = *dblrow;
-          if (MaxVal < *dblrow)
-            MaxVal = *dblrow;
-          dblrow++;
-        }
-      }
-      (void) SeekBlob(image, filepos, SEEK_SET);
-
       for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
       {
-        ReadBlobDoublesXXX(image, ldblk, (double *) BImgBuff);        
-        InsertComplexFloatRow((double *) BImgBuff, i, image, MinVal, MaxVal);
+        q=SetImagePixels(image,0,MATLAB_HDR.SizeY-i-1,image->columns,1);
+        if (q == (PixelPacket *)NULL) goto ExitLoop;
+        (void) ReadBlob(image, ldblk, (unsigned char *)BImgBuff);	  
+        (void) ExportQuantumPixels(image,&quantum_info,z2qtype[z],BImgBuff);
+        if (z<=1 &&			 // fix only during a last pass z==0 || z==1
+	        (CellType==miINT8 || CellType==miINT16 || CellType==miINT32 || CellType==miINT64))
+	  FixSignedValues(q,MATLAB_HDR.SizeX);
+        if (!SyncImagePixels(image)) goto ExitLoop;
       }
+    } while(z-- >= 2);
+ExitLoop:
+
+
+    /* Read complex part of numbers here */
+    if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
+    {        /* Find Min and Max Values for complex parts of floats */
+      CellType = ReadBlobXXXLong(image);    /* Additional object type */
+      i = ReadBlobXXXLong(image);           /* size of a complex part - toss away*/
+
+      if (CellType==miDOUBLE || CellType==miSINGLE)
+      {
+        CalcMinMax(image, &MATLAB_HDR, CellType, ldblk, BImgBuff, &MinVal, &MaxVal);      
+      }
+
+      if (CellType==miDOUBLE)
+        for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
+	{
+          ReadBlobDoublesXXX(image, ldblk, (double *)BImgBuff);
+          InsertComplexDoubleRow((double *)BImgBuff, i, image, MinVal, MaxVal);
+	}
+
+      if (CellType==miSINGLE)
+        for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
+	{
+          ReadBlobFloatsXXX(image, ldblk, (float *)BImgBuff);
+          InsertComplexFloatRow((float *)BImgBuff, i, image, MinVal, MaxVal);
+	}    
     }
+
+      /* Image is gray when no complex flag is set and 2D Matrix AGAIN!!! */
+      /*  Rotate image. */
+    rotated_image = RotateImage(image, 90.0, exception);
+    if (rotated_image != (Image *) NULL)
+    {
+        /* Remove page offsets added by RotateImage */
+      rotated_image->page.x=0;
+      rotated_image->page.y=0;
+
+      blob = rotated_image->blob;
+      rotated_image->blob = image->blob;
+      image->blob = blob;
+      AppendImageToList(&image,rotated_image);      
+      DeleteImageFromList(&image);      
+    }
+
+done_reading:
+
+      /* Allocate next image structure. */    
+    AllocateNextImage(image_info,image);   
+    if (image->next == (Image *) NULL) break;                
+    image=SyncNextImageInList(image);
+    image->columns=image->rows=0;
+    image->colors=0;    
+
+      /* row scan buffer is no longer needed */
+    BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
   }
 
 
-  /*  Rotate image. */
-  rotated_image = RotateImage(image, 90.0, exception);
-  if (rotated_image != (Image *) NULL)
-  {
-    DestroyImage(image);
-    image = FlopImage(rotated_image, exception);
-    if (image == NULL)
-      image = rotated_image;    /* Obtain something if flop operation fails */
-    else
-      DestroyImage(rotated_image);
-  }
-
-  done_reading:
-
   BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
   CloseBlob(image);
+
+
+  {
+    Image *p;    
+    long scene=0;
+    
+    /*
+      Rewind list, removing any empty images while rewinding.
+    */
+    p=image;
+    image=NULL;
+    while (p != (Image *) NULL)
+      {
+        Image *tmp=p;
+        if ((p->rows == 0) || (p->columns == 0)) {
+          p=p->previous;
+          DeleteImageFromList(&tmp);
+        } else {
+          image=p;
+          p=p->previous;
+        }
+      }
+    
+    /*
+      Fix scene numbers
+    */
+    for (p=image; p != (Image *) NULL; p=p->next)
+      p->scene=scene++;
+  }
+
+  if (logging) (void) LogMagickEvent(CoderEvent,GetMagickModule(),"return");
   return (image);
 }
 
@@ -856,10 +794,9 @@ static Image *ReadMATImage(const ImageInfo * image_info, ExceptionInfo * excepti
 */
 ModuleExport void RegisterMATImage(void)
 {
-  MagickInfo
-    *entry;
+  MagickInfo * entry;
 
-  entry=SetMagickInfo("MAT");
+  entry = SetMagickInfo("MAT");
   entry->decoder=(DecoderHandler *) ReadMATImage;
   entry->encoder=(EncoderHandler *) WriteMATImage;
   entry->seekable_stream=MagickTrue;
@@ -923,15 +860,18 @@ ModuleExport void UnregisterMATImage(void)
 static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
 {
   long y;
-  register long x;
-  register const PixelPacket *q;
-  MagickBooleanType status;
+  unsigned z;
+  const PixelPacket *q;
+  unsigned int status;
   int logging;
   unsigned long DataSize;
   char padding;
   char MATLAB_HDR[0x84];
   time_t current_time;
   const struct tm *t;
+  unsigned char *pixels;
+  int is_gray;
+  QuantumInfo quantum_info;
 
   current_time=time((time_t *) NULL);
   t=localtime(&current_time);
@@ -947,15 +887,24 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(MagickFalse);
+  image->depth=8;
+
+  pixels=(unsigned char *) AcquireQuantumMemory(image->rows,sizeof(*pixels));
+  if (pixels == (unsigned char *) NULL)
+    ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
+
+  is_gray = IsGrayImage(image,&image->exception);
+  z = is_gray ? 0 : 3;
 
   /*
     Store MAT header.
   */
-  DataSize = image->rows /*Y*/ * image->columns /*X*/ * 3 /*Z*/;
+  DataSize = image->rows /*Y*/ * image->columns /*X*/;
+  if(!is_gray) DataSize *= 3 /*Z*/;
   padding=((unsigned char)(DataSize-1) & 0x7) ^ 0x7;
 
-  memset(MATLAB_HDR,' ',124);
-  FormatMagickString(MATLAB_HDR,0x84,"MATLAB 5.0 MAT-file, Platform: %s, Created on: %s %s %2d %2d:%2d:%2d %d",
+  (void) memset(MATLAB_HDR,' ',MagickMin(sizeof(MATLAB_HDR),124));
+  FormatMagickString(MATLAB_HDR,MaxTextExtent,"MATLAB 5.0 MAT-file, Platform: %s, Created on: %s %s %2d %2d:%2d:%2d %d",
     OsDesc,
     DayOfWTab[t->tm_wday],
     MonthsTab[t->tm_mon],
@@ -968,63 +917,54 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
   MATLAB_HDR[0x7F]='M';
   MATLAB_HDR[0x80]=0xE;
   MATLAB_HDR[0x81]=0;  MATLAB_HDR[0x82]=0;   MATLAB_HDR[0x83]=0;
-  WriteBlob(image,sizeof(MATLAB_HDR),(unsigned char *) MATLAB_HDR);
+  (void) WriteBlob(image,sizeof(MATLAB_HDR),(unsigned char *) MATLAB_HDR);
 
-  WriteBlobLSBLong(image, DataSize + 56l + padding); /* 0x84 */
-  WriteBlobLSBLong(image, 0x6); /* 0x88 */
-  WriteBlobLSBLong(image, 0x8); /* 0x8C */
-  WriteBlobLSBLong(image, 0x6); /* 0x90 */  
-  WriteBlobLSBLong(image, 0);   
-  WriteBlobLSBLong(image, 0x5); /* 0x98 */  
-  WriteBlobLSBLong(image, 0xC); /* 0x9C */      
-  WriteBlobLSBLong(image, image->rows);    /* x: 0xA0 */  
-  WriteBlobLSBLong(image, image->columns); /* y: 0xA4 */  
-  WriteBlobLSBLong(image, 3);              /* z: 0xA8 */  
-  WriteBlobLSBLong(image, 0);
-  WriteBlobLSBShort(image, 1);  /* 0xB0 */  
-  WriteBlobLSBShort(image, 1);  /* 0xB2 */
-  WriteBlobLSBLong(image, 'M'); /* 0xB4 */
-  WriteBlobLSBLong(image, 0x2); /* 0xB8 */  
-  WriteBlobLSBLong(image, DataSize); /* 0xBC */
+  (void) WriteBlobLSBLong(image, DataSize + 56l + padding); /* 0x84 */
+  (void) WriteBlobLSBLong(image, 0x6); /* 0x88 */
+  (void) WriteBlobLSBLong(image, 0x8); /* 0x8C */
+  (void) WriteBlobLSBLong(image, 0x6); /* 0x90 */  
+  (void) WriteBlobLSBLong(image, 0);   
+  (void) WriteBlobLSBLong(image, 0x5); /* 0x98 */
+  (void) WriteBlobLSBLong(image, is_gray?0x8:0xC); /* 0x9C - DimFlag */
+  (void) WriteBlobLSBLong(image, image->rows);    /* x: 0xA0 */  
+  (void) WriteBlobLSBLong(image, image->columns); /* y: 0xA4 */  
+  if(!is_gray)
+  {
+    (void) WriteBlobLSBLong(image, 3); /* z: 0xA8 */  
+    (void) WriteBlobLSBLong(image, 0);
+  }
+  (void) WriteBlobLSBShort(image, 1);  /* 0xB0 */  
+  (void) WriteBlobLSBShort(image, 1);  /* 0xB2 */
+  (void) WriteBlobLSBLong(image, 'M'); /* 0xB4 */
+  (void) WriteBlobLSBLong(image, 0x2); /* 0xB8 */  
+  (void) WriteBlobLSBLong(image, DataSize); /* 0xBC */
 
   /*
     Store image data.
   */
-  for (y=0; y<(long)image->columns; y++)
   {
-    q=AcquireImagePixels(image,y-1,0,1,image->rows-1,&image->exception);    
-    for (x=0; x < (long) image->rows; x++)
+    GetQuantumInfo(image_info,&quantum_info);
+
+    do
     {
-      WriteBlobByte(image,ScaleQuantumToChar(q->red));
-      q++;
-    }
-  }
-  for (y=0; y<(long)image->columns; y++)
-  {
-    q=AcquireImagePixels(image,y-1,0,1,image->rows-1,&image->exception);
-    for (x=0; x < (long) image->rows; x++)
-    {
-      WriteBlobByte(image,ScaleQuantumToChar(q->green));
-      q++;
-    }
-  }
-  for (y=0; y<(long)image->columns; y++)
-  {
-    q=AcquireImagePixels(image,y-1,0,1,image->rows-1,&image->exception);
-    for (x=0; x < (long) image->rows; x++)
-    {
-      WriteBlobByte(image,ScaleQuantumToChar(q->blue));
-      q++;
-    }
+      for (y=0; y<(long)image->columns; y++)
+      {
+        q = AcquireImagePixels(image,y,0,1,image->rows,&image->exception);
+        (void) ImportQuantumPixels(image,&quantum_info,z2qtype[z],pixels);
+        (void) WriteBlob(image,image->rows,pixels);
+      }    
+    } while(z-- >= 2);
   }
 
-  while(padding-->0) WriteBlobByte(image,0);
+  while(padding-->0) (void) WriteBlobByte(image,0);
 
   status=MagickTrue;
 
   CloseBlob(image);
+  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+
   if (logging)
     (void)LogMagickEvent(CoderEvent,GetMagickModule(),"return MAT");
   
-  return(status);
+  return(status != 0 ? MagickTrue : MagickFalse);
 }
