@@ -71,42 +71,6 @@
 #include "bzlib.h"
 #endif
 
-/*
-  Define declarations.
-*/
-#define PopCharPixel(q,pixel) \
-{ \
-  *(q)++=(unsigned char) (pixel); \
-}
-#define PopLongPixel(q,pixel) \
-{ \
-  *(q)++=(unsigned char) ((pixel) >> 24); \
-  *(q)++=(unsigned char) ((pixel) >> 16); \
-  *(q)++=(unsigned char) ((pixel) >> 8); \
-  *(q)++=(unsigned char) (pixel); \
-}
-#define PopShortPixel(q,pixel) \
-{ \
-  *(q)++=(unsigned char) ((pixel) >> 8); \
-  *(q)++=(unsigned char) (pixel); \
-}
-#define PushCharPixel(pixel,p) \
-{ \
-  pixel=(unsigned char) (*(p)); \
-  (p)++; \
-}
-#define PushLongPixel(pixel,p) \
-{ \
-  pixel=(unsigned long) \
-    ((*(p) << 24) | (*((p)+1) << 16) | (*((p)+2) << 8) | *((p)+3)); \
-  (p)+=4; \
-}
-#define PushShortPixel(pixel,p) \
-{ \
-  pixel=(unsigned short) ((*(p) << 8) | *((p)+1)); \
-  (p)+=2; \
-}
-
 /*
   Forward declarations.
 */
@@ -138,7 +102,6 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsMIFF(const unsigned char *magick,const size_t length)
 {
@@ -181,13 +144,12 @@ static MagickBooleanType IsMIFF(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
 #if defined(HasBZLIB)
 static void *AcquireBZIPMemory(void *context,int items,int size)
 {
-  return((void *) AcquireMagickMemory((size_t) (items*size)));
+  return((void *) AcquireQuantumMemory((size_t) items,(size_t) size));
 }
 #endif
 
@@ -195,7 +157,7 @@ static void *AcquireBZIPMemory(void *context,int items,int size)
 static voidpf AcquireZIPMemory(voidpf context,unsigned int items,
   unsigned int size)
 {
-  return((voidpf) AcquireMagickMemory((size_t) (items*size)));
+  return((voidpf) AcquireQuantumMemory(items,size));
 }
 #endif
 
@@ -213,16 +175,47 @@ static inline size_t MagickMin(const size_t x,const size_t y)
   return(y);
 }
 
-static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
+static inline unsigned char PushCharPixel(const unsigned char **pixels)
+{
+  unsigned char
+    pixel;
+
+  pixel=(unsigned char) *(*pixels)++;
+  return(pixel);
+}
+
+static inline unsigned long PushLongPixel(const unsigned char **pixels)
+{
+  unsigned long
+    pixel;
+
+  pixel=(unsigned long) (*(*pixels)++ << 24);
+  pixel|=(unsigned long) (*(*pixels)++ << 16);
+  pixel|=(unsigned long) (*(*pixels)++ << 8);
+  pixel|=(unsigned long) (*(*pixels)++);
+  return(pixel);
+}
+
+static inline unsigned short PushShortPixel(const unsigned char **pixels)
+{
+  unsigned short
+    pixel;
+
+  pixel=(unsigned short) (*(*pixels)++ << 8);
+  pixel|=(unsigned short) (*(*pixels)++);
+  return(pixel);
+}
+
+static void PushRunlengthPacket(Image *image,const unsigned char *pixels,
   size_t *length,PixelPacket *pixel,IndexPacket *index)
 {
-  register const unsigned char
+  const unsigned char
     *p;
 
   p=pixels;
   if (image->storage_class == PseudoClass)
     {
-      *index=0;
+      *index=(IndexPacket) 0;
       switch (image->depth)
       {
         case 32:
@@ -258,7 +251,7 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
 
           if (image->matte != MagickFalse)
             {
-              PushCharPixel(quantum,p);
+              quantum=PushCharPixel(&p);
               pixel->opacity=ScaleCharToQuantum(quantum);
             }
           break;
@@ -270,7 +263,7 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
 
           if (image->matte != MagickFalse)
             {
-              PushShortPixel(quantum,p);
+              quantum=PushShortPixel(&p);
               pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
             }
           break;
@@ -282,7 +275,7 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
 
           if (image->matte != MagickFalse)
             {
-              PushLongPixel(quantum,p);
+              quantum=PushLongPixel(&p);
               pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
             }
           break;
@@ -301,20 +294,20 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
       unsigned char
         quantum;
 
-      PushCharPixel(quantum,p);
+      quantum=PushCharPixel(&p);
       pixel->red=ScaleCharToQuantum(quantum);
-      PushCharPixel(quantum,p);
+      quantum=PushCharPixel(&p);
       pixel->green=ScaleCharToQuantum(quantum);
-      PushCharPixel(quantum,p);
+      quantum=PushCharPixel(&p);
       pixel->blue=ScaleCharToQuantum(quantum);
       if (image->matte != MagickFalse)
         {
-          PushCharPixel(quantum,p);
+          quantum=PushCharPixel(&p);
           pixel->opacity=ScaleCharToQuantum(quantum);
         }
       if (image->colorspace == CMYKColorspace)
         {
-          PushCharPixel(quantum,p);
+          quantum=PushCharPixel(&p);
           *index=ScaleCharToQuantum(quantum);
         }
       break;
@@ -324,20 +317,20 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
       unsigned short
         quantum;
 
-      PushShortPixel(quantum,p);
+      quantum=PushShortPixel(&p);
       pixel->red=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      PushShortPixel(quantum,p);
+      quantum=PushShortPixel(&p);
       pixel->green=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      PushShortPixel(quantum,p);
+      quantum=PushShortPixel(&p);
       pixel->blue=(Quantum) (quantum >> (image->depth-QuantumDepth));
       if (image->matte != MagickFalse)
         {
-          PushShortPixel(quantum,p);
+          quantum=PushShortPixel(&p);
           pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
         }
       if (image->colorspace == CMYKColorspace)
         {
-          PushShortPixel(quantum,p);
+          quantum=PushShortPixel(&p);
           *index=(IndexPacket) (quantum >> (image->depth-QuantumDepth));
         }
       break;
@@ -347,20 +340,20 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
       unsigned long
         quantum;
 
-      PushLongPixel(quantum,p);
+      quantum=PushLongPixel(&p);
       pixel->red=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      PushLongPixel(quantum,p);
+      quantum=PushLongPixel(&p);
       pixel->green=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      PushLongPixel(quantum,p);
+      quantum=PushLongPixel(&p);
       pixel->blue=(Quantum) (quantum >> (image->depth-QuantumDepth));
       if (image->matte != MagickFalse)
         {
-          PushLongPixel(quantum,p);
+          quantum=PushLongPixel(&p);
           pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
         }
       if (image->colorspace == CMYKColorspace)
         {
-          PushLongPixel(quantum,p);
+          quantum=PushLongPixel(&p);
           *index=(IndexPacket) (quantum >> (image->depth-QuantumDepth));
         }
       break;
@@ -402,6 +395,9 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     keyword[MaxTextExtent],
     *options;
 
+  const unsigned char
+    *p;
+
   double
     version;
 
@@ -442,9 +438,6 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
   MagickStatusType
     flags;
 
-  register const unsigned char
-    *p;
-
   register IndexPacket
     *indexes;
 
@@ -512,6 +505,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     colors=0;
     image->depth=8UL;
     image->compression=NoCompression;
+    GetQuantumInfo(image_info,&quantum_info);
     while ((isgraph(c) != MagickFalse) && (c != (int) ':'))
     {
       register char
@@ -536,8 +530,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
               {
                 *p='\0';
                 length<<=1;
-                comment=(char *) ResizeMagickMemory(comment,
-                  (length+MaxTextExtent)*sizeof(*comment));
+                comment=(char *) ResizeQuantumMemory(comment,length+
+                  MaxTextExtent,sizeof(*comment));
                 if (comment == (char *) NULL)
                   break;
                 p=comment+strlen(comment);
@@ -584,8 +578,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     {
                       *p='\0';
                       length<<=1;
-                      options=(char *) ResizeMagickMemory(options,
-                        (length+MaxTextExtent)*sizeof(*options));
+                      options=(char *) ResizeQuantumMemory(options,length+
+                        MaxTextExtent,sizeof(*options));
                       if (options == (char *) NULL)
                         break;
                       p=options+strlen(options);
@@ -641,8 +635,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
               {
                 if (LocaleCompare(keyword,"class") == 0)
                   {
-                    image->storage_class=(ClassType)
-                      ParseMagickOption(MagickClassOptions,MagickFalse,options);
+                    image->storage_class=(ClassType) ParseMagickOption(
+                      MagickClassOptions,MagickFalse,options);
                     break;
                   }
                 if (LocaleCompare(keyword,"colors") == 0)
@@ -659,7 +653,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                 if (LocaleCompare(keyword,"compression") == 0)
                   {
                     image->compression=(CompressionType) ParseMagickOption(
-                      MagickCompressionOptions,MagickFalse,options);
+                      MagickCompressOptions,MagickFalse,options);
                     break;
                   }
                 if (LocaleCompare(keyword,"columns") == 0)
@@ -779,16 +773,6 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                       MagickOrientationOptions,MagickFalse,options);
                     break;
                   }
-                if (LocaleCompare(keyword,"origin") == 0)
-                  {
-                    char
-                      *geometry;
-
-                    geometry=GetPageGeometry(options);
-                    (void) ParseAbsoluteGeometry(geometry,&image->origin);
-                    geometry=DestroyString(geometry);
-                    break;
-                  }
                 (void) SetImageProperty(image,keyword,options);
                 break;
               }
@@ -830,6 +814,14 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->quality=(unsigned long) atol(options);
                     break;
                   }
+                if (LocaleCompare(keyword,"quantum-format") == 0)
+                  {
+                    quantum_info.format=(QuantumFormatType) ParseMagickOption(
+                      MagickQuantumFormatOptions,MagickFalse,options);
+                    if (quantum_info.format == FloatingPointQuantumFormat)
+                      quantum_info.scale=QuantumRange;
+                    break;
+                  }
                 (void) SetImageProperty(image,keyword,options);
                 break;
               }
@@ -888,6 +880,16 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                     image->ticks_per_second=atol(options);
                     break;
                   }
+                if (LocaleCompare(keyword,"tile-offset") == 0)
+                  {
+                    char
+                      *geometry;
+
+                    geometry=GetPageGeometry(options);
+                    (void) ParseAbsoluteGeometry(geometry,&image->tile_offset);
+                    geometry=DestroyString(geometry);
+                    break;
+                  }
                 (void) SetImageProperty(image,keyword,options);
                 break;
               }
@@ -971,8 +973,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                 Allocate more memory for the image directory.
               */
               length<<=1;
-              image->directory=(char *) ResizeMagickMemory(image->directory,
-                (length+MaxTextExtent)*sizeof(*image->directory));
+              image->directory=(char *) ResizeQuantumMemory(image->directory,
+                length+MaxTextExtent,sizeof(*image->directory));
               if (image->directory == (char *) NULL)
                 ThrowReaderException(CorruptImageError,"UnableToReadImageData");
               p=image->directory+strlen(image->directory);
@@ -1029,9 +1031,9 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
             /*
               Read image colormap from file.
             */
-            packet_size=(size_t) (3*image->depth/8);
-            colormap=(unsigned char *)
-              AcquireMagickMemory(packet_size*image->colors);
+            packet_size=(size_t) (3UL*image->depth/8UL);
+            colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+              packet_size*sizeof(*colormap));
             if (colormap == (unsigned char *) NULL)
               ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
             count=ReadBlob(image,packet_size*image->colors,colormap);
@@ -1048,11 +1050,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  PushCharPixel(pixel,p);
+                  pixel=PushCharPixel(&p);
                   image->colormap[i].red=ScaleCharToQuantum(pixel);
-                  PushCharPixel(pixel,p);
+                  pixel=PushCharPixel(&p);
                   image->colormap[i].green=ScaleCharToQuantum(pixel);
-                  PushCharPixel(pixel,p);
+                  pixel=PushCharPixel(&p);
                   image->colormap[i].blue=ScaleCharToQuantum(pixel);
                 }
                 break;
@@ -1064,11 +1066,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  PushShortPixel(pixel,p);
+                  pixel=PushShortPixel(&p);
                   image->colormap[i].red=ScaleShortToQuantum(pixel);
-                  PushShortPixel(pixel,p);
+                  pixel=PushShortPixel(&p);
                   image->colormap[i].green=ScaleShortToQuantum(pixel);
-                  PushShortPixel(pixel,p);
+                  pixel=PushShortPixel(&p);
                   image->colormap[i].blue=ScaleShortToQuantum(pixel);
                 }
                 break;
@@ -1080,11 +1082,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  PushLongPixel(pixel,p);
+                  pixel=PushLongPixel(&p);
                   image->colormap[i].red=ScaleLongToQuantum(pixel);
-                  PushLongPixel(pixel,p);
+                  pixel=PushLongPixel(&p);
                   image->colormap[i].green=ScaleLongToQuantum(pixel);
-                  PushLongPixel(pixel,p);
+                  pixel=PushLongPixel(&p);
                   image->colormap[i].blue=ScaleLongToQuantum(pixel);
                 }
                 break;
@@ -1099,6 +1101,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     /*
       Allocate image pixels.
     */
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     packet_size=(size_t) (image->depth/8);
     if (image->storage_class == DirectClass)
       packet_size=(size_t) (3*image->depth/8);
@@ -1108,11 +1115,12 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
       packet_size+=image->depth/8;
     if (image->compression == RLECompression)
       packet_size++;
-    length=packet_size*image->columns;
-    pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
-    length=MagickMax(BZipMaxExtent(packet_size*image->columns),
-      ZipMaxExtent(packet_size*image->columns));
-    compress_pixels=(unsigned char *) AcquireMagickMemory(length*
+    length=image->columns;
+    pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+      sizeof(*pixels));
+    length=MagickMax(BZipMaxExtent(packet_size*image->columns),ZipMaxExtent(
+      packet_size*image->columns));
+    compress_pixels=(unsigned char *) AcquireQuantumMemory(length,
       sizeof(*compress_pixels));
     if ((pixels == (unsigned char *) NULL) ||
         (compress_pixels == (unsigned char *) NULL))
@@ -1120,7 +1128,6 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     /*
       Read image pixels.
     */
-    GetQuantumInfo(image_info,&quantum_info);
     quantum_type=RGBQuantum;
     if (image->storage_class == PseudoClass)
       quantum_type=image->matte != MagickFalse ? IndexAlphaQuantum :
@@ -1130,7 +1137,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         quantum_type=image->matte != MagickFalse ? CMYKAQuantum : CMYKQuantum;
       else
         quantum_type=image->matte != MagickFalse ? RGBAQuantum : RGBQuantum;
-    index=0;
+    index=(IndexPacket) 0;
     length=0;
     for (y=0; y < (long) image->rows; y++)
     {
@@ -1164,8 +1171,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                 length=(size_t) ZipMaxExtent(packet_size*image->columns);
                 if (version != 0)
                   length=(size_t) ReadBlobMSBLong(image);
-                zip_info.avail_in=(unsigned int)
-                  ReadBlob(image,length,zip_info.next_in);
+                zip_info.avail_in=(unsigned int) ReadBlob(image,length,
+                  zip_info.next_in);
               }
             if (inflate(&zip_info,Z_SYNC_FLUSH) == Z_STREAM_END)
               break;
@@ -1212,8 +1219,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                 length=(size_t) BZipMaxExtent(packet_size*image->columns);
                 if (version != 0)
                   length=(size_t) ReadBlobMSBLong(image);
-                bzip_info.avail_in=(unsigned int)
-                  ReadBlob(image,length,(unsigned char *) bzip_info.next_in);
+                bzip_info.avail_in=(unsigned int) ReadBlob(image,length,
+                  (unsigned char *) bzip_info.next_in);
               }
             if (BZ2_bzDecompress(&bzip_info) == BZ_STREAM_END)
               break;
@@ -1241,15 +1248,15 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           if (y == 0)
             {
               (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
-              pixel.opacity=TransparentOpacity;
-              index=0;
+              pixel.opacity=(Quantum) TransparentOpacity;
+              index=(IndexPacket) 0;
             }
           for (x=0; x < (long) image->columns; x++)
           {
             if (length == 0)
               {
-                p=ReadBlobStream(image,packet_size,pixels,&count);
-                PushRunlengthPacket(image,p,&length,&pixel,&index);
+                count=ReadBlob(image,packet_size,pixels);
+                PushRunlengthPacket(image,pixels,&length,&pixel,&index);
               }
             length--;
             if ((image->storage_class == PseudoClass) ||
@@ -1261,8 +1268,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         }
         default:
         {
-          p=ReadBlobStream(image,packet_size*image->columns,pixels,&count);
-          status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
+          count=ReadBlob(image,packet_size*image->columns,pixels);
+          status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
           break;
         }
       }
@@ -1421,15 +1428,34 @@ ModuleExport void UnregisterMIFFImage(void)
 %
 */
 
-static inline size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
+static inline void PopCharPixel(const unsigned char pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static inline void PopShortPixel(const unsigned short pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) ((pixel) >> 8);
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static inline void PopLongPixel(const unsigned long pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) ((pixel) >> 24);
+  *(*pixels)++=(unsigned char) ((pixel) >> 16);
+  *(*pixels)++=(unsigned char) ((pixel) >> 8);
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
   size_t length,PixelPacket pixel,IndexPacket index)
 {
-  register unsigned char
+  unsigned char
     *q;
 
-  unsigned long
-    value;
-
   q=pixels;
   if (image->storage_class != DirectClass)
     {
@@ -1455,28 +1481,37 @@ static inline size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
       {
         case 32:
         {
+          unsigned long
+            value;
+
           if (image->matte != MagickFalse)
             {
               value=ScaleQuantumToLong(pixel.opacity);
-              PopLongPixel(q,value);
+              PopLongPixel(value,&q);
             }
           break;
         }
         case 16:
         {
+          unsigned short
+            value;
+
           if (image->matte != MagickFalse)
             {
               value=ScaleQuantumToShort(pixel.opacity);
-              PopShortPixel(q,value);
+              PopShortPixel(value,&q);
             }
           break;
         }
         case 8:
         {
+          unsigned char
+            value;
+
           if (image->matte != MagickFalse)
             {
-              value=(unsigned long) ScaleQuantumToChar(pixel.opacity);
-              PopCharPixel(q,value);
+              value=(unsigned char) ScaleQuantumToChar(pixel.opacity);
+              PopCharPixel(value,&q);
             }
           break;
         }
@@ -1491,61 +1526,70 @@ static inline size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
   {
     case 32:
     {
+      unsigned long
+        value;
+
       value=ScaleQuantumToLong(pixel.red);
-      PopLongPixel(q,value);
+      PopLongPixel(value,&q);
       value=ScaleQuantumToLong(pixel.green);
-      PopLongPixel(q,value);
+      PopLongPixel(value,&q);
       value=ScaleQuantumToLong(pixel.blue);
-      PopLongPixel(q,value);
+      PopLongPixel(value,&q);
       if (image->matte != MagickFalse)
         {
           value=ScaleQuantumToLong(pixel.opacity);
-          PopLongPixel(q,value);
+          PopLongPixel(value,&q);
         }
       if (image->colorspace == CMYKColorspace)
         {
           value=ScaleQuantumToLong(index);
-          PopLongPixel(q,value);
+          PopLongPixel(value,&q);
         }
       break;
     }
     case 16:
     {
+      unsigned short
+        value;
+
       value=ScaleQuantumToShort(pixel.red);
-      PopShortPixel(q,value);
+      PopShortPixel(value,&q);
       value=ScaleQuantumToShort(pixel.green);
-      PopShortPixel(q,value);
+      PopShortPixel(value,&q);
       value=ScaleQuantumToShort(pixel.blue);
-      PopShortPixel(q,value);
+      PopShortPixel(value,&q);
       if (image->matte != MagickFalse)
         {
           value=ScaleQuantumToShort(pixel.opacity);
-          PopShortPixel(q,value);
+          PopShortPixel(value,&q);
         }
       if (image->colorspace == CMYKColorspace)
         {
           value=ScaleQuantumToShort(index);
-          PopShortPixel(q,value);
+          PopShortPixel(value,&q);
         }
       break;
     }
     case 8:
     {
-      value=(unsigned long) ScaleQuantumToChar(pixel.red);
-      PopCharPixel(q,value);
-      value=(unsigned long) ScaleQuantumToChar(pixel.green);
-      PopCharPixel(q,value);
-      value=(unsigned long) ScaleQuantumToChar(pixel.blue);
-      PopCharPixel(q,value);
+      unsigned char
+        value;
+
+      value=(unsigned char) ScaleQuantumToChar(pixel.red);
+      PopCharPixel(value,&q);
+      value=(unsigned char) ScaleQuantumToChar(pixel.green);
+      PopCharPixel(value,&q);
+      value=(unsigned char) ScaleQuantumToChar(pixel.blue);
+      PopCharPixel(value,&q);
       if (image->matte != MagickFalse)
         {
-          value=(unsigned long) ScaleQuantumToChar(pixel.opacity);
-          PopCharPixel(q,value);
+          value=(unsigned char) ScaleQuantumToChar(pixel.opacity);
+          PopCharPixel(value,&q);
         }
       if (image->colorspace == CMYKColorspace)
         {
-          value=(unsigned long) ScaleQuantumToChar(index);
-          PopCharPixel(q,value);
+          value=(unsigned char) ScaleQuantumToChar(index);
+          PopCharPixel(value,&q);
         }
       break;
     }
@@ -1609,16 +1653,14 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     i,
     x;
 
-  register unsigned char
-    *q;
-
   size_t
     length,
     packet_size;
 
   unsigned char
     *compress_pixels,
-    *pixels;
+    *pixels,
+    *q;
 
 #if defined(HasZLIB)
   z_stream
@@ -1644,7 +1686,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     /*
       Allocate image pixels.
     */
-    image->depth=GetImageQuantumDepth(image,MagickTrue);
+    image->depth=image->depth <= 8 ? 8UL : image->depth <= 16 ? 16UL : 32UL;
     if ((image->storage_class == PseudoClass) &&
         (image->colors > (1UL << image->depth)))
       (void) SetImageStorageClass(image,DirectClass);
@@ -1671,14 +1713,15 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
       packet_size+=image->depth/8;
     if (compression == RLECompression)
       packet_size+=image->depth/8;
-    length=packet_size*image->columns;
-    pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
-    length=MagickMax(BZipMaxExtent(packet_size*image->columns),
-      ZipMaxExtent(packet_size*image->columns));
+    length=image->columns;
+    pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+      sizeof(*pixels));
+    length=MagickMax(BZipMaxExtent(packet_size*image->columns),ZipMaxExtent(
+      packet_size*image->columns));
     if ((compression == BZipCompression) || (compression == ZipCompression))
       if (length != (size_t) ((unsigned int) length))
         compression=NoCompression;
-    compress_pixels=(unsigned char *) AcquireMagickMemory(length*
+    compress_pixels=(unsigned char *) AcquireQuantumMemory(length,
       sizeof(*compress_pixels));
     if ((pixels == (unsigned char *) NULL) ||
         (compress_pixels == (unsigned char *) NULL))
@@ -1705,9 +1748,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     if (image->compression != UndefinedCompression)
       {
         (void) FormatMagickString(buffer,MaxTextExtent,
-          "compression=%s  quality=%lu\n",
-          MagickOptionToMnemonic(MagickCompressionOptions,image->compression),
-          image->quality);
+          "compression=%s  quality=%lu\n",MagickOptionToMnemonic(
+          MagickCompressOptions,image->compression),image->quality);
         (void) WriteBlobString(image,buffer);
       }
     if (image->units != UndefinedResolution)
@@ -1735,10 +1777,10 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             image->page.x,image->page.y);
           (void) WriteBlobString(image,buffer);
         }
-    if ((image->origin.x != 0) || (image->origin.y != 0))
+    if ((image->tile_offset.x != 0) || (image->tile_offset.y != 0))
       {
-        (void) FormatMagickString(buffer,MaxTextExtent,"origin=%+ld%+ld\n",
-          image->origin.x,image->origin.y);
+        (void) FormatMagickString(buffer,MaxTextExtent,"tile-offset=%+ld%+ld\n",
+          image->tile_offset.x,image->tile_offset.y);
         (void) WriteBlobString(image,buffer);
       }
     if ((GetNextImageInList(image) != (Image *) NULL) ||
@@ -1844,7 +1886,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           if (profile != (StringInfo *) NULL)
             {
               (void) FormatMagickString(buffer,MaxTextExtent,
-                "profile-%s=%lu\n",name,(unsigned long) GetStringInfoLength(profile));
+                "profile-%s=%lu\n",name,(unsigned long)
+                GetStringInfoLength(profile));
               (void) WriteBlobString(image,buffer);
             }
           name=GetNextImageProfile(image);
@@ -1856,6 +1899,12 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           image->montage);
         (void) WriteBlobString(image,buffer);
       }
+    GetQuantumInfo(image_info,&quantum_info);
+    if (quantum_info.format == FloatingPointQuantumFormat)
+      {
+        (void) WriteBlobString(image,"quantum-format=floating-point\n");
+        quantum_info.scale=1.0/QuantumRange;
+      }
     ResetImagePropertyIterator(image);
     property=GetNextImageProperty(image);
     while (property != (const char *) NULL)
@@ -1907,30 +1956,26 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         while (name != (const char *) NULL)
         {
           profile=GetImageProfile(image,name);
-          (void) WriteBlob(image,GetStringInfoLength(profile),GetStringInfoDatum(profile));
+          (void) WriteBlob(image,GetStringInfoLength(profile),
+            GetStringInfoDatum(profile));
           name=GetNextImageProfile(image);
         }
       }
     if (image->storage_class == PseudoClass)
       {
-        register unsigned char
-          *q;
-
         size_t
           packet_size;
 
         unsigned char
-          *colormap;
-
-        unsigned long
-          pixel;
+          *colormap,
+          *q;
 
         /*
           Allocate colormap.
         */
         packet_size=(size_t) (3*image->depth/8);
-        colormap=(unsigned char *)
-          AcquireMagickMemory(packet_size*image->colors*sizeof(*colormap));
+        colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+          packet_size*sizeof(*colormap));
         if (colormap == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         /*
@@ -1945,33 +1990,42 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
               ThrowWriterException(CorruptImageError,"ImageDepthNotSupported");
             case 32:
             {
+              register unsigned long
+                pixel;
+
               pixel=ScaleQuantumToLong(image->colormap[i].red);
-              PopLongPixel(q,pixel);
+              PopLongPixel(pixel,&q);
               pixel=ScaleQuantumToLong(image->colormap[i].green);
-              PopLongPixel(q,pixel);
+              PopLongPixel(pixel,&q);
               pixel=ScaleQuantumToLong(image->colormap[i].blue);
-              PopLongPixel(q,pixel);
+              PopLongPixel(pixel,&q);
               break;
             }
             case 16:
             {
+              register unsigned short
+                pixel;
+
               pixel=ScaleQuantumToShort(image->colormap[i].red);
-              PopShortPixel(q,pixel);
+              PopShortPixel(pixel,&q);
               pixel=ScaleQuantumToShort(image->colormap[i].green);
-              PopShortPixel(q,pixel);
+              PopShortPixel(pixel,&q);
               pixel=ScaleQuantumToShort(image->colormap[i].blue);
-              PopShortPixel(q,pixel);
+              PopShortPixel(pixel,&q);
               break;
             }
             case 8:
             {
-              pixel=(unsigned long) ScaleQuantumToChar(image->colormap[i].red);
-              PopCharPixel(q,pixel);
-              pixel=(unsigned long)
-                ScaleQuantumToChar(image->colormap[i].green);
-              PopCharPixel(q,pixel);
-              pixel=(unsigned long) ScaleQuantumToChar(image->colormap[i].blue);
-              PopCharPixel(q,pixel);
+              register unsigned char
+                pixel;
+
+              pixel=(unsigned char) ScaleQuantumToChar(image->colormap[i].red);
+              PopCharPixel(pixel,&q);
+              pixel=(unsigned char) ScaleQuantumToChar(
+                image->colormap[i].green);
+              PopCharPixel(pixel,&q);
+              pixel=(unsigned char) ScaleQuantumToChar(image->colormap[i].blue);
+              PopCharPixel(pixel,&q);
               break;
             }
           }
@@ -1982,7 +2036,6 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     /*
       Write image pixels to file.
     */
-    GetQuantumInfo(image_info,&quantum_info);
     quantum_type=RGBQuantum;
     if (image->storage_class == PseudoClass)
       quantum_type=image->matte != MagickFalse ? IndexAlphaQuantum :
@@ -2012,7 +2065,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
               zip_info.zfree=RelinquishZIPMemory;
               zip_info.opaque=(voidpf) NULL;
               code=deflateInit(&zip_info,(int) (image->quality ==
-                UndefinedCompressionQuality ? 7 : MagickMin(image->quality/10,9)));
+                UndefinedCompressionQuality ? 7 : MagickMin(image->quality/10,
+                9)));
               if (code >= 0)
                 status=MagickTrue;
             }
@@ -2064,7 +2118,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
               bzip_info.bzfree=RelinquishBZIPMemory;
               bzip_info.opaque=(void *) NULL;
               code=BZ2_bzCompressInit(&bzip_info,(int) (image->quality ==
-                UndefinedCompressionQuality ? 7 : MagickMin(image->quality/10,9)),
+                UndefinedCompressionQuality ? 7 : MagickMin(image->quality/10,
+                9)),
                 (int) image_info->verbose,0);
               if (code >= 0)
                 status=MagickTrue;
@@ -2075,8 +2130,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           do
           {
             bzip_info.next_out=(char *) compress_pixels;
-            bzip_info.avail_out=(unsigned int)
-              BZipMaxExtent(packet_size*image->columns);
+            bzip_info.avail_out=(unsigned int) BZipMaxExtent(packet_size*
+              image->columns);
             code=BZ2_bzCompress(&bzip_info,BZ_FLUSH);
             if (code >= 0)
               status=MagickTrue;
@@ -2113,7 +2168,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         case RLECompression:
         {
           pixel=(*p);
-          index=0;
+          index=(IndexPacket) 0;
           if (indexes != (IndexPacket *) NULL)
             index=(*indexes);
           length=255;
