@@ -88,7 +88,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadMONOImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -138,10 +137,16 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
       return((Image *) NULL);
     }
   for (i=0; i < image->offset; i++)
-    (void) ReadBlobByte(image);
+    if (ReadBlobByte(image) == EOF)
+      {
+        ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
+          image->filename);
+        break;
+      }
   /*
     Initialize image colormap.
   */
+  image->depth=1;
   if (AllocateImageColormap(image,2) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->ping != MagickFalse)
@@ -152,6 +157,11 @@ static Image *ReadMONOImage(const ImageInfo *image_info,
   /*
     Convert bi-level image to pixel packets.
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   for (y=0; y < (long) image->rows; y++)
   {
     q=SetImagePixels(image,0,y,image->columns,1);
@@ -226,8 +236,7 @@ ModuleExport void RegisterMONOImage(void)
   entry->raw=MagickTrue;
   entry->endian_support=MagickTrue;
   entry->adjoin=MagickFalse;
-  entry->description=ConstantString(
-    "Bi-level bitmap in least-significant-byte first order");
+  entry->description=ConstantString("Raw bi-level bitmap");
   entry->module=ConstantString("MONO");
   (void) RegisterMagickInfo(entry);
 }
@@ -271,7 +280,8 @@ ModuleExport void UnregisterMONOImage(void)
 %
 %  The format of the WriteMONOImage method is:
 %
-%      MagickBooleanType WriteMONOImage(const ImageInfo *image_info,Image *image)
+%      MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
+%        Image *image)
 %
 %  A description of each parameter follows.
 %
@@ -279,7 +289,6 @@ ModuleExport void UnregisterMONOImage(void)
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteMONOImage(const ImageInfo *image_info,
   Image *image)
