@@ -278,8 +278,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
               {
                 *p='\0';
                 length<<=1;
-                comment=(char *) ResizeMagickMemory(comment,
-                  (length+MaxTextExtent)*sizeof(*comment));
+                comment=(char *) ResizeQuantumMemory(comment,length+
+                  MaxTextExtent,sizeof(*comment));
                 if (comment == (char *) NULL)
                   break;
                 p=comment+strlen(comment);
@@ -326,8 +326,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                     {
                       *p='\0';
                       length<<=1;
-                      options=(char *) ResizeMagickMemory(options,
-                        (length+MaxTextExtent)*sizeof(*options));
+                      options=(char *) ResizeQuantumMemory(options,length+
+                        MaxTextExtent,sizeof(*options));
                       if (options == (char *) NULL)
                         break;
                       p=options+strlen(options);
@@ -401,7 +401,7 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 if (LocaleCompare(keyword,"compression") == 0)
                   {
                     image->compression=(CompressionType) ParseMagickOption(
-                      MagickCompressionOptions,MagickFalse,options);
+                      MagickCompressOptions,MagickFalse,options);
                     break;
                   }
                 if (LocaleCompare(keyword,"columns") == 0)
@@ -719,8 +719,8 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 Allocate more memory for the image directory.
               */
               length<<=1;
-              image->directory=(char *) ResizeMagickMemory(image->directory,
-                (length+MaxTextExtent)*sizeof(*image->directory));
+              image->directory=(char *) ResizeQuantumMemory(image->directory,
+                length+MaxTextExtent,sizeof(*image->directory));
               if (image->directory == (char *) NULL)
                 ThrowReaderException(CorruptImageError,"UnableToReadImageData");
               p=image->directory+strlen(image->directory);
@@ -777,9 +777,9 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
             /*
               Read image colormap from file.
             */
-            packet_size=(size_t) (3*depth/8);
-            colormap=(unsigned char *)
-              AcquireMagickMemory(packet_size*image->colors);
+            packet_size=(size_t) (3UL*depth/8UL);
+            colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+              packet_size*sizeof(*colormap));
             if (colormap == (unsigned char *) NULL)
               ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
             count=ReadBlob(image,packet_size*image->colors,colormap);
@@ -853,6 +853,11 @@ static Image *ReadMPCImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     /*
       Attach persistent pixel cache.
     */
@@ -922,6 +927,7 @@ ModuleExport void RegisterMPCImage(void)
   entry=SetMagickInfo("CACHE");
   entry->description=ConstantString("Magick Persistent Cache image format");
   entry->module=ConstantString("CACHE");
+  entry->stealth=MagickTrue;
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("MPC");
   entry->decoder=(DecoderHandler *) ReadMPCImage;
@@ -1081,7 +1087,7 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
       {
         (void) FormatMagickString(buffer,MaxTextExtent,
           "compression=%s  quality=%lu\n",
-          MagickOptionToMnemonic(MagickCompressionOptions,image->compression),
+          MagickOptionToMnemonic(MagickCompressOptions,image->compression),
           image->quality);
         (void) WriteBlobString(image,buffer);
       }
@@ -1298,9 +1304,9 @@ static MagickBooleanType WriteMPCImage(const ImageInfo *image_info,Image *image)
         /*
           Allocate colormap.
         */
-        packet_size=(size_t) (3*depth/8);
-        colormap=(unsigned char *)
-          AcquireMagickMemory(packet_size*image->colors*sizeof(*colormap));
+        packet_size=(size_t) (3UL*depth/8UL);
+        colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+          packet_size*sizeof(*colormap));
         if (colormap == (unsigned char *) NULL)
           return(MagickFalse);
         /*
