@@ -10,7 +10,7 @@
 %                        M   M  P      EEEEE   GGGG                           %
 %                                                                             %
 %                                                                             %
-%                          Write MPEG Image Format.                           %
+%                       Read/Write MPEG Image Format.                         %
 %                                                                             %
 %                              Software Design                                %
 %                                John Cristy                                  %
@@ -91,7 +91,6 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsMPEG(const unsigned char *magick,const size_t length)
 {
@@ -115,9 +114,7 @@ static MagickBooleanType IsMPEG(const unsigned char *magick,const size_t length)
 %
 %  ReadMPEGImage() reads an binary file in the MPEG video stream format
 %  and returns it.  It allocates the memory necessary for the new Image
-%  structure and returns a pointer to the new image.  This method differs from
-%  the other decoder methods in that only the Photoshop resource (MPEG)
-%  information is useful in the returned image.
+%  structure and returns a pointer to the new image.
 %
 %  The format of the ReadMPEGImage method is:
 %
@@ -130,7 +127,6 @@ static MagickBooleanType IsMPEG(const unsigned char *magick,const size_t length)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadMPEGImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -180,8 +176,8 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
   images=NewImageList();
   for (i=(long) read_info->scene; ; i++)
   {
-    (void) FormatMagickString(read_info->filename,MaxTextExtent,
-      "%s%ld.ppm",read_info->unique,i);
+    (void) FormatMagickString(read_info->filename,MaxTextExtent,"%s%ld.ppm",
+      read_info->unique,i);
     if (IsAccessible(read_info->filename) == MagickFalse)
       break;
     image=ReadImage(read_info,exception);
@@ -199,11 +195,11 @@ static Image *ReadMPEGImage(const ImageInfo *image_info,
   */
   for (i=0; ; i++)
   {
-    (void) FormatMagickString(read_info->filename,MaxTextExtent,
-      "%s%ld.ppm",read_info->unique,i);
+    (void) FormatMagickString(read_info->filename,MaxTextExtent,"%s%ld.ppm",
+      read_info->unique,i);
     if (IsAccessible(read_info->filename) == MagickFalse)
       break;
-    (void) remove(read_info->filename);
+    (void) RelinquishUniqueFileResource(read_info->filename);
   }
   read_info=DestroyImageInfo(read_info);
   return(images);
@@ -629,15 +625,15 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     {
       if (coalesce_image != image)
         coalesce_image=DestroyImage(coalesce_image);
-      (void) remove(basename);
+      (void) RelinquishUniqueFileResource(basename);
       if (image->quality != UndefinedCompressionQuality)
         {
           (void) FormatMagickString(filename,MaxTextExtent,"%s.iqm",
             basename);
-          (void) remove(filename);
+          (void) RelinquishUniqueFileResource(filename);
           (void) FormatMagickString(filename,MaxTextExtent,"%s.niq",
             basename);
-          (void) remove(filename);
+          (void) RelinquishUniqueFileResource(filename);
         }
       ThrowWriterException(CoderError,"UnableToWriteMPEGParameters");
     }
@@ -727,17 +723,17 @@ static MagickBooleanType WriteMPEGImage(const ImageInfo *image_info,
     {
       (void) FormatMagickString(p->filename,MaxTextExtent,"%s.%lu.yuv",
         basename,count++);
-      (void) remove(p->filename);
+      (void) RelinquishUniqueFileResource(p->filename);
     }
     (void) CopyMagickString(p->filename,image_info->filename,MaxTextExtent);
   }
   (void) RelinquishUniqueFileResource(basename);
   (void) FormatMagickString(filename,MaxTextExtent,"%s.iqm",basename);
-  (void) remove(filename);
+  (void) RelinquishUniqueFileResource(filename);
   (void) FormatMagickString(filename,MaxTextExtent,"%s.niq",basename);
-  (void) remove(filename);
+  (void) RelinquishUniqueFileResource(filename);
   (void) FormatMagickString(filename,MaxTextExtent,"%s.log",basename);
-  (void) remove(filename);
+  (void) RelinquishUniqueFileResource(filename);
   if (coalesce_image != image)
     coalesce_image=DestroyImage(coalesce_image);
   if (image->debug != MagickFalse)
