@@ -158,7 +158,13 @@ static Image *ReadMTVImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Convert MTV raster image to pixel packets.
     */
-    pixels=(unsigned char *) AcquireMagickMemory((size_t) (3*image->columns));
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
+    pixels=(unsigned char *) AcquireQuantumMemory((size_t) image->columns,
+      3UL*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     for (y=0; y < (long) image->rows; y++)
@@ -362,8 +368,8 @@ static MagickBooleanType WriteMTVImage(const ImageInfo *image_info,Image *image)
     */
     if (image_info->colorspace == UndefinedColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
-    pixels=(unsigned char *)
-      AcquireMagickMemory((size_t) image->columns*sizeof(PixelPacket));
+    pixels=(unsigned char *) AcquireQuantumMemory((size_t) image->columns,
+      3UL*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
