@@ -161,6 +161,11 @@ static Image *ReadOTBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Convert bi-level image to pixel packets.
   */
