@@ -104,8 +104,6 @@ static MagickBooleanType
 %    o chroma2: The address of a character buffer that contains the
 %      chrominance information.
 %
-%
-%
 */
 static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   unsigned char *chroma1,unsigned char *chroma2)
@@ -190,7 +188,7 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   assert(luma != (unsigned char *) NULL);
   assert(chroma1 != (unsigned char *) NULL);
   assert(chroma2 != (unsigned char *) NULL);
-  buffer=(unsigned char *) AcquireMagickMemory(0x800);
+  buffer=(unsigned char *) AcquireQuantumMemory(0x800,sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
@@ -201,7 +199,8 @@ static MagickBooleanType DecodeImage(Image *image,unsigned char *luma,
   {
     PCDGetBits(8);
     length=(sum & 0xff)+1;
-    pcd_table[i]=(PCDTable *) AcquireMagickMemory(length*sizeof(**pcd_table));
+    pcd_table[i]=(PCDTable *) AcquireQuantumMemory(length,
+      sizeof(*pcd_table[i]));
     if (pcd_table[i] == (PCDTable *) NULL)
       {
         buffer=(unsigned char *) RelinquishMagickMemory(buffer);
@@ -559,7 +558,7 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Determine if this is a PCD file.
   */
-  header=(unsigned char *) AcquireMagickMemory(3*0x800);
+  header=(unsigned char *) AcquireQuantumMemory(0x800,3UL*sizeof(*header));
   if (header == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   count=ReadBlob(image,3*0x800,header);
@@ -612,12 +611,20 @@ static Image *ReadPCDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Allocate luma and chroma memory.
   */
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   number_pixels=(MagickSizeType) image->columns*image->rows;
   if (number_pixels != (size_t) number_pixels)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-  chroma1=(unsigned char *) AcquireMagickMemory(image->columns*image->rows+1);
-  chroma2=(unsigned char *) AcquireMagickMemory(image->columns*image->rows+1);
-  luma=(unsigned char *) AcquireMagickMemory(image->columns*image->rows+1);
+  chroma1=(unsigned char *) AcquireQuantumMemory(image->columns+1UL,image->rows*
+    sizeof(*chroma1));
+  chroma2=(unsigned char *) AcquireQuantumMemory(image->columns+1UL,image->rows*
+    sizeof(*chroma2));
+  luma=(unsigned char *) AcquireQuantumMemory(image->columns+1UL,image->rows*
+    sizeof(*luma));
   if ((chroma1 == (unsigned char *) NULL) ||
       (chroma2 == (unsigned char *) NULL) || (luma == (unsigned char *) NULL))
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
