@@ -593,8 +593,8 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
       /*
         Allocate pixel buffers.
       */
-      pixels=(unsigned char *)
-        AcquireMagickMemory(3*image->columns*sizeof(unsigned char));
+      pixels=(unsigned char *) AcquireQuantumMemory(image->columns,
+        3UL*sizeof(*pixels));
       if (pixels == (unsigned char *) NULL)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
       /*
