@@ -299,7 +299,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       magic=ReadBlobLSBLong(image);
       if (magic != 987654321)
         ThrowReaderException(CorruptImageError,"ImproperImageHeader");
-      page_table=(MagickOffsetType *) AcquireMagickMemory(1024*
+      page_table=(MagickOffsetType *) AcquireQuantumMemory(1024UL,
         sizeof(*page_table));
       if (page_table == (MagickOffsetType *) NULL)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -349,8 +349,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->x_resolution=(double) pcx_info.horizontal_resolution;
     image->y_resolution=(double) pcx_info.vertical_resolution;
     image->colors=16;
-    pcx_colormap=(unsigned char *) AcquireMagickMemory(3*256*
-      sizeof(*pcx_colormap));
+    pcx_colormap=(unsigned char *) AcquireQuantumMemory(256UL,
+      3*sizeof(*pcx_colormap));
     if (pcx_colormap == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     count=ReadBlob(image,3*image->colors,pcx_colormap);
@@ -382,12 +382,17 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Read image data.
     */
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     pcx_packets=(unsigned long) image->rows*pcx_info.bytes_per_line*
       pcx_info.planes;
-    pcx_pixels=(unsigned char *) AcquireMagickMemory(pcx_packets*
+    pcx_pixels=(unsigned char *) AcquireQuantumMemory(pcx_packets,
       sizeof(*pcx_pixels));
-    scanline=(unsigned char *) AcquireMagickMemory(MagickMax(image->columns,
-      pcx_info.bytes_per_line)*MagickMax(8,pcx_info.planes)*sizeof(*scanline));
+    scanline=(unsigned char *) AcquireQuantumMemory(MagickMax(image->columns,
+      pcx_info.bytes_per_line),MagickMax(8,pcx_info.planes)*sizeof(*scanline));
     if ((pcx_pixels == (unsigned char *) NULL) ||
         (scanline == (unsigned char *) NULL))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -882,8 +887,8 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
         Write the DCX page table.
       */
       (void) WriteBlobLSBLong(image,0x3ADE68B1L);
-      page_table=(MagickOffsetType *)
-        AcquireMagickMemory(1024*sizeof(*page_table));
+      page_table=(MagickOffsetType *) AcquireQuantumMemory(1024UL,
+        sizeof(*page_table));
       if (page_table == (MagickOffsetType *) NULL)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
       for (scene=0; scene < 1024; scene++)
@@ -955,8 +960,8 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
     /*
       Dump colormap to file.
     */
-    pcx_colormap=(unsigned char *)
-      AcquireMagickMemory(3*256*sizeof(*pcx_colormap));
+    pcx_colormap=(unsigned char *) AcquireQuantumMemory(256UL,
+      3*sizeof(*pcx_colormap));
     if (pcx_colormap == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     (void) memset(pcx_colormap,0,3*256*sizeof(*pcx_colormap));
@@ -975,9 +980,9 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobLSBShort(image,pcx_info.palette_info);
     for (i=0; i < 58; i++)
       (void) WriteBlobByte(image,'\0');
-    length=(size_t) pcx_info.bytes_per_line*pcx_info.planes;
-    pcx_pixels=(unsigned char *)
-      AcquireMagickMemory(length*sizeof(*pcx_pixels));
+    length=(size_t) pcx_info.bytes_per_line;
+    pcx_pixels=(unsigned char *) AcquireQuantumMemory(length,
+      pcx_info.planes*sizeof(*pcx_pixels));
     if (pcx_pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     q=pcx_pixels;
@@ -1031,7 +1036,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
               case 3:
               default:
               {
-                for (x=(long) pcx_info.bytes_per_line; x > 0; x--)
+                for (x=(long) pcx_info.bytes_per_line; x != 0; x--)
                 {
                   *q++=ScaleQuantumToChar((Quantum) (QuantumRange-p->opacity));
                   p++;
