@@ -390,8 +390,14 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
-  packets=(bits_per_pixel*image->columns/8)*image->rows;
-  pixels=(unsigned char *) AcquireMagickMemory(packets+256);
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  packets=bits_per_pixel*image->columns/8;
+  pixels=(unsigned char *) AcquireQuantumMemory(packets+256UL,image->rows*
+    sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   switch (pdb_image.version)
@@ -560,8 +566,8 @@ static Image *ReadPDBImage(const ImageInfo *image_info,ExceptionInfo *exception)
             *p='\0';
             length<<=1;
             length+=MaxTextExtent;
-            comment=(char *) ResizeMagickMemory(comment,
-              (length+MaxTextExtent)*sizeof(*comment));
+            comment=(char *) ResizeQuantumMemory(comment,length+MaxTextExtent,
+              sizeof(*comment));
             if (comment == (char *) NULL)
               break;
             p=comment+strlen(comment);
@@ -796,14 +802,16 @@ static MagickBooleanType WritePDBImage(const ImageInfo *image_info,Image *image)
     pdb_image.width=(short) (16*(image->columns/16+1));
   pdb_image.height=(short) image->rows;
   packets=(bits_per_pixel*image->columns/8)*image->rows;
-  runlength=(unsigned char *) AcquireMagickMemory(2*packets);
+  runlength=(unsigned char *) AcquireQuantumMemory(2UL*packets,
+    sizeof(*runlength));
   if (runlength == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-  buffer=(unsigned char *) AcquireMagickMemory(256);
+  buffer=(unsigned char *) AcquireQuantumMemory(256UL,sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
   packet_size=(size_t) (image->depth > 8 ? 2: 1);
-  scanline=(unsigned char *) AcquireMagickMemory(packet_size*image->columns);
+  scanline=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
+    sizeof(*scanline));
   if (scanline == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     if (image_info->colorspace == UndefinedColorspace)
