@@ -478,12 +478,13 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
   /*
     Allocate pixel and scanline buffer.
   */
-  *extent=row_bytes*image->rows*sizeof(*pixels);
-  pixels=(unsigned char *) AcquireMagickMemory(*extent);
+  pixels=(unsigned char *) AcquireQuantumMemory(image->rows,row_bytes*
+    sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     return((unsigned char *) NULL);
+  *extent=row_bytes*image->rows*sizeof(*pixels);
   (void) ResetMagickMemory(pixels,0,*extent);
-  scanline=(unsigned char *) AcquireMagickMemory(row_bytes*sizeof(scanline));
+  scanline=(unsigned char *) AcquireQuantumMemory(row_bytes,sizeof(*scanline));
   if (scanline == (unsigned char *) NULL)
     return((unsigned char *) NULL);
   if (bytes_per_line < 8)
@@ -885,6 +886,11 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   image->x_resolution=DefaultResolution;
   image->y_resolution=DefaultResolution;
   image->units=UndefinedResolution;
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Interpret PICT opcodes.
   */
@@ -1271,7 +1277,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
             length-=4;
             if (length == 0)
               break;
-            info=(unsigned char *) AcquireMagickMemory(length);
+            info=(unsigned char *) AcquireQuantumMemory(length,sizeof(*info));
             if (info == (unsigned char *) NULL)
               break;
             count=ReadBlob(image,length,info);
@@ -1655,10 +1661,10 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   bytes_per_line=image->columns;
   if ((storage_class == DirectClass) || (image->matte != MagickFalse))
     bytes_per_line*=image->matte ? 4 : 3;
-  buffer=(unsigned char *) AcquireMagickMemory(PictInfoSize);
-  packed_scanline=(unsigned char *) AcquireMagickMemory((size_t)
-   (row_bytes+MaxCount));
-  scanline=(unsigned char *) AcquireMagickMemory(row_bytes);
+  buffer=(unsigned char *) AcquireQuantumMemory(PictInfoSize,sizeof(*buffer));
+  packed_scanline=(unsigned char *) AcquireQuantumMemory((size_t)
+   (row_bytes+MaxCount),sizeof(*packed_scanline));
+  scanline=(unsigned char *) AcquireQuantumMemory(row_bytes,sizeof(*scanline));
   if ((buffer == (unsigned char *) NULL) ||
       (packed_scanline == (unsigned char *) NULL) ||
       (scanline == (unsigned char *) NULL))
