@@ -183,8 +183,8 @@ static unsigned long PNMInteger(Image *image,const unsigned int base)
           if ((size_t) (p-comment+1) >= length)
             {
               length<<=1;
-              comment=(char *) ResizeMagickMemory(comment,
-                (length+MaxTextExtent)*sizeof(*comment));
+              comment=(char *) ResizeQuantumMemory(comment,length+MaxTextExtent,
+                sizeof(*comment));
               if (comment == (char *) NULL)
                 break;
               p=comment+strlen(comment);
@@ -454,7 +454,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Compute pixel scaling table.
         */
-        scale=(Quantum *) AcquireMagickMemory((size_t) (max_value+1)*
+        scale=(Quantum *) AcquireQuantumMemory((size_t) max_value+1UL,
           sizeof(*scale));
         if (scale == (Quantum *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -464,6 +464,11 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     /*
       Convert PNM pixels to runlength-encoded MIFF packets.
     */
@@ -650,10 +655,12 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           Convert PGM raw image to pixel packets.
         */
         packet_size=(size_t) (image->depth <= 8 ? 1 : 2);
-        length=packet_size*image->columns;
-        pixels=(unsigned char *) AcquireMagickMemory(length*sizeof(*pixels));
+        length=image->columns;
+        pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+        length*=packet_size*sizeof(*pixels);
         for (y=0; y < (long) image->rows; y++)
         {
           count=ReadBlob(image,length,pixels);
@@ -721,8 +728,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         packet_size=(size_t) (image->depth <= 8 ? 3 : 6);
         if (image->colorspace == CMYKColorspace)
           packet_size+=(size_t) (image->depth <= 8 ? 1 : 2);
-        pixels=(unsigned char *) AcquireMagickMemory(packet_size*
-          image->columns*sizeof(*pixels));
+        pixels=(unsigned char *) AcquireQuantumMemory(image->columns,
+          packet_size*sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         (void) ResetMagickMemory(&pixel,0,sizeof(LongPixelPacket));
@@ -813,8 +820,9 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           packet_size++;
         if (image->depth > 8)
           packet_size*=2;
-        length=packet_size*image->columns*sizeof(*pixels);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        length=image->columns;
+        pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (y=0; y < (long) image->rows; y++)
@@ -951,7 +959,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         quantum_info.scale=QuantumRange;
         quantum_type=format == 'f' ? GrayQuantum : RGBQuantum;
         length=(format == 'f' ? 1 : 3)*image->columns*sizeof(float);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (y=(long) image->rows-1; y >= 0; y--)
@@ -1599,8 +1607,9 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           Allocate memory for pixels.
         */
         packet_size=(size_t) (image->depth <= 8 ? 3 : 6);
-        length=packet_size*image->columns*sizeof(*pixels);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        length=image->columns;
+        pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         /*
@@ -1661,8 +1670,9 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           packet_size++;
         if (depth > 8)
           packet_size*=2;
-        length=packet_size*image->columns*sizeof(*pixels);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        length=image->columns;
+        pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         for (y=0; y < (long) image->rows; y++)
@@ -1776,7 +1786,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
         quantum_info.scale=1.0/QuantumRange;
         quantum_type=format == 'f' ? GrayQuantum : RGBQuantum;
         length=(format == 'f' ? 1 : 3)*image->columns*sizeof(float);
-        pixels=(unsigned char *) AcquireMagickMemory(length);
+        pixels=(unsigned char *) AcquireQuantumMemory(length,
+          sizeof(*pixels));
         if (pixels == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         for (y=(long) image->rows-1; y >= 0; y--)
