@@ -130,11 +130,11 @@ static MagickBooleanType InvokePostscriptDelegate(
     gs_func_struct;
 
   gs_func=(&gs_func_struct);
-  gs_func_struct.exit=gsapi_exit;
-  gs_func_struct.init_with_args=gsapi_init_with_args;
-  gs_func_struct.new_instance=gsapi_new_instance;
-  gs_func_struct.run_string=gsapi_run_string;
-  gs_func_struct.delete_instance=gsapi_delete_instance;
+  gs_func_struct.exit=(int (*)(gs_main_instance *)) gsapi_exit;
+  gs_func_struct.init_with_args=(int (*)(gs_main_instance *,int,char **)) gsapi_init_with_args;
+  gs_func_struct.new_instance=(int (*)(gs_main_instance **,void *)) gsapi_new_instance;
+  gs_func_struct.run_string=(int (*)(gs_main_instance *,const char *,int,int *)) gsapi_run_string;
+  gs_func_struct.delete_instance=(void (*)(gs_main_instance *)) gsapi_delete_instance;
 #endif
   if (gs_func == (GhostscriptVectors *) NULL)
     return(SystemCommand(verbose,command) == 0 ? MagickFalse : MagickTrue);
@@ -684,36 +684,24 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     read_info->antialias != MagickFalse ? 4 : 1,geometry,density,options,
     read_info->filename,postscript_filename,input_filename);
   status=InvokePostscriptDelegate(read_info->verbose,command);
-  postscript_image=ReadImage(read_info,exception);
-  if (postscript_image == (Image *) NULL)
+  if (status != MagickFalse)
     {
       (void) ConcatenateMagickString(command," -c showpage",MaxTextExtent);
       status=InvokePostscriptDelegate(read_info->verbose,command);
-      *read_info->magick='\0';
-      postscript_image=ReadImage(read_info,exception);
     }
+  postscript_image=(Image *) NULL;
+  if (status == MagickFalse)
+    postscript_image=ReadImage(read_info,exception);
   (void) RelinquishUniqueFileResource(postscript_filename);
   (void) RelinquishUniqueFileResource(read_info->filename);
   (void) RelinquishUniqueFileResource(input_filename);
-  if (postscript_image == (Image *) NULL)
-    {
-      /*
-        Ghostscript has failed-- try the Display Postscript Extension.
-      */
-      image=DestroyImageList(image);
-      (void) FormatMagickString(read_info->filename,MaxTextExtent,"dps:%s",
-        filename);
-      postscript_image=ReadImage(read_info,exception);
-      read_info=DestroyImageInfo(read_info);
-      if (postscript_image != (Image *) NULL)
-        return(GetFirstImageInList(postscript_image));
-      ThrowReaderException(DelegateError,"PostscriptDelegateFailed");
-    }
   read_info=DestroyImageInfo(read_info);
   if (postscript_image == (Image *) NULL)
     {
       image=DestroyImageList(image);
-      ThrowReaderException(DelegateError,"PostscriptDelegateFailed");
+      ThrowFileException(exception,DelegateError,"PostscriptDelegateFailed",
+        image_info->filename);
+      return((Image *) NULL);
     }
   if (LocaleCompare(postscript_image->magick,"BMP") == 0)
     {
