@@ -720,7 +720,8 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
               Allocate pixel array.
             */
             length=(size_t) number_pixels;
-            pixels=(unsigned char *) AcquireMagickMemory(length);
+            pixels=(unsigned char *) AcquireQuantumMemory(length,
+              sizeof(*pixels));
             if (pixels == (unsigned char *) NULL)
               ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
             /*
@@ -822,9 +823,9 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
               /*
                 Allocate pixel array.
               */
-              length=(size_t) ((image->colorspace == CMYKColorspace ? 4 : 3)*
-                number_pixels);
-              pixels=(unsigned char *) AcquireMagickMemory(length);
+              length=(size_t) number_pixels;
+              pixels=(unsigned char *) AcquireQuantumMemory(length,
+                4*sizeof(*pixels));
               if (pixels == (unsigned char *) NULL)
                 ThrowWriterException(ResourceLimitError,
                   "MemoryAllocationFailed");
@@ -976,7 +977,8 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                 Allocate pixel array.
               */
               length=(size_t) number_pixels;
-              pixels=(unsigned char *) AcquireMagickMemory(length);
+              pixels=(unsigned char *) AcquireQuantumMemory(length,
+                sizeof(*pixels));
               if (pixels == (unsigned char *) NULL)
                 ThrowWriterException(ResourceLimitError,
                   "MemoryAllocationFailed");
@@ -994,15 +996,15 @@ static MagickBooleanType WritePS2Image(const ImageInfo *image_info,Image *image)
                 for (x=0; x < (long) image->columns; x++)
                   *q++=(unsigned char) indexes[x];
                 if (image->previous == (Image *) NULL)
-                if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-                    (QuantumTick(y,image->rows) != MagickFalse))
-                  {
-                    status=image->progress_monitor(SaveImageTag,y,image->rows,
-                      image->client_data);
-                    if (status == MagickFalse)
-                      break;
-                  }
-              }
+                  if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+                      (QuantumTick(y,image->rows) != MagickFalse))
+                    {
+                      status=image->progress_monitor(SaveImageTag,y,image->rows,
+                        image->client_data);
+                      if (status == MagickFalse)
+                        break;
+                    }
+                }
               if (compression == LZWCompression)
                 status=LZWEncodeImage(image,length,pixels);
               else
