@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -89,7 +89,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -166,9 +165,9 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Allocate memory for a pixels.
   */
-  packet_size=(size_t) ((image->depth+7)/8);
-  pixels=(unsigned char *) AcquireMagickMemory(packet_size*
-    image->extract_info.width*sizeof(*pixels));
+  packet_size=(size_t) (image->depth+7)/8;
+  pixels=(unsigned char *) AcquireQuantumMemory(image->extract_info.width,
+    packet_size*sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->number_scenes != 0)
@@ -191,6 +190,11 @@ static Image *ReadRAWImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+      if (SetImageExtent(image,0,0) == MagickFalse)
+        {
+          InheritException(exception,&image->exception);
+          return(DestroyImageList(image));
+        }
     for (y=0; y < image->extract_info.y; y++)
       count=ReadBlob(image,packet_size*image->extract_info.width,pixels);
     for (y=0; y < (long) image->rows; y++)
@@ -536,8 +540,8 @@ static MagickBooleanType WriteRAWImage(const ImageInfo *image_info,Image *image)
       Allocate memory for pixels.
     */
     GetQuantumInfo(image_info,&quantum_info);
-    packet_size=(size_t) ((image->depth+7)/8);
-    pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns*
+    packet_size=(size_t) (image->depth+7)/8;
+    pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
       sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
