@@ -369,6 +369,11 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse)  && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     /*
       Allocate SGI pixels.
     */
@@ -377,8 +382,8 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((4*bytes_per_pixel*number_pixels) != ((MagickSizeType) (size_t)
         (4*bytes_per_pixel*number_pixels)))
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    iris_pixels=(unsigned char *) AcquireMagickMemory(4*bytes_per_pixel*
-      iris_info.columns*iris_info.rows);
+    iris_pixels=(unsigned char *) AcquireQuantumMemory(iris_info.columns,
+      iris_info.rows*4*bytes_per_pixel*sizeof(*iris_pixels));
     if (iris_pixels == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     if ((int) iris_info.storage != 0x01)
@@ -389,8 +394,8 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Read standard image format.
         */
-        scanline=(unsigned char *) AcquireMagickMemory(bytes_per_pixel*
-          iris_info.columns*sizeof(*scanline));
+        scanline=(unsigned char *) AcquireQuantumMemory(iris_info.columns,
+          bytes_per_pixel*sizeof(*scanline));
         if (scanline == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         for (z=0; z < (long) iris_info.depth; z++)
@@ -436,11 +441,11 @@ static Image *ReadSGIImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Read runlength-encoded image format.
         */
-        offsets=(ssize_t *) AcquireMagickMemory((size_t) iris_info.rows*
+        offsets=(ssize_t *) AcquireQuantumMemory((size_t) iris_info.rows,
           iris_info.depth*sizeof(*offsets));
-        packets=(unsigned char *) AcquireMagickMemory(4*(size_t)
-          iris_info.columns+10);
-        runlength=(unsigned long *) AcquireMagickMemory(iris_info.rows*
+        packets=(unsigned char *) AcquireQuantumMemory((size_t)
+          iris_info.columns+10UL,4UL*sizeof(*packets));
+        runlength=(unsigned long *) AcquireQuantumMemory(iris_info.rows,
           iris_info.depth*sizeof(*runlength));
         if ((offsets == (ssize_t *) NULL) ||
             (packets == (unsigned char *) NULL) ||
@@ -969,8 +974,8 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
     if ((4*iris_info.bytes_per_pixel*number_pixels) !=
         ((MagickSizeType) (size_t) (4*iris_info.bytes_per_pixel*number_pixels)))
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-    iris_pixels=(unsigned char *) AcquireMagickMemory((size_t)
-      (4*iris_info.bytes_per_pixel*number_pixels*sizeof(*iris_pixels)));
+    iris_pixels=(unsigned char *) AcquireQuantumMemory((size_t) number_pixels,
+      4*iris_info.bytes_per_pixel*sizeof(*iris_pixels));
     if (iris_pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
@@ -1070,11 +1075,11 @@ static MagickBooleanType WriteSGIImage(const ImageInfo *image_info,Image *image)
         /*
           Convert SGI uncompressed pixels.
         */
-        offsets=(ssize_t *) AcquireMagickMemory(iris_info.rows*iris_info.depth*
+        offsets=(ssize_t *) AcquireQuantumMemory(iris_info.rows*iris_info.depth,
           sizeof(*offsets));
-        packets=(unsigned char *) AcquireMagickMemory(4*(2*(size_t)
-          iris_info.columns+10)*image->rows*sizeof(*packets));
-        runlength=(unsigned long *) AcquireMagickMemory(iris_info.rows*
+        packets=(unsigned char *) AcquireQuantumMemory((2*(size_t)
+          iris_info.columns+10)*image->rows,4*sizeof(*packets));
+        runlength=(unsigned long *) AcquireQuantumMemory(iris_info.rows,
           iris_info.depth*sizeof(*runlength));
         if ((offsets == (ssize_t *) NULL) ||
             (packets == (unsigned char *) NULL) ||
