@@ -289,11 +289,17 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
         char
           *comment;
 
+        size_t
+          length;
+
         /*
           TGA image comment.
         */
-        comment=(char *) AcquireMagickMemory((size_t) (tga_info.id_length+
-          MaxTextExtent)*sizeof(*comment));
+        length=(size_t) tga_info.id_length;
+        comment=(char *) NULL;
+        if (~length >= MaxTextExtent)
+          comment=(char *) AcquireQuantumMemory(length+MaxTextExtent,
+            sizeof(*comment));
         if (comment == (char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         count=ReadBlob(image,tga_info.id_length,(unsigned char *) comment);
@@ -360,6 +366,11 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     /*
       Convert TGA pixels to pixel packets.
     */
@@ -820,8 +831,8 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
         /*
           Dump colormap to file (blue, green, red byte order).
         */
-        targa_colormap=(unsigned char *) AcquireMagickMemory((size_t)
-          (3*targa_info.colormap_length)*sizeof(*targa_colormap));
+        targa_colormap=(unsigned char *) AcquireQuantumMemory((size_t)
+          targa_info.colormap_length,3UL*sizeof(*targa_colormap));
         if (targa_colormap == (unsigned char *) NULL)
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
         q=targa_colormap;
@@ -838,8 +849,9 @@ static MagickBooleanType WriteTGAImage(const ImageInfo *image_info,Image *image)
     /*
       Convert MIFF to TGA raster pixels.
     */
-    count=(ssize_t) ((targa_info.bits_per_pixel*targa_info.width) >> 3);
-    targa_pixels=(unsigned char *) AcquireMagickMemory((size_t) count);
+    count=(ssize_t) (targa_info.bits_per_pixel*targa_info.width)/8;
+    targa_pixels=(unsigned char *) AcquireQuantumMemory((size_t) count,
+      sizeof(*targa_pixels));
     if (targa_pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     for (y=(long) (image->rows-1); y >= 0; y--)
