@@ -270,6 +270,7 @@ static int32 TIFFReadPixels(TIFF *tiff,unsigned long bits_per_sample,
   int32
     status;
 
+  (void) bits_per_sample;
   status=TIFFReadScanline(tiff,scanline,(uint32) row,sample);
   return(status);
 }
@@ -286,6 +287,9 @@ static toff_t TIFFGetBlobSize(thandle_t image)
 
 static void TIFFUnmapBlob(thandle_t image,tdata_t base,toff_t size)
 {
+  (void) image;
+  (void) base;
+  (void) size;
 }
 
 static void TIFFWarnings(const char *module,const char *format,va_list warning)
@@ -557,7 +561,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
     if (photometric == PHOTOMETRIC_SEPARATED)
       image->colorspace=CMYKColorspace;
     if (photometric == PHOTOMETRIC_CIELAB)
-      image->colorspace=LABColorspace;
+      image->colorspace=LabColorspace;
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_SAMPLESPERPIXEL,
       &samples_per_pixel);
     (void) TIFFGetFieldDefaulted(tiff,TIFFTAG_RESOLUTIONUNIT,&units);
@@ -730,6 +734,11 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     method=ReadGenericMethod;
     if (TIFFGetField(tiff,TIFFTAG_ROWSPERSTRIP,&rows_per_strip) != 0)
       {
@@ -737,7 +746,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           value[MaxTextExtent];
 
         method=ReadStripMethod;
-        (void) FormatMagickString(value,MaxTextExtent,"%u",rows_per_strip);
+        (void) FormatMagickString(value,MaxTextExtent,"%u",
+          (unsigned int) rows_per_strip);
         (void) SetImageProperty(image,"tiff:rows-per-strip",value);
       }
     if ((samples_per_pixel >= 2) && (interlace == PLANARCONFIG_CONTIG))
@@ -770,7 +780,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
           packet_size*=2;
         length=MagickMax((size_t) TIFFScanlineSize(tiff),packet_size*
           samples_per_pixel*width);
-        scanline=(unsigned char *) AcquireMagickMemory(length* sizeof(*scanline));
+        scanline=(unsigned char *) AcquireQuantumMemory(length,
+          sizeof(*scanline));
         if (scanline == (unsigned char *) NULL)
           {
             TIFFClose(tiff);
@@ -780,7 +791,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         if (image->storage_class == PseudoClass)
           {
             unsigned long
-              depth;
+              range;
 
             uint16
               *blue_colormap,
@@ -792,20 +803,22 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             */
             (void) TIFFGetField(tiff,TIFFTAG_COLORMAP,&red_colormap,
               &green_colormap,&blue_colormap);
-            depth=8;  /* might be old style 8-bit colormap */
+            range=255;  /* might be old style 8-bit colormap */
             for (i=0; i < (long) image->colors; i++)
               if ((red_colormap[i] >= 256) || (green_colormap[i] >= 256) ||
                   (blue_colormap[i] >= 256))
                 {
-                  depth=16;
+                  range=65535;
                   break;
                 }
             for (i=0; i < (long) image->colors; i++)
             {
-              image->colormap[i].red=ScaleAnyToQuantum(red_colormap[i],depth);
-              image->colormap[i].green=ScaleAnyToQuantum(green_colormap[i],
-                depth);
-              image->colormap[i].blue=ScaleAnyToQuantum(blue_colormap[i],depth);
+              image->colormap[i].red=(Quantum) 
+                (((double) QuantumRange*red_colormap[i])/range+0.5);
+              image->colormap[i].green=(Quantum) 
+                (((double) QuantumRange*green_colormap[i])/range+0.5);
+              image->colormap[i].blue=(Quantum) 
+                (((double) QuantumRange*blue_colormap[i])/range+0.5);
             }
           }
         quantum_type=IndexQuantum;
@@ -868,8 +881,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         /*
           Convert TIFF image to DirectClass MIFF image.
         */
-        scanline=(unsigned char *) AcquireMagickMemory((size_t)
-          TIFFScanlineSize(tiff));
+        scanline=(unsigned char *) AcquireQuantumMemory((size_t)
+          TIFFScanlineSize(tiff),sizeof(*scanline));
         if (scanline == (unsigned char *) NULL)
           {
             TIFFClose(tiff);
@@ -925,8 +938,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         /*
           Convert TIFF image to DirectClass MIFF image.
         */
-        scanline=(unsigned char *) AcquireMagickMemory((size_t)
-          TIFFScanlineSize(tiff));
+        scanline=(unsigned char *) AcquireQuantumMemory((size_t)
+          TIFFScanlineSize(tiff),sizeof(*scanline));
         if (scanline == (unsigned char *) NULL)
           {
             TIFFClose(tiff);
@@ -998,8 +1011,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             TIFFClose(tiff);
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
-        pixels=(uint32 *) AcquireMagickMemory((size_t) number_pixels*
-          sizeof(uint32));
+        pixels=(uint32 *) AcquireQuantumMemory((size_t) number_pixels,
+          sizeof(*pixels));
         if (pixels == (uint32 *) NULL)
           {
             TIFFClose(tiff);
@@ -1073,8 +1086,8 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
         image->extract_info.width=columns;
         image->extract_info.height=rows;
         number_pixels=columns*rows;
-        tile_pixels=(uint32 *) AcquireMagickMemory((size_t) columns*rows*
-          sizeof(uint32));
+        tile_pixels=(uint32 *) AcquireQuantumMemory((size_t) columns*rows,
+          sizeof(*tile_pixels));
         if (tile_pixels == (uint32 *) NULL)
           {
             TIFFClose(tiff);
@@ -1164,7 +1177,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
             TIFFClose(tiff);
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
-        pixels=(uint32 *) AcquireMagickMemory((size_t) number_pixels*
+        pixels=(uint32 *) AcquireQuantumMemory((size_t) number_pixels,
           sizeof(*pixels));
         if (pixels == (uint32 *) NULL)
           {
@@ -1531,8 +1544,8 @@ static MagickBooleanType GetTIFFInfo(Image *image,TIFF *tiff,
 {
   assert(tiff_info != (TIFFInfo *) NULL);
   (void) ResetMagickMemory(tiff_info,0,sizeof(*tiff_info));
-  tiff_info->scanline=(unsigned char *) AcquireMagickMemory((size_t)
-    TIFFScanlineSize(tiff));
+  tiff_info->scanline=(unsigned char *) AcquireQuantumMemory((size_t)
+    TIFFScanlineSize(tiff),sizeof(*tiff_info->scanline));
   if (tiff_info->scanline == (unsigned char *) NULL)
     {
       DestroyTIFFInfo(tiff_info);
@@ -1540,10 +1553,11 @@ static MagickBooleanType GetTIFFInfo(Image *image,TIFF *tiff,
     }
   if (TIFFIsTiled(tiff) != 0)
     {
-      tiff_info->scanlines=(unsigned char *) AcquireMagickMemory((size_t)
-        image->extract_info.height*TIFFScanlineSize(tiff));
-      tiff_info->pixels=(unsigned char *) AcquireMagickMemory((size_t)
-        TIFFTileSize(tiff));
+      tiff_info->scanlines=(unsigned char *) AcquireQuantumMemory((size_t)
+        image->extract_info.height*TIFFScanlineSize(tiff),
+        sizeof(*tiff_info->scanlines));
+      tiff_info->pixels=(unsigned char *) AcquireQuantumMemory((size_t)
+        TIFFTileSize(tiff),sizeof(*tiff_info->scanlines));
       if ((tiff_info->scanlines == (unsigned char *) NULL) ||
           (tiff_info->pixels == (unsigned char *) NULL))
         {
@@ -1824,7 +1838,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
         /*
           Full color TIFF raster.
         */
-        if (image->colorspace == LABColorspace)
+        if (image->colorspace == LabColorspace)
           photometric=PHOTOMETRIC_CIELAB;
         else
           if (image->colorspace == YCbCrColorspace)
@@ -2010,6 +2024,15 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
           9));
         break;
       }
+      case COMPRESSION_CCITTFAX3:
+      {
+        /*
+          Byte-aligned EOL.
+        */
+        (void) TIFFSetField(tiff,TIFFTAG_GROUP3OPTIONS,4);
+        (void) TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,image->rows);
+        break;
+      }
       case COMPRESSION_CCITTFAX4:
       {
         (void) TIFFSetField(tiff,TIFFTAG_ROWSPERSTRIP,image->rows);
@@ -2351,9 +2374,9 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
         /*
           Colormapped TIFF image.
         */
-        red=(uint16 *) AcquireMagickMemory(65536*sizeof(*red));
-        green=(uint16 *) AcquireMagickMemory(65536*sizeof(*green));
-        blue=(uint16 *) AcquireMagickMemory(65536*sizeof(*blue));
+        red=(uint16 *) AcquireQuantumMemory(65536,sizeof(*red));
+        green=(uint16 *) AcquireQuantumMemory(65536,sizeof(*green));
+        blue=(uint16 *) AcquireQuantumMemory(65536,sizeof(*blue));
         if ((red == (uint16 *) NULL) || (green == (uint16 *) NULL) ||
             (blue == (uint16 *) NULL))
           ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
