@@ -80,7 +80,6 @@
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadTILEImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -117,6 +116,11 @@ static Image *ReadTILEImage(const ImageInfo *image_info,
   (void) SetImageBackgroundColor(image);
   image->matte=tile_image->matte;
   (void) CopyMagickString(image->filename,image_info->filename,MaxTextExtent);
+  if (LocaleCompare(tile_image->magick,"PATTERN") == 0)
+    {
+      tile_image->tile_offset.x=0;
+      tile_image->tile_offset.y=0;
+    }
   (void) TextureImage(image,tile_image);
   tile_image=DestroyImage(tile_image);
   return(GetFirstImageInList(image));
