@@ -81,7 +81,6 @@
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -196,7 +195,8 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         image->rows=height;
         if (AllocateImageColormap(image,pixel_mode == 1 ? 256UL : 16UL) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-        tim_colormap=(unsigned char *) AcquireMagickMemory(image->colors*2);
+        tim_colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
+          2UL*sizeof(*tim_colormap));
         if (tim_colormap == (unsigned char *) NULL)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         count=ReadBlob(image,2*image->colors,tim_colormap);
@@ -219,6 +219,11 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     /*
       Read image data.
     */
@@ -230,7 +235,8 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image_size=2*width*height;
     bytes_per_line=width*2;
     width=(width*16)/bits_per_pixel;
-    tim_data=(unsigned char *) AcquireMagickMemory(image_size);
+    tim_data=(unsigned char *) AcquireQuantumMemory(image_size,
+      sizeof(*tim_data));
     if (tim_data == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     count=ReadBlob(image,image_size,tim_data);
@@ -261,13 +267,13 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           p=tim_pixels+y*bytes_per_line;
           for (x=0; x < ((long) image->columns-1); x+=2)
           {
-            indexes[x]=(*p) & 0xf;
-            indexes[x+1]=(*p >> 4) & 0xf;
+            indexes[x]=(IndexPacket) ((*p) & 0x0f);
+            indexes[x+1]=(IndexPacket) ((*p >> 4) & 0x0f);
             p++;
           }
           if ((image->columns % 2) != 0)
             {
-              indexes[x]=(*p >> 4) & 0xf;
+              indexes[x]=(IndexPacket) ((*p >> 4) & 0x0f);
               p++;
             }
           if (SyncImagePixels(image) == MagickFalse)
