@@ -232,6 +232,11 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
   image->rows=(unsigned long) (((page.height*image->y_resolution)/delta.y)+0.5);
   image->page.x=0;
   image->page.y=0;
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   texture=(Image *) NULL;
   if (image_info->texture != (char *) NULL)
     {
@@ -394,7 +399,8 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     count;
 
   unsigned long
-    depth;
+    depth,
+    max_value;
 
   /*
     Open image file.
@@ -417,9 +423,10 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (LocaleNCompare((char *) text,MagickID,strlen(MagickID)) != 0)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   count=(ssize_t) sscanf(text+32,"%lu,%lu,%lu,%s",&image->columns,
-    &image->rows,&depth,format);
+    &image->rows,&max_value,format);
   if (count != 4)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  for (depth=1; (1UL << depth) < max_value; depth++);
   if (LocaleNCompare(format,"CMYK",4) == 0)
     image->colorspace=CMYKColorspace;
   image->matte=strchr(format,'A') != (char *) NULL ? MagickTrue : MagickFalse;
@@ -603,7 +610,7 @@ static MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
   image->depth=GetImageQuantumDepth(image,MagickTrue);
   (void) FormatMagickString(buffer,MaxTextExtent,
     "# ImageMagick pixel enumeration: %lu,%lu,%lu,%s\n",image->columns,
-    image->rows,image->depth,format);
+    image->rows,(1UL << image->depth)-1,format);
   (void) WriteBlobString(image,buffer);
   scene=0;
   do
