@@ -230,8 +230,8 @@ static MagickBooleanType WriteUILImage(const ImageInfo *image_info,Image *image)
           number_pixels=(MagickSizeType) image->columns*image->rows;
           if (number_pixels != ((MagickSizeType) (size_t) number_pixels))
             ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-          matte_image=(unsigned char *)
-            AcquireMagickMemory(image->columns*image->rows);
+          matte_image=(unsigned char *) AcquireQuantumMemory(image->columns,
+            image->rows*sizeof(*matte_image));
           if (matte_image == (unsigned char *) NULL)
             ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
           for (y=0; y < (long) image->rows; y++)
