@@ -137,13 +137,23 @@ static Image *ReadUYVYImage(const ImageInfo *image_info,
   if (status == MagickFalse)
     return((Image *) NULL);
   for (i=0; i < image->offset; i++)
-    (void) ReadBlobByte(image);
+    if (ReadBlobByte(image) == EOF)
+      {
+        ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
+          image->filename);
+        break;
+      }
   image->depth=8;
   if (image_info->ping != MagickFalse)
     {
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Accumulate UYVY, then unpack into two pixels.
   */
