@@ -55,8 +55,8 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/montage.h"
-#include "magick/resize.h"
 #include "magick/quantum.h"
+#include "magick/resize.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
@@ -92,14 +92,14 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
 #define ClientName  "montage"
 
   char
-    **filelist;
+    **filelist,
+    *label;
 
   Image
     *image,
@@ -137,7 +137,7 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   image=AllocateImage(image_info);
-  filelist=(char **) AcquireMagickMemory(sizeof(filelist));
+  filelist=(char **) AcquireMagickMemory(sizeof(*filelist));
   if (filelist == (char **) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   filelist[0]=(char *) image_info->filename;
@@ -168,7 +168,9 @@ static Image *ReadVIDImage(const ImageInfo *image_info,ExceptionInfo *exception)
     CatchException(exception);
     if (next_image == (Image *) NULL)
       break;
-    (void) SetImageProperty(next_image,"label",DefaultTileLabel);
+    label=InterpretImageProperties(image_info,next_image,DefaultTileLabel);
+    (void) SetImageProperty(next_image,"label",label);
+    label=DestroyString(label);
     if (image_info->debug != MagickFalse)
       (void) LogMagickEvent(CoderEvent,GetMagickModule(),"geometry: %ldx%ld",
         next_image->columns,next_image->rows);
