@@ -89,7 +89,6 @@ static MagickBooleanType
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
 static MagickBooleanType WBMPReadInteger(Image *image,unsigned long *value)
@@ -173,7 +172,12 @@ static Image *ReadWBMPImage(const ImageInfo *image_info,
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   for (i=0; i < image->offset; i++)
-    (void) ReadBlobByte(image);
+    if (ReadBlobByte(image) == EOF)
+      {
+        ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
+          image->filename);
+        break;
+      }
   if (AllocateImageColormap(image,2) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->ping != MagickFalse)
@@ -181,6 +185,11 @@ static Image *ReadWBMPImage(const ImageInfo *image_info,
       CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Convert bi-level image to pixel packets.
   */
@@ -408,6 +417,7 @@ static MagickBooleanType WriteWBMPImage(const ImageInfo *image_info,
           bit=0;
           byte=0;
         }
+      p++;
     }
     if (bit != 0)
       (void) WriteBlobByte(image,byte);
