@@ -77,9 +77,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image:  Method ReadXCImage returns a pointer to the image after
-%      creating it. A null image is returned if there is a memory shortage
-%      or if the image cannot be read.
+%    o image:  The image.
 %
 %    o image_info: The image info.
 %
@@ -142,6 +140,11 @@ static Image *ReadXCImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image->colormap[0]=image->background_color;
       color.index=0.0;
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   for (y=0; y < (long) image->rows; y++)
   {
     q=GetImagePixels(image,0,y,image->columns,1);
