@@ -307,7 +307,7 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
   offset=SeekBlob(image,(MagickOffsetType) (length-i),SEEK_CUR);
   if (offset < 0)
     (void) ThrowMagickException(&image->exception,GetMagickModule(),
-      CorruptImageError,"InvalidImageHeader","`%s'",image->filename);
+      CorruptImageError,"ImproperImageHeader","`%s'",image->filename);
   return(string);
 }
 
@@ -321,7 +321,8 @@ static int load_tile (Image* image, Image* tile_image, XCFDocInfo* inDocInfo,
   XCFPixelPacket *xcfdata, *xcfodata;
   unsigned char  *graydata;
 
-  xcfdata = xcfodata = (XCFPixelPacket *) AcquireMagickMemory(data_length);
+  xcfdata = xcfodata = (XCFPixelPacket *) AcquireQuantumMemory(data_length,
+    sizeof(*xcfdata));
   graydata = (unsigned char *)xcfdata;  /* used by gray and indexed */
   nmemb_read_successfully = ReadBlob(image, data_length, (unsigned char *) xcfdata);
   if (nmemb_read_successfully > (ssize_t) (tile_image->columns*tile_image->rows))
@@ -370,8 +371,8 @@ static int load_tile_rle (Image* image, Image* tile_image, XCFDocInfo* inDocInfo
 
   bpp = (int) inDocInfo->bpp;
 
-  xcfdata = xcfodata = (unsigned char *)
-    AcquireMagickMemory((size_t) data_length);
+  xcfdata = xcfodata = (unsigned char *) AcquireQuantumMemory((size_t)
+    data_length,sizeof(*xcfdata));
 
   nmemb_read_successfully = ReadBlob(image, (size_t) data_length, xcfdata);
 
@@ -600,10 +601,10 @@ static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
             fail = MagickTrue;
           break;
         case COMPRESS_ZLIB:
-          ThrowBinaryException(CoderError,"ZipCompressionNotSupported",
+          ThrowBinaryException(CoderError,"ZipCompressNotSupported",
             image->filename)
         case COMPRESS_FRACTAL:
-          ThrowBinaryException(CoderError,"FractalCompressionNotSupported",
+          ThrowBinaryException(CoderError,"FractalCompressNotSupported",
             image->filename)
       }
 
@@ -806,7 +807,7 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
         if (!amount)
           ThrowBinaryException(CorruptImageError,"CorruptImage",
             image->filename);
-        prop_size -= (unsigned long) MagickMin(16, amount);
+        prop_size -= (unsigned long) MagickMin(16, (size_t) amount);
         }
       }
       break;
@@ -923,12 +924,15 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   register long
     i;
 
-  unsigned long
-    image_type;
+  size_t
+    length;
 
   ssize_t
     count;
 
+  unsigned long
+    image_type;
+
   XCFDocInfo
     doc_info;
 
@@ -957,6 +961,8 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   doc_info.exception=exception;
   doc_info.width=ReadBlobMSBLong(image);
   doc_info.height=ReadBlobMSBLong(image);
+  if ((doc_info.width > 262144) || (doc_info.height > 262144))
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   doc_info.image_type=ReadBlobMSBLong(image);
   /*
     Initialize image attributes.
@@ -974,6 +980,11 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     else
       if ( image_type == GIMP_INDEXED )
         ThrowReaderException(CoderError,"ColormapTypeNotSupported");
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   (void) SetImageBackgroundColor(image);
   /*
     Read properties.
@@ -1038,7 +1049,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         (doc_info.compression != COMPRESS_RLE) &&
         (doc_info.compression != COMPRESS_ZLIB) &&
         (doc_info.compression != COMPRESS_FRACTAL))
-          ThrowReaderException(CorruptImageError,"CompressionNotValid");
+          ThrowReaderException(CorruptImageError,"UnrecognizedImageCompression");
       }
       break;
 
@@ -1067,9 +1078,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
 
         /* BOGUS: we don't write these yet because we aren't
-        //      reading them properly yet :(
-        //image->x_resolution = xres;
-        //image->y_resolution = yres;
+              reading them properly yet :(
+              image->x_resolution = xres;
+              image->y_resolution = yres;
         */
       }
       break;
@@ -1147,7 +1158,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         amount = (long) ReadBlob(image,(size_t) amount, (unsigned char *) &buf);
         if (!amount)
           ThrowReaderException(CorruptImageError,"CorruptImage");
-        prop_size -= (unsigned long) MagickMin(16, amount);
+        prop_size -= (unsigned long) MagickMin(16, (size_t) amount);
       }
     }
     break;
@@ -1179,6 +1190,12 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         foundAllLayers = MagickTrue;
       else
         number_layers++;
+      if (EOFBlob(image) != MagickFalse)
+        {
+          ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
+            image->filename);
+          break;
+        }
     } while (foundAllLayers  == MagickFalse);
     offset=SeekBlob(image, oldPos, SEEK_SET); /* restore the position! */
     if (offset < 0)
@@ -1186,8 +1203,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
 
 
     /* allocate our array of layer info blocks */
-    layer_info=(XCFLayerInfo *)
-      AcquireMagickMemory(number_layers*sizeof(XCFLayerInfo));
+    length=(size_t) number_layers;
+    layer_info=(XCFLayerInfo *) AcquireQuantumMemory(length,
+      sizeof(*layer_info));
     if (layer_info == (XCFLayerInfo *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(layer_info,0,number_layers*sizeof(XCFLayerInfo));
