@@ -162,8 +162,8 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
       packet_size+=(image->depth+7)/8;
       image->matte=MagickTrue;
     }
-  pixels=(unsigned char *)
-    AcquireMagickMemory(packet_size*image->extract_info.width);
+  pixels=(unsigned char *) AcquireQuantumMemory(image->extract_info.width,
+    packet_size*sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->number_scenes != 0)
@@ -187,6 +187,11 @@ static Image *ReadYCBCRImage(const ImageInfo *image_info,
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     switch (image_info->interlace)
     {
       case NoInterlace:
@@ -625,7 +630,7 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
   packet_size=(size_t) ((3*image->depth+7)/8);
   if (LocaleCompare(image_info->magick,"YCbCrA") == 0)
     packet_size+=(image->depth+7)/8;
-  pixels=(unsigned char *) AcquireMagickMemory(packet_size*image->columns*
+  pixels=(unsigned char *) AcquireQuantumMemory(image->columns,packet_size*
     sizeof(*pixels));
   if (pixels == (unsigned char *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
