@@ -498,8 +498,7 @@ static int GetOneCharacter(const unsigned char *text,size_t *length)
   return((int) c);
 }
 
-static unsigned long *EncodeSJIS(const Image *image,const char *text,
-  size_t *count)
+static unsigned long *EncodeSJIS(const char *text,size_t *count)
 {
   int
     c;
@@ -519,11 +518,13 @@ static unsigned long *EncodeSJIS(const Image *image,const char *text,
   *count=0;
   if ((text == (char *) NULL) || (*text == '\0'))
     return((unsigned long *) NULL);
-  length=strlen(text)+MaxTextExtent;
-  encoding=(unsigned long *) AcquireMagickMemory(length*sizeof(*encoding));
+  length=strlen(text);
+  if (~length < MaxTextExtent)
+    return((unsigned long *) NULL);
+  length+=MaxTextExtent;
+  encoding=(unsigned long *) AcquireQuantumMemory(length,sizeof(*encoding));
   if (encoding == (unsigned long *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      image->filename);
+    return((unsigned long *) NULL);
   q=encoding;
   for (p=text; *p != '\0'; p+=length)
   {
@@ -561,19 +562,16 @@ static unsigned long *EncodeSJIS(const Image *image,const char *text,
 %
 %  The format of the EncodeText function is:
 %
-%      encoding=EncodeText(const Image *image,const char *text,size_t count)
+%      encoding=EncodeText(const char *text,size_t count)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
-%
 %    o text: The text.
 %
 %    o count: return the number of characters generated by the encoding.
 %
 */
-static unsigned long *EncodeText(const Image *image,const char *text,
-  size_t *count)
+static unsigned long *EncodeText(const char *text,size_t *count)
 {
   register const char
     *p;
@@ -581,17 +579,22 @@ static unsigned long *EncodeText(const Image *image,const char *text,
   register unsigned long
     *q;
 
+  size_t
+    length;
+
   unsigned long
     *encoding;
 
   *count=0;
   if ((text == (char *) NULL) || (*text == '\0'))
     return((unsigned long *) NULL);
-  encoding=(unsigned long *)
-    AcquireMagickMemory((strlen(text)+MaxTextExtent)*sizeof(*encoding));
+  length=strlen(text);
+  if (~length < MaxTextExtent)
+    return((unsigned long *) NULL);
+  length+=MaxTextExtent;
+  encoding=(unsigned long *) AcquireQuantumMemory(length,sizeof(*encoding));
   if (encoding == (unsigned long *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      image->filename);
+    return((unsigned long *) NULL);
   q=encoding;
   for (p=text; *p != '\0'; p++)
     *q++=(unsigned char) *p;
@@ -618,8 +621,7 @@ static unsigned long *EncodeText(const Image *image,const char *text,
 %
 %  The format of the EncodeUnicode function is:
 %
-%      unsigned short *EncodeUnicode(const Image *image,
-%        const unsigned char *text,size_t count)
+%      unsigned short *EncodeUnicode(const unsigned char *text,size_t count)
 %
 %  A description of each parameter follows:
 %
@@ -683,8 +685,7 @@ static long GetUnicodeCharacter(const unsigned char *text,size_t *length)
   return((long) c);
 }
 
-static unsigned long *EncodeUnicode(const Image *image,const char *text,
-  size_t *count)
+static unsigned long *EncodeUnicode(const char *text,size_t *count)
 {
   long
     c;
@@ -704,11 +705,13 @@ static unsigned long *EncodeUnicode(const Image *image,const char *text,
   *count=0;
   if ((text == (char *) NULL) || (*text == '\0'))
     return((unsigned long *) NULL);
-  length=strlen(text)+MaxTextExtent;
-  unicode=(unsigned long *) AcquireMagickMemory(length*sizeof(*unicode));
+  length=strlen(text);
+  if (~length < MaxTextExtent)
+    return((unsigned long *) NULL);
+  length+=MaxTextExtent;
+  unicode=(unsigned long *) AcquireQuantumMemory(length,sizeof(*unicode));
   if (unicode == (unsigned long *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      image->filename);
+    return((unsigned long *) NULL);
   q=unicode;
   for (p=text; *p != '\0'; p+=length)
   {
@@ -1390,12 +1393,12 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   {
     case ft_encoding_sjis:
     {
-      text=EncodeSJIS(image,draw_info->text,&length);
+      text=EncodeSJIS(draw_info->text,&length);
       break;
     }
     case ft_encoding_unicode:
     {
-      text=EncodeUnicode(image,draw_info->text,&length);
+      text=EncodeUnicode(draw_info->text,&length);
       break;
     }
     default:
@@ -1404,22 +1407,22 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
         {
           if (LocaleCompare(draw_info->encoding,"SJIS") == 0)
             {
-              text=EncodeSJIS(image,draw_info->text,&length);
+              text=EncodeSJIS(draw_info->text,&length);
               break;
             }
           if ((LocaleCompare(draw_info->encoding,"UTF-8") == 0) ||
               (encoding_type != ft_encoding_none))
             {
-              text=EncodeUnicode(image,draw_info->text,&length);
+              text=EncodeUnicode(draw_info->text,&length);
               break;
             }
         }
       if (encoding_type == ft_encoding_unicode)
         {
-          text=EncodeUnicode(image,draw_info->text,&length);
+          text=EncodeUnicode(draw_info->text,&length);
           break;
         }
-      text=EncodeText(image,draw_info->text,&length);
+      text=EncodeText(draw_info->text,&length);
       break;
     }
   }
@@ -1476,15 +1479,16 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   {
     glyph.id=FT_Get_Char_Index(face,text[i]);
     if (glyph.id == 0)
-      glyph.id=text[i];
+      glyph.id=FT_Get_Char_Index(face,'?');
     if ((glyph.id != 0) && (last_glyph.id != 0) && FT_HAS_KERNING(face))
       {
         FT_Vector
           kerning;
 
-        (void) FT_Get_Kerning(face,last_glyph.id,glyph.id,ft_kerning_default,
+        status=FT_Get_Kerning(face,last_glyph.id,glyph.id,ft_kerning_default,
           &kerning);
-        origin.x+=kerning.x;
+        if (status == 0)
+          origin.x+=kerning.x;
       }
     glyph.origin=origin;
     status=FT_Load_Glyph(face,glyph.id,flags);
@@ -1552,7 +1556,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
               p+=bitmap->bitmap.width;
               continue;
             }
-          q=GetCacheView(image_view,x_offset,y_offset,bitmap->bitmap.width,1);
+          q=GetCacheViewPixels(image_view,x_offset,y_offset,
+            bitmap->bitmap.width,1);
           active=q != (PixelPacket *) NULL ? MagickTrue : MagickFalse;
           for (x=0; x < (long) bitmap->bitmap.width; x++)
           {
@@ -1568,7 +1573,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
             if (draw_info->text_antialias == MagickFalse)
               fill_opacity=fill_opacity > 0.5 ? 1.0 : 0.0;
             if (active == MagickFalse)
-              q=GetCacheView(image_view,x_offset,y_offset,1,1);
+              q=GetCacheViewPixels(image_view,x_offset,y_offset,1,1);
             if (q == (PixelPacket *) NULL)
               {
                 p++;
@@ -1598,6 +1603,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       FT_Done_Glyph(last_glyph.image);
     last_glyph=glyph;
   }
+  if (last_glyph.id != 0)
+    FT_Done_Glyph(last_glyph.image);
   if ((draw_info->stroke.opacity != TransparentOpacity) ||
       (draw_info->stroke_pattern != (Image *) NULL))
     {
@@ -1612,12 +1619,10 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
           (void) DrawImage(image,annotate_info);
         }
       }
-  if (glyph.id != 0)
-    FT_Done_Glyph(glyph.image);
   /*
     Determine font metrics.
   */
-  glyph.id=0;
+  glyph.id=FT_Get_Char_Index(face,'_');
   glyph.origin=origin;
   status=FT_Load_Glyph(face,glyph.id,flags);
   if (status == 0)
@@ -1638,6 +1643,8 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
                 metrics->width=bitmap->left;
             }
         }
+      if (glyph.id != 0)
+        FT_Done_Glyph(glyph.image);
     }
   metrics->width-=metrics->bounds.x1/64.0;
   metrics->bounds.x1/=64.0;
@@ -1923,7 +1930,7 @@ static MagickBooleanType RenderPostscript(Image *image,
       annotate_view=OpenCacheView(annotate_image);
       for (y=0; y < (long) annotate_image->rows; y++)
       {
-        q=GetCacheView(annotate_view,0,y,annotate_image->columns,1);
+        q=GetCacheViewPixels(annotate_view,0,y,annotate_image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
         for (x=0; x < (long) annotate_image->columns; x++)
@@ -2024,8 +2031,11 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
       */
       display=XOpenDisplay(draw_info->server_name);
       if (display == (Display *) NULL)
-        ThrowBinaryException(XServerError,"UnableToOpenXServer",
-          draw_info->server_name);
+        {
+          ThrowXWindowException(XServerError,"UnableToOpenXServer",
+            draw_info->server_name);
+          return(MagickFalse);
+        }
       /*
         Get user defaults from X resource database.
       */
@@ -2039,15 +2049,21 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
       resource_info.foreground_color=AcquireString("#000000000000");
       map_info=XAllocStandardColormap();
       if (map_info == (XStandardColormap *) NULL)
-        ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
-          image->filename);
+        {
+          ThrowXWindowException(ResourceLimitError,"MemoryAllocationFailed",
+            image->filename);
+          return(MagickFalse);
+        }
       /*
         Initialize visual info.
       */
       visual_info=XBestVisualInfo(display,map_info,&resource_info);
       if (visual_info == (XVisualInfo *) NULL)
-        ThrowBinaryException(XServerError,"UnableToGetVisual",
-          image->filename);
+        {
+          ThrowXWindowException(XServerError,"UnableToGetVisual",
+            image->filename);
+          return(MagickFalse);
+        }
       map_info->colormap=(Colormap) NULL;
       pixel.pixels=(unsigned long *) NULL;
       /*
@@ -2063,14 +2079,20 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
       */
       font_info=XBestFont(display,&resource_info,MagickFalse);
       if (font_info == (XFontStruct *) NULL)
-        ThrowBinaryException(XServerError,"UnableToLoadFont",draw_info->font);
+        {
+          ThrowXWindowException(XServerError,"UnableToLoadFont",
+            draw_info->font);
+          return(MagickFalse);
+        }
       if ((map_info == (XStandardColormap *) NULL) ||
           (visual_info == (XVisualInfo *) NULL) ||
           (font_info == (XFontStruct *) NULL))
         {
           XFreeResources(display,visual_info,map_info,&pixel,font_info,
             &resource_info,(XWindowInfo *) NULL);
-          ThrowBinaryException(XServerError,"UnableToLoadFont",image->filename);
+          ThrowXWindowException(XServerError,"UnableToLoadFont",
+            image->filename);
+          return(MagickFalse);
         }
       cache_info=(*draw_info);
     }
@@ -2088,7 +2110,11 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
       (void) CloneString(&resource_info.font,draw_info->font);
       font_info=XBestFont(display,&resource_info,MagickFalse);
       if (font_info == (XFontStruct *) NULL)
-        ThrowBinaryException(XServerError,"UnableToLoadFont",draw_info->font);
+        {
+          ThrowXWindowException(XServerError,"UnableToLoadFont",
+            draw_info->font);
+          return(MagickFalse);
+        }
     }
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(AnnotateEvent,GetMagickModule(),
@@ -2137,8 +2163,11 @@ static MagickBooleanType RenderX11(Image *image,const DrawInfo *draw_info,
   pixel.pen_color.blue=ScaleQuantumToShort(draw_info->fill.blue);
   status=XAnnotateImage(display,&pixel,&annotate_info,image);
   if (status == 0)
-    ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
-      image->filename);
+    {
+      ThrowXWindowException(ResourceLimitError,"MemoryAllocationFailed",
+        image->filename);
+      return(MagickFalse);
+    }
   return(MagickTrue);
 }
 #else
