@@ -164,10 +164,6 @@ MagickExport Image *CompareImageChannels(Image *image,
   if ((reconstruct_image->columns != image->columns) ||
       (reconstruct_image->rows != image->rows))
     ThrowImageException(ImageError,"ImageSizeDiffers");
-  if (image->colorspace != reconstruct_image->colorspace)
-    ThrowImageException(ImageError,"ImageColorspaceDiffers");
-  if (image->matte != reconstruct_image->matte)
-    ThrowImageException(ImageError,"ImageOpacityDiffers");
   difference_image=CloneImage(image,image->columns,image->rows,MagickTrue,
     exception);
   if (difference_image == (Image *) NULL)
@@ -182,8 +178,8 @@ MagickExport Image *CompareImageChannels(Image *image,
   (void) QueryMagickColor("#ffffff",&white,exception);
   if (difference_image->colorspace == CMYKColorspace)
     {
-      RGBtoCMYK(&red);
-      RGBtoCMYK(&white);
+      ConvertRGBToCMYK(&red);
+      ConvertRGBToCMYK(&white);
     }
   /*
     Generate difference image.
@@ -195,8 +191,8 @@ MagickExport Image *CompareImageChannels(Image *image,
   difference_view=OpenCacheView(difference_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     r=SetCacheView(difference_view,0,y,difference_image->columns,1);
     if ((p == (const PixelPacket *) NULL) ||
@@ -217,19 +213,20 @@ MagickExport Image *CompareImageChannels(Image *image,
       if ((channel & BlueChannel) != 0)
         if (p->blue != q->blue)
           difference=MagickTrue;
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         if (p->opacity != q->opacity)
           difference=MagickTrue;
       if (((channel & IndexChannel) != 0) &&
-          (image->colorspace == CMYKColorspace))
+          (image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         if (indexes[x] != reconstruct_indexes[x])
           difference=MagickTrue;
       SetMagickPixelPacket(reconstruct_image,q,reconstruct_indexes+x,&source);
       if (difference != MagickFalse)
-        MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&red,
+        MagickPixelCompositeOver(&source,7.5*QuantumRange/10.0,&red,
           (MagickRealType) red.opacity,&composite);
       else
-        MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&white,
+        MagickPixelCompositeOver(&source,7.5*QuantumRange/10.0,&white,
           (MagickRealType) white.opacity,&composite);
       SetPixelPacket(difference_image,&composite,r,difference_indexes+x);
       p++;
@@ -333,8 +330,8 @@ static MagickRealType GetAbsoluteError(const Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
@@ -388,8 +385,8 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
@@ -412,7 +409,7 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
           distortion+=fabs(p->blue-(double) q->blue);
           area++;
         }
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         {
           distortion+=fabs(p->opacity-(double) q->opacity);
           area++;
@@ -473,8 +470,8 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
@@ -482,10 +479,12 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
     reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
-      if (image->matte != MagickFalse)
+      if ((channel & OpacityChannel) != 0)
         {
-          alpha=QuantumScale*(QuantumRange-(double) p->opacity);
-          beta=QuantumScale*(QuantumRange-(double) q->opacity);
+          if (image->matte != MagickFalse)
+            alpha=QuantumScale*(QuantumRange-(double) p->opacity);
+          if (reconstruct_image->matte != MagickFalse)
+            beta=QuantumScale*(QuantumRange-(double) q->opacity);
         }
       if ((channel & RedChannel) != 0)
         {
@@ -514,8 +513,18 @@ static MagickRealType GetMeanErrorPerPixel(Image *image,
             maximum_error=distance;
           area++;
         }
+      if ((channel & OpacityChannel) != 0)
+        {
+          distance=fabs(alpha*p->opacity-beta*q->opacity);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
       if (((channel & IndexChannel) != 0) &&
-          (image->colorspace == CMYKColorspace))
+          (image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         {
           distance=fabs(alpha*indexes[x]-beta*reconstruct_indexes[x]);
           mean_error_per_pixel+=distance;
@@ -569,8 +578,8 @@ static MagickRealType GetMeanSquaredError(const Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
@@ -596,14 +605,15 @@ static MagickRealType GetMeanSquaredError(const Image *image,
           distortion+=distance*distance;
           area++;
         }
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         {
           distance=p->opacity-(MagickRealType) q->opacity;
           distortion+=distance*distance;
           area++;
         }
       if (((channel & IndexChannel) != 0) &&
-          (image->colorspace == CMYKColorspace))
+          (image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         {
           distance=indexes[x]-(MagickRealType) reconstruct_indexes[x];
           distortion+=distance*distance;
@@ -649,8 +659,8 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
@@ -676,14 +686,15 @@ static MagickRealType GetPeakAbsoluteError(const Image *image,
           if (distance > distortion)
             distortion=distance;
         }
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         {
           distance=fabs(p->opacity-(double) q->opacity);
           if (distance > distortion)
             distortion=distance;
         }
       if (((channel & IndexChannel) != 0) &&
-          (image->colorspace == CMYKColorspace))
+          (image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         {
           distance=fabs(indexes[x]-(double) reconstruct_indexes[x]);
           if (distance > distortion)
@@ -737,10 +748,6 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
   if ((reconstruct_image->columns != image->columns) ||
       (reconstruct_image->rows != image->rows))
     ThrowBinaryException(ImageError,"ImageSizeDiffers",image->filename);
-  if (image->colorspace != reconstruct_image->colorspace)
-    ThrowBinaryException(ImageError,"ImageColorspaceDiffers",image->filename);
-  if (image->matte != reconstruct_image->matte)
-    ThrowBinaryException(ImageError,"ImageOpacityDiffers",image->filename);
   /*
     Get image distortion.
   */
@@ -877,10 +884,6 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   if ((reconstruct_image->columns != image->columns) ||
       (reconstruct_image->rows != image->rows))
     ThrowBinaryException(ImageError,"ImageSizeDiffers",image->filename);
-  if (image->colorspace != reconstruct_image->colorspace)
-    ThrowBinaryException(ImageError,"ImageColorspaceDiffers",image->filename);
-  if (image->matte != reconstruct_image->matte)
-    ThrowBinaryException(ImageError,"ImageOpacityDiffers",image->filename);
   area=0.0;
   maximum_error=0.0;
   mean_error_per_pixel=0.0;
@@ -889,8 +892,8 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   reconstruct_view=OpenCacheView(reconstruct_image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,&image->exception);
-    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,&image->exception);
+    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
       &image->exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
       break;
@@ -916,16 +919,14 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
       if (distance > maximum_error)
         maximum_error=distance;
       area++;
-      if (image->matte != MagickFalse)
-        {
-          distance=fabs(p->opacity-(double) q->opacity);
-          mean_error_per_pixel+=distance;
-          mean_error+=distance*distance;
-          if (distance > maximum_error)
-            maximum_error=distance;
-          area++;
-        }
-      if (image->colorspace == CMYKColorspace)
+      distance=fabs(p->opacity-(double) q->opacity);
+      mean_error_per_pixel+=distance;
+      mean_error+=distance*distance;
+      if (distance > maximum_error)
+        maximum_error=distance;
+      area++;
+      if ((image->colorspace == CMYKColorspace) &&
+          (reconstruct_image->colorspace == CMYKColorspace))
         {
           distance=fabs(indexes[x]-(double) reconstruct_indexes[x]);
           mean_error_per_pixel+=distance;
