@@ -23,13 +23,18 @@ extern "C" {
 #endif
 
 /*
-  ImageMagick Alpha Composite Inline Methods.
+  ImageMagick Alpha Composite Inline Methods (special export)
 */
 
 #include "magick/color.h"
 #include "magick/image.h"
 #include "magick/image-private.h"
 
+static inline MagickRealType RoundToUnity(const MagickRealType value)
+{
+  return(value < 0.0 ? 0.0 : (value > 1.0) ? 1.0 : value);
+}
+
 static inline MagickRealType MagickOver_(const MagickRealType p,
   const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
 {
@@ -39,7 +44,10 @@ static inline MagickRealType MagickOver_(const MagickRealType p,
   pixel=(1.0-QuantumScale*alpha)*p+(1.0-QuantumScale*beta)*q*QuantumScale*alpha;
   return(pixel);
 }
-                                                                                
+
+/*
+  Compose pixel p over pixel q with the given opacities
+*/
 static inline void MagickCompositeOver(const PixelPacket *p,
   const MagickRealType alpha,const PixelPacket *q,const MagickRealType beta,
   PixelPacket *composite)
@@ -53,6 +61,7 @@ static inline void MagickCompositeOver(const PixelPacket *p,
       return;
     }
   gamma=1.0-QuantumScale*QuantumScale*alpha*beta;
+#if !defined(UseHDRI)
   composite->opacity=(Quantum) (QuantumRange*(1.0-gamma)+0.5);
   gamma=1.0/(gamma <= MagickEpsilon ? 1.0 : gamma);
   composite->red=(Quantum) (gamma*MagickOver_((MagickRealType) p->red,alpha,
@@ -61,8 +70,21 @@ static inline void MagickCompositeOver(const PixelPacket *p,
     (MagickRealType) q->green,beta)+0.5);
   composite->blue=(Quantum) (gamma*MagickOver_((MagickRealType) p->blue,alpha,
     (MagickRealType) q->blue,beta)+0.5);
+#else
+  composite->opacity=(Quantum) (QuantumRange*(1.0-gamma));
+  gamma=1.0/(gamma <= MagickEpsilon ? 1.0 : gamma);
+  composite->red=(Quantum) (gamma*MagickOver_((MagickRealType) p->red,alpha,
+    (MagickRealType) q->red,beta));
+  composite->green=(Quantum) (gamma*MagickOver_((MagickRealType) p->green,alpha,
+    (MagickRealType) q->green,beta));
+  composite->blue=(Quantum) (gamma*MagickOver_((MagickRealType) p->blue,alpha,
+    (MagickRealType) q->blue,beta));
+#endif
 }
 
+/*
+  Compose pixel p over pixel q with the given opacities
+*/
 static inline void MagickPixelCompositeOver(const MagickPixelPacket *p,
   const MagickRealType alpha,const MagickPixelPacket *q,
   const MagickRealType beta,MagickPixelPacket *composite)
@@ -85,9 +107,43 @@ static inline void MagickPixelCompositeOver(const MagickPixelPacket *p,
     composite->index=gamma*MagickOver_(p->index,alpha,q->index,beta);
 }
 
-static inline MagickRealType RoundToUnity(const MagickRealType value)
+
+static inline MagickRealType MagickPlus_(const MagickRealType p,
+  const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
 {
-  return(value < 0.0 ? 0.0 : (value > 1.0) ? 1.0 : value);
+  return((1.0-QuantumScale*alpha)*p+(1.0-QuantumScale*beta)*q);
+}
+
+/*
+  Add two pixels with the given opacities
+*/
+static inline void MagickPixelCompositePlus(const MagickPixelPacket *p,
+  const MagickRealType alpha,const MagickPixelPacket *q,
+  const MagickRealType beta,MagickPixelPacket *composite)
+{
+  MagickRealType
+    gamma;
+
+  gamma=RoundToUnity((1.0-QuantumScale*alpha)+(1.0-QuantumScale*beta));
+  composite->opacity=(MagickRealType) QuantumRange*(1.0-gamma);
+  gamma=1.0/(fabs(gamma) <= MagickEpsilon ? 1.0 : gamma);
+  composite->red=gamma*MagickPlus_(p->red,alpha,q->red,beta);
+  composite->green=gamma*MagickPlus_(p->green,alpha,q->green,beta);
+  composite->blue=gamma*MagickPlus_(p->blue,alpha,q->blue,beta);
+  if (q->colorspace == CMYKColorspace)
+    composite->index=gamma*MagickPlus_(p->index,alpha,q->index,beta);
+}
+
+/*
+  Blend pixel colors p and q by the amount given
+*/
+static inline void MagickPixelCompositeBlend(const MagickPixelPacket *p,
+  const MagickRealType alpha,const MagickPixelPacket *q,
+  const MagickRealType beta,MagickPixelPacket *composite)
+{
+  MagickPixelCompositePlus(p,(MagickRealType) QuantumRange-alpha*
+    (QuantumRange-p->opacity),q,(MagickRealType) QuantumRange-beta*
+    (QuantumRange-q->opacity),composite);
 }
 
 #if defined(__cplusplus) || defined(c_plusplus)
