@@ -46,6 +46,7 @@
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
+#include "magick/colorspace-private.h"
 #include "magick/composite.h"
 #include "magick/composite-private.h"
 #include "magick/constitute.h"
@@ -62,6 +63,7 @@
 #include "magick/pixel-private.h"
 #include "magick/property.h"
 #include "magick/quantum.h"
+#include "magick/resample.h"
 #include "magick/resource_.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
@@ -343,6 +345,30 @@ static inline void CompositeDifference(const MagickPixelPacket *p,
     composite->index=gamma*Difference(p->index,alpha,q->index,beta);
 }
 
+static inline MagickRealType Divide(const MagickRealType p,
+  const MagickRealType q)
+{
+  MagickRealType
+    pixel;
+
+  if (q == 0.0)
+    return(0.0);
+  pixel=p/q;
+  return((MagickRealType) QuantumRange*pixel);
+}
+
+static inline void CompositeDivide(const MagickPixelPacket *p,
+  const MagickRealType alpha,const MagickPixelPacket *q,
+  const MagickRealType beta,MagickPixelPacket *composite)
+{
+  composite->red=Divide(p->red,q->red);
+  composite->green=Divide(p->green,q->green);
+  composite->blue=Divide(p->blue,q->blue);
+  composite->opacity=Divide(alpha,beta);
+  if (q->colorspace == CMYKColorspace)
+    composite->index=Divide(p->index,q->index);
+}
+
 static inline MagickRealType Exclusion(const MagickRealType p,
   const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
 {
@@ -763,7 +789,7 @@ static MagickRealType SoftLight(const MagickRealType p,
     (2.0*QuantumScale*(1.0-QuantumScale*alpha)*p-(1.0-QuantumScale*alpha)))+
     QuantumScale*(1.0-QuantumScale*alpha)*p*(1.0-(1.0-QuantumScale*beta))+
     QuantumScale*(1.0-QuantumScale*beta)*q*(1.0-(1.0-QuantumScale*alpha));
-  return(pixel);
+  return((MagickRealType) QuantumRange*pixel);
 }
 
 static inline void CompositeSoftLight(const MagickPixelPacket *p,
@@ -1088,6 +1114,9 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
       register PixelPacket
         *r;
 
+      ResampleFilter
+        *resample_filter;
+
       ViewInfo
         *composite_view,
         *displace_view,
@@ -1118,6 +1147,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         Shift image pixels as defined by a displacement map.
       */
       GetMagickPixelPacket(displace_image,&pixel);
+      resample_filter=AcquireResampleFilter(image,
+        GetImageVirtualPixelMethod(image),&image->exception);
       image_view=OpenCacheView(image);
       displace_view=OpenCacheView(displace_image);
       composite_view=OpenCacheView(composite_image);
@@ -1125,10 +1156,10 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
       {
         if (((y+y_offset) < 0) || ((y+y_offset) >= (long) image->rows))
           continue;
-        p=AcquireCacheView(composite_view,0,y,composite_image->columns,1,
+        p=AcquireCacheViewPixels(composite_view,0,y,composite_image->columns,1,
           &image->exception);
-        q=GetCacheView(image_view,0,y+y_offset,image->columns,1);
-        r=GetCacheView(displace_view,0,y,displace_image->columns,1);
+        q=GetCacheViewPixels(image_view,0,y+y_offset,image->columns,1);
+        r=GetCacheViewPixels(displace_view,0,y,displace_image->columns,1);
         if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL) ||
             (r == (PixelPacket *) NULL))
           break;
@@ -1153,9 +1184,8 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             y_displace=(vertical_scale*(PixelIntensityToQuantum(p)-
               (((MagickRealType) QuantumRange+1.0)/2.0)))/
               (((MagickRealType) QuantumRange+1.0)/2.0);
-          pixel=InterpolatePixelColor(image,image_view,image->interpolate,
-            (double) (x_offset+x+x_displace),(double) (y_offset+y+y_displace),
-            &image->exception);
+          pixel=ResamplePixelColor(resample_filter,(double)
+            (x_offset+x+x_displace),(double) (y_offset+y+y_displace));
           SetPixelPacket(displace_image,&pixel,r,displace_indexes+x);
           p++;
           q++;
@@ -1164,6 +1194,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         if (SyncCacheView(displace_view) == MagickFalse)
           break;
       }
+      resample_filter=DestroyResampleFilter(resample_filter);
       composite_view=CloseCacheView(composite_view);
       displace_view=CloseCacheView(displace_view);
       image_view=CloseCacheView(image_view);
@@ -1179,24 +1210,14 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
           */
           flags=ParseGeometry(composite_image->geometry,&geometry_info);
           source_dissolve=geometry_info.rho/100.0;
-          destination_dissolve=1.0;
-          if ((source_dissolve-MagickEpsilon) < 0.0)
-            source_dissolve=0.0;
-          if ((source_dissolve+MagickEpsilon) > 1.0)
-            {
-              destination_dissolve=2.0-source_dissolve;
-              source_dissolve=1.0;
-            }
+          destination_dissolve=1.0-source_dissolve;
+          if (source_dissolve > 1.0)
+            destination_dissolve=2.0-source_dissolve;
           if ((flags & SigmaValue) != 0)
             destination_dissolve=geometry_info.sigma/100.0;
-          if ((destination_dissolve-MagickEpsilon) < 0.0)
-            destination_dissolve=0.0;
           modify_outside_overlay=MagickTrue;
           if ((destination_dissolve+MagickEpsilon) > 1.0 )
-            {
-              destination_dissolve=1.0;
-              modify_outside_overlay=MagickFalse;
-            }
+            modify_outside_overlay=MagickFalse;
         }
       break;
     }
@@ -1206,21 +1227,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         {
           flags=ParseGeometry(composite_image->geometry,&geometry_info);
           source_dissolve=geometry_info.rho/100.0;
-          if ((source_dissolve-MagickEpsilon) < 0.0)
-            source_dissolve=0.0;
-          if ((source_dissolve+MagickEpsilon) > 1.0)
-            source_dissolve=1.0;
           destination_dissolve=1.0-source_dissolve;
           if ((flags & SigmaValue) != 0)
             destination_dissolve=geometry_info.sigma/100.0;
-          if ((destination_dissolve-MagickEpsilon) < 0.0)
-            destination_dissolve=0.0;
           modify_outside_overlay=MagickTrue;
           if ((destination_dissolve+MagickEpsilon) > 1.0)
-            {
-              destination_dissolve=1.0;
-              modify_outside_overlay=MagickFalse;
-            }
+            modify_outside_overlay=MagickFalse;
         }
       break;
     }
@@ -1287,7 +1299,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     p=(PixelPacket *) NULL;
     if ((y >= y_offset) && ((y-y_offset) < (long) composite_image->rows))
       {
-        p=AcquireCacheView(composite_view,0,y-y_offset,composite_image->columns,
+        p=AcquireCacheViewPixels(composite_view,0,y-y_offset,composite_image->columns,
           1,&image->exception);
         if (p == (const PixelPacket *) NULL)
           break;
@@ -1295,7 +1307,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         if (x_offset < 0)
           p-=x_offset;
       }
-    q=GetCacheView(image_view,0,y,image->columns,1);
+    q=GetCacheViewPixels(image_view,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
     indexes=GetCacheViewIndexes(image_view);
@@ -1396,6 +1408,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         }
       switch (compose)
       {
+        case AddCompositeOp:
+        {
+          CompositeAdd(&source,source.opacity,&destination,destination.opacity,
+            &composite);
+          break;
+        }
         case ClearCompositeOp:
         {
           CompositeClear(&destination,&composite);
@@ -1417,6 +1435,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             composite.opacity=(MagickRealType) OpaqueOpacity;
           break;
         }
+        case DivideCompositeOp:
+        {
+          CompositeDivide(&source,source.opacity,&destination,
+            destination.opacity,&composite);
+          break;
+        }
         case DstCompositeOp:
           break;
         case OverCompositeOp:
@@ -1651,6 +1675,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             composite.opacity=source.opacity;
           break;
         }
+        case SubtractCompositeOp:
+        {
+          CompositeSubtract(&source,source.opacity,&destination,
+            destination.opacity,&composite);
+          break;
+        }
         case LuminizeCompositeOp:
         {
           if (source.opacity == TransparentOpacity)
@@ -1689,37 +1719,25 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             composite.opacity=source.opacity;
           break;
         }
-        case AddCompositeOp:  /* deprecated */
-        {
-          CompositeAdd(&source,source.opacity,&destination,destination.opacity,
-            &composite);
-          break;
-        }
-        case SubtractCompositeOp:  /* deprecated */
-        {
-          CompositeSubtract(&source,source.opacity,&destination,
-            destination.opacity,&composite);
-          break;
-        }
-        case CopyRedCompositeOp:  /* deprecated */
+        case CopyRedCompositeOp:
         case CopyCyanCompositeOp:
         {
           composite.red=source.red;
           break;
         }
-        case CopyGreenCompositeOp:  /* deprecated */
+        case CopyGreenCompositeOp:
         case CopyMagentaCompositeOp:
         {
           composite.green=source.green;
           break;
         }
-        case CopyBlueCompositeOp:  /* deprecated */
+        case CopyBlueCompositeOp:
         case CopyYellowCompositeOp:
         {
           composite.blue=source.blue;
           break;
         }
-        case CopyOpacityCompositeOp:  /* deprecated */
+        case CopyOpacityCompositeOp:
         {
           if (source.matte == MagickFalse)
             {
@@ -1733,11 +1751,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         case CopyBlackCompositeOp:
         {
           if (source.colorspace != CMYKColorspace)
-            {
-              composite.index=(MagickRealType) (QuantumRange-
-                MagickPixelIntensityToQuantum(&source));
-              break;
-            }
+            ConvertRGBToCMYK(&source); 
           composite.index=source.index;
           break;
         }
