@@ -71,7 +71,7 @@
 /*
   Typedef declarations.
 */
-typedef struct _Ascii85Info
+struct _Ascii85Info
 {
   long
     offset,
@@ -79,7 +79,7 @@ typedef struct _Ascii85Info
 
   unsigned char
     buffer[10];
-} Ascii85Info;
+};
 
 typedef struct HuffmanTable
 {
@@ -274,8 +274,7 @@ MagickExport void Ascii85Initialize(Image *image)
   if (image->ascii85 == (Ascii85Info *) NULL)
     image->ascii85=(Ascii85Info *) AcquireMagickMemory(sizeof(*image->ascii85));
   if (image->ascii85 == (Ascii85Info *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      image->filename);
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(image->ascii85,0,sizeof(*image->ascii85));
   image->ascii85->line_break=MaxLineExtent << 1;
   image->ascii85->offset=0;
@@ -429,7 +428,6 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
     byte;
 
   long
-    count,
     y;
 
   MagickBooleanType
@@ -448,6 +446,9 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
   register unsigned char
     *p;
 
+  ssize_t
+    count;
+
   unsigned char
     *scanline;
 
@@ -470,9 +471,10 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  mb_hash=(HuffmanTable **) AcquireMagickMemory(HashSize*sizeof(*mb_hash));
-  mw_hash=(HuffmanTable **) AcquireMagickMemory(HashSize*sizeof(*mw_hash));
-  scanline=(unsigned char *) AcquireMagickMemory((size_t) image->columns);
+  mb_hash=(HuffmanTable **) AcquireQuantumMemory(HashSize,sizeof(*mb_hash));
+  mw_hash=(HuffmanTable **) AcquireQuantumMemory(HashSize,sizeof(*mw_hash));
+  scanline=(unsigned char *) AcquireQuantumMemory((size_t) image->columns,
+    sizeof(*scanline));
   if ((mb_hash == (HuffmanTable **) NULL) ||
       (mw_hash == (HuffmanTable **) NULL) ||
       (scanline == (unsigned char *) NULL))
@@ -585,7 +587,7 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
         {
           count+=entry->count;
           if ((x+count) > (long) image->columns)
-            count=(long) image->columns-x;
+            count=(ssize_t) image->columns-x;
           if (count > 0)
             {
               if (color != MagickFalse)
@@ -754,7 +756,7 @@ MagickExport MagickBooleanType HuffmanEncodeImage(const ImageInfo *image_info,
   width=image->columns;
   if (LocaleCompare(image_info->magick,"FAX") == 0)
     width=(unsigned long) MagickMax(image->columns,1728);
-  scanline=(unsigned char *) AcquireMagickMemory((size_t) (width+1)*
+  scanline=(unsigned char *) AcquireQuantumMemory((size_t) width+1UL,
     sizeof(*scanline));
   if (scanline == (unsigned char *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -932,9 +934,6 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
   int
     unique_file;
 
-  long
-    j;
-
   MagickBooleanType
     status;
 
@@ -1012,7 +1011,8 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
   for (i=1; i < (long) TIFFNumberOfStrips(tiff); i++)
     if (byte_count[i] > strip_size)
       strip_size=byte_count[i];
-  buffer=(unsigned char *) AcquireMagickMemory((size_t) strip_size);
+  buffer=(unsigned char *) AcquireQuantumMemory((size_t) strip_size,
+    sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     {
       TIFFClose(tiff);
@@ -1033,8 +1033,7 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
       byte_count[i]);
     if (fillorder == FILLORDER_LSB2MSB)
       TIFFReverseBits(buffer,(unsigned long) count);
-    for (j=0; j < (long) count; j++)
-      (void) WriteBlobByte(image,(unsigned char) buffer[j]);
+    (void) WriteBlob(image,count,buffer);
   }
   buffer=(unsigned char *) RelinquishMagickMemory(buffer);
   TIFFClose(tiff);
@@ -1135,7 +1134,7 @@ MagickExport MagickBooleanType LZWEncodeImage(Image *image,const size_t length,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(pixels != (unsigned char *) NULL);
-  table=(TableType *) AcquireMagickMemory((1 << 12)*sizeof(*table));
+  table=(TableType *) AcquireQuantumMemory(1UL << 12,sizeof(*table));
   if (table == (TableType *) NULL)
     return(MagickFalse);
   /*
@@ -1270,7 +1269,7 @@ MagickExport MagickBooleanType PackbitsEncodeImage(Image *image,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(pixels != (unsigned char *) NULL);
-  packbits=(unsigned char *) AcquireMagickMemory(128);
+  packbits=(unsigned char *) AcquireQuantumMemory(128UL,sizeof(*packbits));
   if (packbits == (unsigned char *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
@@ -1396,10 +1395,10 @@ MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,const size_t length,
     i;
 
   size_t
-    compressed_packets;
+    compress_packets;
 
   unsigned char
-    *compressed_pixels;
+    *compress_pixels;
 
   z_stream
     stream;
@@ -1408,15 +1407,16 @@ MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,const size_t length,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  compressed_packets=(size_t) (1.001*length+12);
-  compressed_pixels=(unsigned char *) AcquireMagickMemory(compressed_packets);
-  if (compressed_pixels == (unsigned char *) NULL)
+  compress_packets=(size_t) (1.001*length+12);
+  compress_pixels=(unsigned char *) AcquireQuantumMemory(compress_packets,
+    sizeof(*compress_pixels));
+  if (compress_pixels == (unsigned char *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
   stream.next_in=pixels;
   stream.avail_in=(unsigned int) length;
-  stream.next_out=compressed_pixels;
-  stream.avail_out=(unsigned int) compressed_packets;
+  stream.next_out=compress_pixels;
+  stream.avail_out=(unsigned int) compress_packets;
   stream.zalloc=(alloc_func) NULL;
   stream.zfree=(free_func) NULL;
   stream.opaque=(voidpf) NULL;
@@ -1429,14 +1429,14 @@ MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,const size_t length,
         status=deflateEnd(&stream);
       else
         (void) deflateEnd(&stream);
-      compressed_packets=(size_t) stream.total_out;
+      compress_packets=(size_t) stream.total_out;
     }
   if (status != Z_OK)
     ThrowBinaryException(CoderError,"UnableToZipCompressImage",image->filename)
   else
-    for (i=0; i < (long) compressed_packets; i++)
-      (void) WriteBlobByte(image,compressed_pixels[i]);
-  compressed_pixels=(unsigned char *) RelinquishMagickMemory(compressed_pixels);
+    for (i=0; i < (long) compress_packets; i++)
+      (void) WriteBlobByte(image,compress_pixels[i]);
+  compress_pixels=(unsigned char *) RelinquishMagickMemory(compress_pixels);
   return(status == Z_OK ? MagickTrue : MagickFalse);
 }
 #else
@@ -1447,7 +1447,7 @@ MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  ThrowBinaryException(MissingDelegateError,"ZLIBLibraryIsNotAvailable",
+  ThrowBinaryException(MissingDelegateError,"ZipLibraryIsNotAvailable",
     image->filename);
 }
 #endif
