@@ -304,8 +304,8 @@ MagickExport const ConfigureInfo **GetConfigureInfoList(const char *pattern,
   p=GetConfigureInfo("*",exception);
   if (p == (const ConfigureInfo *) NULL)
     return((const ConfigureInfo **) NULL);
-  options=(const ConfigureInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(configure_list)+1)*sizeof(*options));
+  options=(const ConfigureInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(configure_list)+1UL,sizeof(*options));
   if (options == (const ConfigureInfo **) NULL)
     return((const ConfigureInfo **) NULL);
   /*
@@ -400,8 +400,8 @@ MagickExport char **GetConfigureList(const char *pattern,
     return((char **) NULL);
   AcquireSemaphoreInfo(&configure_semaphore);
   RelinquishSemaphoreInfo(configure_semaphore);
-  options=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(configure_list)+1)*sizeof(*options));
+  options=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(configure_list)+1UL,sizeof(*options));
   if (options == (char **) NULL)
     return((char **) NULL);
   AcquireSemaphoreInfo(&configure_semaphore);
@@ -986,8 +986,7 @@ static MagickBooleanType LoadConfigureList(const char *xml,const char *filename,
     configure_info=(ConfigureInfo *) AcquireMagickMemory(
       sizeof(*configure_info));
     if (configure_info == (ConfigureInfo *) NULL)
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",filename);
+      ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(configure_info,0,sizeof(*configure_info));
     configure_info->path=ConstantString(filename);
     configure_info->signature=MagickSignature;
