@@ -479,8 +479,8 @@ MagickExport const DelegateInfo **GetDelegateInfoList(const char *pattern,
   p=GetDelegateInfo("*","*",exception);
   if (p == (const DelegateInfo *) NULL)
     return((const DelegateInfo **) NULL);
-  delegates=(const DelegateInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(delegate_list)+1)*sizeof(*delegates));
+  delegates=(const DelegateInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(delegate_list)+1UL,sizeof(*delegates));
   if (delegates == (const DelegateInfo **) NULL)
     return((const DelegateInfo **) NULL);
   /*
@@ -575,8 +575,8 @@ MagickExport char **GetDelegateList(const char *pattern,
   p=GetDelegateInfo("*","*",exception);
   if (p == (const DelegateInfo *) NULL)
     return((char **) NULL);
-  delegates=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(delegate_list)+1)*sizeof(*delegates));
+  delegates=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(delegate_list)+1UL,sizeof(*delegates));
   if (delegates == (char **) NULL)
     return((char **) NULL);
   AcquireSemaphoreInfo(&delegate_semaphore);
@@ -731,6 +731,13 @@ static MagickBooleanType InitializeDelegateList(ExceptionInfo *exception)
 %
 */
 
+static inline size_t MagickMin(const size_t x,const size_t y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
 static void CopyDelegateFile(const char *source,const char *destination)
 {
   int
@@ -771,10 +778,10 @@ static void CopyDelegateFile(const char *source,const char *destination)
       (void) close(destination_file);
       return;
     }
-  quantum=(size_t) (fstat(source_file,&file_info) < 0 ? 0 : file_info.st_size);
-  if ((quantum == 0) || (quantum > MagickMaxBufferSize))
-    quantum=MagickMaxBufferSize;
-  buffer=(unsigned char *) AcquireMagickMemory(quantum*sizeof(*buffer));
+  quantum=(size_t) MagickMaxBufferSize;
+  if ((fstat(source_file,&file_info) == 0) && (file_info.st_size != 0))
+    quantum=MagickMin((size_t) file_info.st_size,MagickMaxBufferSize);
+  buffer=(unsigned char *) AcquireQuantumMemory(quantum,sizeof(*buffer));
   if (buffer == (unsigned char *) NULL)
     {
       (void) close(source_file);
@@ -1217,8 +1224,8 @@ static MagickBooleanType LoadDelegateList(const char *xml,const char *filename,
     */
     delegate_info=(DelegateInfo *) AcquireMagickMemory(sizeof(*delegate_info));
     if (delegate_info == (DelegateInfo *) NULL)
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",filename);
+      ThrowFatalException(ResourceLimitFatalError,
+        "MemoryAllocationFailed");
     (void) ResetMagickMemory(delegate_info,0,sizeof(*delegate_info));
     delegate_info->path=ConstantString(filename);
     delegate_info->signature=MagickSignature;
