@@ -41,6 +41,7 @@
   Include declarations.
 */
 #include "magick/studio.h"
+#include "magick/cache-view.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
@@ -54,6 +55,7 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/quantum.h"
+#include "magick/resample.h"
 #include "magick/string_.h"
 
 /*
@@ -61,6 +63,154 @@
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%     C l u t I m a g e                                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ClutImage() replaces colors in the image from a color lookup table.
+%
+%  The format of the ClutImage method is:
+%
+%      MagickBooleanType ClutImage(Image *image,const ChannelType channel)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o channel: The channel.
+%
+%    o clut_image: The color lookup.
+%
+*/
+
+MagickExport MagickBooleanType ClutImage(Image *image,const Image *clut_image)
+{
+  MagickBooleanType
+    status;
+
+  status=ClutImageChannel(image,DefaultChannels,clut_image);
+  return(status);
+}
+
+MagickExport MagickBooleanType ClutImageChannel(Image *image,
+  const ChannelType channel,const Image *clut_image)
+{
+#define ClutImageTag  "Clut/Image"
+
+  IndexPacket
+    *indexes;
+
+  long
+    y;
+
+  MagickBooleanType
+    status;
+
+  MagickPixelPacket
+    pixel;
+
+  register long
+    x;
+
+  register PixelPacket
+    *q;
+
+  ResampleFilter
+    *resample_filter;
+
+  ViewInfo
+    *clut_view;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  assert(clut_image != (Image *) NULL);
+  assert(clut_image->signature == MagickSignature);
+  if (SetImageStorageClass(image,DirectClass) == MagickFalse)
+    return(MagickFalse);
+  /*
+    Clut image.
+  */
+  GetMagickPixelPacket(clut_image,&pixel);
+  resample_filter=AcquireResampleFilter(clut_image,
+    GetImageVirtualPixelMethod(clut_image),&image->exception);
+  clut_view=OpenCacheView(clut_image);
+  for (y=0; y < (long) image->rows; y++)
+  {
+    q=GetImagePixels(image,0,y,image->columns,1);
+    if (q == (PixelPacket *) NULL)
+      break;
+    indexes=GetIndexes(image);
+    for (x=0; x < (long) image->columns; x++)
+    {
+      if ((channel & RedChannel) != 0)
+        {
+          pixel=ResamplePixelColor(resample_filter,QuantumScale*q->red*
+            clut_image->columns,QuantumScale*q->red*clut_image->rows);
+          q->red=RoundToQuantum(pixel.red);
+        }
+      if ((channel & GreenChannel) != 0)
+        {
+          pixel=ResamplePixelColor(resample_filter,QuantumScale*q->green*
+            clut_image->columns,QuantumScale*q->green*clut_image->rows);
+          q->green=RoundToQuantum(pixel.green);
+        }
+      if ((channel & BlueChannel) != 0)
+        {
+          pixel=ResamplePixelColor(resample_filter,QuantumScale*q->blue*
+            clut_image->columns,QuantumScale*q->blue*clut_image->rows);
+          q->blue=RoundToQuantum(pixel.blue);
+        }
+      if ((channel & OpacityChannel) != 0)
+        {
+          if (clut_image->matte == MagickFalse)
+            {
+              pixel=ResamplePixelColor(resample_filter,QuantumScale*
+                q->opacity*clut_image->columns,QuantumScale*q->opacity*
+                clut_image->rows);
+              q->opacity=RoundToQuantum(pixel.opacity);
+            }
+          else
+            {
+              pixel=ResamplePixelColor(resample_filter,QuantumScale*
+                (QuantumRange-q->opacity)*clut_image->columns,QuantumScale*
+                (QuantumRange-q->opacity)*clut_image->rows);
+              q->opacity=(Quantum) QuantumRange-RoundToQuantum(pixel.opacity);
+            }
+        }
+      if (((channel & IndexChannel) != 0) &&
+          (image->colorspace == CMYKColorspace))
+        {
+          pixel=ResamplePixelColor(resample_filter,QuantumScale*indexes[x]*
+            clut_image->columns,QuantumScale*indexes[x]*clut_image->rows);
+          indexes[x]=RoundToQuantum(pixel.index);
+        }
+      q++;
+    }
+    if (SyncImagePixels(image) == MagickFalse)
+      break;
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+        (QuantumTick(y,image->rows) != MagickFalse))
+      {
+        status=image->progress_monitor(ClutImageTag,y,image->rows,
+          image->client_data);
+        if (status == MagickFalse)
+          break;
+      }
+  }
+  resample_filter=DestroyResampleFilter(resample_filter);
+  clut_view=CloseCacheView(clut_view);
+  return(MagickTrue);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %     C o n t r a s t I m a g e                                               %
 %                                                                             %
 %                                                                             %
@@ -83,6 +233,33 @@
 %    o sharpen: Increase or decrease image contrast.
 %
 */
+
+static void Contrast(const int sign,Quantum *red,Quantum *green,Quantum *blue)
+{
+  double
+    brightness,
+    hue,
+    saturation;
+
+  /*
+    Enhance contrast: dark color become darker, light color become lighter.
+  */
+  assert(red != (Quantum *) NULL);
+  assert(green != (Quantum *) NULL);
+  assert(blue != (Quantum *) NULL);
+  hue=0.0;
+  saturation=0.0;
+  brightness=0.0;
+  ConvertRGBToHSB(*red,*green,*blue,&hue,&saturation,&brightness);
+  brightness+=0.5*sign*(0.5*(sin(MagickPI*(brightness-0.5))+1.0)-brightness);
+  if (brightness > 1.0)
+    brightness=1.0;
+  else
+    if (brightness < 0.0)
+      brightness=0.0;
+  ConvertHSBToRGB(hue,saturation,brightness,red,green,blue);
+}
+
 MagickExport MagickBooleanType ContrastImage(Image *image,
   const MagickBooleanType sharpen)
 {
@@ -270,9 +447,9 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  histogram=(MagickPixelPacket *) AcquireMagickMemory((MaxMap+1)*
+  histogram=(MagickPixelPacket *) AcquireQuantumMemory(MaxMap+1UL,
     sizeof(*histogram));
-  normalize_map=(MagickPixelPacket *) AcquireMagickMemory((MaxMap+1)*
+  normalize_map=(MagickPixelPacket *) AcquireQuantumMemory(MaxMap+1UL,
     sizeof(*normalize_map));
   if ((histogram == (MagickPixelPacket *) NULL) ||
       (normalize_map == (MagickPixelPacket *) NULL))
@@ -310,7 +487,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           histogram[ScaleQuantumToMap(p->green)].green++;
         if ((channel & BlueChannel) != 0)
           histogram[ScaleQuantumToMap(p->blue)].blue++;
-        if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+        if ((channel & OpacityChannel) != 0)
           histogram[ScaleQuantumToMap(p->opacity)].opacity++;
         if (((channel & IndexChannel) != 0) &&
             (image->colorspace == CMYKColorspace))
@@ -386,7 +563,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
     }
   black.opacity=0.0;
   white.opacity=MaxRange(QuantumRange);
-  if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+  if ((channel & OpacityChannel) != 0)
     {
       intensity=0.0;
       for (x=0; x <= (long) MaxMap; x++)
@@ -471,7 +648,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
                 (MagickRealType) (MaxMap*(i-black.blue)/(white.blue-
                 black.blue)));
       }
-    if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+    if ((channel & OpacityChannel) != 0)
       {
         if (i < (long) black.opacity)
           normalize_map[i].opacity=0.0;
@@ -502,9 +679,8 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
   /*
     Normalize the image.
   */
-  if ((((channel & OpacityChannel) != 0) && (image->matte != MagickFalse)) ||
-      (((channel & IndexChannel) != 0) &&
-        (image->colorspace == CMYKColorspace)))
+  if (((channel & OpacityChannel) != 0) || (((channel & IndexChannel) != 0) &&
+      (image->colorspace == CMYKColorspace)))
     image->storage_class=DirectClass;
   if (image->storage_class == PseudoClass)
     {
@@ -531,7 +707,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
               image->colormap[i].blue=RoundToQuantum(normalize_map[
                 ScaleQuantumToMap(image->colormap[i].blue)].blue);
           }
-        if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+        if ((channel & OpacityChannel) != 0)
           {
             if (black.opacity != white.opacity)
               image->colormap[i].opacity=RoundToQuantum(normalize_map[
@@ -559,27 +735,27 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
       if ((channel & GreenChannel) != 0)
         {
           if (black.green != white.green)
-            q->green=RoundToQuantum(
-              normalize_map[ScaleQuantumToMap(q->green)].green);
+            q->green=RoundToQuantum(normalize_map[
+              ScaleQuantumToMap(q->green)].green);
         }
       if ((channel & BlueChannel) != 0)
         {
           if (black.blue != white.blue)
-            q->blue=RoundToQuantum(
-              normalize_map[ScaleQuantumToMap(q->blue)].blue);
+            q->blue=RoundToQuantum(normalize_map[
+              ScaleQuantumToMap(q->blue)].blue);
         }
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         {
           if (black.opacity != white.opacity)
-            q->opacity=RoundToQuantum(
-              normalize_map[ScaleQuantumToMap(q->opacity)].opacity);
+            q->opacity=RoundToQuantum(normalize_map[ScaleQuantumToMap(
+              q->opacity)].opacity);
         }
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
         {
           if (black.index != white.index)
-            indexes[x]=(IndexPacket) RoundToQuantum(
-              normalize_map[ScaleQuantumToMap(indexes[x])].index);
+            indexes[x]=(IndexPacket) RoundToQuantum(normalize_map[
+              ScaleQuantumToMap(indexes[x])].index);
         }
       q++;
     }
@@ -744,8 +920,8 @@ MagickExport Image *EnhanceImage(const Image *image,ExceptionInfo *exception)
       q->red=(Quantum) ((aggregate.red+(total_weight/2)-1)/total_weight);
       q->green=(Quantum) ((aggregate.green+(total_weight/2)-1)/total_weight);
       q->blue=(Quantum) ((aggregate.blue+(total_weight/2)-1)/total_weight);
-      q->opacity=(Quantum)
-        ((aggregate.opacity+(total_weight/2)-1)/total_weight);
+      q->opacity=(Quantum) ((aggregate.opacity+(total_weight/2)-1)/
+        total_weight);
       p++;
       q++;
     }
@@ -822,11 +998,11 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  histogram=(MagickPixelPacket *) AcquireMagickMemory((MaxMap+1)*
+  histogram=(MagickPixelPacket *) AcquireQuantumMemory(MaxMap+1UL,
     sizeof(*histogram));
-  map=(MagickPixelPacket *) AcquireMagickMemory((MaxMap+1)*sizeof(*map));
-  equalize_map=(PixelPacket *)
-    AcquireMagickMemory((MaxMap+1)*sizeof(*equalize_map));
+  map=(MagickPixelPacket *) AcquireQuantumMemory(MaxMap+1UL,sizeof(*map));
+  equalize_map=(PixelPacket *) AcquireQuantumMemory(MaxMap+1UL,
+    sizeof(*equalize_map));
   if ((histogram == (MagickPixelPacket *) NULL) ||
       (map == (MagickPixelPacket *) NULL) ||
       (equalize_map == (PixelPacket *) NULL))
@@ -1038,8 +1214,8 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (gamma == 1.0)
     return(MagickTrue);
-  gamma_map=(MagickRealType *)
-    AcquireMagickMemory((MaxMap+1)*sizeof(*gamma_map));
+  gamma_map=(MagickRealType *) AcquireQuantumMemory(MaxMap+1UL,
+    sizeof(*gamma_map));
   if (gamma_map == (MagickRealType *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
@@ -1056,17 +1232,24 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
       for (i=0; i < (long) image->colors; i++)
       {
         if ((channel & RedChannel) != 0)
-          image->colormap[i].red=RoundToQuantum
-            (gamma_map[ScaleQuantumToMap(image->colormap[i].red)]);
+          image->colormap[i].red=RoundToQuantum(gamma_map[
+            ScaleQuantumToMap(image->colormap[i].red)]);
         if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=RoundToQuantum
-            (gamma_map[ScaleQuantumToMap(image->colormap[i].green)]);
+          image->colormap[i].green=RoundToQuantum(gamma_map[
+            ScaleQuantumToMap(image->colormap[i].green)]);
         if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=RoundToQuantum
-            (gamma_map[ScaleQuantumToMap(image->colormap[i].blue)]);
+          image->colormap[i].blue=RoundToQuantum(gamma_map[
+            ScaleQuantumToMap(image->colormap[i].blue)]);
         if ((channel & OpacityChannel) != 0)
-          image->colormap[i].opacity=RoundToQuantum
-            (gamma_map[ScaleQuantumToMap(image->colormap[i].opacity)]);
+          {
+            if (image->matte == MagickFalse)
+              image->colormap[i].opacity=RoundToQuantum(gamma_map[
+                ScaleQuantumToMap(image->colormap[i].opacity)]);
+            else
+              image->colormap[i].opacity=(Quantum) QuantumRange-RoundToQuantum(
+                gamma_map[ScaleQuantumToMap((Quantum) QuantumRange-
+                image->colormap[i].opacity)]);
+          }
       }
     }
   /*
@@ -1086,8 +1269,14 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
         q->green=RoundToQuantum(gamma_map[ScaleQuantumToMap(q->green)]);
       if ((channel & BlueChannel) != 0)
         q->blue=RoundToQuantum(gamma_map[ScaleQuantumToMap(q->blue)]);
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-        q->opacity=RoundToQuantum(gamma_map[ScaleQuantumToMap(q->opacity)]);
+      if ((channel & OpacityChannel) != 0)
+        {
+          if (image->matte == MagickFalse)
+            q->opacity=RoundToQuantum(gamma_map[ScaleQuantumToMap(q->opacity)]);
+          else
+            q->opacity=(Quantum) QuantumRange-RoundToQuantum(
+              gamma_map[ScaleQuantumToMap((Quantum) QuantumRange-q->opacity)]);
+        }
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
         indexes[x]=RoundToQuantum(gamma_map[ScaleQuantumToMap(indexes[x])]);
@@ -1211,9 +1400,6 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   MagickBooleanType
     status;
 
-  MagickRealType
-    *levels_map;
-
   register long
     i,
     x;
@@ -1221,10 +1407,6 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   register PixelPacket
     *q;
 
-  unsigned long
-    black,
-    white;
-
   /*
     Allocate and initialize levels map.
   */
@@ -1232,45 +1414,28 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  levels_map=(MagickRealType *) AcquireMagickMemory((MaxMap+1)*
-    sizeof(*levels_map));
-  if (levels_map == (MagickRealType *) NULL)
-    ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
-      image->filename);
-  black=ScaleQuantumToMap(RoundToQuantum(black_point));
-  white=ScaleQuantumToMap(RoundToQuantum(white_point));
-  for (i=0; i < (long) black; i++)
-    levels_map[i]=0.0;
-  if (gamma == 1.0)
-    {
-      for ( ; i < (long) white; i++)
-        levels_map[i]=(MagickRealType) (MaxMap*(((MagickRealType) i-black)/
-          (white-black)));
-    }
-  else
-    for ( ; i < (long) white; i++)
-      levels_map[i]=(MagickRealType) (MaxMap*(pow(((double) i-black)/
-        (white-black),1.0/gamma)));
-  for ( ; i <= (long) MaxMap; i++)
-    levels_map[i]=(MagickRealType) MaxMap;
   if (image->storage_class == PseudoClass)
+    for (i=0; i < (long) image->colors; i++)
     {
       /*
         Level colormap.
       */
-      for (i=0; i < (long) image->colors; i++)
-      {
-        if ((channel & RedChannel) != 0)
-          image->colormap[i].red=ScaleMapToQuantum(levels_map[
-            ScaleQuantumToMap(image->colormap[i].red)]);
-        if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=ScaleMapToQuantum(levels_map[
-            ScaleQuantumToMap(image->colormap[i].green)]);
-        if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=ScaleMapToQuantum(levels_map[
-            ScaleQuantumToMap(image->colormap[i].blue)]);
+      if ((channel & RedChannel) != 0)
+        image->colormap[i].red=RoundToQuantum((MagickRealType) QuantumRange*
+          pow(((double) image->colormap[i].red-black_point)/(white_point-
+          black_point),1.0/gamma));
+      if ((channel & GreenChannel) != 0)
+        image->colormap[i].green=RoundToQuantum((MagickRealType) QuantumRange*
+          pow(((double) image->colormap[i].green-black_point)/(white_point-
+          black_point),1.0/gamma));
+      if ((channel & BlueChannel) != 0)
+        image->colormap[i].blue=RoundToQuantum((MagickRealType) QuantumRange*
+          pow(((double) image->colormap[i].blue-black_point)/(white_point-
+          black_point),1.0/gamma));
+      if ((channel & OpacityChannel) != 0)
+        image->colormap[i].opacity=RoundToQuantum((MagickRealType) QuantumRange*          pow(((double) image->colormap[i].opacity-black_point)/(white_point-
+          black_point),1.0/gamma));
       }
-    }
   /*
     Level image.
   */
@@ -1283,17 +1448,21 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->red)]);
+        q->red=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          q->red-black_point)/(white_point-black_point),1.0/gamma));
       if ((channel & GreenChannel) != 0)
-        q->green=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->green)]);
+        q->green=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          q->green-black_point)/(white_point-black_point),1.0/gamma));
       if ((channel & BlueChannel) != 0)
-        q->blue=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->blue)]);
-      if (((channel & OpacityChannel) != 0) & (image->matte != MagickFalse))
-        q->opacity=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->opacity)]);
+        q->blue=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          q->blue-black_point)/(white_point-black_point),1.0/gamma));
+      if ((channel & OpacityChannel) != 0)
+        q->opacity=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          q->opacity-black_point)/(white_point-black_point),1.0/gamma));
       if (((channel & IndexChannel) != 0) &&
-          ((image->storage_class == PseudoClass) ||
-           (image->colorspace == CMYKColorspace)))
-        indexes[x]=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(indexes[x])]);
+          (image->colorspace == CMYKColorspace))
+        indexes[x]=RoundToQuantum((MagickRealType) QuantumRange*pow(((double)
+          indexes[x]-black_point)/(white_point-black_point),1.0/gamma));
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -1307,7 +1476,6 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
           break;
       }
   }
-  levels_map=(MagickRealType *) RelinquishMagickMemory(levels_map);
   return(MagickTrue);
 }
 
@@ -1370,7 +1538,7 @@ MagickExport MagickBooleanType LinearStretchImage(Image *image,
   */
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  histogram=(MagickRealType *) AcquireMagickMemory((MaxMap+1)*
+  histogram=(MagickRealType *) AcquireQuantumMemory(MaxMap+1UL,
     sizeof(*histogram));
   if (histogram == (MagickRealType *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -1443,6 +1611,83 @@ MagickExport MagickBooleanType LinearStretchImage(Image *image,
 %      hue.
 %
 */
+
+static void ModulateHSB(const double percent_hue,
+  const double percent_saturation,const double percent_brightness,
+  Quantum *red,Quantum *green,Quantum *blue)
+{
+  double
+    brightness,
+    hue,
+    saturation;
+
+  /*
+    Increase or decrease color brightness, saturation, or hue.
+  */
+  assert(red != (Quantum *) NULL);
+  assert(green != (Quantum *) NULL);
+  assert(blue != (Quantum *) NULL);
+  ConvertRGBToHSB(*red,*green,*blue,&hue,&saturation,&brightness);
+  hue+=0.5*(0.01*percent_hue-1.0);
+  while (hue < 0.0)
+    hue+=1.0;
+  while (hue > 1.0)
+    hue-=1.0;
+  saturation*=0.01*percent_saturation;
+  brightness*=0.01*percent_brightness;
+  ConvertHSBToRGB(hue,saturation,brightness,red,green,blue);
+}
+
+static void ModulateHSL(const double percent_hue,
+  const double percent_saturation,const double percent_luminosity,
+  Quantum *red,Quantum *green,Quantum *blue)
+{
+  double
+    hue,
+    luminosity,
+    saturation;
+
+  /*
+    Increase or decrease color luminosity, saturation, or hue.
+  */
+  assert(red != (Quantum *) NULL);
+  assert(green != (Quantum *) NULL);
+  assert(blue != (Quantum *) NULL);
+  ConvertRGBToHSL(*red,*green,*blue,&hue,&saturation,&luminosity);
+  hue+=0.5*(0.01*percent_hue-1.0);
+  while (hue < 0.0)
+    hue+=1.0;
+  while (hue > 1.0)
+    hue-=1.0;
+  saturation*=0.01*percent_saturation;
+  luminosity*=0.01*percent_luminosity;
+  ConvertHSLToRGB(hue,saturation,luminosity,red,green,blue);
+}
+
+static void ModulateHWB(const double percent_hue,const double percent_whiteness,  const double percent_blackness,Quantum *red,Quantum *green,Quantum *blue)
+{
+  double
+    blackness,
+    hue,
+    whiteness;
+
+  /*
+    Increase or decrease color blackness, whiteness, or hue.
+  */
+  assert(red != (Quantum *) NULL);
+  assert(green != (Quantum *) NULL);
+  assert(blue != (Quantum *) NULL);
+  ConvertRGBToHWB(*red,*green,*blue,&hue,&whiteness,&blackness);
+  hue+=0.5*(0.01*percent_hue-1.0);
+  while (hue < 0.0)
+    hue+=1.0;
+  while (hue > 1.0)
+    hue-=1.0;
+  blackness*=0.01*percent_blackness;
+  whiteness*=0.01*percent_whiteness;
+  ConvertHWBToRGB(hue,whiteness,blackness,red,green,blue);
+}
+
 MagickExport MagickBooleanType ModulateImage(Image *image,const char *modulate)
 {
 #define ModulateImageTag  "Modulate/Image"
@@ -1649,12 +1894,13 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               (image->colormap[i].green != image->colormap[i].blue))
             continue;
         if ((channel & RedChannel) != 0)
-          image->colormap[i].red=QuantumRange-image->colormap[i].red;
+          image->colormap[i].red=(Quantum) QuantumRange-
+            image->colormap[i].red;
         if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=QuantumRange-
+          image->colormap[i].green=(Quantum) QuantumRange-
             image->colormap[i].green;
         if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=QuantumRange-
+          image->colormap[i].blue=(Quantum) QuantumRange-
             image->colormap[i].blue;
       }
     }
@@ -1677,14 +1923,13 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               continue;
             }
           if ((channel & RedChannel) != 0)
-            q->red=QuantumRange-q->red;
+            q->red=(Quantum) QuantumRange-q->red;
           if ((channel & GreenChannel) != 0)
-            q->green=QuantumRange-q->green;
+            q->green=(Quantum) QuantumRange-q->green;
           if ((channel & BlueChannel) != 0)
-            q->blue=QuantumRange-q->blue;
-          if (((channel & OpacityChannel) != 0) &&
-              (image->matte != MagickFalse))
-            q->opacity=QuantumRange-q->opacity;
+            q->blue=(Quantum) QuantumRange-q->blue;
+          if ((channel & OpacityChannel) != 0)
+            q->opacity=(Quantum) QuantumRange-q->opacity;
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
             indexes[x]=(IndexPacket) QuantumRange-indexes[x];
@@ -1715,13 +1960,13 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=QuantumRange-q->red;
+        q->red=(Quantum) QuantumRange-q->red;
       if ((channel & GreenChannel) != 0)
-        q->green=QuantumRange-q->green;
+        q->green=(Quantum) QuantumRange-q->green;
       if ((channel & BlueChannel) != 0)
-        q->blue=QuantumRange-q->blue;
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-        q->opacity=QuantumRange-q->opacity;
+        q->blue=(Quantum) QuantumRange-q->blue;
+      if ((channel & OpacityChannel) != 0)
+        q->opacity=(Quantum) QuantumRange-q->opacity;
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
         indexes[x]=(IndexPacket) QuantumRange-indexes[x];
@@ -1758,8 +2003,9 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
 %
 %  The format of the NormalizeImage method is:
 %
-%      MagickBooleanType NormalizeImage(Image *image,
-%        const unsigned long channel)
+%      MagickBooleanType NormalizeImage(Image *image)
+%      MagickBooleanType NormalizeImageChannel(Image *image,
+%        const ChannelType channel)
 %
 %  A description of each parameter follows:
 %
@@ -1886,8 +2132,8 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  sigmoidal_map=(MagickRealType *)
-    AcquireMagickMemory((MaxMap+1)*sizeof(*sigmoidal_map));
+  sigmoidal_map=(MagickRealType *) AcquireQuantumMemory(MaxMap+1UL,
+    sizeof(*sigmoidal_map));
   if (sigmoidal_map == (MagickRealType *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
@@ -1952,7 +2198,7 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
         q->green=RoundToQuantum(sigmoidal_map[ScaleQuantumToMap(q->green)]);
       if ((channel & BlueChannel) != 0)
         q->blue=RoundToQuantum(sigmoidal_map[ScaleQuantumToMap(q->blue)]);
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         q->opacity=RoundToQuantum(sigmoidal_map[ScaleQuantumToMap(q->opacity)]);
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
