@@ -234,7 +234,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           (void) FormatMagickSize(GetBlobSize(image),format);
           (void) fprintf(file,"%s ",format);
         }
-      if (elapsed_time > 0.02)
+      if (elapsed_time > 0.06)
         (void) fprintf(file,"%0.3fu %ld:%02ld",user_time,
           (long) (elapsed_time/60.0+0.5),(long) ceil(fmod(elapsed_time,60.0)));
       (void) fprintf(file,"\n");
@@ -276,7 +276,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         (image->magick_rows != image->rows))
       (void) fprintf(file,"  Base geometry: %lux%lu\n",image->magick_columns,
         image->magick_rows);
-  (void) fprintf(file,"  Type: %s\n",MagickOptionToMnemonic(MagickImageOptions,
+  (void) fprintf(file,"  Type: %s\n",MagickOptionToMnemonic(MagickTypeOptions,
     (long) type));
   (void) fprintf(file,"  Endianess: %s\n",MagickOptionToMnemonic(
     MagickEndianOptions,(long) image->endian));
@@ -448,8 +448,8 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           channel_statistics[OpacityChannel].standard_deviation/(double) scale,
           channel_statistics[OpacityChannel].standard_deviation/(double)
           QuantumRange);
-      channel_statistics=(ChannelStatistics *)
-        RelinquishMagickMemory(channel_statistics);
+      channel_statistics=(ChannelStatistics *) RelinquishMagickMemory(
+        channel_statistics);
       if (colorspace == CMYKColorspace)
         (void) fprintf(file,"  Total ink density: %.0f%%\n",100.0*
           GetImageTotalInkDensity(image)/(double) QuantumRange);
@@ -457,7 +457,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
       p=NewImageList();
       if (image->matte != MagickFalse)
         {
-          IndexPacket
+          register const IndexPacket
             *indexes;
 
           register const PixelPacket
@@ -470,10 +470,10 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
             p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
             if (p == (const PixelPacket *) NULL)
               break;
-            indexes=GetIndexes(image);
+            indexes=AcquireIndexes(image);
             for (x=0; x < (long) image->columns; x++)
             {
-              if (p->opacity == TransparentOpacity)
+              if (p->opacity == (Quantum) TransparentOpacity)
                 break;
               p++;
             }
@@ -498,10 +498,8 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
               (void) fprintf(file,"  %s\n",tuple);
             }
         }
-      image->total_colors=GetNumberColors(image,(FILE *) NULL,
-        &image->exception);
-      (void) fprintf(file,"  Colors: %lu\n",image->total_colors);
-      if ((ping == MagickFalse) && (image->total_colors <= 1024))
+      if ((ping == MagickFalse) &&
+          (IsHistogramImage(image,&image->exception) != MagickFalse))
         {
           (void) fprintf(file,"  Histogram:\n");
           (void) GetNumberColors(image,file,&image->exception);
@@ -639,7 +637,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
     if (image->scene != 0)
       (void) fprintf(file,"  Scene: %lu\n",image->scene);
   (void) fprintf(file,"  Compression: %s\n",
-    MagickOptionToMnemonic(MagickCompressionOptions,(long) image->compression));
+    MagickOptionToMnemonic(MagickComposeOptions,(long) image->compression));
   if (image->quality != UndefinedCompressionQuality)
     (void) fprintf(file,"  Quality: %lu\n",image->quality);
   (void) fprintf(file,"  Orientation: %s\n",
@@ -690,12 +688,13 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
         property=GetNextImageProperty(tile);
         while (property != (const char *) NULL)
         {
-          if (*property == '[')
-            continue;
-          (void) fprintf(file,"  %s:\n",property);
-          value=GetImageProperty(tile,property);
-          if (value != (const char *) NULL)
-            (void) fprintf(file,"%s\n",value);
+          if (*property != '[')
+            {
+              (void) fprintf(file,"  %s:\n",property);
+              value=GetImageProperty(tile,property);
+              if (value != (const char *) NULL)
+                (void) fprintf(file,"%s\n",value);
+            }
           property=GetNextImageProperty(tile);
         }
         tile=DestroyImage(tile);
@@ -862,8 +861,10 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
               (void) fprintf(file,"    %s[%ld,%ld]: ",tag,dataset,record);
               length=(size_t) (GetStringInfoDatum(profile)[i++] << 8);
               length|=GetStringInfoDatum(profile)[i++];
-              attribute=(char *) AcquireMagickMemory((length+MaxTextExtent)*
-                sizeof(*attribute));
+              attribute=(char *) NULL;
+              if (~length >= MaxTextExtent)
+                attribute=(char *) AcquireQuantumMemory(length+MaxTextExtent,
+                  sizeof(*attribute));
               if (attribute != (char *) NULL)
                 {
                   (void) CopyMagickString(attribute,(char *)
@@ -894,7 +895,7 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
     (void) fprintf(file,"  Tainted: True\n");
   else
     (void) fprintf(file,"  Tainted: False\n");
-  if (elapsed_time > 0.02)
+  if (elapsed_time > 0.06)
     {
       (void) fprintf(file,"  User time: %0.3fu\n",user_time);
       (void) fprintf(file,"  Elapsed time: %ld:%02ld\n",
