@@ -367,7 +367,7 @@ MagickExport void DeleteImages(Image **images,const char *scenes,
   assert(exception->signature == MagickSignature);
   *images=GetFirstImageInList(*images);
   length=GetImageListLength(*images);
-  delete_list=(MagickBooleanType *) AcquireMagickMemory(length*
+  delete_list=(MagickBooleanType *) AcquireQuantumMemory(length,
     sizeof(*delete_list));
   if (delete_list == (MagickBooleanType *) NULL)
     {
@@ -748,7 +748,7 @@ MagickExport Image **ImageListToArray(const Image *images,
   assert(images->signature == MagickSignature);
   if (images->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
-  group=(Image **) AcquireMagickMemory((size_t) (GetImageListLength(images)+1)*
+  group=(Image **) AcquireQuantumMemory((size_t) GetImageListLength(images)+1UL,
     sizeof(*group));
   if (group == (Image **) NULL)
     {
