@@ -275,8 +275,8 @@ MagickExport const LocaleInfo **GetLocaleInfoList(const char *pattern,
   p=GetLocaleInfo_("*",exception);
   if (p == (const LocaleInfo *) NULL)
     return((const LocaleInfo **) NULL);
-  messages=(const LocaleInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfNodesInSplayTree(locale_list)+1)*sizeof(*messages));
+  messages=(const LocaleInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfNodesInSplayTree(locale_list)+1UL,sizeof(*messages));
   if (messages == (const LocaleInfo **) NULL)
     return((const LocaleInfo **) NULL);
   /*
@@ -372,8 +372,8 @@ MagickExport char **GetLocaleList(const char *pattern,
     return((char **) NULL);
   AcquireSemaphoreInfo(&locale_semaphore);
   RelinquishSemaphoreInfo(locale_semaphore);
-  messages=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfNodesInSplayTree(locale_list)+1)*sizeof(*messages));
+  messages=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfNodesInSplayTree(locale_list)+1UL,sizeof(*messages));
   if (messages == (char **) NULL)
     return((char **) NULL);
   AcquireSemaphoreInfo(&locale_semaphore);
@@ -589,6 +589,7 @@ static MagickBooleanType InitializeLocaleList(ExceptionInfo *exception)
           register const char
             *p;
 
+          (void) setlocale(LC_ALL,"");
           locale=(char *) NULL;
           p=setlocale(LC_CTYPE,(const char *) NULL);
           if (p != (const char *) NULL)
@@ -738,8 +739,8 @@ static MagickBooleanType TraverseLocaleMap(const char *filename,
 
   status=MagickTrue;
   if (depth >= MaxRecursionDepth)
-    (void) ThrowMagickException(exception,GetMagickModule(),
-      ConfigureError,"IncludeElementNestedTooDeeply","`%s'",filename);
+    (void) ThrowMagickException(exception,GetMagickModule(),ConfigureError,
+      "IncludeElementNestedTooDeeply","`%s'",filename);
   else
     if (node != (XMLTreeInfo *) NULL)
       {
@@ -767,8 +768,8 @@ static MagickBooleanType TraverseLocaleMap(const char *filename,
             locale_info=(LocaleInfo *) AcquireMagickMemory(
               sizeof(*locale_info));
             if (locale_info == (LocaleInfo *) NULL)
-              ThrowMagickFatalException(ResourceLimitFatalError,
-                "MemoryAllocationFailed",filename);
+              ThrowFatalException(ResourceLimitFatalError,
+                "MemoryAllocationFailed");
             (void) ResetMagickMemory(locale_info,0,sizeof(*locale_info));
             locale_info->path=ConstantString(filename);
             locale_info->signature=MagickSignature;
@@ -886,7 +887,7 @@ static MagickBooleanType LoadLocaleList(const char *xml,const char *filename,
       }
     include=GetNextXMLTreeTag(include);
   }
-  components=(XMLTreeInfo **) AcquireMagickMemory(MaxRecursionDepth*
+  components=(XMLTreeInfo **) AcquireQuantumMemory(MaxRecursionDepth,
     sizeof(*components));
   if (components == (XMLTreeInfo **) NULL)
     {
