@@ -364,8 +364,8 @@ MagickExport const MagicInfo **GetMagicInfoList(const char *pattern,
   p=GetMagicInfo((const unsigned char *) "*",0,exception);
   if (p == (const MagicInfo *) NULL)
     return((const MagicInfo **) NULL);
-  aliases=(const MagicInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(magic_list)+1)*sizeof(*aliases));
+  aliases=(const MagicInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(magic_list)+1UL,sizeof(*aliases));
   if (aliases == (const MagicInfo **) NULL)
     return((const MagicInfo **) NULL);
   /*
@@ -459,8 +459,8 @@ MagickExport char **GetMagicList(const char *pattern,
   p=GetMagicInfo((const unsigned char *) "*",0,exception);
   if (p == (const MagicInfo *) NULL)
     return((char **) NULL);
-  aliases=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(magic_list)+1)*sizeof(*aliases));
+  aliases=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(magic_list)+1UL,sizeof(*aliases));
   if (aliases == (char **) NULL)
     return((char **) NULL);
   AcquireSemaphoreInfo(&magic_semaphore);
@@ -737,8 +737,7 @@ static MagickBooleanType LoadMagicList(const char *xml,const char *filename,
     */
     magic_info=(MagicInfo *) AcquireMagickMemory(sizeof(*magic_info));
     if (magic_info == (MagicInfo *) NULL)
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",filename);
+      ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(magic_info,0,sizeof(*magic_info));
     magic_info->path=ConstantString(filename);
     magic_info->signature=MagickSignature;
