@@ -116,9 +116,9 @@ extern MagickExport MagickStatusType
   GetMagickThreadSupport(const MagickInfo *);
 
 extern MagickExport void
-  DestroyMagick(void),
   DestroyMagickList(void),
-  InitializeMagick(const char *);
+  MagickCoreGenesis(const char *,const MagickBooleanType),
+  MagickCoreTerminus(void);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
