@@ -38,21 +38,26 @@ extern "C" {
   EvaluateMagickPrefix(MagickMethodPrefix,method)
 
 #define AcquireCacheNexus  PrependMagickMethod(AcquireCacheNexus)
-#define AcquireCacheView  PrependMagickMethod(AcquireCacheView)
+#define AcquireCacheViewIndexes  PrependMagickMethod(AcquireCacheViewIndexes)
+#define AcquireCacheViewPixels  PrependMagickMethod(AcquireCacheViewPixels)
 #define AcquireDrawInfo  PrependMagickMethod(AcquireDrawInfo)
 #define AcquireExceptionInfo  PrependMagickMethod(AcquireExceptionInfo)
 #define AcquireFxInfo  PrependMagickMethod(AcquireFxInfo)
 #define AcquireImageInfo  PrependMagickMethod(AcquireImageInfo)
 #define AcquireImagePixels  PrependMagickMethod(AcquireImagePixels)
+#define AcquireIndexes  PrependMagickMethod(AcquireIndexes)
 #define AcquireMagickMemory  PrependMagickMethod(AcquireMagickMemory)
 #define AcquireMagickResource  PrependMagickMethod(AcquireMagickResource)
 #define AcquireMemory  PrependMagickMethod(AcquireMemory)
+#define AcquireNexusIndexes  PrependMagickMethod(AcquireNexusIndexes)
 #define AcquireOneCacheViewPixel  PrependMagickMethod(AcquireOneCacheViewPixel)
 #define AcquireOneMagickPixel  PrependMagickMethod(AcquireOneMagickPixel)
 #define AcquireOnePixel  PrependMagickMethod(AcquireOnePixel)
 #define AcquireOneVirtualPixel  PrependMagickMethod(AcquireOneVirtualPixel)
 #define AcquireQuantizeInfo  PrependMagickMethod(AcquireQuantizeInfo)
 #define AcquireQuantumInfo  PrependMagickMethod(AcquireQuantumInfo)
+#define AcquireQuantumMemory  PrependMagickMethod(AcquireQuantumMemory)
+#define AcquireResampleFilter  PrependMagickMethod(AcquireResampleFilter)
 #define AcquireSemaphoreInfo  PrependMagickMethod(AcquireSemaphoreInfo)
 #define AcquireStreamInfo  PrependMagickMethod(AcquireStreamInfo)
 #define AcquireStringInfo  PrependMagickMethod(AcquireStringInfo)
@@ -78,7 +83,7 @@ extern "C" {
 #define AllocateNextImage  PrependMagickMethod(AllocateNextImage)
 #define AllocateSemaphoreInfo  PrependMagickMethod(AllocateSemaphoreInfo)
 #define AllocateString  PrependMagickMethod(AllocateString)
-#define AnalyzeImage  PrependMagickMethod(AnalyzeImage)
+#define analyzeImage  PrependMagickMethod(analyzeImage)
 #define AnimateImages  PrependMagickMethod(AnimateImages)
 #define AnnotateImage  PrependMagickMethod(AnnotateImage)
 #define AppendImageFormat  PrependMagickMethod(AppendImageFormat)
@@ -115,6 +120,7 @@ extern "C" {
 #define ClipPathImage  PrependMagickMethod(ClipPathImage)
 #define CloneBlobInfo  PrependMagickMethod(CloneBlobInfo)
 #define CloneCacheMethods  PrependMagickMethod(CloneCacheMethods)
+#define CloneCacheView  PrependMagickMethod(CloneCacheView)
 #define CloneDrawInfo  PrependMagickMethod(CloneDrawInfo)
 #define CloneImageAttributes  PrependMagickMethod(CloneImageAttributes)
 #define CloneImageInfo  PrependMagickMethod(CloneImageInfo)
@@ -132,6 +138,8 @@ extern "C" {
 #define CloseBlob  PrependMagickMethod(CloseBlob)
 #define CloseCacheView  PrependMagickMethod(CloseCacheView)
 #define CloseMagickLog  PrependMagickMethod(CloseMagickLog)
+#define ClutImageChannel  PrependMagickMethod(ClutImageChannel)
+#define ClutImage  PrependMagickMethod(ClutImage)
 #define CoalesceImages  PrependMagickMethod(CoalesceImages)
 #define ColorFloodfillImage  PrependMagickMethod(ColorFloodfillImage)
 #define ColorizeImage  PrependMagickMethod(ColorizeImage)
@@ -148,6 +156,7 @@ extern "C" {
 #define CompositeImage  PrependMagickMethod(CompositeImage)
 #define CompositeLayers  PrependMagickMethod(CompositeLayers)
 #define CompressImageColormap  PrependMagickMethod(CompressImageColormap)
+#define ConcatenateColorComponent  PrependMagickMethod(ConcatenateColorComponent)
 #define ConcatenateMagickString  PrependMagickMethod(ConcatenateMagickString)
 #define ConcatenateStringInfo  PrependMagickMethod(ConcatenateStringInfo)
 #define ConcatenateString  PrependMagickMethod(ConcatenateString)
@@ -157,9 +166,14 @@ extern "C" {
 #define ConstituteImage  PrependMagickMethod(ConstituteImage)
 #define ContinueTimer  PrependMagickMethod(ContinueTimer)
 #define ContrastImage  PrependMagickMethod(ContrastImage)
-#define Contrast  PrependMagickMethod(Contrast)
 #define ContrastStretchImageChannel  PrependMagickMethod(ContrastStretchImageChannel)
 #define ContrastStretchImage  PrependMagickMethod(ContrastStretchImage)
+#define ConvertHSBToRGB  PrependMagickMethod(ConvertHSBToRGB)
+#define ConvertHSLToRGB  PrependMagickMethod(ConvertHSLToRGB)
+#define ConvertHWBToRGB  PrependMagickMethod(ConvertHWBToRGB)
+#define ConvertRGBToHSB  PrependMagickMethod(ConvertRGBToHSB)
+#define ConvertRGBToHSL  PrependMagickMethod(ConvertRGBToHSL)
+#define ConvertRGBToHWB  PrependMagickMethod(ConvertRGBToHWB)
 #define ConvolveImageChannel  PrependMagickMethod(ConvolveImageChannel)
 #define ConvolveImage  PrependMagickMethod(ConvolveImage)
 #define CopyMagickMemory  PrependMagickMethod(CopyMagickMemory)
@@ -169,13 +183,18 @@ extern "C" {
 #define DeconstructImages  PrependMagickMethod(DeconstructImages)
 #define DefineImageOption  PrependMagickMethod(DefineImageOption)
 #define DefineImageProperty  PrependMagickMethod(DefineImageProperty)
+#define DefineImageRegistry  PrependMagickMethod(DefineImageRegistry)
 #define DeleteImageAttribute  PrependMagickMethod(DeleteImageAttribute)
 #define DeleteImageFromList  PrependMagickMethod(DeleteImageFromList)
 #define DeleteImageList  PrependMagickMethod(DeleteImageList)
 #define DeleteImageOption  PrependMagickMethod(DeleteImageOption)
+#define DeleteImageProfile  PrependMagickMethod(DeleteImageProfile)
 #define DeleteImageProperty  PrependMagickMethod(DeleteImageProperty)
+#define DeleteImageRegistry  PrependMagickMethod(DeleteImageRegistry)
 #define DeleteImages  PrependMagickMethod(DeleteImages)
 #define DeleteMagickRegistry  PrependMagickMethod(DeleteMagickRegistry)
+#define DeleteNodeByValueFromSplayTree  PrependMagickMethod(DeleteNodeByValueFromSplayTree)
+#define DeleteNodeFromSplayTree  PrependMagickMethod(DeleteNodeFromSplayTree)
 #define DescribeImage  PrependMagickMethod(DescribeImage)
 #define DespeckleImage  PrependMagickMethod(DespeckleImage)
 #define DestroyBlob  PrependMagickMethod(DestroyBlob)
@@ -200,6 +219,7 @@ extern "C" {
 #define DestroyImage  PrependMagickMethod(DestroyImage)
 #define DestroyImageProfiles  PrependMagickMethod(DestroyImageProfiles)
 #define DestroyImageProperties  PrependMagickMethod(DestroyImageProperties)
+#define DestroyImageRegistry  PrependMagickMethod(DestroyImageRegistry)
 #define DestroyImages  PrependMagickMethod(DestroyImages)
 #define DestroyLinkedList  PrependMagickMethod(DestroyLinkedList)
 #define DestroyLocaleList  PrependMagickMethod(DestroyLocaleList)
@@ -216,6 +236,7 @@ extern "C" {
 #define DestroyQuantizeInfo  PrependMagickMethod(DestroyQuantizeInfo)
 #define DestroyQuantumInfo  PrependMagickMethod(DestroyQuantumInfo)
 #define DestroyRandomReservoir  PrependMagickMethod(DestroyRandomReservoir)
+#define DestroyResampleFilter  PrependMagickMethod(DestroyResampleFilter)
 #define DestroySemaphoreInfo  PrependMagickMethod(DestroySemaphoreInfo)
 #define DestroySemaphore  PrependMagickMethod(DestroySemaphore)
 #define DestroySplayTree  PrependMagickMethod(DestroySplayTree)
@@ -235,6 +256,7 @@ extern "C" {
 #define DisplayImages  PrependMagickMethod(DisplayImages)
 #define DisposeImages  PrependMagickMethod(DisposeImages)
 #define DistillRandomEvent  PrependMagickMethod(DistillRandomEvent)
+#define DistortImage  PrependMagickMethod(DistortImage)
 #define DrawAffineImage  PrependMagickMethod(DrawAffineImage)
 #define DrawClipPath  PrependMagickMethod(DrawClipPath)
 #define DrawGradientImage  PrependMagickMethod(DrawGradientImage)
@@ -249,6 +271,7 @@ extern "C" {
 #define EscapeString  PrependMagickMethod(EscapeString)
 #define EvaluateImageChannel  PrependMagickMethod(EvaluateImageChannel)
 #define EvaluateImage  PrependMagickMethod(EvaluateImage)
+#define ExcerptImage  PrependMagickMethod(ExcerptImage)
 #define ExecuteModuleProcess  PrependMagickMethod(ExecuteModuleProcess)
 #define ExpandAffine  PrependMagickMethod(ExpandAffine)
 #define ExpandFilename  PrependMagickMethod(ExpandFilename)
@@ -287,6 +310,7 @@ extern "C" {
 #define GammaImage  PrependMagickMethod(GammaImage)
 #define GaussianBlurImageChannel  PrependMagickMethod(GaussianBlurImageChannel)
 #define GaussianBlurImage  PrependMagickMethod(GaussianBlurImage)
+#define GaussJordanElimination  PrependMagickMethod(GaussJordanElimination)
 #define GetAffineMatrix  PrependMagickMethod(GetAffineMatrix)
 #define GetBlobError  PrependMagickMethod(GetBlobError)
 #define GetBlobFileHandle  PrependMagickMethod(GetBlobFileHandle)
@@ -305,6 +329,7 @@ extern "C" {
 #define GetCacheViewPixels  PrependMagickMethod(GetCacheViewPixels)
 #define GetCacheView  PrependMagickMethod(GetCacheView)
 #define GetCacheViewStorageClass  PrependMagickMethod(GetCacheViewStorageClass)
+#define GetCacheVirtualPixelMethod  PrependMagickMethod(GetCacheVirtualPixelMethod)
 #define GetClientName  PrependMagickMethod(GetClientName)
 #define GetClientPath  PrependMagickMethod(GetClientPath)
 #define GetCoderInfoList  PrependMagickMethod(GetCoderInfoList)
@@ -371,6 +396,7 @@ extern "C" {
 #define GetImageQuantizeError  PrependMagickMethod(GetImageQuantizeError)
 #define GetImageQuantumDepth  PrependMagickMethod(GetImageQuantumDepth)
 #define GetImageRange  PrependMagickMethod(GetImageRange)
+#define GetImageRegistry  PrependMagickMethod(GetImageRegistry)
 #define GetImageTotalInkDensity  PrependMagickMethod(GetImageTotalInkDensity)
 #define GetImageType  PrependMagickMethod(GetImageType)
 #define GetImageVirtualPixelMethod  PrependMagickMethod(GetImageVirtualPixelMethod)
@@ -432,6 +458,7 @@ extern "C" {
 #define GetNextImage  PrependMagickMethod(GetNextImage)
 #define GetNextImageProfile  PrependMagickMethod(GetNextImageProfile)
 #define GetNextImageProperty  PrependMagickMethod(GetNextImageProperty)
+#define GetNextImageRegistry  PrependMagickMethod(GetNextImageRegistry)
 #define GetNextKeyInHashmap  PrependMagickMethod(GetNextKeyInHashmap)
 #define GetNextKeyInSplayTree  PrependMagickMethod(GetNextKeyInSplayTree)
 #define GetNextValueInHashmap  PrependMagickMethod(GetNextValueInHashmap)
@@ -480,6 +507,7 @@ extern "C" {
 #define GetValueFromLinkedList  PrependMagickMethod(GetValueFromLinkedList)
 #define GetValueFromSplayTree  PrependMagickMethod(GetValueFromSplayTree)
 #define GetXMLTreeAttribute  PrependMagickMethod(GetXMLTreeAttribute)
+#define GetXMLTreeAttributes  PrependMagickMethod(GetXMLTreeAttributes)
 #define GetXMLTreeChild  PrependMagickMethod(GetXMLTreeChild)
 #define GetXMLTreeContent  PrependMagickMethod(GetXMLTreeContent)
 #define GetXMLTreeOrdered  PrependMagickMethod(GetXMLTreeOrdered)
@@ -493,13 +521,9 @@ extern "C" {
 #define HashPointerType  PrependMagickMethod(HashPointerType)
 #define HashStringInfoType  PrependMagickMethod(HashStringInfoType)
 #define HashStringType  PrependMagickMethod(HashStringType)
-#define HSBTransform  PrependMagickMethod(HSBTransform)
-#define HSLTransform  PrependMagickMethod(HSLTransform)
 #define Huffman2DEncodeImage  PrependMagickMethod(Huffman2DEncodeImage)
 #define HuffmanDecodeImage  PrependMagickMethod(HuffmanDecodeImage)
 #define HuffmanEncodeImage  PrependMagickMethod(HuffmanEncodeImage)
-#define Hull  PrependMagickMethod(Hull)
-#define HWBTransform  PrependMagickMethod(HWBTransform)
 #define IdentifyImage  PrependMagickMethod(IdentifyImage)
 #define IdentityAffine  PrependMagickMethod(IdentityAffine)
 #define ImageListToArray  PrependMagickMethod(ImageListToArray)
@@ -509,6 +533,7 @@ extern "C" {
 #define ImplodeImage  PrependMagickMethod(ImplodeImage)
 #define ImportImagePixels  PrependMagickMethod(ImportImagePixels)
 #define ImportQuantumPixels  PrependMagickMethod(ImportQuantumPixels)
+#define increase  PrependMagickMethod(increase)
 #define InheritException  PrependMagickMethod(InheritException)
 #define InitializeMagick  PrependMagickMethod(InitializeMagick)
 #define InitializeMagickResources  PrependMagickMethod(InitializeMagickResources)
@@ -533,6 +558,8 @@ extern "C" {
 #define IsGlob  PrependMagickMethod(IsGlob)
 #define IsGrayImage  PrependMagickMethod(IsGrayImage)
 #define IsHashmapEmpty  PrependMagickMethod(IsHashmapEmpty)
+#define IsHighDynamicRangeImage  PrependMagickMethod(IsHighDynamicRangeImage)
+#define IsHistogramImage  PrependMagickMethod(IsHistogramImage)
 #define IsImageObject  PrependMagickMethod(IsImageObject)
 #define IsImagesEqual  PrependMagickMethod(IsImagesEqual)
 #define IsImageSimilar  PrependMagickMethod(IsImageSimilar)
@@ -564,7 +591,7 @@ extern "C" {
 #define ListLogInfo  PrependMagickMethod(ListLogInfo)
 #define ListMagicInfo  PrependMagickMethod(ListMagicInfo)
 #define ListMagickInfo  PrependMagickMethod(ListMagickInfo)
-#define ListMagickOptionInfo  PrependMagickMethod(ListMagickOptionInfo)
+#define ListMagickOptions  PrependMagickMethod(ListMagickOptions)
 #define ListMagickResourceInfo  PrependMagickMethod(ListMagickResourceInfo)
 #define ListMimeInfo  PrependMagickMethod(ListMimeInfo)
 #define ListModuleInfo  PrependMagickMethod(ListModuleInfo)
@@ -599,9 +626,6 @@ extern "C" {
 #define MedianFilterImage  PrependMagickMethod(MedianFilterImage)
 #define MinifyImage  PrependMagickMethod(MinifyImage)
 #define ModifyImage  PrependMagickMethod(ModifyImage)
-#define ModulateHSB  PrependMagickMethod(ModulateHSB)
-#define ModulateHSL  PrependMagickMethod(ModulateHSL)
-#define ModulateHWB  PrependMagickMethod(ModulateHWB)
 #define ModulateImage  PrependMagickMethod(ModulateImage)
 #define MontageImageList  PrependMagickMethod(MontageImageList)
 #define MontageImages  PrependMagickMethod(MontageImages)
@@ -683,7 +707,9 @@ extern "C" {
 #define RandomThresholdImage  PrependMagickMethod(RandomThresholdImage)
 #define ReacquireMemory  PrependMagickMethod(ReacquireMemory)
 #define ReadBlobByte  PrependMagickMethod(ReadBlobByte)
+#define ReadBlobDouble  PrependMagickMethod(ReadBlobDouble)
 #define ReadBlobFloat  PrependMagickMethod(ReadBlobFloat)
+#define ReadBlobLongLong  PrependMagickMethod(ReadBlobLongLong)
 #define ReadBlobLong  PrependMagickMethod(ReadBlobLong)
 #define ReadBlobLSBLong  PrependMagickMethod(ReadBlobLSBLong)
 #define ReadBlobLSBShort  PrependMagickMethod(ReadBlobLSBShort)
@@ -712,6 +738,7 @@ extern "C" {
 #define RegisterCUTImage  PrependMagickMethod(RegisterCUTImage)
 #define RegisterDCMImage  PrependMagickMethod(RegisterDCMImage)
 #define RegisterDIBImage  PrependMagickMethod(RegisterDIBImage)
+#define RegisterDNGImage  PrependMagickMethod(RegisterDNGImage)
 #define RegisterDOTImage  PrependMagickMethod(RegisterDOTImage)
 #define RegisterDPSImage  PrependMagickMethod(RegisterDPSImage)
 #define RegisterDPXImage  PrependMagickMethod(RegisterDPXImage)
@@ -726,6 +753,7 @@ extern "C" {
 #define RegisterHTMLImage  PrependMagickMethod(RegisterHTMLImage)
 #define RegisterICONImage  PrependMagickMethod(RegisterICONImage)
 #define RegisterINFOImage  PrependMagickMethod(RegisterINFOImage)
+#define RegisterIPLImage  PrependMagickMethod(RegisterIPLImage)
 #define RegisterJP2Image  PrependMagickMethod(RegisterJP2Image)
 #define RegisterJPEGImage  PrependMagickMethod(RegisterJPEGImage)
 #define RegisterLABELImage  PrependMagickMethod(RegisterLABELImage)
@@ -813,18 +841,22 @@ extern "C" {
 #define RemoveImageOption  PrependMagickMethod(RemoveImageOption)
 #define RemoveImageProfile  PrependMagickMethod(RemoveImageProfile)
 #define RemoveImageProperty  PrependMagickMethod(RemoveImageProperty)
+#define RemoveImageRegistry  PrependMagickMethod(RemoveImageRegistry)
 #define RemoveLastElementFromLinkedList  PrependMagickMethod(RemoveLastElementFromLinkedList)
 #define RemoveLastImageFromList  PrependMagickMethod(RemoveLastImageFromList)
 #define RemoveNodeByValueFromSplayTree  PrependMagickMethod(RemoveNodeByValueFromSplayTree)
 #define RemoveNodeFromSplayTree  PrependMagickMethod(RemoveNodeFromSplayTree)
 #define RemoveZeroDelayLayers  PrependMagickMethod(RemoveZeroDelayLayers)
 #define ReplaceImageInList  PrependMagickMethod(ReplaceImageInList)
+#define ResampleImage  PrependMagickMethod(ResampleImage)
+#define ResamplePixelColor  PrependMagickMethod(ResamplePixelColor)
 #define ResetHashmapIterator  PrependMagickMethod(ResetHashmapIterator)
 #define ResetImageAttributeIterator  PrependMagickMethod(ResetImageAttributeIterator)
 #define ResetImageOptionIterator  PrependMagickMethod(ResetImageOptionIterator)
 #define ResetImagePage  PrependMagickMethod(ResetImagePage)
 #define ResetImageProfileIterator  PrependMagickMethod(ResetImageProfileIterator)
 #define ResetImagePropertyIterator  PrependMagickMethod(ResetImagePropertyIterator)
+#define ResetImageRegistryIterator  PrependMagickMethod(ResetImageRegistryIterator)
 #define ResetLinkedListIterator  PrependMagickMethod(ResetLinkedListIterator)
 #define ResetMagickMemory  PrependMagickMethod(ResetMagickMemory)
 #define ResetSplayTreeIterator  PrependMagickMethod(ResetSplayTreeIterator)
@@ -832,12 +864,14 @@ extern "C" {
 #define ResetTimer  PrependMagickMethod(ResetTimer)
 #define ResizeImage  PrependMagickMethod(ResizeImage)
 #define ResizeMagickMemory  PrependMagickMethod(ResizeMagickMemory)
+#define ResizeQuantumMemory  PrependMagickMethod(ResizeQuantumMemory)
 #define ReverseImageList  PrependMagickMethod(ReverseImageList)
 #define RGBTransformImage  PrependMagickMethod(RGBTransformImage)
 #define RollImage  PrependMagickMethod(RollImage)
 #define RotateImage  PrependMagickMethod(RotateImage)
 #define SampleImage  PrependMagickMethod(SampleImage)
 #define ScaleImage  PrependMagickMethod(ScaleImage)
+#define ScaleResampleFilter  PrependMagickMethod(ScaleResampleFilter)
 #define SeedRandomReservoir  PrependMagickMethod(SeedRandomReservoir)
 #define SeekBlob  PrependMagickMethod(SeekBlob)
 #define SegmentImage  PrependMagickMethod(SegmentImage)
@@ -850,6 +884,7 @@ extern "C" {
 #define SetCacheThreshold  PrependMagickMethod(SetCacheThreshold)
 #define SetCacheView  PrependMagickMethod(SetCacheView)
 #define SetCacheViewStorageClass  PrependMagickMethod(SetCacheViewStorageClass)
+#define SetCacheVirtualPixelMethod  PrependMagickMethod(SetCacheVirtualPixelMethod)
 #define SetClientName  PrependMagickMethod(SetClientName)
 #define SetClientPath  PrependMagickMethod(SetClientPath)
 #define SetErrorHandler  PrependMagickMethod(SetErrorHandler)
@@ -877,6 +912,7 @@ extern "C" {
 #define SetImageProfile  PrependMagickMethod(SetImageProfile)
 #define SetImageProgressMonitor  PrependMagickMethod(SetImageProgressMonitor)
 #define SetImageProperty  PrependMagickMethod(SetImageProperty)
+#define SetImageRegistry  PrependMagickMethod(SetImageRegistry)
 #define SetImageStorageClass  PrependMagickMethod(SetImageStorageClass)
 #define SetImageType  PrependMagickMethod(SetImageType)
 #define SetImageVirtualPixelMethod  PrependMagickMethod(SetImageVirtualPixelMethod)
@@ -932,7 +968,6 @@ extern "C" {
 #define StripString  PrependMagickMethod(StripString)
 #define SubstituteString  PrependMagickMethod(SubstituteString)
 #define SwirlImage  PrependMagickMethod(SwirlImage)
-#define SyncBlob  PrependMagickMethod(SyncBlob)
 #define SyncCacheNexus  PrependMagickMethod(SyncCacheNexus)
 #define SyncCacheView  PrependMagickMethod(SyncCacheView)
 #define SyncImageList  PrependMagickMethod(SyncImageList)
@@ -954,9 +989,6 @@ extern "C" {
 #define TintImage  PrependMagickMethod(TintImage)
 #define Tokenizer  PrependMagickMethod(Tokenizer)
 #define TransformColorspace  PrependMagickMethod(TransformColorspace)
-#define TransformHSB  PrependMagickMethod(TransformHSB)
-#define TransformHSL  PrependMagickMethod(TransformHSL)
-#define TransformHWB  PrependMagickMethod(TransformHWB)
 #define TransformImage  PrependMagickMethod(TransformImage)
 #define TransformImages  PrependMagickMethod(TransformImages)
 #define TransformRGBImage  PrependMagickMethod(TransformRGBImage)
@@ -980,6 +1012,7 @@ extern "C" {
 #define UnregisterCUTImage  PrependMagickMethod(UnregisterCUTImage)
 #define UnregisterDCMImage  PrependMagickMethod(UnregisterDCMImage)
 #define UnregisterDIBImage  PrependMagickMethod(UnregisterDIBImage)
+#define UnregisterDNGImage  PrependMagickMethod(UnregisterDNGImage)
 #define UnregisterDOTImage  PrependMagickMethod(UnregisterDOTImage)
 #define UnregisterDPSImage  PrependMagickMethod(UnregisterDPSImage)
 #define UnregisterDPXImage  PrependMagickMethod(UnregisterDPXImage)
@@ -994,6 +1027,7 @@ extern "C" {
 #define UnregisterHTMLImage  PrependMagickMethod(UnregisterHTMLImage)
 #define UnregisterICONImage  PrependMagickMethod(UnregisterICONImage)
 #define UnregisterINFOImage  PrependMagickMethod(UnregisterINFOImage)
+#define UnregisterIPLImage  PrependMagickMethod(UnregisterIPLImage)
 #define UnregisterJP2Image  PrependMagickMethod(UnregisterJP2Image)
 #define UnregisterJPEGImage  PrependMagickMethod(UnregisterJPEGImage)
 #define UnregisterLABELImage  PrependMagickMethod(UnregisterLABELImage)
@@ -1160,6 +1194,7 @@ extern "C" {
 #define XWindowByProperty  PrependMagickMethod(XWindowByProperty)
 #define ZLIBEncodeImage  PrependMagickMethod(ZLIBEncodeImage)
 #define ZoomImage  PrependMagickMethod(ZoomImage)
+
 #endif
 
 #if defined(__cplusplus) || defined(c_plusplus)
