@@ -447,8 +447,8 @@ MagickExport const MimeInfo **GetMimeInfoList(const char *pattern,
   p=GetMimeInfo((char *) NULL,(unsigned char *) "*",0,exception);
   if (p == (const MimeInfo *) NULL)
     return((const MimeInfo **) NULL);
-  aliases=(const MimeInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(mime_list)+1)*sizeof(*aliases));
+  aliases=(const MimeInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(mime_list)+1UL,sizeof(*aliases));
   if (aliases == (const MimeInfo **) NULL)
     return((const MimeInfo **) NULL);
   /*
@@ -542,8 +542,8 @@ MagickExport char **GetMimeList(const char *pattern,
   p=GetMimeInfo((char *) NULL,(unsigned char *) "*",0,exception);
   if (p == (const MimeInfo *) NULL)
     return((char **) NULL);
-  aliases=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfElementsInLinkedList(mime_list)+1)*sizeof(*aliases));
+  aliases=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfElementsInLinkedList(mime_list)+1UL,sizeof(*aliases));
   if (aliases == (char **) NULL)
     return((char **) NULL);
   AcquireSemaphoreInfo(&mime_semaphore);
@@ -857,8 +857,7 @@ static MagickBooleanType LoadMimeList(const char *xml,const char *filename,
     */
     mime_info=(MimeInfo *) AcquireMagickMemory(sizeof(*mime_info));
     if (mime_info == (MimeInfo *) NULL)
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",filename);
+      ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(mime_info,0,sizeof(*mime_info));
     mime_info->path=ConstantString(filename);
     mime_info->signature=MagickSignature;
