@@ -68,7 +68,7 @@
 #include "magick/utility.h"
 
 /*
-  ImageMagick values.
+  ImageMagick options.
 */
 static const OptionInfo
   AlignOptions[] =
@@ -82,6 +82,17 @@ static const OptionInfo
     { "Start", (long) LeftAlign },
     { (char *) NULL, (long) UndefinedAlign }
   },
+  AlphaOptions[] =
+  {
+    { "Undefined", (long) UndefinedAlphaChannel },
+    { "Activate", (long) ActivateAlphaChannel },
+    { "Deactivate", (long) DeactivateAlphaChannel },
+    { "Off", (long) DeactivateAlphaChannel },
+    { "On", (long) ActivateAlphaChannel },
+    { "Reset", (long) ResetAlphaChannel },
+    { "Set", (long) SetAlphaChannel },
+    { (char *) NULL, (long) UndefinedAlphaChannel }
+  },
   BooleanOptions[] =
   {
     { "False", 0L },
@@ -137,6 +148,8 @@ static const OptionInfo
     { "+adaptive-threshold", 1L },
     { "+affine", 0L },
     { "-affine", 1L },
+    { "+alpha", 1L },
+    { "-alpha", 1L },
     { "+annotate", 0L },
     { "-annotate", 2L },
     { "+antialias", 0L },
@@ -187,6 +200,8 @@ static const OptionInfo
     { "-clip-path", 1L },
     { "+clone", 0L },
     { "-clone", 1L },
+    { "+clut", 0L },
+    { "-clut", 0L },
     { "+coalesce", 0L },
     { "-coalesce", 0L },
     { "+colorize", 0L },
@@ -243,7 +258,7 @@ static const OptionInfo
     { "-dispose", 1L },
     { "+dissolve", 0L },
     { "-dissolve", 1L },
-    { "+distort", 0L },
+    { "+distort", 2L },
     { "-distort", 2L },
     { "+dither", 0L },
     { "-dither", 0L },
@@ -599,7 +614,7 @@ static const OptionInfo
     { "-write", 1L },
     { (char *) NULL, (long) 0L }
   },
-  CompositeOptions[] =
+  ComposeOptions[] =
   {
     { "Undefined", (long) UndefinedCompositeOp },
     { "Add", (long) AddCompositeOp },
@@ -621,6 +636,7 @@ static const OptionInfo
     { "CopyRed", (long) CopyRedCompositeOp },
     { "CopyYellow", (long) CopyYellowCompositeOp },
     { "Darken", (long) DarkenCompositeOp },
+    { "Divide", (long) DivideCompositeOp },
     { "Dst", (long) DstCompositeOp },
     { "Difference", (long) DifferenceCompositeOp },
     { "Displace", (long) DisplaceCompositeOp },
@@ -660,7 +676,7 @@ static const OptionInfo
     { "Xor", (long) XorCompositeOp },
     { (char *) NULL, (long) UndefinedCompositeOp }
   },
-  CompressionOptions[] =
+  CompressOptions[] =
   {
     { "Undefined", (long) UndefinedCompression },
     { "BZip", (long) BZipCompression },
@@ -680,12 +696,13 @@ static const OptionInfo
   ColorspaceOptions[] =
   {
     { "Undefined", (long) UndefinedColorspace },
+    { "CMY", (long) CMYColorspace },
     { "CMYK", (long) CMYKColorspace },
     { "Gray", (long) GRAYColorspace },
     { "HSB", (long) HSBColorspace },
     { "HSL", (long) HSLColorspace },
     { "HWB", (long) HWBColorspace },
-    { "LAB", (long) LABColorspace },
+    { "Lab", (long) LabColorspace },
     { "Log", (long) LogColorspace },
     { "OHTA", (long) OHTAColorspace },
     { "Rec601Luma", (long) Rec601LumaColorspace },
@@ -712,7 +729,7 @@ static const OptionInfo
     { "String", (long) StringData },
     { (char *) NULL, (long) UndefinedData }
   },
-  DecorationOptions[] =
+  DecorateOptions[] =
   {
     { "Undefined", (long) UndefinedDecoration },
     { "LineThrough", (long) LineThroughDecoration },
@@ -740,8 +757,10 @@ static const OptionInfo
     { "AffineProjection", (long) AffineProjectionDistortion },
     { "Bilinear", (long) BilinearDistortion },
     { "Perspective", (long) PerspectiveDistortion },
+    { "PerspectiveProjection", (long) PerspectiveProjectionDistortion },
     { "ScaleRotateTranslate", (long) ScaleRotateTranslateDistortion },
     { "SRT", (long) ScaleRotateTranslateDistortion },
+    { "Arc", (long) ArcDistortion },
     { (char *) NULL, (long) UndefinedDistortion }
   },
   EndianOptions[] =
@@ -812,22 +831,6 @@ static const OptionInfo
     { "Static", (long) StaticGravity },
     { (char *) NULL, UndefinedGravity }
   },
-  ImageOptions[] =
-  {
-    { "Undefined", (long) UndefinedType },
-    { "Bilevel", (long) BilevelType },
-    { "ColorSeparation", (long) ColorSeparationType },
-    { "ColorSeparationMatte", (long) ColorSeparationMatteType },
-    { "Grayscale", (long) GrayscaleType },
-    { "GrayscaleMatte", (long) GrayscaleMatteType },
-    { "Optimize", (long) OptimizeType },
-    { "Palette", (long) PaletteType },
-    { "PaletteBilevelMatte", (long) PaletteBilevelMatteType },
-    { "PaletteMatte", (long) PaletteMatteType },
-    { "TrueColorMatte", (long) TrueColorMatteType },
-    { "TrueColor", (long) TrueColorType },
-    { (char *) NULL, (long) UndefinedType }
-  },
   IntentOptions[] =
   {
     { "Undefined", (long) UndefinedIntent },
@@ -897,62 +900,64 @@ static const OptionInfo
   },
   ListOptions[] =
   {
-    { "Undefined",     MagickUndefinedOptions },
-    { "Align",         MagickAlignOptions },
-    { "Boolean",       MagickBooleanOptions },
-    { "Channel",       MagickChannelOptions },
-    { "Class",         MagickClassOptions },
-    { "ClipPath",      MagickClipPathOptions },
-    { "Colorspace",    MagickColorspaceOptions },
-    { "Composite",     MagickCompositeOptions },
-    { "Command",       MagickCommandOptions },
-    { "Compression",   MagickCompressionOptions },
-    { "DataType",      MagickDataTypeOptions },
-    { "Decoration",    MagickDecorationOptions },
-    { "Dispose",       MagickDisposeOptions },
-    { "Distort",       MagickDistortOptions },
-    { "Endian",        MagickEndianOptions },
-    { "Evaluate",      MagickEvaluateOptions },
-    { "FillRule",      MagickFillRuleOptions },
-    { "Filter",        MagickFilterOptions },
-    { "Gravity",       MagickGravityOptions },
-    { "Image",         MagickImageOptions },
-    { "Intent",        MagickIntentOptions },
-    { "Interlace",     MagickInterlaceOptions },
-    { "Interpolate",   MagickInterpolateOptions },
-    { "Layers",        MagickLayersOptions },
-    { "LineCap",       MagickLineCapOptions },
-    { "LineJoin",      MagickLineJoinOptions },
-    { "List",          MagickListOptions },
-    { "LogEvent",      MagickLogEventOptions },
-    { "Metric",        MagickMetricOptions },
-    { "Method",        MagickMethodOptions },
-    { "Mime",          MagickMimeOptions },
-    { "Mode",          MagickModeOptions },
-    { "Mogrify",       MagickMogrifyOptions },
-    { "Noise",         MagickNoiseOptions },
-    { "Orientation",   MagickOrientationOptions },
-    { "Preview",       MagickPreviewOptions },
-    { "Primitive",     MagickPrimitiveOptions },
-    { "QuantumFormat", MagickQuantumFormatOptions },
-    { "Resolution",    MagickResolutionOptions },
-    { "Resource",      MagickResourceOptions },
-    { "Storage",       MagickStorageOptions },
-    { "Stretch",       MagickStretchOptions },
-    { "Style",         MagickStyleOptions },
-    { "VirtualPixel",  MagickVirtualPixelOptions },
-    { "Coder",         MagickCoderOptions },
-    { "Color",         MagickColorOptions },
-    { "Configure",     MagickConfigureOptions },
-    { "Delegate",      MagickDelegateOptions },
-    { "Format",        MagickFormatOptions },
-    { "Locale",        MagickLocaleOptions },
-    { "Log",           MagickLogOptions },
-    { "Magic",         MagickMagicOptions },
-    { "Module",        MagickModuleOptions },
-    { "Threshold",     MagickThresholdOptions },
-    { "Type",          MagickTypeOptions },
-    { (char *) NULL,   MagickUndefinedOptions }
+    { "Undefined", (long) MagickUndefinedOptions },
+    { "Align", (long) MagickAlignOptions },
+    { "Alpha", (long) MagickAlphaOptions },
+    { "Boolean", (long) MagickBooleanOptions },
+    { "Channel", (long) MagickChannelOptions },
+    { "Class", (long) MagickClassOptions },
+    { "ClipPath", (long) MagickClipPathOptions },
+    { "Colorspace", (long) MagickColorspaceOptions },
+    { "Compose", (long) MagickComposeOptions },
+    { "Command", (long) MagickCommandOptions },
+    { "Compress", (long) MagickCompressOptions },
+    { "DataType", (long) MagickDataTypeOptions },
+    { "Debug", (long) MagickDebugOptions },
+    { "Decoration", (long) MagickDecorateOptions },
+    { "Dispose", (long) MagickDisposeOptions },
+    { "Distort", (long) MagickDistortOptions },
+    { "Endian", (long) MagickEndianOptions },
+    { "Evaluate", (long) MagickEvaluateOptions },
+    { "FillRule", (long) MagickFillRuleOptions },
+    { "Filter", (long) MagickFilterOptions },
+    { "Font", (long) MagickFontOptions },
+    { "Gravity", (long) MagickGravityOptions },
+    { "Intent", (long) MagickIntentOptions },
+    { "Interlace", (long) MagickInterlaceOptions },
+    { "Interpolate", (long) MagickInterpolateOptions },
+    { "Layers", (long) MagickLayersOptions },
+    { "LineCap", (long) MagickLineCapOptions },
+    { "LineJoin", (long) MagickLineJoinOptions },
+    { "List", (long) MagickListOptions },
+    { "LogEvent", (long) MagickLogEventOptions },
+    { "Metric", (long) MagickMetricOptions },
+    { "Method", (long) MagickMethodOptions },
+    { "Mime", (long) MagickMimeOptions },
+    { "Mode", (long) MagickModeOptions },
+    { "Mogrify", (long) MagickMogrifyOptions },
+    { "Noise", (long) MagickNoiseOptions },
+    { "Orientation", (long) MagickOrientationOptions },
+    { "Preview", (long) MagickPreviewOptions },
+    { "Primitive", (long) MagickPrimitiveOptions },
+    { "QuantumFormat", (long) MagickQuantumFormatOptions },
+    { "Resolution", (long) MagickResolutionOptions },
+    { "Resource", (long) MagickResourceOptions },
+    { "Storage", (long) MagickStorageOptions },
+    { "Stretch", (long) MagickStretchOptions },
+    { "Style", (long) MagickStyleOptions },
+    { "VirtualPixel", (long) MagickVirtualPixelOptions },
+    { "Coder", (long) MagickCoderOptions },
+    { "Color", (long) MagickColorOptions },
+    { "Configure", (long) MagickConfigureOptions },
+    { "Delegate", (long) MagickDelegateOptions },
+    { "Format", (long) MagickFormatOptions },
+    { "Locale", (long) MagickLocaleOptions },
+    { "Log", (long) MagickLogOptions },
+    { "Magic", (long) MagickMagicOptions },
+    { "Module", (long) MagickModuleOptions },
+    { "Threshold", (long) MagickThresholdOptions },
+    { "Type", (long) MagickTypeOptions },
+    { (char *) NULL, (long) MagickUndefinedOptions }
   },
   LogEventOptions[] =
   {
@@ -1011,6 +1016,7 @@ static const OptionInfo
   {
     { "append", MagickTrue },
     { "average", MagickTrue },
+    { "clut", MagickTrue },
     { "coalesce", MagickTrue },
     { "combine", MagickTrue },
     { "composite", MagickTrue },
@@ -1114,7 +1120,7 @@ static const OptionInfo
   },
   QuantumFormatOptions[] =
   {
-    { "Undefined", (long) UndefinedClass },
+    { "Undefined", (long) UndefinedQuantumFormat },
     { "FloatingPoint", (long) FloatingPointQuantumFormat },
     { "Signed", (long) SignedQuantumFormat },
     { "Unsigned", (long) UnsignedQuantumFormat },
@@ -1173,17 +1179,36 @@ static const OptionInfo
     { "Oblique", (long) ObliqueStyle },
     { (char *) NULL, (long) UndefinedStyle }
   },
+  TypeOptions[] =
+  {
+    { "Undefined", (long) UndefinedType },
+    { "Bilevel", (long) BilevelType },
+    { "ColorSeparation", (long) ColorSeparationType },
+    { "ColorSeparationMatte", (long) ColorSeparationMatteType },
+    { "Grayscale", (long) GrayscaleType },
+    { "GrayscaleMatte", (long) GrayscaleMatteType },
+    { "Optimize", (long) OptimizeType },
+    { "Palette", (long) PaletteType },
+    { "PaletteBilevelMatte", (long) PaletteBilevelMatteType },
+    { "PaletteMatte", (long) PaletteMatteType },
+    { "TrueColorMatte", (long) TrueColorMatteType },
+    { "TrueColor", (long) TrueColorType },
+    { (char *) NULL, (long) UndefinedType }
+  },
   VirtualPixelOptions[] =
   {
     { "Undefined", (long) UndefinedVirtualPixelMethod },
     { "Background", (long) BackgroundVirtualPixelMethod },
+    { "Black", (long) BlackVirtualPixelMethod },
     { "Constant", (long) BackgroundVirtualPixelMethod },
     { "Dither", (long) DitherVirtualPixelMethod },
     { "Edge", (long) EdgeVirtualPixelMethod },
+    { "Gray", (long) GrayVirtualPixelMethod },
     { "Mirror", (long) MirrorVirtualPixelMethod },
     { "Random", (long) RandomVirtualPixelMethod },
     { "Tile", (long) TileVirtualPixelMethod },
     { "Transparent", (long) TransparentVirtualPixelMethod },
+    { "White", (long) WhiteVirtualPixelMethod },
     { (char *) NULL, (long) UndefinedVirtualPixelMethod }
   };
 
@@ -1424,21 +1449,23 @@ MagickExport const char *GetImageOption(const ImageInfo *image_info,
 %
 */
 
-static const OptionInfo *GetOptionInfo(const MagickOption value)
+static const OptionInfo *GetOptionInfo(const MagickOption option)
 {
-  switch (value)
+  switch (option)
   {
     case MagickAlignOptions: return(AlignOptions);
+    case MagickAlphaOptions: return(AlphaOptions);
     case MagickBooleanOptions: return(BooleanOptions);
     case MagickChannelOptions: return(ChannelOptions);
     case MagickClassOptions: return(ClassOptions);
     case MagickClipPathOptions: return(ClipPathOptions);
     case MagickColorspaceOptions: return(ColorspaceOptions);
     case MagickCommandOptions: return(CommandOptions);
-    case MagickCompositeOptions: return(CompositeOptions);
-    case MagickCompressionOptions: return(CompressionOptions);
+    case MagickComposeOptions: return(ComposeOptions);
+    case MagickCompressOptions: return(CompressOptions);
     case MagickDataTypeOptions: return(DataTypeOptions);
-    case MagickDecorationOptions: return(DecorationOptions);
+    case MagickDebugOptions: return(LogEventOptions);
+    case MagickDecorateOptions: return(DecorateOptions);
     case MagickDisposeOptions: return(DisposeOptions);
     case MagickDistortOptions: return(DistortOptions);
     case MagickEndianOptions: return(EndianOptions);
@@ -1446,7 +1473,6 @@ static const OptionInfo *GetOptionInfo(const MagickOption value)
     case MagickFillRuleOptions: return(FillRuleOptions);
     case MagickFilterOptions: return(FilterOptions);
     case MagickGravityOptions: return(GravityOptions);
-    case MagickImageOptions: return(ImageOptions);
     case MagickIntentOptions: return(IntentOptions);
     case MagickInterlaceOptions: return(InterlaceOptions);
     case MagickInterpolateOptions: return(InterpolateOptions);
@@ -1469,6 +1495,7 @@ static const OptionInfo *GetOptionInfo(const MagickOption value)
     case MagickStorageOptions: return(StorageOptions);
     case MagickStretchOptions: return(StretchOptions);
     case MagickStyleOptions: return(StyleOptions);
+    case MagickTypeOptions: return(TypeOptions);
     case MagickVirtualPixelOptions: return(VirtualPixelOptions);
     default: break;
   }
@@ -1490,10 +1517,9 @@ MagickExport char **GetMagickOptions(const MagickOption value)
   if (option_info == (const OptionInfo *) NULL)
     return((char **) NULL);
   for (i=0; option_info[i].mnemonic != (const char *) NULL; i++);
-  values=(char **) AcquireMagickMemory((size_t) (i+1)*sizeof(*values));
+  values=(char **) AcquireQuantumMemory((size_t) i+1UL,sizeof(*values));
   if (values == (char **) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"UnableToAcquireString",
-      option_info[0].mnemonic);
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   for (i=0; option_info[i].mnemonic != (const char *) NULL; i++)
     values[i]=AcquireString(option_info[i].mnemonic);
   values[i]=(char *) NULL;
@@ -1538,6 +1564,7 @@ MagickExport char *GetNextImageOption(const ImageInfo *image_info)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%                                                                             %
 %     I s M a g i c k O p t i o n                                             %
 %                                                                             %
 %                                                                             %
@@ -1553,9 +1580,7 @@ MagickExport char *GetNextImageOption(const ImageInfo *image_info)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
-%
-%    o exception: Return any errors or warnings in this structure.
+%    o option: The option.
 %
 */
 MagickExport MagickBooleanType IsMagickOption(const char *option)
@@ -1586,17 +1611,17 @@ MagickExport MagickBooleanType IsMagickOption(const char *option)
 %
 %  The format of the MagickOptionToMnemonic method is:
 %
-%      const char *MagickOptionToMnemonic(const MagickOption value,
+%      const char *MagickOptionToMnemonic(const MagickOption option,
 %        const long type)
 %
 %  A description of each parameter follows:
 %
-%    o values: The values.
+%    o option: The option.
 %
 %    o type: one or more values separated by commas.
 %
 */
-MagickExport const char *MagickOptionToMnemonic(const MagickOption value,
+MagickExport const char *MagickOptionToMnemonic(const MagickOption option,
   const long type)
 {
   const OptionInfo
@@ -1605,12 +1630,14 @@ MagickExport const char *MagickOptionToMnemonic(const MagickOption value,
   register long
     i;
 
-  option_info=GetOptionInfo(value);
+  option_info=GetOptionInfo(option);
   if (option_info == (const OptionInfo *) NULL)
     return((const char *) NULL);
   for (i=0; option_info[i].mnemonic != (const char *) NULL; i++)
     if (type == option_info[i].type)
       break;
+  if (option_info[i].mnemonic == (const char *) NULL)
+    return("undefined");
   return(option_info[i].mnemonic);
 }
 
@@ -1619,29 +1646,29 @@ MagickExport const char *MagickOptionToMnemonic(const MagickOption value,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   L i s t M a g i c k O p t i o n I n f o                                   %
+%   L i s t M a g i c k O p t i o n s                                         %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ListMagickOptionInfo() lists the contents of enumerated option type(s).
+%  ListMagickOptions() lists the contents of enumerated option type(s).
 %
-%  The format of the ListMagickOptionInfo method is:
+%  The format of the ListMagickOptions method is:
 %
-%      MagickBooleanType ListMagickOptionInfo(FILE *file,
-%           const MagickOption option,ExceptionInfo *exception)
+%      MagickBooleanType ListMagickOptions(FILE *file,const MagickOption option,
+%        ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o file:   List Magick Options Available
+%    o file:  list options to this file handle.
 %
-%    o option: Index to the option table to list
+%    o option:  list these options.
 %
-%    o exception: Return any errors or warnings in this structure.
+%    o exception:  return any errors or warnings in this structure.
 %
 */
-MagickExport MagickBooleanType ListMagickOptionInfo(FILE *file,
+MagickExport MagickBooleanType ListMagickOptions(FILE *file,
   const MagickOption option,ExceptionInfo *magick_unused(exception))
 {
   const OptionInfo
