@@ -103,7 +103,7 @@ MagickExport MagickBooleanType PaintFloodfillImage(Image *image,
   const long x_offset,const long y_offset,const DrawInfo *draw_info,
   const PaintMethod method)
 {
-#define MaxStacksize  (1 << 15)
+#define MaxStacksize  (1UL << 15)
 #define PushSegmentStack(up,left,right,delta) \
 { \
   if (s >= (segment_stack+MaxStacksize)) \
@@ -184,7 +184,7 @@ MagickExport MagickBooleanType PaintFloodfillImage(Image *image,
   if (floodplane_image == (Image *) NULL)
     return(MagickFalse);
   (void) SetImageOpacity(floodplane_image,OpaqueOpacity);
-  segment_stack=(SegmentInfo *) AcquireMagickMemory(MaxStacksize*
+  segment_stack=(SegmentInfo *) AcquireQuantumMemory(MaxStacksize,
     sizeof(*segment_stack));
   if (segment_stack == (SegmentInfo *) NULL)
     {
@@ -225,7 +225,7 @@ MagickExport MagickBooleanType PaintFloodfillImage(Image *image,
     q+=x1;
     for (x=x1; x >= 0; x--)
     {
-      if (q->opacity == TransparentOpacity)
+      if (q->opacity == (Quantum) TransparentOpacity)
         break;
       SetMagickPixelPacket(image,p,indexes+x,&pixel);
       if (method == FloodfillMethod)
@@ -236,7 +236,7 @@ MagickExport MagickBooleanType PaintFloodfillImage(Image *image,
       else
         if (IsMagickColorSimilar(&pixel,target) != MagickFalse)
           break;
-      q->opacity=TransparentOpacity;
+      q->opacity=(Quantum) TransparentOpacity;
       p--;
       q--;
     }
@@ -265,7 +265,7 @@ MagickExport MagickBooleanType PaintFloodfillImage(Image *image,
               indexes=GetIndexes(image);
               for ( ; x < (long) image->columns; x++)
               {
-                if (q->opacity == TransparentOpacity)
+                if (q->opacity == (Quantum) TransparentOpacity)
                   break;
                 SetMagickPixelPacket(image,p,indexes+x,&pixel);
                 if (method == FloodfillMethod)
@@ -276,7 +276,7 @@ MagickExport MagickBooleanType PaintFloodfillImage(Image *image,
                 else
                   if (IsMagickColorSimilar(&pixel,target) != MagickFalse)
                     break;
-                q->opacity=TransparentOpacity;
+                q->opacity=(Quantum) TransparentOpacity;
                 p++;
                 q++;
               }
@@ -299,7 +299,7 @@ MagickExport MagickBooleanType PaintFloodfillImage(Image *image,
           indexes=GetIndexes(image);
           for ( ; x <= x2; x++)
           {
-            if (q->opacity == TransparentOpacity)
+            if (q->opacity == (Quantum) TransparentOpacity)
               break;
             SetMagickPixelPacket(image,p,indexes+x,&pixel);
             if (method == FloodfillMethod)
@@ -335,15 +335,14 @@ MagickExport MagickBooleanType PaintFloodfillImage(Image *image,
           fill_color=GetFillColor(draw_info,x,y);
           SetMagickPixelPacket(image,&fill_color,(IndexPacket *) NULL,&fill);
           if (image->colorspace == CMYKColorspace)
-            RGBtoCMYK(&fill);
+            ConvertRGBToCMYK(&fill);
           if ((channel & RedChannel) != 0)
             q->red=RoundToQuantum(fill.red);
           if ((channel & GreenChannel) != 0)
             q->green=RoundToQuantum(fill.green);
           if ((channel & BlueChannel) != 0)
             q->blue=RoundToQuantum(fill.blue);
-          if (((channel & OpacityChannel) != 0) &&
-              (image->matte != MagickFalse))
+          if ((channel & OpacityChannel) != 0)
             q->opacity=RoundToQuantum(fill.opacity);
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
@@ -457,8 +456,7 @@ MagickExport MagickBooleanType PaintOpaqueImageChannel(Image *image,
             q->green=RoundToQuantum(fill->green);
           if ((channel & BlueChannel) != 0)
             q->blue=RoundToQuantum(fill->blue);
-          if (((channel & OpacityChannel) != 0) &&
-              (image->matte != MagickFalse))
+          if ((channel & OpacityChannel) != 0)
             q->opacity=RoundToQuantum(fill->opacity);
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
