@@ -45,15 +45,7 @@ static inline MagickPixelPacket *CloneMagickPixelPacket(
 
   clone_pixel=(MagickPixelPacket *) AcquireMagickMemory(sizeof(*clone_pixel));
   if (clone_pixel == (MagickPixelPacket *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=(char *) RelinquishMagickMemory(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   *clone_pixel=(*pixel);
   return(clone_pixel);
 }
@@ -64,8 +56,7 @@ static inline void SetMagickPixelPacket(const Image *image,
   pixel->red=(MagickRealType) color->red;
   pixel->green=(MagickRealType) color->green;
   pixel->blue=(MagickRealType) color->blue;
-  if (image->matte != MagickFalse)
-    pixel->opacity=(MagickRealType) color->opacity;
+  pixel->opacity=(MagickRealType) color->opacity;
   if (((image->colorspace == CMYKColorspace) ||
        (image->storage_class == PseudoClass)) &&
       (index != (const IndexPacket *) NULL))
@@ -78,9 +69,7 @@ static inline void SetPixelPacket(const Image *image,
   color->red=RoundToQuantum(pixel->red);
   color->green=RoundToQuantum(pixel->green);
   color->blue=RoundToQuantum(pixel->blue);
-  color->opacity=OpaqueOpacity;
-  if (image->matte != MagickFalse)
-    color->opacity=RoundToQuantum(pixel->opacity);
+  color->opacity=RoundToQuantum(pixel->opacity);
   if (((image->colorspace == CMYKColorspace) ||
        (image->storage_class == PseudoClass)) &&
       (index != (const IndexPacket *) NULL))
