@@ -17,7 +17,7 @@
 %                                October 2001                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -63,8 +63,8 @@
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetImageTotalInkDensity() returns the toal ink density for a CMYK image.
-%  Total nk Density (TID) is determined by adding the CMYK values in the
+%  GetImageTotalInkDensity() returns the total ink density for a CMYK image.
+%  Total Ink Density (TID) is determined by adding the CMYK values in the
 %  darkest shadow area in an image.
 %
 %  The format of the GetImageTotalInkDensity method is:
