@@ -839,7 +839,8 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             (DWORD) GetStringInfoLength(profile));
           if ((source_profile == (cmsHPROFILE) NULL) ||
               (target_profile == (cmsHPROFILE) NULL))
-            ThrowBinaryException(ResourceLimitError,"UnableToManageColor",name);
+            ThrowBinaryException(ResourceLimitError,
+              "ColorspaceColorProfileMismatch",name);
           switch (cmsGetColorSpace(source_profile))
           {
             case icSigCmykData:
@@ -858,7 +859,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             }
             case icSigLabData:
             {
-              source_colorspace=LABColorspace;
+              source_colorspace=LabColorspace;
               source_type=(DWORD) TYPE_Lab_16;
               source_channels=3;
               break;
@@ -910,7 +911,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
             }
             case icSigLabData:
             {
-              target_colorspace=LABColorspace;
+              target_colorspace=LabColorspace;
               target_type=(DWORD) TYPE_Lab_16;
               target_channels=3;
               break;
@@ -951,7 +952,7 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
               ((source_colorspace == CMYKColorspace) &&
                (image->colorspace != CMYKColorspace)) ||
               ((source_colorspace != GRAYColorspace) &&
-               (source_colorspace != LABColorspace) &&
+               (source_colorspace != LabColorspace) &&
                (source_colorspace != CMYKColorspace) &&
                (image->colorspace != RGBColorspace)))
             ThrowProfileException(ImageError,"ColorspaceColorProfileMismatch",
@@ -982,10 +983,11 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           /*
             Transform image as dictated by the source and target image profiles.
           */
-          length=(size_t) image->columns*source_channels*sizeof(*source_pixels);
-          source_pixels=(unsigned short *) AcquireMagickMemory(length);
-          length=(size_t) image->columns*target_channels*sizeof(*target_pixels);
-          target_pixels=(unsigned short *) AcquireMagickMemory(length);
+          length=(size_t) image->columns;
+          source_pixels=(unsigned short *) AcquireQuantumMemory(length,
+            source_channels*sizeof(*source_pixels));
+          target_pixels=(unsigned short *) AcquireQuantumMemory(length,
+            target_channels*sizeof(*target_pixels));
           if ((source_pixels == (unsigned short *) NULL) ||
               (target_pixels == (unsigned short *) NULL))
             {
