@@ -430,7 +430,9 @@ static MagickBooleanType GetIPTCProperty(const Image *image,const char *key)
     if (((long) GetStringInfoDatum(profile)[i+1] == dataset) &&
         ((long) GetStringInfoDatum(profile)[i+2] == record))
       {
-        message=(char *) AcquireMagickMemory((length+1)*sizeof(message));
+        message=(char *) NULL;
+        if (~length >= 1)
+          message=(char *) AcquireQuantumMemory(length+1UL,sizeof(*message));
         if (message != (char *) NULL)
           {
             (void) CopyMagickString(message,(char *) GetStringInfoDatum(
@@ -605,7 +607,10 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
     count=(ssize_t) ReadPropertyByte(&info,&length);
     if ((count != 0) && ((size_t) count <= length))
       {
-        resource=(char *) AcquireMagickMemory((size_t) count+MaxTextExtent);
+        resource=(char *) NULL;
+        if (~(1UL*count) >= MaxTextExtent)
+          resource=(char *) AcquireQuantumMemory((size_t) count+MaxTextExtent,
+            sizeof(*resource));
         if (resource != (char *) NULL)
           {
             for (i=0; i < (long) count; i++)
@@ -639,7 +644,10 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
     /*
       We have the resource of interest.
     */
-    attribute=(char *) AcquireMagickMemory((size_t) count+MaxTextExtent);
+    attribute=(char *) NULL;
+    if (~(1UL*count) >= MaxTextExtent)
+      attribute=(char *) AcquireQuantumMemory((size_t) count+MaxTextExtent,
+        sizeof(*attribute));
     if (attribute != (char *) NULL)
       {
         (void) CopyMagickMemory(attribute,(char *) info,(size_t) count);
@@ -1286,8 +1294,10 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
             case EXIF_FMT_BYTE:
             case EXIF_FMT_STRING:
             {
-              value=(char *) AcquireMagickMemory((size_t) (number_bytes+1)*
-                sizeof(*value));
+              value=(char *) NULL;
+              if (~(1UL*number_bytes) >= 1)
+                value=(char *) AcquireQuantumMemory((size_t) number_bytes+1UL,
+                  sizeof(*value));
               if (value != (char *) NULL)
                 {
                   register long
@@ -1389,6 +1399,9 @@ static MagickBooleanType GetXMPProperty(const Image *image,
   ExceptionInfo
     *exception;
 
+  MagickBooleanType
+    status;
+
   register long
     i;
 
@@ -1396,6 +1409,7 @@ static MagickBooleanType GetXMPProperty(const Image *image,
     *p;
 
   XMLTreeInfo
+    *child,
     *xmp;
 
   profile=GetImageProfile(image,"xmp");
@@ -1413,16 +1427,22 @@ static MagickBooleanType GetXMPProperty(const Image *image,
   exception=DestroyExceptionInfo(exception);
   if (xmp == (XMLTreeInfo *) NULL)
     return(MagickFalse);
-  xmp=GetXMLTreeChild(xmp,"rdf:RDF");
-  if (xmp == (XMLTreeInfo *) NULL)
-    return(MagickFalse);
-  xmp=GetXMLTreeChild(xmp,"rdf:Description");
-  if (xmp == (XMLTreeInfo *) NULL)
-    return(MagickFalse);
-  if (image->properties == (void *) NULL)
-    ((Image *) image)->properties=NewSplayTree(CompareSplayTreeString,
-      RelinquishMagickMemory,RelinquishMagickMemory);
-  return(GetXMLTreeAttributes(xmp,(SplayTreeInfo *) image->properties));
+  status=MagickFalse;
+  child=GetXMLTreeChild(xmp,"rdf:RDF");
+  if (child != (XMLTreeInfo *) NULL)
+    {
+      child=GetXMLTreeChild(child,"rdf:Description");
+      if (child != (XMLTreeInfo *) NULL)
+        {
+          if (image->properties == (void *) NULL)
+            ((Image *) image)->properties=NewSplayTree(CompareSplayTreeString,
+              RelinquishMagickMemory,RelinquishMagickMemory);
+          status=GetXMLTreeAttributes(child,(SplayTreeInfo *)
+            image->properties);
+        }
+    }
+  xmp=DestroyXMLTree(xmp);
+  return(status);
 }
 
 static char *TracePSClippath(const unsigned char *blob,size_t length,
@@ -1909,12 +1929,9 @@ MagickExport const char *GetImageProperty(const Image *image,
           status|=FxEvaluateChannelExpression(fx_info,BlueChannel,0,0,&alpha,
             exception);
           pixel.blue=(MagickRealType) QuantumRange*alpha;
-          if (image->matte != MagickFalse)
-            {
-              status|=FxEvaluateChannelExpression(fx_info,OpacityChannel,0,0,
-                &alpha,exception);
-              pixel.opacity=(MagickRealType) QuantumRange*(1.0-alpha);
-            }
+          status|=FxEvaluateChannelExpression(fx_info,OpacityChannel,0,0,&alpha,
+            exception);
+          pixel.opacity=(MagickRealType) QuantumRange*(1.0-alpha);
           if (image->colorspace == CMYKColorspace)
             {
               status|=FxEvaluateChannelExpression(fx_info,BlackChannel,0,0,
@@ -2266,8 +2283,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
     if ((size_t) (q-interpret_text+MaxTextExtent) >= extent)
       {
         extent+=MaxTextExtent;
-        interpret_text=(char *) ResizeMagickMemory(interpret_text,(extent+
-          MaxTextExtent+1)*sizeof(*interpret_text));
+        interpret_text=(char *) ResizeQuantumMemory(interpret_text,extent+
+          MaxTextExtent+1,sizeof(*interpret_text));
         if (interpret_text == (char *) NULL)
           break;
         q=interpret_text+strlen(interpret_text);
@@ -2332,8 +2349,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         if ((size_t) (q-interpret_text+length+1) >= extent)
           {
             extent+=length;
-            interpret_text=(char *) ResizeMagickMemory(interpret_text,
-              (extent+MaxTextExtent)*sizeof(*interpret_text));
+            interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+              extent+MaxTextExtent,sizeof(*interpret_text));
             if (interpret_text == (char *) NULL)
               break;
             q=interpret_text+strlen(interpret_text);
@@ -2440,8 +2457,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         if ((size_t) (q-interpret_text+length+1) >= extent)
           {
             extent+=length;
-            interpret_text=(char *) ResizeMagickMemory(interpret_text,
-              (extent+MaxTextExtent)*sizeof(*interpret_text));
+            interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+              extent+MaxTextExtent,sizeof(*interpret_text));
             if (interpret_text == (char *) NULL)
               break;
             q=interpret_text+strlen(interpret_text);
@@ -2586,7 +2603,7 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           Image compression method.
         */
         q+=FormatMagickString(q,extent,"%s",MagickOptionToMnemonic(
-          MagickCompressionOptions,(long) image->compression));
+          MagickCompressOptions,(long) image->compression));
         break;
       }
       case 'D':
@@ -2656,8 +2673,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
             if ((size_t) (q-interpret_text+length+1) >= extent)
               {
                 extent+=length;
-                interpret_text=(char *) ResizeMagickMemory(interpret_text,
-                  (extent+MaxTextExtent)*sizeof(*interpret_text));
+                interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+                  extent+MaxTextExtent,sizeof(*interpret_text));
                 if (interpret_text == (char *) NULL)
                   break;
                 q=interpret_text+strlen(interpret_text);
@@ -2685,8 +2702,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
                         if ((size_t) (q-interpret_text+length+1) >= extent)
                           {
                             extent+=length;
-                            interpret_text=(char *) ResizeMagickMemory(
-                              interpret_text,(extent+MaxTextExtent)*
+                            interpret_text=(char *) ResizeQuantumMemory(
+                              interpret_text,extent+MaxTextExtent,
                               sizeof(*interpret_text));
                             if (interpret_text == (char *) NULL)
                               break;
@@ -2705,8 +2722,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
             if ((size_t) (q-interpret_text+length+1) >= extent)
               {
                 extent+=length;
-                interpret_text=(char *) ResizeMagickMemory(interpret_text,
-                  (extent+MaxTextExtent)*sizeof(*interpret_text));
+                interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+                  extent+MaxTextExtent,sizeof(*interpret_text));
                 if (interpret_text == (char *) NULL)
                   break;
                 q=interpret_text+strlen(interpret_text);
@@ -2723,8 +2740,8 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
             if ((size_t) (q-interpret_text+length+1) >= extent)
               {
                 extent+=length;
-                interpret_text=(char *) ResizeMagickMemory(interpret_text,
-                  (extent+MaxTextExtent)*sizeof(*interpret_text));
+                interpret_text=(char *) ResizeQuantumMemory(interpret_text,
+                  extent+MaxTextExtent,sizeof(*interpret_text));
                 if (interpret_text == (char *) NULL)
                   break;
                 q=interpret_text+strlen(interpret_text);
@@ -2977,21 +2994,6 @@ MagickExport MagickBooleanType SetImageProperty(Image *image,
         }
       break;
     }
-    case 'O':
-    case 'o':
-    {
-      if (LocaleCompare(property,"tile-offset") == 0)
-        {
-          char
-            *geometry;
-
-          geometry=GetPageGeometry(value);
-          flags=ParseAbsoluteGeometry(geometry,&image->tile_offset);
-          geometry=DestroyString(geometry);
-          break;
-        }
-      break;
-    }
     case 'P':
     case 'p':
     {
@@ -3007,6 +3009,21 @@ MagickExport MagickBooleanType SetImageProperty(Image *image,
         }
       break;
     }
+    case 'T':
+    case 't':
+    {
+      if (LocaleCompare(property,"tile-offset") == 0)
+        {
+          char
+            *geometry;
+
+          geometry=GetPageGeometry(value);
+          flags=ParseAbsoluteGeometry(geometry,&image->tile_offset);
+          geometry=DestroyString(geometry);
+          break;
+        }
+      break;
+    }
     default:
       break;
   }
