@@ -346,15 +346,7 @@ MagickExport QuantizeInfo *AcquireQuantizeInfo(const ImageInfo *image_info)
 
   quantize_info=(QuantizeInfo *) AcquireMagickMemory(sizeof(*quantize_info));
   if (quantize_info == (QuantizeInfo *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=DestroyString(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   GetQuantizeInfo(quantize_info);
   if (image_info != (ImageInfo *) NULL)
     {
@@ -499,7 +491,8 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
       cube_info->quantize_info->colorspace);
   else
     if ((image->colorspace != GRAYColorspace) &&
-        (image->colorspace != RGBColorspace))
+        (image->colorspace != RGBColorspace) &&
+        (image->colorspace != CMYColorspace))
       (void) SetImageColorspace((Image *) image,RGBColorspace);
   if (AllocateImageColormap(image,cube_info->colors) == MagickFalse)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
@@ -521,7 +514,7 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
       image_view=OpenCacheView(image);
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetCacheView(image_view,0,y,image->columns,1);
+        q=GetCacheViewPixels(image_view,0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
           break;
         indexes=GetCacheViewIndexes(image_view);
@@ -594,9 +587,13 @@ static MagickBooleanType AssignImageColors(Image *image,CubeInfo *cube_info)
         q++;
       }
     }
-  if ((IsAssociatedAlpha(image,cube_info) != MagickFalse) &&
+  if (0 && (IsAssociatedAlpha(image,cube_info) != MagickFalse) &&
       (cube_info->transparent_index >= 0))
     {
+      /*
+        Introduces black bar:
+          convert -size 100x100 gradient:blue-none -colors 256 image.png
+      */
       image->colormap[cube_info->transparent_index].red=
         image->transparent_color.red;
       image->colormap[cube_info->transparent_index].green=
@@ -717,13 +714,14 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
       cube_info->quantize_info->colorspace);
   else
     if ((image->colorspace != GRAYColorspace) &&
+        (image->colorspace != CMYColorspace) &&
         (image->colorspace != RGBColorspace))
       (void) SetImageColorspace((Image *) image,RGBColorspace);
   error.opacity=0.0;
   image_view=OpenCacheView(image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
     if (p == (const PixelPacket *) NULL)
       break;
     if (cube_info->nodes > MaxNodes)
@@ -810,7 +808,7 @@ static MagickBooleanType ClassifyImageColors(CubeInfo *cube_info,
   }
   for (y++; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
     if (p == (const PixelPacket *) NULL)
       break;
     if (cube_info->nodes > MaxNodes)
@@ -929,15 +927,7 @@ MagickExport QuantizeInfo *CloneQuantizeInfo(const QuantizeInfo *quantize_info)
 
   clone_info=(QuantizeInfo *) AcquireMagickMemory(sizeof(*clone_info));
   if (clone_info == (QuantizeInfo *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=DestroyString(message);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   GetQuantizeInfo(clone_info);
   if (quantize_info == (QuantizeInfo *) NULL)
     return(clone_info);
@@ -981,17 +971,18 @@ MagickExport QuantizeInfo *CloneQuantizeInfo(const QuantizeInfo *quantize_info)
 static void ClosestColor(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       ClosestColor(image,cube_info,node_info->child[i]);
   if (node_info->number_unique != 0)
@@ -1115,17 +1106,18 @@ MagickExport void CompressImageColormap(Image *image)
 static unsigned long DefineImageColormap(Image *image,CubeInfo *cube_info,
   NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       DefineImageColormap(image,cube_info,node_info->child[i]);
   if (node_info->number_unique != 0)
@@ -1337,7 +1329,7 @@ static MagickBooleanType Dither(const Image *image,ViewInfo *image_view,
       /*
         Distribute error.
       */
-      q=GetCacheView(image_view,p->x,p->y,1,1);
+      q=GetCacheViewPixels(image_view,p->x,p->y,1,1);
       if (q == (PixelPacket *) NULL)
         return(MagickFalse);
       indexes=GetCacheViewIndexes(image_view);
@@ -1596,7 +1588,7 @@ static CubeInfo *GetCubeInfo(const QuantizeInfo *quantize_info,
     Initialize dither resources.
   */
   length=(size_t) (1UL << (4*(8-CacheShift)));
-  cube_info->cache=(long *) AcquireMagickMemory(length*
+  cube_info->cache=(long *) AcquireQuantumMemory(length,
     sizeof(*cube_info->cache));
   if (cube_info->cache == (long *) NULL)
     return((CubeInfo *) NULL);
@@ -1675,7 +1667,7 @@ static NodeInfo *GetNodeInfo(CubeInfo *cube_info,const unsigned long id,
       nodes=(Nodes *) AcquireMagickMemory(sizeof(*nodes));
       if (nodes == (Nodes *) NULL)
         return((NodeInfo *) NULL);
-      nodes->nodes=(NodeInfo *) AcquireMagickMemory(NodesInAList*
+      nodes->nodes=(NodeInfo *) AcquireQuantumMemory(NodesInAList,
         sizeof(*nodes->nodes));
       if (nodes->nodes == (NodeInfo *) NULL)
         return((NodeInfo *) NULL);
@@ -1780,7 +1772,7 @@ MagickExport MagickBooleanType GetImageQuantizeError(Image *image)
   image_view=OpenCacheView(image);
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheView(image_view,0,y,image->columns,1,&image->exception);
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
     indexes=GetCacheViewIndexes(image_view);
@@ -2286,20 +2278,21 @@ MagickExport MagickBooleanType PosterizeImage(Image *image,
 static void PruneChild(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   NodeInfo
     *parent;
 
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       PruneChild(image,cube_info,node_info->child[i]);
   /*
@@ -2346,17 +2339,18 @@ static void PruneChild(const Image *image,CubeInfo *cube_info,
 static void PruneLevel(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       PruneLevel(image,cube_info,node_info->child[i]);
   if (node_info->level == cube_info->depth)
@@ -2393,17 +2387,18 @@ static void PruneLevel(const Image *image,CubeInfo *cube_info,
 static void PruneToCubeDepth(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       PruneToCubeDepth(image,cube_info,node_info->child[i]);
   if (node_info->level > cube_info->depth)
@@ -2474,7 +2469,9 @@ MagickExport MagickBooleanType QuantizeImage(const QuantizeInfo *quantize_info,
       colors=maximum_colors;
       for (depth=1; colors != 0; depth++)
         colors>>=2;
-      if (quantize_info->dither != MagickFalse)
+      if ((quantize_info->dither != MagickFalse) && (depth > 2))
+        depth--;
+      if ((image->matte != MagickFalse) && (depth > 5))
         depth--;
     }
   /*
@@ -2674,17 +2671,18 @@ MagickExport MagickBooleanType QuantizeImages(const QuantizeInfo *quantize_info,
 static void Reduce(const Image *image,CubeInfo *cube_info,
   const NodeInfo *node_info)
 {
-  long
-    number_children;
-
   register long
     i;
 
+  unsigned long
+    number_children;
+
   /*
     Traverse any children.
   */
-  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ? 8L : 16L;
-  for (i=0; i < number_children; i++)
+  number_children=IsAssociatedAlpha(image,cube_info) == MagickFalse ?
+    8UL : 16UL;
+  for (i=0; i < (long) number_children; i++)
     if (node_info->child[i] != (NodeInfo *) NULL)
       Reduce(image,cube_info,node_info->child[i]);
   if (node_info->quantize_error <= cube_info->pruning_threshold)
