@@ -24,6 +24,13 @@ extern "C" {
 
 #include "magick/semaphore.h"
 
+typedef enum
+{
+  UndefinedEndian,
+  LSBEndian,
+  MSBEndian
+} EndianType;
+
 typedef enum
 {
   UndefinedQuantum,
@@ -99,7 +106,7 @@ static inline Quantum RoundToQuantum(const MagickRealType value)
   if (value <= 0.0)
     return((Quantum) 0);
   if (value >= QuantumRange)
-    return(QuantumRange);
+    return((Quantum) QuantumRange);
   return((Quantum) (value+0.5));
 #endif
 }
@@ -110,8 +117,10 @@ static inline Quantum ScaleAnyToQuantum(const QuantumAny quantum,
   QuantumAny
     scale;
 
+  if ((depth == 0) || (depth > QuantumDepth))
+    return(0);
   scale=(QuantumAny) QuantumRange/((QuantumAny) QuantumRange >>
-     (QuantumAny) (QuantumDepth-depth));
+    (QuantumAny) (QuantumDepth-depth));
   return((Quantum) (scale*quantum));
 }
 
@@ -121,8 +130,10 @@ static inline QuantumAny ScaleQuantumToAny(const Quantum quantum,
   QuantumAny
     scale;
 
+  if ((depth == 0) || (depth > QuantumDepth))
+    return(0);
   scale=(QuantumAny) QuantumRange/((QuantumAny) QuantumRange >>
-     (QuantumAny) (QuantumDepth-depth));
+    (QuantumAny) (QuantumDepth-depth));
   return((QuantumAny) quantum/scale);
 }
 
@@ -182,13 +193,13 @@ static inline unsigned long ScaleQuantumToLong(const Quantum quantum)
 
 static inline unsigned long ScaleQuantumToMap(const Quantum quantum)
 {
-#if !defined(UseHDRI)
-  return((unsigned long) quantum);
-#else
   if (quantum <= 0.0)
     return(0UL);
   if (quantum >= MaxMap)
     return((unsigned long) MaxMap);
+#if !defined(UseHDRI)
+  return((unsigned long) quantum);
+#else
   return((unsigned long) (quantum+0.5));
 #endif
 }
@@ -241,7 +252,7 @@ static inline Quantum ScaleMapToQuantum(const MagickRealType value)
   if (value <= 0.0)
     return(0);
   if (value >= MaxMap)
-    return(QuantumRange);
+    return((Quantum) QuantumRange);
   return((Quantum) (value+0.5));
 #endif
 }
@@ -274,13 +285,13 @@ static inline unsigned long ScaleQuantumToLong(const Quantum quantum)
 
 static inline unsigned long ScaleQuantumToMap(const Quantum quantum)
 {
+  if (quantum <= 0)
+    return(0);
+  if ((1UL*quantum) >= MaxMap)
+    return((unsigned long) MaxMap);
 #if !defined(UseHDRI)
   return((unsigned long) quantum);
 #else
-  if (quantum <= 0.0)
-    return(0);
-  if (quantum >= MaxMap)
-    return((unsigned long) MaxMap);
   return((unsigned long) (quantum+0.5));
 #endif
 }
@@ -355,18 +366,20 @@ static inline unsigned long ScaleQuantumToLong(const Quantum quantum)
 
 static inline unsigned long ScaleQuantumToMap(const Quantum quantum)
 {
-#if !defined(UseHDRI)
-  unsigned long
-    pixel;
-
-  pixel=(unsigned long) ((quantum+MagickULLConstant(32768))/
-    MagickULLConstant(65537));
-  return(pixel);
-#else
   if (quantum <= 0.0)
     return(0);
   if ((quantum/65537.0) >= (MagickRealType) MaxMap)
     return((unsigned long) MaxMap);
+#if !defined(UseHDRI)
+  {
+    unsigned long
+      pixel;
+
+    pixel=(unsigned long) ((quantum+MagickULLConstant(32768))/
+      MagickULLConstant(65537));
+    return(pixel);
+  }
+#else
   return((unsigned long) (quantum/65537.0));
 #endif
 }
@@ -440,7 +453,7 @@ static inline unsigned char ScaleQuantumToChar(const Quantum quantum)
 
 static inline unsigned long ScaleQuantumToLong(const Quantum quantum)
 {
-#if !defined(HasHDRI)
+#if !defined(UseHDRI)
   return((unsigned long) ((quantum+2147483648.0)/4294967297.0));
 #else
   return((unsigned long) (quantum/4294967297.0));
@@ -449,13 +462,13 @@ static inline unsigned long ScaleQuantumToLong(const Quantum quantum)
 
 static inline unsigned long ScaleQuantumToMap(const Quantum quantum)
 {
-#if !defined(HasHDRI)
-  return((unsigned long) ((quantum+2147450879.0)/281479271612415.0));
-#else
   if (quantum <= 0.0)
     return(0);
   if ((quantum/281479271612415.0) >= (MagickRealType) MaxMap)
     return((unsigned long) MaxMap);
+#if !defined(UseHDRI)
+  return((unsigned long) ((quantum+2147450879.0)/281479271612415.0));
+#else
   return((unsigned long) (quantum/281479271612415.0));
 #endif
 }
