@@ -424,7 +424,7 @@ MagickExport MagickBooleanType SetImageRegistry(const RegistryType type,
       if (image->signature != MagickSignature)
         {
           (void) ThrowMagickException(exception,GetMagickModule(),RegistryError,
-            "UnableToSetRegistry","Image structure expected");
+            "UnableToSetRegistry",key);
           return(MagickFalse);
         }
       clone_value=(void *) CloneImageList(image,exception);
@@ -439,7 +439,7 @@ MagickExport MagickBooleanType SetImageRegistry(const RegistryType type,
       if (image_info->signature != MagickSignature)
         {
           (void) ThrowMagickException(exception,GetMagickModule(),RegistryError,
-            "UnableToSetRegistry","ImageInfo structure expected");
+            "UnableToSetRegistry",key);
           return(MagickFalse);
         }
       clone_value=(void *) CloneImageInfo(image_info);
@@ -450,16 +450,7 @@ MagickExport MagickBooleanType SetImageRegistry(const RegistryType type,
     return(MagickFalse);
   registry_info=(RegistryInfo *) AcquireMagickMemory(sizeof(*registry_info));
   if (registry_info == (RegistryInfo *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",message);
-      message=DestroyString(message);
-      return(MagickFalse);
-    }
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(registry_info,0,sizeof(*registry_info));
   registry_info->type=type;
   registry_info->value=clone_value;
