@@ -55,6 +55,7 @@
 #include "magick/pixel-private.h"
 #include "magick/monitor.h"
 #include "magick/quantum.h"
+#include "magick/resample.h"
 #include "magick/resize.h"
 #include "magick/string_.h"
 #include "magick/utility.h"
@@ -90,8 +91,7 @@ typedef struct _FilterInfo
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  AdaptiveResizeImage() adaptively resize image with data dependent
-%  triangulation.
+%  AdaptiveResizeImage() adaptively resize image with pixel resampling.
 %
 %  The format of the AdaptiveResizeImage method is:
 %
@@ -136,8 +136,10 @@ MagickExport Image *AdaptiveResizeImage(const Image *image,
   register PixelPacket
     *q;
 
+  ResampleFilter
+    *resample_filter;
+
   ViewInfo
-    *image_view,
     *resize_view;
 
   /*
@@ -163,7 +165,8 @@ MagickExport Image *AdaptiveResizeImage(const Image *image,
       return((Image *) NULL);
     }
   GetMagickPixelPacket(image,&pixel);
-  image_view=OpenCacheView(image);
+  resample_filter=AcquireResampleFilter(image,GetImageVirtualPixelMethod(image),
+    exception);
   resize_view=OpenCacheView(resize_image);
   for (y=0; y < (long) resize_image->rows; y++)
   {
@@ -175,16 +178,15 @@ MagickExport Image *AdaptiveResizeImage(const Image *image,
     for (x=0; x < (long) resize_image->columns; x++)
     {
       offset.x=(MagickRealType) (x*image->columns/resize_image->columns);
-      pixel=InterpolatePixelColor(image,image_view,image->interpolate,
-        offset.x-0.5,offset.y-0.5,exception);
+      pixel=ResamplePixelColor(resample_filter,offset.x-0.5,offset.y-0.5);
       SetPixelPacket(resize_image,&pixel,q,resize_indexes+x);
       q++;
     }
     if (SyncCacheView(resize_view) == MagickFalse)
       break;
   }
+  resample_filter=DestroyResampleFilter(resample_filter);
   resize_view=CloseCacheView(resize_view);
-  image_view=CloseCacheView(image_view);
   return(resize_image);
 }
 
@@ -461,6 +463,83 @@ MagickExport Image *MinifyImage(const Image *image,ExceptionInfo *exception)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   R e s a m p l e I m a g e                                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ResampleImage() resample image to desired resolution.
+%
+%    Bessel   Blackman   Box
+%    Catrom   Cubic      Gaussian
+%    Hanning  Hermite    Lanczos
+%    Mitchell Point      Quandratic
+%    Sinc     Triangle
+%
+%  Most of the filters are FIR (finite impulse response), however, Bessel,
+%  Gaussian, and Sinc are IIR (infinite impulse response).  Bessel and Sinc
+%  are windowed (brought down to zero) with the Blackman filter.
+%
+%  The format of the ResampleImage method is:
+%
+%      Image *ResampleImage(Image *image,const double x_resolution,
+%        const double y_resolution,const FilterTypes filter,const double blur,
+         ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+%    o x_resolution: The new image x resolution.
+%
+%    o y_resolution: The new image y resolution.
+%
+%    o filter: Image filter to use.
+%
+%    o blur: The blur factor where > 1 is blurry, < 1 is sharp.
+%
+*/
+MagickExport Image *ResampleImage(const Image *image,const double x_resolution,
+  const double y_resolution,const FilterTypes filter,const double blur,
+  ExceptionInfo *exception)
+{
+#define ResampleImageTag  "Resample/Image"
+
+  Image
+    *resample_image;
+
+  unsigned long
+    height,
+    width;
+
+  /*
+    Initialize sampled image attributes.
+  */
+  assert(image != (const Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  width=(unsigned long) (x_resolution*image->columns/
+    (image->x_resolution == 0.0 ? 72.0 : image->x_resolution)+0.5);
+  height=(unsigned long) (y_resolution*image->rows/
+    (image->y_resolution == 0.0 ? 72.0 : image->y_resolution)+0.5);
+  resample_image=ResizeImage(image,width,height,filter,blur,exception);
+  if (resample_image != (Image *) NULL)
+    {
+      resample_image->x_resolution=x_resolution;
+      resample_image->y_resolution=y_resolution;
+    }
+  return(resample_image);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   R e s i z e I m a g e                                                     %
 %                                                                             %
 %                                                                             %
@@ -803,10 +882,12 @@ static MagickBooleanType HorizontalFilter(const Image *image,
             pixel.red+=alpha*(pixels+j)->red;
             pixel.green+=alpha*(pixels+j)->green;
             pixel.blue+=alpha*(pixels+j)->blue;
+            pixel.opacity+=alpha*(pixels+j)->opacity;
           }
           resize_pixels[y].red=RoundToQuantum(pixel.red);
           resize_pixels[y].green=RoundToQuantum(pixel.green);
           resize_pixels[y].blue=RoundToQuantum(pixel.blue);
+          resize_pixels[y].opacity=RoundToQuantum(pixel.opacity);
         }
       else
         {
@@ -820,21 +901,13 @@ static MagickBooleanType HorizontalFilter(const Image *image,
             pixel.red+=alpha*(pixels+j)->red;
             pixel.green+=alpha*(pixels+j)->green;
             pixel.blue+=alpha*(pixels+j)->blue;
+            pixel.opacity+=contribution[i].weight*(pixels+j)->opacity;
             gamma+=alpha;
           }
           gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
           resize_pixels[y].red=RoundToQuantum(gamma*pixel.red);
           resize_pixels[y].green=RoundToQuantum(gamma*pixel.green);
           resize_pixels[y].blue=RoundToQuantum(gamma*pixel.blue);
-        }
-      if ((image->matte != MagickFalse) && (resize->matte != MagickFalse))
-        {
-          for (i=0; i < n; i++)
-          {
-            j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
-              (contribution[i].pixel-contribution[0].pixel);
-            pixel.opacity+=contribution[i].weight*(pixels+j)->opacity;
-          }
           resize_pixels[y].opacity=RoundToQuantum(pixel.opacity);
         }
       if ((image->colorspace == CMYKColorspace) &&
@@ -1005,10 +1078,12 @@ static MagickBooleanType VerticalFilter(const Image *image,Image *resize,
             pixel.red+=alpha*(pixels+j)->red;
             pixel.green+=alpha*(pixels+j)->green;
             pixel.blue+=alpha*(pixels+j)->blue;
+            pixel.opacity+=alpha*(pixels+j)->opacity;
           }
           resize_pixels[x].red=RoundToQuantum(pixel.red);
           resize_pixels[x].green=RoundToQuantum(pixel.green);
           resize_pixels[x].blue=RoundToQuantum(pixel.blue);
+          resize_pixels[x].opacity=RoundToQuantum(pixel.opacity);
         }
       else
         {
@@ -1021,21 +1096,13 @@ static MagickBooleanType VerticalFilter(const Image *image,Image *resize,
             pixel.red+=alpha*(pixels+j)->red;
             pixel.green+=alpha*(pixels+j)->green;
             pixel.blue+=alpha*(pixels+j)->blue;
+            pixel.opacity+=contribution[i].weight*(pixels+j)->opacity;
             gamma+=alpha;
           }
           gamma=1.0/(fabs((double) gamma) <= MagickEpsilon ? 1.0 : gamma);
           resize_pixels[x].red=RoundToQuantum(gamma*pixel.red);
           resize_pixels[x].green=RoundToQuantum(gamma*pixel.green);
           resize_pixels[x].blue=RoundToQuantum(gamma*pixel.blue);
-        }
-      if ((image->matte != MagickFalse) && (resize->matte != MagickFalse))
-        {
-          for (i=0; i < n; i++)
-          {
-            j=(long) ((contribution[i].pixel-contribution[0].pixel)*
-              image->columns+x);
-            pixel.opacity+=contribution[i].weight*(pixels+j)->opacity;
-          }
           resize_pixels[x].opacity=RoundToQuantum(pixel.opacity);
         }
       if ((image->colorspace == CMYKColorspace) &&
@@ -1183,8 +1250,8 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
   support=MagickMax(x_support,y_support);
   if (support < filters[i].support)
     support=filters[i].support;
-  contribution=(ContributionInfo *) AcquireMagickMemory((size_t)
-    (2.0*MagickMax(support,0.5)+3.0)*sizeof(*contribution));
+  contribution=(ContributionInfo *) AcquireQuantumMemory((size_t)
+    (2.0*MagickMax(support,0.5)+3.0),sizeof(*contribution));
   if (contribution == (ContributionInfo *) NULL)
     {
       resize_image=DestroyImage(resize_image);
@@ -1302,6 +1369,7 @@ MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
 
   register PixelPacket
     *sample_pixels;
+
   /*
     Initialize sampled image attributes.
   */
@@ -1321,9 +1389,9 @@ MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
   /*
     Allocate scan line buffer and column offset buffers.
   */
-  x_offset=(long *) AcquireMagickMemory((size_t) sample_image->columns*
+  x_offset=(long *) AcquireQuantumMemory((size_t) sample_image->columns,
     sizeof(*x_offset));
-  y_offset=(long *) AcquireMagickMemory((size_t) sample_image->rows*
+  y_offset=(long *) AcquireQuantumMemory((size_t) sample_image->rows,
     sizeof(*y_offset));
   if ((x_offset == (long *) NULL) || (y_offset == (long *) NULL))
     {
@@ -1490,15 +1558,15 @@ MagickExport Image *ScaleImage(const Image *image,const unsigned long columns,
   /*
     Allocate memory.
   */
-  x_vector=(MagickPixelPacket *) AcquireMagickMemory((size_t) image->columns*
+  x_vector=(MagickPixelPacket *) AcquireQuantumMemory((size_t) image->columns,
     sizeof(*x_vector));
   scanline=x_vector;
   if (image->rows != scale_image->rows)
-    scanline=(MagickPixelPacket *) AcquireMagickMemory((size_t) image->columns*
+    scanline=(MagickPixelPacket *) AcquireQuantumMemory((size_t) image->columns,
       sizeof(*scanline));
-  scale_scanline=(MagickPixelPacket *) AcquireMagickMemory((size_t)
-    scale_image->columns*sizeof(*scale_scanline));
-  y_vector=(MagickPixelPacket *) AcquireMagickMemory((size_t) image->columns*
+  scale_scanline=(MagickPixelPacket *) AcquireQuantumMemory((size_t)
+    scale_image->columns,sizeof(*scale_scanline));
+  y_vector=(MagickPixelPacket *) AcquireQuantumMemory((size_t) image->columns,
     sizeof(*y_vector));
   if ((scanline == (MagickPixelPacket *) NULL) ||
       (scale_scanline == (MagickPixelPacket *) NULL) ||
