@@ -22,11 +22,33 @@
 extern "C" {
 #endif
 
+typedef enum
+{
+  UndefinedFilter,
+  PointFilter,
+  BoxFilter,
+  TriangleFilter,
+  HermiteFilter,
+  HanningFilter,
+  HammingFilter,
+  BlackmanFilter,
+  GaussianFilter,
+  QuadraticFilter,
+  CubicFilter,
+  CatromFilter,
+  MitchellFilter,
+  LanczosFilter,
+  BesselFilter,
+  SincFilter
+} FilterTypes;
+
 extern MagickExport Image
   *AdaptiveResizeImage(const Image *,const unsigned long,const unsigned long,
     ExceptionInfo *),
   *MagnifyImage(const Image *,ExceptionInfo *),
   *MinifyImage(const Image *,ExceptionInfo *),
+  *ResampleImage(const Image *,const double,const double,const FilterTypes,
+    const double,ExceptionInfo *),
   *ResizeImage(const Image *,const unsigned long,const unsigned long,
     const FilterTypes,const double,ExceptionInfo *),
   *SampleImage(const Image *,const unsigned long,const unsigned long,
