@@ -480,7 +480,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
   /*
     Speed up distance calculations.
   */
-  squares=(MagickRealType *) AcquireMagickMemory(513*sizeof(*squares));
+  squares=(MagickRealType *) AcquireQuantumMemory(513UL,sizeof(*squares));
   if (squares == (MagickRealType *) NULL)
     ThrowBinaryException(ResourceLimitError,"MemoryAllocationFailed",
       image->filename);
@@ -936,8 +936,8 @@ MagickExport MagickPixelPacket GetImageDynamicThreshold(const Image *image,
   (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
   for (i=0; i < MaxDimension; i++)
   {
-    histogram[i]=(long *) AcquireMagickMemory(256*sizeof(**histogram));
-    extrema[i]=(short *) AcquireMagickMemory(256*sizeof(**histogram));
+    histogram[i]=(long *) AcquireQuantumMemory(256UL,sizeof(**histogram));
+    extrema[i]=(short *) AcquireQuantumMemory(256UL,sizeof(**histogram));
     if ((histogram[i] == (long *) NULL) || (extrema[i] == (short *) NULL))
       {
         for (i-- ; i >= 0; i--)
@@ -1320,7 +1320,8 @@ static IntervalTree *InitializeIntervalTree(const ZeroCrossing *zero_crossing,
   /*
     Allocate interval tree.
   */
-  list=(IntervalTree **) AcquireMagickMemory(TreeLength*sizeof(*list));
+  list=(IntervalTree **) AcquireQuantumMemory((size_t) TreeLength,
+    sizeof(*list));
   if (list == (IntervalTree **) NULL)
     return((IntervalTree *) NULL);
   /*
@@ -1488,14 +1489,15 @@ static MagickRealType OptimalTau(const long *histogram,const double max_tau,
   /*
     Allocate interval tree.
   */
-  list=(IntervalTree **) AcquireMagickMemory(TreeLength*sizeof(*list));
+  list=(IntervalTree **) AcquireQuantumMemory((size_t) TreeLength,
+    sizeof(*list));
   if (list == (IntervalTree **) NULL)
     return(0.0);
   /*
     Allocate zero crossing list.
   */
   count=(unsigned long) ((max_tau-min_tau)/delta_tau)+2;
-  zero_crossing=(ZeroCrossing *) AcquireMagickMemory((size_t) count*
+  zero_crossing=(ZeroCrossing *) AcquireQuantumMemory((size_t) count,
     sizeof(*zero_crossing));
   if (zero_crossing == (ZeroCrossing *) NULL)
     return(0.0);
@@ -1504,13 +1506,13 @@ static MagickRealType OptimalTau(const long *histogram,const double max_tau,
   /*
     Initialize zero crossing list.
   */
-  derivative=(MagickRealType *) AcquireMagickMemory(256*sizeof(*derivative));
-  second_derivative=(MagickRealType *) AcquireMagickMemory(256*
+  derivative=(MagickRealType *) AcquireQuantumMemory(256,sizeof(*derivative));
+  second_derivative=(MagickRealType *) AcquireQuantumMemory(256,
     sizeof(*second_derivative));
   if ((derivative == (MagickRealType *) NULL) ||
       (second_derivative == (MagickRealType *) NULL))
-    ThrowMagickFatalException(ResourceLimitFatalError,
-      "UnableToAllocateDerivatives","OptimalTau");
+    ThrowFatalException(ResourceLimitFatalError,
+      "UnableToAllocateDerivatives");
   i=0;
   for (tau=max_tau; tau >= min_tau; tau-=delta_tau)
   {
@@ -1669,10 +1671,10 @@ static void ScaleSpace(const long *histogram,const MagickRealType tau,
     u,
     x;
 
-  gamma=(MagickRealType *) AcquireMagickMemory(256*sizeof(*gamma));
+  gamma=(MagickRealType *) AcquireQuantumMemory(256,sizeof(*gamma));
   if (gamma == (MagickRealType *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,
-      "UnableToAllocateGammaMap","ScaleSpace");
+    ThrowFatalException(ResourceLimitFatalError,
+      "UnableToAllocateGammaMap");
   alpha=1.0/(tau*sqrt(2.0*MagickPI));
   beta=(-1.0/(2.0*tau*tau));
   for (x=0; x <= 255; x++)
@@ -1757,8 +1759,8 @@ MagickExport MagickBooleanType SegmentImage(Image *image,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   for (i=0; i < MaxDimension; i++)
   {
-    histogram[i]=(long *) AcquireMagickMemory(256*sizeof(**histogram));
-    extrema[i]=(short *) AcquireMagickMemory(256*sizeof(**extrema));
+    histogram[i]=(long *) AcquireQuantumMemory(256,sizeof(**histogram));
+    extrema[i]=(short *) AcquireQuantumMemory(256,sizeof(**extrema));
     if ((histogram[i] == (long *) NULL) || (extrema[i] == (short *) NULL))
       {
         for (i-- ; i >= 0; i--)
