@@ -154,7 +154,7 @@ MagickExport Image *AffineTransformImage(const Image *image,
     (unsigned long) (max.y-min.y+0.5),MagickTrue,exception);
   if (affine_image == (Image *) NULL)
     return((Image *) NULL);
-  affine_image->background_color.opacity=TransparentOpacity;
+  affine_image->background_color.opacity=(Quantum) TransparentOpacity;
   (void) SetImageBackgroundColor(affine_image);
   /*
     Adjust transform translation for direct image to image transformation.
@@ -314,12 +314,16 @@ static inline void CropToFitImage(Image **image,const MagickRealType x_shear,
 static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
   ExceptionInfo *exception)
 {
+#define TileHeight  128
+#define TileWidth  128
 #define RotateImageTag  "Rotate/Image"
 
   Image
     *rotate_image;
 
   long
+    tile_x,
+    tile_y,
     y;
 
   MagickBooleanType
@@ -336,7 +340,8 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
     *rotate_indexes;
 
   register const PixelPacket
-    *p;
+    *p,
+    *tile_pixels;
 
   register long
     x;
@@ -344,6 +349,10 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
   register PixelPacket
     *q;
 
+  unsigned long
+    tile_width,
+    tile_height;
+
   /*
     Initialize rotated image attributes.
   */
@@ -402,28 +411,45 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
       /*
         Rotate 90 degrees.
       */
-      for (y=0; y < (long) image->rows; y++)
+      for (tile_y=0; tile_y < (long) image->rows; tile_y+=TileHeight)
       {
-        p=AcquireImagePixels(image,0,y,image->columns,1,exception);
-        q=SetImagePixels(rotate_image,(long) (image->rows-y-1),0,1,
-          rotate_image->rows);
-        if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
-          break;
-        indexes=GetIndexes(image);
-        rotate_indexes=GetIndexes(rotate_image);
-        for (x=0; x < (long) image->columns; x++)
+        for (tile_x=0; tile_x < (long) image->columns; tile_x+=TileWidth)
         {
-          SetMagickPixelPacket(image,p,indexes+x,&pixel);
-          SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+x);
-          p++;
-          q++;
-        }
-        if (SyncImagePixels(rotate_image) == MagickFalse)
-          break;
-        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-            (QuantumTick(y,image->rows) != MagickFalse))
+          tile_width=TileWidth;
+          if ((tile_x+TileWidth) > (long) image->columns)
+            tile_width=1UL*(TileWidth-(tile_x+TileWidth-image->columns));
+          tile_height=TileHeight;
+          if ((tile_y+TileHeight) > (long) image->rows)
+            tile_height=1UL*(TileHeight-(tile_y+TileHeight-image->rows));
+          tile_pixels=AcquireImagePixels(image,tile_x,tile_y,tile_width,
+            tile_height,exception);
+          if (tile_pixels == (const PixelPacket *) NULL)
+            break;
+          for (y=0; y < (long) tile_width; y++)
           {
-            status=image->progress_monitor(RotateImageTag,y,image->rows,
+            q=SetImagePixels(rotate_image,(long) rotate_image->columns-(tile_y+
+              tile_height),tile_x+y,tile_height,1);
+            if (q == (PixelPacket *) NULL)
+              break;
+            rotate_indexes=GetIndexes(rotate_image);
+            p=tile_pixels+(tile_height-1)*tile_width+y;
+            indexes=GetIndexes(image)+(tile_height-1)*tile_width+y;
+            for (x=0; x < (long) tile_height; x++)
+            {
+              SetMagickPixelPacket(image,p,indexes,&pixel);
+              SetPixelPacket(rotate_image,&pixel,q,rotate_indexes+x);
+              p-=tile_width;
+              indexes-=tile_width;
+              q++;
+            }
+            if (SyncImagePixels(rotate_image) == MagickFalse)
+              break;
+          }
+        }
+        if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+            (QuantumTick(tile_y,image->rows) != MagickFalse))
+          {
+            status=image->progress_monitor(RotateImageTag,tile_y,image->rows,
               image->client_data);
             if (status == MagickFalse)
               break;
@@ -478,7 +504,7 @@ static Image *IntegralRotateImage(const Image *image,unsigned long rotations,
     case 3:
     {
       /*
-        Rotate 270 degrees.
+        Rotate 90 degrees.
       */
       for (y=0; y < (long) image->rows; y++)
       {
@@ -659,7 +685,7 @@ static void XShearImage(Image *image,const MagickRealType degrees,
     SetMagickPixelPacket(image,&image->background_color,(IndexPacket *) NULL,
       &background);
     if (image->colorspace == CMYKColorspace)
-      RGBtoCMYK(&background);
+      ConvertRGBToCMYK(&background);
     pixel=background;
     GetMagickPixelPacket(image,&source);
     GetMagickPixelPacket(image,&destination);
@@ -843,7 +869,7 @@ static void YShearImage(Image *image,const MagickRealType degrees,
     SetMagickPixelPacket(image,&image->background_color,(IndexPacket *) NULL,
       &background);
     if (image->colorspace == CMYKColorspace)
-      RGBtoCMYK(&background);
+      ConvertRGBToCMYK(&background);
     pixel=background;
     GetMagickPixelPacket(image,&source);
     GetMagickPixelPacket(image,&destination);
