@@ -296,7 +296,7 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
         if ((channel & BlueChannel) != 0)
           status|=p->blue != ScaleAnyToQuantum(ScaleQuantumToAny(p->blue,
             depth),depth);
-        if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+        if ((channel & OpacityChannel) != 0)
           status|=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(p->opacity,
             depth),depth);
         if (((channel & IndexChannel) != 0) &&
@@ -476,7 +476,7 @@ MagickExport MagickBooleanType GetImageChannelMean(const Image *image,
           *standard_deviation+=(double) p->blue*p->blue;
           area++;
         }
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         {
           *mean+=p->opacity;
           *standard_deviation+=(double) p->opacity*p->opacity;
@@ -630,7 +630,7 @@ MagickExport MagickBooleanType GetImageChannelRange(const Image *image,
             if (pixel.blue > *maxima)
               *maxima=(double) pixel.blue;
           }
-        if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+        if ((channel & OpacityChannel) != 0)
           {
             if (pixel.opacity < *minima)
               *minima=(double) pixel.opacity;
@@ -736,11 +736,11 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  length=(AllChannels+1)*sizeof(*channel_statistics);
-  channel_statistics=(ChannelStatistics *) AcquireMagickMemory(length);
+  length=AllChannels+1UL;
+  channel_statistics=(ChannelStatistics *) AcquireQuantumMemory(length,
+    sizeof(*channel_statistics));
   if (channel_statistics == (ChannelStatistics *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      image->filename);
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(channel_statistics,0,length);
   for (i=0; i <= AllChannels; i++)
   {
@@ -792,18 +792,15 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
               continue;
             }
         }
-      if (image->matte != MagickFalse)
+      if (channel_statistics[OpacityChannel].depth != QuantumDepth)
         {
-          if (channel_statistics[OpacityChannel].depth != QuantumDepth)
+          depth=channel_statistics[OpacityChannel].depth;
+          status=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(
+            p->opacity,depth),depth) ? MagickTrue : MagickFalse;
+          if (status != MagickFalse)
             {
-              depth=channel_statistics[OpacityChannel].depth;
-              status=p->opacity != ScaleAnyToQuantum(ScaleQuantumToAny(
-                p->opacity,depth),depth) ? MagickTrue : MagickFalse;
-              if (status != MagickFalse)
-                {
-                  channel_statistics[OpacityChannel].depth++;
-                  continue;
-                }
+              channel_statistics[OpacityChannel].depth++;
+              continue;
             }
         }
       if (image->colorspace == CMYKColorspace)
@@ -841,16 +838,13 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
       channel_statistics[BlueChannel].mean+=p->blue;
       channel_statistics[BlueChannel].standard_deviation+=(double)
         p->blue*p->blue;
-      if (image->matte != MagickFalse)
-        {
-          if ((double) p->opacity < channel_statistics[OpacityChannel].minima)
-            channel_statistics[OpacityChannel].minima=(double) p->opacity;
-          if ((double) p->opacity > channel_statistics[OpacityChannel].maxima)
-            channel_statistics[OpacityChannel].maxima=(double) p->opacity;
-          channel_statistics[OpacityChannel].mean+=p->opacity;
-          channel_statistics[OpacityChannel].standard_deviation+=(double)
-            p->opacity*p->opacity;
-        }
+      if ((double) p->opacity < channel_statistics[OpacityChannel].minima)
+        channel_statistics[OpacityChannel].minima=(double) p->opacity;
+      if ((double) p->opacity > channel_statistics[OpacityChannel].maxima)
+        channel_statistics[OpacityChannel].maxima=(double) p->opacity;
+      channel_statistics[OpacityChannel].mean+=p->opacity;
+      channel_statistics[OpacityChannel].standard_deviation+=(double)
+        p->opacity*p->opacity;
       if (image->colorspace == CMYKColorspace)
         {
           if ((double) indexes[x] < channel_statistics[BlackChannel].minima)
@@ -884,9 +878,7 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
     channel_statistics[AllChannels].standard_deviation+=
       channel_statistics[i].standard_deviation;
   }
-  channels=3;
-  if (image->matte != MagickFalse)
-    channels++;
+  channels=4;
   if (image->colorspace == CMYKColorspace)
     channels++;
   channel_statistics[AllChannels].mean/=channels;
@@ -1016,8 +1008,7 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
             q->green=ScaleAnyToQuantum(ScaleQuantumToAny(q->green,depth),depth);
           if ((channel & BlueChannel) != 0)
             q->blue=ScaleAnyToQuantum(ScaleQuantumToAny(q->blue,depth),depth);
-          if (((channel & OpacityChannel) != 0) &&
-              (image->matte != MagickFalse))
+          if ((channel & OpacityChannel) != 0)
             q->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(q->opacity,depth),
               depth);
           if (((channel & IndexChannel) != 0) &&
@@ -1044,8 +1035,7 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
                 depth);
             if ((channel & BlueChannel) != 0)
               q->blue=ScaleAnyToQuantum(ScaleQuantumToAny(q->blue,depth),depth);
-            if (((channel & OpacityChannel) != 0) &&
-                (image->matte != MagickFalse))
+            if ((channel & OpacityChannel) != 0)
               q->opacity=ScaleAnyToQuantum(ScaleQuantumToAny(q->opacity,depth),
                 depth);
             q++;
