@@ -217,8 +217,7 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
           pixel.red+=r[u].red;
           pixel.green+=r[u].green;
           pixel.blue+=r[u].blue;
-          if (image->matte != MagickFalse)
-            pixel.opacity+=r[u].opacity;
+          pixel.opacity+=r[u].opacity;
           if (image->colorspace == CMYKColorspace)
             pixel.index=(MagickRealType) indexes[x+(r-p)+u];
         }
@@ -227,8 +226,7 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
       mean.red=(MagickRealType) (pixel.red/number_pixels+offset);
       mean.green=(MagickRealType) (pixel.green/number_pixels+offset);
       mean.blue=(MagickRealType) (pixel.blue/number_pixels+offset);
-      if (image->matte != MagickFalse)
-        mean.opacity=(MagickRealType) (pixel.opacity/number_pixels+offset);
+      mean.opacity=(MagickRealType) (pixel.opacity/number_pixels+offset);
       if (image->colorspace == CMYKColorspace)
         mean.index=(MagickRealType) (pixel.index/number_pixels+offset);
       q->red=(Quantum) (((MagickRealType)
@@ -237,9 +235,8 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
         q->green <= mean.green) ? 0 : QuantumRange);
       q->blue=(Quantum) (((MagickRealType)
         q->blue <= mean.blue) ? 0 : QuantumRange);
-      if (image->matte != MagickFalse)
-        q->opacity=(Quantum) (((MagickRealType)
-          q->opacity <= mean.opacity) ? 0 : QuantumRange);
+      q->opacity=(Quantum) (((MagickRealType)
+        q->opacity <= mean.opacity) ? 0 : QuantumRange);
       if (image->colorspace == CMYKColorspace)
         threshold_indexes[x]=(IndexPacket) (((MagickRealType)
           threshold_indexes[x] <= mean.index) ? 0 : QuantumRange);
@@ -357,9 +354,15 @@ MagickExport MagickBooleanType BilevelImageChannel(Image *image,
         if ((channel & BlueChannel) != 0)
           q->blue=(Quantum) ((MagickRealType)
             q->blue <= threshold ? 0 : QuantumRange);
-        if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-          q->opacity=(Quantum) ((MagickRealType)
-            q->opacity <= threshold ?  OpaqueOpacity : TransparentOpacity);
+        if ((channel & OpacityChannel) != 0)
+          {
+            if (image->matte == MagickFalse)
+              q->opacity=(Quantum) ((MagickRealType)
+                q->opacity <= threshold ? 0 : QuantumRange);
+            else
+              q->opacity=(Quantum) ((MagickRealType)
+                q->opacity <= threshold ?  OpaqueOpacity : TransparentOpacity);
+          }
         if (((channel & IndexChannel) != 0) &&
             (image->colorspace == CMYKColorspace))
           indexes[x]=(IndexPacket) ((MagickRealType)
@@ -599,15 +602,15 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
   }
   description = GetXMLTreeChild(threshold,"description");
   if ( description == (XMLTreeInfo *)NULL ) {
-   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlMissingElement", "<description>, map \"%s\"", map_id);
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+      "XmlMissingElement", "<description>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     return(map);
   }
   levels = GetXMLTreeChild(threshold,"levels");
   if ( levels == (XMLTreeInfo *)NULL ) {
-   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlMissingElement", "<levels>, map \"%s\"", map_id);
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+      "XmlMissingElement", "<levels>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     return(map);
   }
@@ -615,8 +618,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
   /* The map has been found -- Allocate a Threshold Map to return */
   map = (ThresholdMap *)AcquireMagickMemory(sizeof(ThresholdMap));
   if ( map == (ThresholdMap *)NULL )
-    ThrowMagickFatalException(ResourceLimitFatalError,
-         "UnableToAcquireThresholdMap",map_id);
+    ThrowFatalException(ResourceLimitFatalError,"UnableToAcquireThresholdMap");
   map->map_id = (char *)NULL;
   map->description = (char *)NULL;
   map->levels = (int *)NULL;
@@ -632,16 +634,16 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
 
   attr = GetXMLTreeAttribute(levels, "width");
   if ( attr == (char *)NULL ) {
-   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlMissingAttribute", "<levels width>, map \"%s\"", map_id);
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+      "XmlMissingAttribute", "<levels width>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
     return(map);
   }
   map->width = atoi(attr);
   if ( map->width == 0 ) {
-   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlInvalidAttribute", "<levels width>, map \"%s\"", map_id);
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+     "XmlInvalidAttribute", "<levels width>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
     return(map);
@@ -649,16 +651,16 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
 
   attr = GetXMLTreeAttribute(levels, "height");
   if ( attr == (char *)NULL ) {
-   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlMissingAttribute", "<levels height>, map \"%s\"", map_id);
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+      "XmlMissingAttribute", "<levels height>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
     return(map);
   }
   map->height = atoi(attr);
   if ( map->height == 0 ) {
-   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlInvalidAttribute", "<levels height>, map \"%s\"", map_id);
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+      "XmlInvalidAttribute", "<levels height>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
     return(map);
@@ -666,16 +668,16 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
 
   attr = GetXMLTreeAttribute(levels, "divisor");
   if ( attr == (char *)NULL ) {
-   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlMissingAttribute", "<levels divisor>, map \"%s\"", map_id);
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+      "XmlMissingAttribute", "<levels divisor>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
     return(map);
   }
   map->divisor = atoi(attr);
   if ( map->divisor < 2 ) {
-   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlInvalidAttribute", "<levels divisor>, map \"%s\"", map_id);
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+      "XmlInvalidAttribute", "<levels divisor>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
     return(map);
@@ -684,32 +686,30 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
   /* Allocate the theshold levels array */
   content = GetXMLTreeContent(levels);
   if ( content == (char *)NULL ) {
-   (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlMissingContent", "<levels>, map \"%s\"", map_id);
+    (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+      "XmlMissingContent", "<levels>, map \"%s\"", map_id);
     thresholds = DestroyXMLTree(thresholds);
     map = DestroyThresholdMap(map);
     return(map);
   }
-  map->levels = (int *)AcquireMagickMemory(
-           map->width*map->height*sizeof(int));
+  map->levels=(int *) AcquireQuantumMemory((size_t) map->width,map->height*
+    sizeof(*map->levels));
   if ( map->levels == (int *)NULL )
-    ThrowMagickFatalException(ResourceLimitFatalError,
-        "UnableToAcquireThresholdMap", map_id);
-
+    ThrowFatalException(ResourceLimitFatalError,"UnableToAcquireThresholdMap");
   { /* parse levels into integer array */
     int i;
     char *p;
     for( i=0; i<map->width*map->height; i++) {
       map->levels[i] = (int)strtol(content, &p, 10);
       if ( p == content ) {
-       (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
           "XmlInvalidContent", "<level> too few values, map \"%s\"", map_id);
         thresholds = DestroyXMLTree(thresholds);
         map = DestroyThresholdMap(map);
         return(map);
       }
       if ( map->levels[i] < 0 || map->levels[i] > map->divisor ) {
-       (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
           "XmlInvalidContent", "<level> %d out of range, map \"%s\"",
           map->levels[i], map_id);
         thresholds = DestroyXMLTree(thresholds);
@@ -721,7 +721,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
     (void) strtol(content, &p, 10);
     if ( p != content ) {
        (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-          "XmlInvalidContent", "<level> too many values, map \"%s\"", map_id);
+         "XmlInvalidContent", "<level> too many values, map \"%s\"", map_id);
       thresholds = DestroyXMLTree(thresholds);
       map = DestroyThresholdMap(map);
       return(map);
@@ -834,8 +834,8 @@ MagickBooleanType ListThresholdMapFile(FILE *file,const char *xml,
   {
     map = GetXMLTreeAttribute(threshold, "map");
     if (map == (char *) NULL) {
-     (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlMissingAttribute", "<map>");
+      (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+        "XmlMissingAttribute", "<map>");
       thresholds=DestroyXMLTree(thresholds);
       return(MagickFalse);
     }
@@ -843,15 +843,15 @@ MagickBooleanType ListThresholdMapFile(FILE *file,const char *xml,
     /* alias is optional, no if test needed */
     description=GetXMLTreeChild(threshold,"description");
     if ( description == (XMLTreeInfo *)NULL ) {
-     (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlMissingElement", "<description>, map \"%s\"", map);
+      (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+        "XmlMissingElement", "<description>, map \"%s\"", map);
       thresholds=DestroyXMLTree(thresholds);
       return(MagickFalse);
     }
     content=GetXMLTreeContent(description);
     if ( content == (char *)NULL ) {
-     (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
-         "XmlMissingContent", "<description>, map \"%s\"", map);
+      (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+        "XmlMissingContent", "<description>, map \"%s\"", map);
       thresholds=DestroyXMLTree(thresholds);
       return(MagickFalse);
     }
@@ -1082,9 +1082,8 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
     token[p-threshold_map] = '\0';
     map = GetThresholdMap(token, exception);
     if ( map == (ThresholdMap *)NULL ) {
-     (void) ThrowMagickException(exception,GetMagickModule(),
-          OptionError,"InvalidArgument","%s : '%s'",
-          "ordered-dither", threshold_map);
+      (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
+        "InvalidArgument","%s : '%s'","ordered-dither",threshold_map);
       return(MagickFalse);
     }
   }
@@ -1104,8 +1103,7 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
     levels.red     = ((channel & RedChannel  )   != 0) ? levels.index : 0;
     levels.green   = ((channel & GreenChannel)   != 0) ? levels.index : 0;
     levels.blue    = ((channel & BlueChannel)    != 0) ? levels.index : 0;
-    levels.opacity = ((channel & OpacityChannel) != 0
-                    && (image->matte != MagickFalse)) ? levels.index : 0;
+    levels.opacity = ((channel & OpacityChannel) != 0) ? levels.index : 0;
     levels.index   = ((channel & IndexChannel)   != 0
             && (image->colorspace == CMYKColorspace)) ? levels.index : 0;
 
@@ -1442,8 +1440,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
               threshold.blue=(MagickRealType) (QuantumRange*
                 GetRandomValue());
         }
-      if (((channel & OpacityChannel) != 0) &&
-          (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         {
           if ((MagickRealType) q->opacity < min_threshold)
             threshold.opacity=min_threshold;
@@ -1475,7 +1472,7 @@ MagickExport MagickBooleanType RandomThresholdImageChannel(Image *image,
       if ((channel & BlueChannel) != 0)
         q->blue=(Quantum) ((MagickRealType) q->blue <= threshold.blue ? 0 :
           QuantumRange);
-      if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
+      if ((channel & OpacityChannel) != 0)
         q->opacity=(Quantum) ((MagickRealType) q->opacity <= threshold.opacity ?
           0 : QuantumRange);
       if (((channel & IndexChannel) != 0) &&
@@ -1590,9 +1587,9 @@ MagickExport MagickBooleanType WhiteThresholdImage(Image *image,
       {
         if ((MagickRealType) PixelIntensityToQuantum(q) > pixel.red)
           {
-            q->red=QuantumRange;
-            q->green=QuantumRange;
-            q->blue=QuantumRange;
+            q->red=(Quantum) QuantumRange;
+            q->green=(Quantum) QuantumRange;
+            q->blue=(Quantum) QuantumRange;
           }
         q++;
       }
@@ -1600,13 +1597,13 @@ MagickExport MagickBooleanType WhiteThresholdImage(Image *image,
       for (x=0; x < (long) image->columns; x++)
       {
         if ((MagickRealType) q->red > pixel.red)
-          q->red=QuantumRange;
+          q->red=(Quantum) QuantumRange;
         if ((MagickRealType) q->green > pixel.green)
-          q->green=QuantumRange;
+          q->green=(Quantum) QuantumRange;
         if ((MagickRealType) q->blue > pixel.blue)
-          q->blue=QuantumRange;
+          q->blue=(Quantum) QuantumRange;
         if ((MagickRealType) q->opacity > pixel.opacity)
-          q->opacity=QuantumRange;
+          q->opacity=(Quantum) QuantumRange;
         q++;
       }
     if (SyncImagePixels(image) == MagickFalse)
