@@ -473,7 +473,7 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       crop_image=CloneImage(image,1,1,MagickTrue,exception);
       if (crop_image == (Image *) NULL)
         return((Image *) NULL);
-      crop_image->background_color.opacity=TransparentOpacity;
+      crop_image->background_color.opacity=(Quantum) TransparentOpacity;
       (void) SetImageBackgroundColor(crop_image);
       crop_image->page=bounding_box;
       crop_image->page.x=(-1);
@@ -541,7 +541,7 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
   crop_view=OpenCacheView(crop_image);
   for (y=0; y < (long) crop_image->rows; y++)
   {
-    p=AcquireCacheView(image_view,page.x,page.y+y,crop_image->columns,1,
+    p=AcquireCacheViewPixels(image_view,page.x,page.y+y,crop_image->columns,1,
       exception);
     q=SetCacheView(crop_view,0,y,crop_image->columns,1);
     if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
@@ -574,6 +574,103 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   E x c e r p t I m a g e                                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ExcerptImage() returns a excerpt of the image as defined by the geometry.
+%
+%  The format of the ExcerptImage method is:
+%
+%      Image *ExcerptImage(const Image *image,const RectangleInfo *geometry,
+%        ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o geometry: Define the region of the image to extend with members
+%      x, y, width, and height.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport Image *ExcerptImage(const Image *image,
+  const RectangleInfo *geometry,ExceptionInfo *exception)
+{
+#define ExcerptImageTag  "Flip/Image"
+
+  Image
+    *excerpt_image;
+
+  long
+    y;
+
+  MagickBooleanType
+    status;
+
+  register IndexPacket
+    *excerpt_indexes,
+    *indexes;
+
+  register const PixelPacket
+    *p;
+
+  register PixelPacket
+    *q;
+
+  /*
+    Allocate excerpt image.
+  */
+  assert(image != (const Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  assert(geometry != (const RectangleInfo *) NULL);
+  assert(exception != (ExceptionInfo *) NULL);
+  assert(exception->signature == MagickSignature);
+  excerpt_image=CloneImage(image,geometry->width,geometry->height,MagickTrue,
+    exception);
+  if (excerpt_image == (Image *) NULL)
+    return((Image *) NULL);
+  /*
+    Excerpt each row.
+  */
+  for (y=0; y < (long) excerpt_image->rows; y++)
+  {
+    p=AcquireImagePixels(image,geometry->x,geometry->y+y,geometry->width,1,
+      exception);
+    q=GetImagePixels(excerpt_image,0,y,excerpt_image->columns,1);
+    if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
+      break;
+    (void) CopyMagickMemory(q,p,(size_t) excerpt_image->columns*sizeof(*q));
+    indexes=GetIndexes(image);
+    excerpt_indexes=GetIndexes(excerpt_image);
+    if ((indexes != (IndexPacket *) NULL) &&
+        (excerpt_indexes != (IndexPacket *) NULL))
+      (void) CopyMagickMemory(excerpt_indexes,indexes,(size_t)
+        excerpt_image->columns*sizeof(*excerpt_indexes));
+    if (SyncImagePixels(excerpt_image) == MagickFalse)
+      break;
+    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
+        (QuantumTick(y,excerpt_image->rows) != MagickFalse))
+      {
+        status=image->progress_monitor(ExcerptImageTag,y,excerpt_image->rows,
+          image->client_data);
+        if (status == MagickFalse)
+          break;
+      }
+  }
+  return(excerpt_image);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   E x t e n t I m a g e                                                     %
 %                                                                             %
 %                                                                             %
@@ -795,7 +892,7 @@ MagickExport Image *FlipImage(const Image *image,ExceptionInfo *exception)
     flip_indexes=GetIndexes(flip_image);
     if ((indexes != (IndexPacket *) NULL) &&
         (flip_indexes != (IndexPacket *) NULL))
-      (void) CopyMagickMemory(flip_indexes,indexes,(size_t) image->columns*
+      (void) CopyMagickMemory(flip_indexes,indexes,(size_t) flip_image->columns*
         sizeof(*flip_indexes));
     if (SyncImagePixels(flip_image) == MagickFalse)
       break;
@@ -1898,7 +1995,7 @@ MagickExport Image *TrimImage(const Image *image,ExceptionInfo *exception)
       crop_image=CloneImage(image,1,1,MagickTrue,exception);
       if (crop_image == (Image *) NULL)
         return((Image *) NULL);
-      crop_image->background_color.opacity=TransparentOpacity;
+      crop_image->background_color.opacity=(Quantum) TransparentOpacity;
       (void) SetImageBackgroundColor(crop_image);
       crop_image->page=image->page;
       crop_image->page.x=(-1);
