@@ -506,8 +506,8 @@ MagickExport const TypeInfo **GetTypeInfoList(const char *pattern,
   p=GetTypeInfo("*",exception);
   if (p == (const TypeInfo *) NULL)
     return((const TypeInfo **) NULL);
-  fonts=(const TypeInfo **) AcquireMagickMemory((size_t)
-    (GetNumberOfNodesInSplayTree(type_list)+1)*sizeof(*fonts));
+  fonts=(const TypeInfo **) AcquireQuantumMemory((size_t)
+    GetNumberOfNodesInSplayTree(type_list)+1UL,sizeof(*fonts));
   if (fonts == (const TypeInfo **) NULL)
     return((const TypeInfo **) NULL);
   /*
@@ -599,8 +599,8 @@ MagickExport char **GetTypeList(const char *pattern,unsigned long *number_fonts,
   p=GetTypeInfo("*",exception);
   if (p == (const TypeInfo *) NULL)
     return((char **) NULL);
-  fonts=(char **) AcquireMagickMemory((size_t)
-    (GetNumberOfNodesInSplayTree(type_list)+1)*sizeof(*fonts));
+  fonts=(char **) AcquireQuantumMemory((size_t)
+    GetNumberOfNodesInSplayTree(type_list)+1UL,sizeof(*fonts));
   if (fonts == (char **) NULL)
     return((char **) NULL);
   /*
@@ -688,6 +688,7 @@ MagickExport MagickBooleanType LoadFontConfigFonts(SplayTreeInfo *type_list,
   /*
     Load system fonts.
   */
+  (void) exception;
   font_config=FcInitLoadConfigAndFonts();
   object_set=FcObjectSetBuild(FC_FAMILY,FC_STYLE,FC_SLANT,FC_WIDTH,FC_WEIGHT,
     FC_FILE,(char *) NULL);
@@ -977,7 +978,7 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
     return(MagickFalse);
   if (type_list == (SplayTreeInfo *) NULL)
     {
-      type_list=NewSplayTree(CompareSplayTreeString,RelinquishMagickMemory,
+      type_list=NewSplayTree(CompareSplayTreeString,(void *(*)(void *)) NULL,
         DestroyTypeNode);
       if (type_list == (SplayTreeInfo *) NULL)
         {
@@ -1041,8 +1042,7 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
     */
     type_info=(TypeInfo *) AcquireMagickMemory(sizeof(*type_info));
     if (type_info == (TypeInfo *) NULL)
-      ThrowMagickFatalException(ResourceLimitFatalError,
-        "MemoryAllocationFailed",filename);
+      ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(type_info,0,sizeof(*type_info));
     type_info->path=ConstantString(filename);
     type_info->signature=MagickSignature;
@@ -1113,8 +1113,7 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
         if (LocaleCompare(attribute,"normal") == 0)
           type_info->weight=400;
       }
-    status=AddValueToSplayTree(type_list,ConstantString(type_info->name),
-      type_info);
+    status=AddValueToSplayTree(type_list,type_info->name,type_info);
     if (status == MagickFalse)
       (void) ThrowMagickException(exception,GetMagickModule(),
         ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
