@@ -17,7 +17,7 @@
 %                               September 2002                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -68,7 +68,6 @@
 %
 %      const char *GetMagickCopyright(void)
 %
-%
 */
 MagickExport const char *GetMagickCopyright(void)
 {
@@ -92,7 +91,6 @@ MagickExport const char *GetMagickCopyright(void)
 %
 %      char *GetMagickHomeURL(void)
 %
-%
 */
 MagickExport char *GetMagickHomeURL(void)
 {
@@ -103,14 +101,14 @@ MagickExport char *GetMagickHomeURL(void)
     *element;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   LinkedListInfo
     *paths;
 
-  GetExceptionInfo(&exception);
-  paths=GetConfigurePaths(MagickURLFilename,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  paths=GetConfigurePaths(MagickURLFilename,exception);
+  exception=DestroyExceptionInfo(exception);
   if (paths == (LinkedListInfo *) NULL)
     return(ConstantString(MagickHomeURL));
   element=(const char *) GetNextValueInLinkedList(paths);
@@ -144,7 +142,6 @@ MagickExport char *GetMagickHomeURL(void)
 %
 %  No parameters are required.
 %
-%
 */
 MagickExport const char *GetMagickPackageName(void)
 {
@@ -172,7 +169,6 @@ MagickExport const char *GetMagickPackageName(void)
 %
 %    o depth: The quantum depth is returned as a number.
 %
-%
 */
 MagickExport const char *GetMagickQuantumDepth(unsigned long *depth)
 {
@@ -202,7 +198,6 @@ MagickExport const char *GetMagickQuantumDepth(unsigned long *depth)
 %
 %    o range: The quantum range is returned as a number.
 %
-%
 */
 MagickExport const char *GetMagickQuantumRange(unsigned long *range)
 {
@@ -230,7 +225,6 @@ MagickExport const char *GetMagickQuantumRange(unsigned long *range)
 %
 %  No parameters are required.
 %
-%
 */
 MagickExport const char *GetMagickReleaseDate(void)
 {
