@@ -312,10 +312,16 @@ int main ( int argc, char **argv )
        !strcmp( "PAL", format ) ||
        !strcmp( "PCD", format ) ||
        !strcmp( "PCDS", format ) ||
+       !strcmp( "PGM", format ) ||
+       !strcmp( "PPM", format ) ||
+       !strcmp( "PNM", format ) ||
+       !strcmp( "SGI", format ) ||
+       !strcmp( "XPM", format ) ||
        !strcmp( "UYVY", format ) ||
        !strcmp( "YUV", format ) || (final->compression == JPEGCompression))
     fuzz_factor = 0.06;
   
+  SetImageColorspace(final,original->colorspace);
   if ( !IsImagesEqual(original, final ) &&
        (original->error.normalized_mean_error > fuzz_factor) )
     {
