@@ -128,6 +128,7 @@ typedef struct _MagickWand
 #include "wand/composite.h"
 #include "wand/conjure.h"
 #include "wand/convert.h"
+#include "wand/deprecate.h"
 #include "wand/display.h"
 #include "wand/drawing-wand.h"
 #include "wand/identify.h"
@@ -140,6 +141,12 @@ typedef struct _MagickWand
 #include "wand/pixel-wand.h"
 #include "wand/stream.h"
 
+extern WandExport char
+  *MagickGetException(const MagickWand *,ExceptionType *);
+
+extern WandExport ExceptionType
+  MagickGetExceptionType(const MagickWand *);
+
 extern WandExport long
   MagickGetIteratorIndex(MagickWand *);
 
