@@ -56,14 +56,11 @@
 */
 #define ThrowFileException(exception,severity,tag,context) \
 { \
-  char \
-    *message; \
- \
-  message=GetExceptionMessage(errno); \
-  (void) ThrowMagickException(exception,GetMagickModule(),severity,tag, \
-    "`%s': %s",context,message); \
-  message=DestroyString(message); \
+  (void) ThrowMagickException(exception,GetMagickModule(),severity, \
+    tag == (const char *) NULL ? "unknown" : tag,"`%s': %s",context, \
+    strerror(errno)); \
 }
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -96,7 +93,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static MagickBooleanType ConcatenateImages(int argc,char **argv,
@@ -148,6 +144,7 @@ static void ConvertUsage(void)
       "                     triangulation",
       "-adaptive-sharpen geometry",
       "                     adaptively sharpen pixels; increase effect near edges",
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-annotate geometry text",
       "                     annotate the image with text",
       "-auto-orient         automatically orient image",
@@ -270,6 +267,7 @@ static void ConvertUsage(void)
     {
       "-append              append an image sequence",
       "-average             average an image sequence",
+      "-clut                apply a color lookup table to the image",
       "-coalesce            merge a sequence of images",
       "-combine             combine a sequence of images",
       "-composite           composite image",
@@ -290,6 +288,7 @@ static void ConvertUsage(void)
     {
       "-adjoin              join images into a single multi-image file",
       "-affine matrix       affine transform matrix",
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
       "-attenuate value     lessen (or intensify) when adding noise to an image",
@@ -333,7 +332,6 @@ static void ConvertUsage(void)
       "-log format          format of debugging information",
       "-loop iterations     add Netscape loop extension to your GIF animation",
       "-mask filename       associate a mask with the image",
-      "-matte               store matte channel if the image has one",
       "-mattecolor color    frame color",
       "-monitor             monitor progress",
       "-orient type         image orientation",
@@ -604,6 +602,22 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowConvertException(OptionError,"UnrecognizedAlphaChannelType",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("annotate",option+1) == 0)
           {
             if (*option == '+')
@@ -830,6 +844,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             AppendImageToList(&image_stack[k],clone_images);
             break;
           }
+        if (LocaleCompare("clut",option+1) == 0)
+          break;
         if (LocaleCompare("coalesce",option+1) == 0)
           break;
         if (LocaleCompare("colorize",option+1) == 0)
@@ -891,11 +907,11 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowConvertException(OptionError,"MissingArgument",option);
-            compose=ParseMagickOption(MagickCompositeOptions,MagickFalse,
+            compose=ParseMagickOption(MagickComposeOptions,MagickFalse,
               argv[i]);
             if (compose < 0)
-              ThrowConvertException(OptionError,
-                "UnrecognizedComposeOperator",argv[i]);
+              ThrowConvertException(OptionError,"UnrecognizedComposeOperator",
+                argv[i]);
             break;
           }
         if (LocaleCompare("composite",option+1) == 0)
@@ -903,18 +919,18 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
-              ThrowConvertException(OptionError,
-                "UnrecognizedImageCompression",argv[i]);
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
+              ThrowConvertException(OptionError,"UnrecognizedImageCompression",
+                argv[i]);
             break;
           }
         if (LocaleCompare("contrast",option+1) == 0)
@@ -983,7 +999,6 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
                 argv[i]);
             (void) SetLogEventMask(argv[i]);
             break;
-            break;
           }
         if (LocaleCompare("define",option+1) == 0)
           {
@@ -1075,11 +1090,12 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("distort",option+1) == 0)
           {
+            char
+              *p;
+
             long
               op;
 
-            if (*option == '+')
-              break;
             i++;
             if (i == (long) argc)
               ThrowConvertException(OptionError,"MissingArgument",option);
@@ -1090,7 +1106,8 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            if (IsGeometry(argv[i]) == MagickFalse)
+            (void) strtod(argv[i],&p);
+            if (p == argv[i])
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
@@ -2423,7 +2440,7 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) (argc-1))
               ThrowConvertException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickTypeOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowConvertException(OptionError,"UnrecognizedImageType",
                 argv[i]);
