@@ -134,6 +134,7 @@ static void DisplayUsage(void)
     },
     *settings[]=
     {
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
       "-backdrop            display image centered on a backdrop",
@@ -165,7 +166,6 @@ static void DisplayUsage(void)
       "-log format          format of debugging information",
       "-loop iterations     loop images then exit",
       "-map type            display image using this Standard Colormap",
-      "-matte               store matte channel if the image has one",
       "-monitor             monitor progress",
       "-page geometry       size and location of an image canvas",
       "-profile filename    add, delete, or apply an image profile",
@@ -371,7 +371,7 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
         message);
       message=DestroyString(message);
     }
-  image_marker=(unsigned long *) AcquireMagickMemory((argc+1)*
+  image_marker=(unsigned long *) AcquireQuantumMemory((size_t) argc+1UL,
     sizeof(*image_marker));
   if (image_marker == (unsigned long *) NULL)
     {
@@ -683,6 +683,22 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
     {
       case 'a':
       {
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowDisplayException(OptionError,"UnrecognizedAlphaChannelType",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("antialias",option+1) == 0)
           break;
         if (LocaleCompare("authenticate",option+1) == 0)
@@ -851,18 +867,18 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) argc)
               ThrowDisplayException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
-              ThrowDisplayException(OptionError,
-                "UnrecognizedImageCompression",argv[i]);
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
+              ThrowDisplayException(OptionError,"UnrecognizedImageCompression",
+                argv[i]);
             break;
           }
         if (LocaleCompare("contrast",option+1) == 0)
