@@ -92,6 +92,7 @@ static void IdentifyUsage(void)
   static const char
     *settings[]=
     {
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-antialias           remove pixel-aliasing",
       "-authenticate value  decrypt image with this password",
       "-channel type        apply option to select image channels",
@@ -105,6 +106,7 @@ static void IdentifyUsage(void)
       "-extract geometry    extract area from image",
       "-format \"string\"     output formatted image characteristics",
       "-fuzz distance       colors within this distance are considered equal",
+      "-gamma value         level of gamma correction",
       "-help                print program options",
       "-interlace type      type of image interlacing scheme",
       "-interpolate method  pixel color interpolation method",
@@ -112,7 +114,6 @@ static void IdentifyUsage(void)
       "-list type           Color, Configure, Delegate, Format, Magic, Module,",
       "                     Resource, or Type",
       "-log format          format of debugging information",
-      "-matte               store matte channel if the image has one",
       "-monitor             monitor progress",
       "-ping                efficiently determine image attributes",
       "-quiet               suppress all warning messages",
@@ -331,6 +332,22 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
     {
       case 'a':
       {
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowIdentifyException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowIdentifyException(OptionError,"UnrecognizedAlphaChannelType",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("antialias",option+1) == 0)
           break;
         if (LocaleCompare("authenticate",option+1) == 0)
@@ -490,6 +507,19 @@ WandExport MagickBooleanType IdentifyImageCommand(ImageInfo *image_info,
           }
         ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
       }
+      case 'g':
+      {
+        if (LocaleCompare("gamma",option+1) == 0)
+          {
+            i++;
+            if (i == (long) (argc-1))
+              ThrowIdentifyException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowIdentifyInvalidArgumentException(option,argv[i]);
+            break;
+          }
+        ThrowIdentifyException(OptionError,"UnrecognizedOption",option)
+      }
       case 'h':
       {
         if ((LocaleCompare("help",option+1) == 0) ||
