@@ -93,7 +93,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 static void ImportUsage(void)
@@ -590,16 +589,16 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) argc)
               ThrowImportException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
               ThrowImportException(OptionError,"UnrecognizedImageCompression",
                 argv[i]);
             break;
@@ -947,7 +946,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             break;
           }
         if (LocaleCompare("ping",option+1) == 0)
-          ThrowImportException(OptionError,"DeprecatedOption",option);
+          break;  /* deprecated option */
         if (LocaleCompare("pointsize",option+1) == 0)
           {
             if (*option == '+')
@@ -1180,7 +1179,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowImportException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickTypeOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowImportException(OptionError,"UnrecognizedImageType",argv[i]);
             break;
