@@ -29,7 +29,6 @@ extern WandExport ChannelStatistics
 extern WandExport char
   *MagickGetImageFilename(MagickWand *),
   *MagickGetImageFormat(MagickWand *),
-  *MagickGetImageProperty(MagickWand *,const char *),
   *MagickGetImageSignature(MagickWand *),
   *MagickIdentifyImage(MagickWand *);
 
@@ -91,6 +90,8 @@ extern WandExport MagickBooleanType
     const long,const long),
   MagickClipImage(MagickWand *),
   MagickClipPathImage(MagickWand *,const char *,const MagickBooleanType),
+  MagickClutImage(MagickWand *,const MagickWand *),
+  MagickClutImageChannel(MagickWand *,const ChannelType,const MagickWand *),
   MagickColorizeImage(MagickWand *,const PixelWand *,const PixelWand *),
   MagickCommentImage(MagickWand *,const char *),
   MagickCompositeImage(MagickWand *,const MagickWand *,const CompositeOperator,
@@ -108,12 +109,11 @@ extern WandExport MagickBooleanType
   MagickCropImage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   MagickCycleColormapImage(MagickWand *,const long),
-  MagickDeleteImageProperty(MagickWand *,const char *),
   MagickDespeckleImage(MagickWand *),
   MagickDisplayImage(MagickWand *,const char *),
   MagickDisplayImages(MagickWand *,const char *),
   MagickDistortImage(MagickWand *,const DistortImageMethod,const unsigned long,
-    const double *),
+    const double *,const MagickBooleanType),
   MagickDrawImage(MagickWand *,const DrawingWand *),
   MagickEdgeImage(MagickWand *,const double),
   MagickEmbossImage(MagickWand *,const double,const double),
@@ -197,7 +197,6 @@ extern WandExport MagickBooleanType
   MagickPosterizeImage(MagickWand *,const unsigned long,
     const MagickBooleanType),
   MagickPreviousImage(MagickWand *),
-  MagickProfileImage(MagickWand *,const char *,const void *,const size_t),
   MagickQuantizeImage(MagickWand *,const unsigned long,const ColorspaceType,
     const unsigned long,const MagickBooleanType,const MagickBooleanType),
   MagickQuantizeImages(MagickWand *,const unsigned long,const ColorspaceType,
@@ -262,8 +261,6 @@ extern WandExport MagickBooleanType
   MagickResetImagePage(MagickWand *,const char *),
   MagickSetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,const void *),
-  MagickSetImageProfile(MagickWand *,const char *,const void *,const size_t),
-  MagickSetImageProperty(MagickWand *,const char *,const char *),
   MagickSetImageRedPrimary(MagickWand *,const double,const double),
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
@@ -361,9 +358,7 @@ extern WandExport ResolutionType
 
 extern WandExport unsigned char
   *MagickGetImageBlob(MagickWand *,size_t *),
-  *MagickGetImagesBlob(MagickWand *,size_t *),
-  *MagickGetImageProfile(MagickWand *,const char *,size_t *),
-  *MagickRemoveImageProfile(MagickWand *,const char *,size_t *);
+  *MagickGetImagesBlob(MagickWand *,size_t *);
 
 extern WandExport unsigned long
   MagickGetImageColors(MagickWand *),
