@@ -13,7 +13,7 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  MagickWand property methods.
+  MagickWand property, options, and profile  methods.
 */
 
 #ifndef _MAGICKWAND_MAGICK_PROPERTY_H
@@ -24,11 +24,14 @@ extern "C" {
 #endif
 
 extern WandExport char
-  *MagickGetException(MagickWand *,ExceptionType *),
   *MagickGetFilename(const MagickWand *),
   *MagickGetFormat(MagickWand *),
   *MagickGetHomeURL(void),
+  **MagickGetImageProfiles(MagickWand *,const char *,unsigned long *),
+  *MagickGetImageProperty(MagickWand *,const char *),
+  **MagickGetImageProperties(MagickWand *,const char *,unsigned long *),
   *MagickGetOption(MagickWand *,const char *),
+  **MagickGetOptions(MagickWand *,const char *,unsigned long *),
   *MagickQueryConfigureOption(const char *),
   **MagickQueryConfigureOptions(const char *,unsigned long *),
   **MagickQueryFonts(const char *,unsigned long *),
@@ -62,11 +65,13 @@ extern WandExport InterpolatePixelMethod
 
 extern WandExport MagickBooleanType
   MagickDeleteOption(MagickWand *,const char *),
+  MagickDeleteImageProperty(MagickWand *,const char *),
   MagickGetAntialias(const MagickWand *),
   MagickGetPage(const MagickWand *,unsigned long *,unsigned long *,long *,
     long *),
   MagickGetSize(const MagickWand *,unsigned long *,unsigned long *),
   MagickGetSizeOffset(const MagickWand *,long *),
+  MagickProfileImage(MagickWand *,const char *,const void *,const size_t),
   MagickSetAntialias(MagickWand *,const MagickBooleanType),
   MagickSetBackgroundColor(MagickWand *,const PixelWand *),
   MagickSetCompression(MagickWand *,const CompressionType),
@@ -74,6 +79,8 @@ extern WandExport MagickBooleanType
   MagickSetDepth(MagickWand *,const unsigned long),
   MagickSetFilename(MagickWand *,const char *),
   MagickSetFormat(MagickWand *,const char *),
+  MagickSetImageProfile(MagickWand *,const char *,const void *,const size_t),
+  MagickSetImageProperty(MagickWand *,const char *,const char *),
   MagickSetInterlaceScheme(MagickWand *,const InterlaceType),
   MagickSetInterpolateMethod(MagickWand *,const InterpolatePixelMethod),
   MagickSetOption(MagickWand *,const char *,const char *),
@@ -98,6 +105,10 @@ extern WandExport PixelWand
 extern WandExport OrientationType
   MagickGetOrientationType(MagickWand *);
 
+extern WandExport unsigned char
+  *MagickGetImageProfile(MagickWand *,const char *,size_t *),
+  *MagickRemoveImageProfile(MagickWand *,const char *,size_t *);
+
 extern WandExport unsigned long
   MagickGetCompressionQuality(MagickWand *),
   MagickGetResource(const ResourceType),
