@@ -272,6 +272,97 @@ WandExport MagickBooleanType MagickClearException(MagickWand *wand)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k G e t E x c e p t i o n                                       %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetException() returns the severity, reason, and description of any
+%  error that occurs when using other methods in this API.
+%
+%  The format of the MagickGetException method is:
+%
+%      char *MagickGetException(const MagickWand *wand,ExceptionType *severity)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+%    o severity: The severity of the error is returned here.
+%
+*/
+WandExport char *MagickGetException(const MagickWand *wand,
+  ExceptionType *severity)
+{
+  char
+    *description;
+
+  assert(wand != (const MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  assert(severity != (ExceptionType *) NULL);
+  *severity=wand->exception->severity;
+  description=(char *) AcquireQuantumMemory(2UL*MaxTextExtent,
+    sizeof(*description));
+  if (description == (char *) NULL)
+    {
+      (void) ThrowMagickException(wand->exception,GetMagickModule(),WandError,
+        "MemoryAllocationFailed","`%s'",wand->name);
+      return((char *) NULL);
+    }
+  *description='\0';
+  if (wand->exception->reason != (char *) NULL)
+    (void) CopyMagickString(description,GetLocaleExceptionMessage(
+      wand->exception->severity,wand->exception->reason),MaxTextExtent);
+  if (wand->exception->description != (char *) NULL)
+    {
+      (void) ConcatenateMagickString(description," (",MaxTextExtent);
+      (void) ConcatenateMagickString(description,GetLocaleExceptionMessage(
+        wand->exception->severity,wand->exception->description),MaxTextExtent);
+      (void) ConcatenateMagickString(description,")",MaxTextExtent);
+    }
+  return(description);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   M a g i c k G e t  E x c e p t i o n T y p e                              %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickGetExceptionType() the exception type associated with the wand.  If
+%  no exception has occurred, UndefinedExceptionType is returned.
+%
+%  The format of the MagickGetExceptionType method is:
+%
+%      ExceptionType MagickGetExceptionType(const MagickWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport ExceptionType MagickGetExceptionType(const MagickWand *wand)
+{
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  return(wand->exception->severity);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k G e t I t e r a t o r I n d e x                               %
 %                                                                             %
 %                                                                             %
@@ -466,7 +557,7 @@ WandExport double *MagickQueryFontMetrics(MagickWand *wand,
         "ContainsNoImages","`%s'",wand->name);
       return((double *) NULL);
     }
-  font_metrics=(double *) AcquireMagickMemory(13*sizeof(*font_metrics));
+  font_metrics=(double *) AcquireQuantumMemory(13UL,sizeof(*font_metrics));
   if (font_metrics == (double *) NULL)
     return((double *) NULL);
   draw_info=PeekDrawingWand(drawing_wand);
@@ -574,7 +665,7 @@ WandExport double *MagickQueryMultilineFontMetrics(MagickWand *wand,
         "ContainsNoImages","`%s'",wand->name);
       return((double *) NULL);
     }
-  font_metrics=(double *) AcquireMagickMemory(13*sizeof(*font_metrics));
+  font_metrics=(double *) AcquireQuantumMemory(13UL,sizeof(*font_metrics));
   if (font_metrics == (double *) NULL)
     return((double *) NULL);
   draw_info=PeekDrawingWand(drawing_wand);
