@@ -111,6 +111,7 @@ static void MontageUsage(void)
     {
       "-adjoin              join images into a single multi-image file",
       "-affine matrix       affine transform matrix",
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
       "-authenticate value  decrypt image with this password",
       "-blue-primary point  chromaticity blue primary point",
       "-bordercolor color   border color",
@@ -148,7 +149,6 @@ static void MontageUsage(void)
       "-label string        assign a label to an image",
       "-limit type value    pixel cache resource limit",
       "-log format          format of debugging information",
-      "-matte               store matte channel if the image has one",
       "-mattecolor color    frame color",
       "-mode type           framing style",
       "-monitor             monitor progress",
@@ -429,6 +429,22 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
               ThrowMontageInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowMontageException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowMontageException(OptionError,"UnrecognizedAlphaChannelType",
+                argv[i]);
+            break;
+          }
         if (LocaleCompare("annotate",option+1) == 0)
           {
             if (*option == '+')
@@ -644,28 +660,27 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            compose=ParseMagickOption(MagickCompositeOptions,MagickFalse,
-              argv[i]);
+            compose=ParseMagickOption(MagickComposeOptions,MagickFalse,argv[i]);
             if (compose < 0)
-              ThrowMontageException(OptionError,
-                "UnrecognizedComposeOperator",argv[i]);
+              ThrowMontageException(OptionError,"UnrecognizedComposeOperator",
+                argv[i]);
             break;
           }
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
-              ThrowMontageException(OptionError,
-                "UnrecognizedCompressionType",argv[i]);
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
+              ThrowMontageException(OptionError,"UnrecognizedCompressType",
+                argv[i]);
             break;
           }
         if (LocaleCompare("crop",option+1) == 0)
@@ -1494,7 +1509,7 @@ WandExport MagickBooleanType MontageImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowMontageException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickTypeOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowMontageException(OptionError,"UnrecognizedImageType",
                 argv[i]);
