@@ -517,7 +517,7 @@ WandExport PixelWand **PixelGetCurrentIteratorRow(PixelIterator *iterator,
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
   *number_wands=0;
   iterator->active=MagickTrue;
-  p=AcquireCacheView(iterator->view,iterator->region.x,iterator->region.y+
+  p=AcquireCacheViewPixels(iterator->view,iterator->region.x,iterator->region.y+
     iterator->y,iterator->region.width,1,iterator->exception);
   if (p == (const PixelPacket *) NULL)
     return((PixelWand **) NULL);
@@ -574,7 +574,8 @@ WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
   assert(severity != (ExceptionType *) NULL);
   *severity=iterator->exception->severity;
-  description=(char *) AcquireMagickMemory(2*MaxTextExtent);
+  description=(char *) AcquireQuantumMemory(2UL*MaxTextExtent,
+    sizeof(*description));
   if (description == (char *) NULL)
     {
       char
@@ -605,6 +606,39 @@ WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   P i x e l G e t E x c e p t i o n T y p e                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  PixelGetIteratorExceptionType() the exception type associated with the wand.
+%  If no exception has occurred, UndefinedExceptionType is returned.
+%
+%  The format of the PixelGetIteratorExceptionType method is:
+%
+%      ExceptionType PixelGetIteratorExceptionType(const PixelWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport ExceptionType PixelGetIteratorExceptionType(
+  const PixelIterator *wand)
+{
+  assert(wand != (const PixelIterator *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  return(wand->exception->severity);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   P i x e l G e t I t e r a t o r R o w                                     %
 %                                                                             %
 %                                                                             %
@@ -678,7 +712,7 @@ WandExport PixelWand **PixelGetNextIteratorRow(PixelIterator *iterator,
     iterator->y++;
   if (PixelSetIteratorRow(iterator,iterator->y) == MagickFalse)
     return((PixelWand **) NULL);
-  p=AcquireCacheView(iterator->view,iterator->region.x,iterator->region.y+
+  p=AcquireCacheViewPixels(iterator->view,iterator->region.x,iterator->region.y+
     iterator->y,iterator->region.width,1,iterator->exception);
   if (p == (const PixelPacket *) NULL)
     return((PixelWand **) NULL);
@@ -753,7 +787,7 @@ WandExport PixelWand **PixelGetPreviousIteratorRow(PixelIterator *iterator,
     iterator->y--;
   if (PixelSetIteratorRow(iterator,iterator->y) == MagickFalse)
     return((PixelWand **) NULL);
-  p=AcquireCacheView(iterator->view,iterator->region.x,iterator->region.y+
+  p=AcquireCacheViewPixels(iterator->view,iterator->region.x,iterator->region.y+
     iterator->y,iterator->region.width,1,iterator->exception);
   if (p == (const PixelPacket *) NULL)
     return((PixelWand **) NULL);
@@ -946,7 +980,7 @@ WandExport MagickBooleanType PixelSyncIterator(PixelIterator *iterator)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
   if (SetCacheViewStorageClass(iterator->view,DirectClass) == MagickFalse)
     return(MagickFalse);
-  p=GetCacheView(iterator->view,iterator->region.x,iterator->region.y+
+  p=GetCacheViewPixels(iterator->view,iterator->region.x,iterator->region.y+
     iterator->y,iterator->region.width,1);
   if (p == (PixelPacket *) NULL)
     {
