@@ -208,7 +208,7 @@ WandExport PixelWand **ClonePixelWands(const PixelWand **wands,
   PixelWand
     **clone_wands;
 
-  clone_wands=(PixelWand **) AcquireMagickMemory((size_t) number_wands*
+  clone_wands=(PixelWand **) AcquireQuantumMemory((size_t) number_wands,
     sizeof(*clone_wands));
   if (clone_wands == (PixelWand **) NULL)
     {
@@ -468,7 +468,7 @@ WandExport PixelWand **NewPixelWands(const unsigned long number_wands)
   PixelWand
     **wands;
 
-  wands=(PixelWand **) AcquireMagickMemory((size_t) number_wands*
+  wands=(PixelWand **) AcquireQuantumMemory((size_t) number_wands,
     sizeof(*wands));
   if (wands == (PixelWand **) NULL)
     {
@@ -522,68 +522,6 @@ WandExport MagickBooleanType PixelClearException(PixelWand *wand)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   P i x e l G e t E x c e p t i o n                                         %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  PixelGetException() returns the severity, reason, and description of any
-%  error that occurs when using other methods in this API.
-%
-%  The format of the PixelGetException method is:
-%
-%      char *PixelGetException(const PixelWand *wand,ExceptionType *severity)
-%
-%  A description of each parameter follows:
-%
-%    o wand: The pixel wand.
-%
-%    o severity: The severity of the error is returned here.
-%
-*/
-WandExport char *PixelGetException(const PixelWand *wand,
-  ExceptionType *severity)
-{
-  char
-    *description;
-
-  assert(wand != (const PixelWand *) NULL);
-  assert(wand->signature == WandSignature);
-  if (wand->debug != MagickFalse)
-    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
-  assert(severity != (ExceptionType *) NULL);
-  *severity=wand->exception->severity;
-  description=(char *) AcquireMagickMemory(2*MaxTextExtent);
-  if (description == (char *) NULL)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
-  *description='\0';
-  if (wand->exception->reason != (char *) NULL)
-    (void) CopyMagickString(description,GetLocaleExceptionMessage(
-      wand->exception->severity,wand->exception->reason),MaxTextExtent);
-  if (wand->exception->description != (char *) NULL)
-    {
-      (void) ConcatenateMagickString(description," (",MaxTextExtent);
-      (void) ConcatenateMagickString(description,GetLocaleExceptionMessage(
-        wand->exception->severity,wand->exception->description),MaxTextExtent);
-      (void) ConcatenateMagickString(description,")",MaxTextExtent);
-    }
-  return(description);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
 %   P i x e l G e t A l p h a                                                 %
 %                                                                             %
 %                                                                             %
@@ -638,7 +576,7 @@ WandExport Quantum PixelGetAlphaQuantum(const PixelWand *wand)
   assert(wand->signature == WandSignature);
   if (wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
-  return(QuantumRange-RoundToQuantum(wand->pixel.opacity));
+  return((Quantum) QuantumRange-RoundToQuantum(wand->pixel.opacity));
 }
 
 /*
@@ -948,6 +886,101 @@ WandExport Quantum PixelGetCyanQuantum(const PixelWand *wand)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   P i x e l G e t E x c e p t i o n                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  PixelGetException() returns the severity, reason, and description of any
+%  error that occurs when using other methods in this API.
+%
+%  The format of the PixelGetException method is:
+%
+%      char *PixelGetException(const PixelWand *wand,ExceptionType *severity)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The pixel wand.
+%
+%    o severity: The severity of the error is returned here.
+%
+*/
+WandExport char *PixelGetException(const PixelWand *wand,
+  ExceptionType *severity)
+{
+  char
+    *description;
+
+  assert(wand != (const PixelWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  assert(severity != (ExceptionType *) NULL);
+  *severity=wand->exception->severity;
+  description=(char *) AcquireQuantumMemory(2UL*MaxTextExtent,
+    sizeof(*description));
+  if (description == (char *) NULL)
+    {
+      char
+        *message;
+
+      message=GetExceptionMessage(errno);
+      ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
+        message);
+      message=DestroyString(message);
+    }
+  *description='\0';
+  if (wand->exception->reason != (char *) NULL)
+    (void) CopyMagickString(description,GetLocaleExceptionMessage(
+      wand->exception->severity,wand->exception->reason),MaxTextExtent);
+  if (wand->exception->description != (char *) NULL)
+    {
+      (void) ConcatenateMagickString(description," (",MaxTextExtent);
+      (void) ConcatenateMagickString(description,GetLocaleExceptionMessage(
+        wand->exception->severity,wand->exception->description),MaxTextExtent);
+      (void) ConcatenateMagickString(description,")",MaxTextExtent);
+    }
+  return(description);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   P i x e l G e t E x c e p t i o n T y p e                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  PixelGetExceptionType() the exception type associated with the wand.  If
+%  no exception has occurred, UndefinedExceptionType is returned.
+%
+%  The format of the PixelGetExceptionType method is:
+%
+%      ExceptionType PixelGetExceptionType(const PixelWand *wand)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+*/
+WandExport ExceptionType PixelGetExceptionType(const PixelWand *wand)
+{
+  assert(wand != (const PixelWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  return(wand->exception->severity);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   P i x e l G e t F u z z                                                   %
 %                                                                             %
 %                                                                             %
@@ -1069,7 +1102,7 @@ WandExport void PixelGetHSL(const PixelWand *wand,double *hue,
   assert(wand->signature == WandSignature);
   if (wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
-  TransformHSL(RoundToQuantum(wand->pixel.red),RoundToQuantum(
+  ConvertRGBToHSL(RoundToQuantum(wand->pixel.red),RoundToQuantum(
     wand->pixel.green),RoundToQuantum(wand->pixel.blue),hue,saturation,
     luminosity);
 }
@@ -1953,7 +1986,7 @@ WandExport void PixelSetHSL(PixelWand *wand,const double hue,
   assert(wand->signature == WandSignature);
   if (wand->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
-  HSLTransform(hue,saturation,luminosity,&red,&green,&blue);
+  ConvertHSLToRGB(hue,saturation,luminosity,&red,&green,&blue);
   wand->pixel.red=(MagickRealType) red;
   wand->pixel.green=(MagickRealType) green;
   wand->pixel.blue=(MagickRealType) blue;
